Test=`env|grep RDA_Program_Version`

##  The previous line MUST be the first line in the script.  If not, the check
##  for determining if this is called or started straight from command line
##  will not work (it will throw errors back to the screen).

if [ -z "$Test" ]; then
   echo "This script cannot be run standalone"
   echo "It must be called from the main RDA rda.sh"
   echo "Exiting from rda.sh"
   exit
fi
###########################################################################
##    Name: rda.sh                                Version: 3.10
##      By: Oracle Corp.                    Last Modified: November 05, 2002
##                                                Written: 2/20/02  
##
## Purpose: This is the source script for common functions that will be needed
##          for multiple modules.  Because there can be no guarantee of the
##          order the modules will be sourced, it is best to put common
##          functions in a central spot that is sourced early in the process.
##          This is not intended to be a standalone script, it should be 
##          be sourced from an executable script.
##
##   Usage: As a call from a script
##             . ./RDA_script_0000_COMMON/rda.sh
##
###########################################################################

##############################################################################
##  Modifications Section:
##############################################################################
##     Date        Author     Function       Changes
##############################################################################
##  11/05/2002     fkobylan   Run_SQL        Chgd to use a variable from
##   V3.10                                   RDAParms.xml to determine how
##                                          long to allow sql stmts to run.
##  09/18/2002     fkobylan   Cat_File       Added code to handle xml files.
##   V3.09                                   Also added code for Web Cache.
##                                           Fixed problem with determining
##                                           file readability.  Added code
##                                           to assist with diagnosing file
##                                           access problems.
##                            Cat_SQLNET     Added code  to assist with
##                                           diagnosing file access problems.
##  08/30/2002     fkobylan   Cat_File       Cleaned up HTML tagging that caused
##   V3.08                                   probs on some browsers (iss 172).
##                            Cat_SQLNET     Moved here from NETWORK/rda.sh.
##                            Use_lsnrctl    Moved here from NETWORK/rda.sh.
##                                           Added html formatting to Errors
##                                           section of listener.
##                            Use_agentctl   Added new function for Intelligent
##                                           Agent processing for 9i.
##  06/18/2002     fkobylan   Run_SQL        Dlt'd reference to Where variable
##   V3.06                                   as it's not used anywhere.
##                                           Added debug info to display connect
##                                           string on connection test.
##                            Debug          Dlt'd reference to Where variable
##                                           as it's not used anywhere.
##                            Get_Password   Fixed problem when user just hits
##                                           enter (no password typed in).
##  05/27/2002     eferrer    Get_Password   New function that is meant to be
##   V3.05                                   used by all modules that need
##                                           the user to enter a password for
##                                           an account.
##  05/21/2002     fkobylan                  Just chgd version to keep up with
##   V3.04                                   chgs to other modules.
##  04/04/2002     fkobylan   Run_SQL        Added code to skip connect to db
##   V3.02                                   if db is down or invalid uid/pwd.
##                                           This is controlled by        
##                                           variable Connect_to_DB.
##                                           Also chgd ctr increment code
##                                           to work w/o errors in bash (use
##                                           let notation instead of double
##                                           parens).
##  03/27/2002     fkobylan   Cat_File       Added new function to track down
##   V3.01                                   and print files.  Also fixed to
##                                           only produce output file when
##                                           file is found or not optional.
##  02/20/2002     fkobylan                  created 
##                                           based on code from original rda.sh.
#############################################################################

#############################################################################
##   Program Explanation:
##   ===================
##   The script is not intended to be a stand alone program.  Its function
##   is to store common functions available for all modules.  Examples are
##   Debug, Hang_Check and Run_SQL.  This script will be sourced early in the
##   main RDA driver script to make sure the functions are defined and
##   available for all functions.
#############################################################################

##################################
### Start of Review_OS Function ###
##################################

##  It seems we have a problem with some commands hanging.  This function
##  will allow an easy method of being able to cancel out of the command
##  (after it has been put in background) once it has been running for a
##  predetermined number of seconds.  Max_Times_to_Try should be set to a
##  multiple of 5 seconds to tell the function how long to allow a command
##  to run.  Just after the Hang_Check function call, there should be a check
##  for Command_Hung.  If it contains a value of "Y", we had to cancel the
##  command and the output should handle it appropriately.
Hang_Check ()
{
Times_Tried=0
Done_With_Command=N
Command_Hung=N
while [ "$Done_With_Command" = "N" ]
do
   sleep 5
   if [ "$JOBS_LIST" = "y" ]; then
      JOBS=`jobs -l|cut -d" " -f3`
   else
      JOBS=`jobs -p`
   fi
   if [ "$JOBS" != "" ]; then
      if  [ $Times_Tried -eq $Max_Times_to_Try ]; then
         kill -9 $JOBS
         Command_Hung=Y
         Done_With_Command=Y
      else
         let Times_Tried=$Times_Tried+1
      fi
   else
      Done_With_Command=Y
   fi
done
}

Run_SQL ()
{
## Procedure Name: Run_SQL
################################################################
## To use this routine, all output is put in the OUT_DIR
## and to the OUT_FILE which means you may have to reset the OUT_FILE
## when spooling the next file.
##
## Ie. to make a call to Run_SQL you may:
## 1) set SQL_Login_Password
## 2) set the SQL=select... use \* for special characters..
## 3) set the OUT_DIR or just the OUT_FILE if OUT_DIR defaults okay.
## 4) call the Procedure Run_SQL
## 5) Process the SQL output file: OUT_FILE.lst
################################################################

if [ "$Connect_to_DB" = "N" ]; then
   echo "<PRE>" > $OUT_DIR/${OUT_FILE}.txt
   echo $Connect_to_DB_Message >> $OUT_DIR/${OUT_FILE}.txt
   echo "</PRE>" >> $OUT_DIR/${OUT_FILE}.txt
else
   if [ $Hang_CTR -gt 2 ]; then
      echo "The attempt to run sql for this section" > $OUT_DIR/${OUT_FILE}.txt
      echo "was skipped since 3 previous queries have hung" >> $OUT_DIR/${OUT_FILE}.txt
      if [ -z "$Display_SQL_Problems" ]; then
         echo "rda.sh has encountered problems connecting to the database"
         echo "Information gathered by sqlplus may be missing or incomplete"
         echo "Please investigate, correct and resubmit rda.sh"
         Display_SQL_Problems=N
      fi
   else
      Run_SQL_Job &
      Max_Times_to_Try=$SQL_Hang_Times_To_Try
      Hang_Check
      if [ "$Command_Hung" = "Y" ]; then
         echo "The attempt to run the sql for this section" > $OUT_DIR/${OUT_FILE}.txt
         echo "took longer than 30 seconds so the job was cancelled" >> $OUT_DIR/${OUT_FILE}.txt
         let Hang_CTR=$Hang_CTR+1
      else
   #  Check if the spool file exists, if not, create a spool file with
   #  a message to check if the DB is up and the environment is set correctly.
         if [ -a "$OUT_DIR/${OUT_FILE}.txt" ]; then
            true
         else
            echo "No SQL output was generated." > $OUT_DIR/${OUT_FILE}.txt
            echo "Make sure the database is available and the ORACLE_SID specified" >> $OUT_DIR/${OUT_FILE}.txt
            echo "belongs to the ORACLE_HOME in setup.txt" >> $OUT_DIR/${OUT_FILE}.txt
         fi
      fi
   fi
fi
}

Run_SQL_Job ()
{
if [ "$Connect_Test" = "Y" ]; then
   DebugMessage=" Inside Run_SQL_Job Doing connection test:
      Connect String: $SQL_Login_Password
      SQL: $SQL"
else
   DebugMessage=" Inside Run_SQL_Job:
      SQL: $SQL"
fi
Debug

#
# Expected spool file named rda_out.txt or ProgramName_out.txt
#

if [ "$Connect_Test" = "Y" -a "$DebugMode" = "y" ]; then
   $ORACLE_HOME/bin/sqlplus  /nolog << Zen 
    connect $SQL_Login_Password 
    set arraysize 4
    set pagesize 1000
    set pause off
    set linesize 80
    spool $OUT_DIR/$OUT_FILE.txt
    $SQL
    spool off
   exit
Zen
else
   $ORACLE_HOME/bin/sqlplus -s /nolog << Zen | grep NoThING
    connect $SQL_Login_Password 
    set arraysize 4
    set pagesize 1000
    set pause off
    set linesize 80
    spool $OUT_DIR/$OUT_FILE.txt
    $SQL
    spool off
   exit
Zen
fi
}
 
Run_SQL_File ()
{
## Procedure Name: Run_SQL_File
################################################################
## Similar to Run_SQL except the runs the SQL from a supplied
## file
## It calls sqlplus with: start $SQLFILE $PARMS
##
## Set the SQLFILE:   SQLFILE=/tmp/xyz.sql
## Set the PARMS:       PARMS="Jones%" 
################################################################

DebugMessage=" Inside RunSQLfile:
   SQLFILE: $SQLFILE
     parms: $PARMS"
Debug

  if [ "$usobSpool" = "on" ]; then
     echo "sqlfile: $SQLFILE
     parms: $PARMS" >>  $usobSpoolFile
   fi

#  echo "Run SQLFILE $SQLFILE ..."

$ORACLE_HOME/bin/sqlplus -s /nolog << Zen | grep NoThING
 connect $SQL_Login_Password 
 $SetOption
 set pagesize 1000
 spool $OUT_DIR/$OUT_FILE.txt
 start $SQLFILE $PARMS
 spool off
exit
Zen
#  Check if the spool file exists, if not, create a spool file with
#  a message to check if the DB is up and the environment is set correctly.
if [ -a "$OUT_DIR/$OUT_FILE.txt" ]; then
   true
else
   echo "No SQL output was generated." > $OUT_DIR/$OUT_FILE.txt
   echo "Make sure the database is available and the ORACLE_SID specified" >> $OUT_DIR/$OUT_FILE.txt
   echo "belongs to the ORACLE_HOME in setup.txt." >> $OUT_DIR/$OUT_FILE.txt
fi
}


##
## This function gets the password
##
Get_Password()
{
Pwd_Check_Done=N
Pwd_Confirm=N
Times_Tried=1
while [ "$Pwd_Check_Done" = "N" ]
do
   while [ "$Pwd_Confirm" = "N" ]
   do
      echo "$PWD_MESSAGE"
      echo "The value will not be visible to you"
      stty -echo
      read pwd1
      stty echo
      echo
      echo "Please re-enter password to confirm"
      stty -echo
      read pwd2
      stty echo
      if [ "$pwd1" = "" ]; then
         Times_Tried=`expr $Times_Tried + 1`
         if [ $Times_Tried -gt 3 ]; then
            echo
            echo "Failure to enter a valid password on 3 attempts"
            echo "Exiting srda.sh"
            exit
         else
            echo
            echo "Password entered was blank"
            echo "Please try again...."
            echo
         fi
      else
         if [ "$pwd1" = "$pwd2" ]; then
            echo "Password confirmed"
            echo
            Pwd_Confirm=Y
            Pwd_Check_Done=Y
         else
            let Times_Tried=$Times_Tried+1
#  Allow 3 attempts at getting the password right.  If they fail after 3 tries,
#  end the process.
            if [ $Times_Tried -gt 3 ]; then
               echo "Failure to match password on 3 attempts"
               echo "Exiting rda.sh"
               exit
            else
               echo
               echo "Password entries do not match"
               echo "Please try again...."
               echo
            fi
         fi
      fi
   done
done
NameVar=`echo "$Module_Password" | awk -F"=" '{print $1}'`
ValueVar=`echo $pwd1`
eval  `echo "$NameVar=$ValueVar"`
}


Debug ()
{
  if [ "$DebugMode" = "y" ]; then
     echo "------------------Debug RUN: `date`" >> $OUT_DIR/${PRD}_Debug.log
     echo ") $DebugMessage"  | tee -a $OUT_DIR/${PRD}_Debug.txt
  fi
}

Cat_File ()
{

if [ "$RELATIVE_TO_OH" = "Y" ]; then
   LOCATION=${ORACLE_HOME}${DIRECTORY}
else
   LOCATION=`eval echo $DIRECTORY`
fi

if [ "$PARTIAL_FILE_NAME" = "Y" ]; then
   FILE_LIST=`ls $LOCATION/${FILE_WANTED} 2>/dev/null`   
   HIGH_LEVEL=$DISPLAY_NAME
else
   FILE_LIST=`echo $LOCATION/${FILE_WANTED}` 
fi
for f in $FILE_LIST
do
   if [ "$PARTIAL_FILE_NAME" = "Y" ]; then
      FILE_WANTED=`basename $f`
      DISPLAY_NAME=$HIGH_LEVEL_`echo $FILE_WANTED | tr '.' '_'`.htm
      OUTPUT_FILE=$OUT_DIR/${PRD}_${DISPLAY_NAME}
   else
      OUTPUT_FILE=$OUT_DIR/${PRD}_${DISPLAY_NAME}
   fi

   DebugMessage=" Inside Cat_File, looking for $FILE_WANTED in $LOCATION"
   Debug

   FILE_FOUND=N
   if [ -r "$f" ]; then
      FILE_FOUND=Y
   fi

   if [ "$FILE_FOUND" = "Y" ]; then
      echo "<Center><H3>Display of $FILE_WANTED file </H3></Center>" > $OUTPUT_FILE
      echo "<br><H4>$FILE_WANTED info taken from $f</H4>" >> $OUTPUT_FILE
      echo "<PRE>" >> $OUTPUT_FILE
#  This NEEDS to be outside the textarea section...  Rather than checking for
#  the xml file twice, this is easier.
      if [ "$TAIL_IT" = "Y" ]; then
         echo "<B>Tailing $TAIL_AMOUNT lines from $FILE_WANTED</B>" >> $OUTPUT_FILE
      fi
#  If the file being brought back contains actual xml, browsers will parse
#  and evaluate the xml data and not display the text.  To keep the links at
#  the top of the page working, we want to keep the file extension as htm,
#  but we need to do something special to the tagging around the xml data so
#  it isn't evaluated.  The only consistent method found appears to be using
#  the textarea tag.  In some browsers, this will create a scrollable window
#  to display the data, but it does work in IE, NS (4.X and 7) and Opera.
#  I haven't been able to find anything else that is not deprecated that will
#  work in all the common browser implementations.  So if the file name ends in
#  xml, add the extra tagging.
      XML_Check=`echo $f|grep '[xml|dtd]$'`
      if [ -z "$XML_Check" ]; then
         true
      else
         echo "<TEXTAREA READONLY ROWS=75 COLS=120>" >> $OUTPUT_FILE
fi
      if [ "$TAIL_IT" = "Y" ]; then
         tail -$TAIL_AMOUNT $f >> $OUTPUT_FILE
      else
         pr $f >> $OUTPUT_FILE
      fi
      if [ -z "$XML_Check" ]; then
         true
      else
         echo "</TEXTAREA>" >> $OUTPUT_FILE
      fi
      echo "</PRE>" >> $OUTPUT_FILE
   fi

#  If we didn't find the file we were looking for and it is not an optional
#  file, we still need to create some output saying we looked for it but
#  couldn't find it.  We also need to dynamically build a file list so we
#  only have links if there is an output file to display.

   if [ "$FILE_FOUND" = "N" -a "$OPTIONAL" = "N" ]; then
      echo "<Center><H3>Display of $FILE_WANTED file </H3></Center>" > $OUTPUT_FILE
      echo "<br><B>No readable $FILE_WANTED found." >> $OUTPUT_FILE
      echo "May be file permission problems or file does not exist.</B><br><br>" >> $OUTPUT_FILE
      echo "<b>Permissions are</b>:  `ls -l $f 2>&1`<br><br>" >> $OUTPUT_FILE
      echo "<b>Userid is</b>:  `id 2>&1`" >> $OUTPUT_FILE
   fi
   if [ "$FILE_FOUND" = "Y" -o "$OPTIONAL" = "N" ]; then
      if [ "$TYPE" = "HIDDEN" ]; then
         HIDDEN_FILE=`echo $HIDDEN_FILE ${PRD}_${DISPLAY_NAME}#$FILE_WANTED`
      elif
         [ "$TYPE" = "PROFILE" ]; then
         PROFILE_FILE=`echo $PROFILE_FILE ${PRD}_${DISPLAY_NAME}#$FILE_WANTED`
      elif [ "$TYPE" = "AGENT" ]; then
         AGENT_FILE=`echo $AGENT_FILE ${PRD}_${DISPLAY_NAME}#$FILE_WANTED`
      elif [ "$TYPE" = "NAMES" ]; then
         NAMES_FILE=`echo $NAMES_FILE ${PRD}_${DISPLAY_NAME}#$FILE_WANTED`
      elif [ "$TYPE" = "HS" ]; then
         HS_FILE=`echo $HS_FILE ${PRD}_${DISPLAY_NAME}#$FILE_WANTED`
      elif [ "$TYPE" = "OMS" ]; then
         OMS_FILE=`echo $OMS_FILE ${PRD}_${DISPLAY_NAME}#$FILE_WANTED`
      elif [ "$TYPE" = "EMS" ]; then
         EMS_FILE=`echo $EMS_FILE ${PRD}_${DISPLAY_NAME}#$FILE_WANTED`
      elif [ "$TYPE" = "OID" ]; then
         OID_FILE=`echo $OID_FILE ${PRD}_${DISPLAY_NAME}#$FILE_WANTED`
      elif [ "$TYPE" = "SQLNET" ]; then
         SQLNET_FILE=`echo $SQLNET_FILE ${PRD}_${DISPLAY_NAME}#$FILE_WANTED` 
      elif [ "$SECTION" = "WEBCACHE" ]; then
         if [ "$TYPE" = "LOG" ]; then
            WEBCACHE_LOG_FILE=`echo $WEBCACHE_LOG_FILE ${PRD}_${DISPLAY_NAME}#$FILE_WANTED` 
         elif [ "$TYPE" = "CONFIG" ]; then
            WEBCACHE_CONFIG_FILE=`echo $WEBCACHE_CONFIG_FILE ${PRD}_${DISPLAY_NAME}#$FILE_WANTED` 
         elif [ "$TYPE" = "DTD" ]; then
            WEBCACHE_DTD_FILE=`echo $WEBCACHE_DTD_FILE ${PRD}_${DISPLAY_NAME}#$FILE_WANTED` 
         fi
      fi
   fi
done
}

#  This function will execute a call to lsnrctl.  It will be up to the calling
#  function to provide the command name to be executed and anything else
#  specific (like a listener name) for executing this command.  The calling
#  function will need to set the name of the output file in variable
#  Lsnrctl_File before calling this function.  The calling function should also
#  either turn on or off the variable for looking for and gathering log
#  information (controlled by variable GET_LOGS).  For any runs of this going
#  after a specific sqlnet listener, list_of needs to be unset to not cause
#  problems with later executions of the command.
Use_lsnrctl ()
{
  lsnrctl $LSNR_CMD $list_of  > $OUT_TMP/lstatus.txt$$
  cat $OUT_TMP/lstatus.txt$$  >> $OUT_DIR/${Lsnrctl_File}
if [ "$GET_LOGS" = "Y" ]; then
   Log_File=`grep "Log File" $OUT_TMP/lstatus.txt$$ | awk '{print $4}'`

   DebugMessage=" Inside Use_lsnrctl, getting the listener logfile if requested
     Log_File = $Log_File"
   Debug

   if [ "$Log_File" != "" ];then
      if [ -a "$Log_File" ];then
         Total_TNS_Errors=`grep "TNS-" $Log_File | wc | awk '{print $1}'`  
         Recent_TNS_Errors=`tail -1000 $Log_File | grep "TNS-" | wc | awk '{print $1}'` 
 
         Last_50_Errors=`grep "TNS-" $Log_File | tail -50`  

         DebugMessage=" Inside Use_lsnrctl, showing the last 50 errors from listener"
         Debug

          echo "
========<B>ERRORS IN LOG:</B>======================================================
============================================================================
        Listener Name: <B>$list_of</B>
    Listener Log File: <B>$Log_File</B>
     Total TNS Errors: <B>$Total_TNS_Errors</B>
           TNS Errors: <B>$Recent_TNS_Errors  (In Last 1000 lines)</B>
   Last 50 Errors for: <B>$list_of</B>
============================================================================
$Last_50_Errors 

        " >> $OUT_DIR/${Lsnrctl_File}
      else
         echo "Could Not read the log file: $Log_File" >> $OUT_DIR/${Lsnrctl_File}
         echo "It does not exist even though it is specified for this listener" >> $OUT_DIR/${Lsnrctl_File}
      fi
   else
      echo "Log File entry not found in listener status: " >> $OUT_DIR/${Lsnrctl_File}
      echo "(This may be because the listener is not up)" >> $OUT_DIR/${Lsnrctl_File}
   fi
fi
rm -f $OUT_TMP/lstatus.txt$$ 2>/dev/null

}

#  This function will execute a call to agentctl.  It will be up to the calling
#  function to provide the command name to be executed and anything else
#  specific for executing this command.  The calling will need to set the name
#  of the output file in variable Agentctl_File before calling this function.
Use_agentctl ()
{
  agentctl $Agentctl_CMD > $OUT_TMP/agentctl.txt$$
  cat $OUT_TMP/agentctl.txt$$  >> $OUT_DIR/${Agentctl_File}
  rm $OUT_TMP/agentctl.txt$$  2>/dev/null
}

#  This function will gather sqlnet and some intelligent agent files.  This is
#  different from Cat_File above in that it looks in a few well known places
#  for files rather than just a single location.
Cat_SQLNET ()
{
DebugMessage=" Inside Cat_SQLNET, looking for $FILE_WANTED in $ORACLE_HOME/bin"
Debug

OUTPUT_FILE=$OUT_DIR/${PRD}_$DISPLAY_NAME
FILE_FOUND=N
echo "<center><H3>Displays of $FILE_WANTED file from all well known locations</H3></center>" > $OUTPUT_FILE
echo >> $OUTPUT_FILE

if [ -r "$ORACLE_HOME/bin/$FILE_WANTED" ]; then
   echo "<H4>$FILE_WANTED info taken from $ORACLE_HOME/bin/$FILE_WANTED</H4>" >> $OUTPUT_FILE
   echo "<H5>Files from this location will override the contents for $FILE_WANTED at every other location</H5>" >> $OUTPUT_FILE
   echo "<PRE>" >> $OUTPUT_FILE
   cat $ORACLE_HOME/bin/$FILE_WANTED >> $OUTPUT_FILE
   echo "</PRE>" >> $OUTPUT_FILE
   FILE_FOUND=Y
fi

DebugMessage=" Inside Cat_SQLNET, looking for $FILE_WANTED in /etc"
Debug

if [ -r "/etc/$FILE_WANTED" ]; then
   echo "<H4>$FILE_WANTED info taken from /etc/$FILE_WANTED</H4>" >> $OUTPUT_FILE
   echo "<PRE>" >> $OUTPUT_FILE
   cat /etc/$FILE_WANTED >> $OUTPUT_FILE
   echo "</PRE>" >> $OUTPUT_FILE
   FILE_FOUND=Y
fi

DebugMessage=" Inside Cat_SQLNET, looking for $FILE_WANTED in /var/opt/oracle"
Debug

if [ -r "/var/opt/oracle/$FILE_WANTED" ]; then
   echo "<H4>$FILE_WANTED info taken from /var/opt/oracle/$FILE_WANTED</H4>" >> $OUTPUT_FILE
   echo "<PRE>" >> $OUTPUT_FILE
   cat /var/opt/oracle/$FILE_WANTED >> $OUTPUT_FILE
   echo "</PRE>" >> $OUTPUT_FILE
   FILE_FOUND=Y
fi

DebugMessage=" Inside Cat_SQLNET, looking for $FILE_WANTED in $ORACLE_HOME/network/admin"
Debug

if [ -r "$ORACLE_HOME/network/admin/$FILE_WANTED" ]; then
   echo "<H4>$FILE_WANTED info taken from $ORACLE_HOME/network/admin/$FILE_WANTED</H4>" >> $OUTPUT_FILE
   echo "<PRE>" >> $OUTPUT_FILE
   cat $ORACLE_HOME/network/admin/$FILE_WANTED >> $OUTPUT_FILE
   echo "</PRE>" >> $OUTPUT_FILE
   FILE_FOUND=Y
fi

DebugMessage=" Inside Cat_SQLNET, looking for $FILE_WANTED using $TNS_ADMIN"
Debug

if [ -z "$TNS_ADMIN" ]; then
   true
elif [ "$TNS_ADMIN" = "$ORACLE_HOME/bin" -o "$TNS_ADMIN" = "/etc" -o "$TNS_ADMIN" = "/var/opt/oracle" -o "$TNS_ADMIN" = "$ORACLE_HOME/network/admin" ]; then
   true
else
   if [ -r "$TNS_ADMIN/$FILE_WANTED" ]; then
      echo "<H4>$FILE_WANTED info taken from $TNS_ADMIN/$FILE_WANTED using the TNS_ADMIN environment variable</H4>" >> $OUTPUT_FILE
      echo "<PRE>" >> $OUTPUT_FILE
      cat $TNS_ADMIN/$FILE_WANTED >> $OUTPUT_FILE
      echo "</PRE>" >> $OUTPUT_FILE
      FILE_FOUND=Y
   fi
fi

#  If we didn't find the file we were looking for and it is not an optional
#  file, we still need to create some output saying we looked for it but
#  couldn't find it.  We also need to dynamically build a file list so we
#  only have links if there is an output file to display.

if [ "$FILE_FOUND" = "N" -a "$OPTIONAL" = "N" ]; then
   echo "<B>No readable $FILE_WANTED found.  Searched in all the usual places." >> $OUTPUT_FILE
   echo "May be file permission problems or file not found.</B><br><br>" >> $OUTPUT_FILE
   echo "<b>Permissions for $ORACLE_HOME/bin/$FILE_WANTED are</b>:  `ls -l $ORACLE_HOME/bin/$FILE_WANTED 2>&1`<br>" >> $OUTPUT_FILE
   echo "<b>Permissions for /etc/$FILE_WANTED are</b>:  `ls -l /etc/$FILE_WANTED 2>&1`<br>" >> $OUTPUT_FILE
   echo "<b>Permissions for /var/opt/oracle/$FILE_WANTED are</b>:  `ls -l /var/opt/oracle/$FILE_WANTED 2>&1`<br>" >> $OUTPUT_FILE
   echo "<b>Permissions for $ORACLE_HOME/network/admin/$FILE_WANTED are</b>:  `ls -l $ORACLE_HOME/network/admin/$FILE_WANTED 2>&1`<br>" >> $OUTPUT_FILE
   if [ -z "$TNS_ADMIN" ]; then
      true
   elif [ "$TNS_ADMIN" = "$ORACLE_HOME/bin" -o "$TNS_ADMIN" = "/etc" -o "$TNS_ADMIN" = "/var/opt/oracle" -o "$TNS_ADMIN" = "$ORACLE_HOME/network/admin" ]; then
      true
   else
      echo "<b>Permissions for $TNS_ADMIN/$FILE_WANTED are</b>:  `ls -l $TNS_ADMIN/$FILE_WANTED 2>&1`<br>" >> $OUTPUT_FILE
   fi
   echo "<b>Userid is</b>:  `id`<br>" >> $OUTPUT_FILE
fi
 
if [ "$FILE_FOUND" = "Y" -o "$OPTIONAL" = "N" ]; then
   if [ "$TYPE" = "AGENT" ]; then
      AGENT_FILE=`echo $AGENT_FILE ${PRD}_$DISPLAY_NAME#$FILE_WANTED`
   else
      SQLNET_FILE=`echo $SQLNET_FILE ${PRD}_$DISPLAY_NAME#$FILE_WANTED`
   fi
fi
}
