Test=`env|grep RDA_Program_Version`

##  The previous line MUST be the first line in the script.  If not, the check
##  for determining if this is called or started straight from command line
##  will not work (it will throw errors back to the screen).

if [ -z "$Test" ]; then
   echo "This script cannot be run standalone"
   echo "It must be called from the main RDA rda.sh"
   echo "Exiting from rda.sh"
   exit
fi
###########################################################################

###########################################################################
##    Name: rda.sh                                Version: 3.10
##      By: Oracle Corp.                    Last Modified: November 06, 2002
##                                                Written: 2/18/02  
##
## Purpose: This is the source script for handling OS Setup (determining
##          the operating system, its version and setting appropriate values
##          for commands).  It is not executable as a standalone.  It must
##          be sourced from an executable script.
##
##   Usage: As a call from a script
##             . ./RDA_script_0001_SETUP_OS/rda.sh
##
###########################################################################

##############################################################################
##  Modifications Section:
##############################################################################
##     Date        Author     Function       Changes
##############################################################################
##  11/04/2002     fkobylan   Setup_OS       Chgd to use domain name gotten from
##   3.10                                    setup script.
##                                           Chgd to use tail rather than head
##                                           for Sun and HP system error log.
##                                           Added commands to get udp network
##                                           settings.
##  09/04/2002     fkobylan   Setup_OS       Added code to get more h/w info
##   3.09                                    from HP (use cstm).  Also grepping
##                                           this data to get phys memory
##                                           installed.  Will use sysdef
##                                           extensions. (issue 185).
##                                           Removed all mention of TWO_TASK 
##                                           and unset the variable.
##                                           Reworked O/S bits and version
##                                           determination.
##                                           Added code to support Security
##                                           needs.
##                                           Changed sysdef for HP to use
##                                           kmtune in version 11 and later.
##  08/30/2002     fkobylan   Setup_OS       Chgd code for gathering Linux
##   3.08                                    tcp parms.  Since the processing
##                                           is totally different from what we
##                                           had before, need to setup up new
##                                           variables to make it generic and
##                                           let NETWORK/rda.sh know what it
##                                           needs to do.  (Issue 163)
##                                           Added code to determine physical
##                                           memory installed on server.  Since
##                                           some platforms (HP) make this al-
##                                           most impossible, had to also code
##                                           for inability to gather data
##                                           (issue 134).
##                                           Added code to handle commands not
##                                           available on PTX.  Also fixed
##                                           problem with PTX jobs.
##                                           Removed top command from Tru64
##                                           processing.  Also, added code
##                                           to gather current settings from
##                                           sysconfig (Tru64 version of
##                                           sysdef).
##                                           Added further debugging data when
##                                           connection to the database fails.
##  06/25/2002     fkobylan   Setup_OS       Added comments to check for glogin
##   3.07                                    and login.sql prompts if having
##                                           problems connecting to the DB.
##                                           Added code to process identifying
##                                           if intimate shared memory is in
##                                           use.  At this point, this in only
##                                           for Sun 2.8 and higher.
##  06/19/2002     fkobylan   Setup_OS       Chg'd handling of top command.
##   3.06                                    Too many problems on AIX as it 
##                                           is a non-standard install.
##                                           Added more informative messages
##                                           when testing db connection and
##                                           prompting for a password when
##                                           using "as sysdba" clause.
##  05/27/2002     eferrer    Get_APPS_Pwd   Modified the sections where the 
##   V3.05                    Get_OESDBA_Pwd code gets the password, setting
##                            Setup_OS       PWD_MESSAGE and Module_Password
##                                           and then calling the Get_Password
##                                           function in the COMMON rda.sh.
##                 fkobylan   Setup_OS       Added parameters to top command
##                                           for AIX.
##  05/20/2002     fkobylan   Setup_OS       Added command for checking java
##   3.04                                    version installed.  Command is
##                                           currently the same on all platforms
##                                           Also added code to fix issues with
##                                           LD_LIBRARY_PATH setting.
##                                           Corrected problem with db connect
##                                           test.
##                 eferrer    Get_OESDBA_Pwd New function to get Express Server
##                                           DBA password.
##  05/09/2002     eferrer    Get_APPS_Pwd   New function to get the system
##   3.03                                    user password to the Demand Planning
##                                           Server database for the OLAP
##                                           module
##  04/03/2002     fkobylan   Setup_OS       Added definition for UNIX95 env
##   3.02                                    variable for HP to allow use of
##                                           ps -o command.
##                                           Added code to HP for using swapinfo
##                                           to gather swap space information
##                                           (if executable, otherwise will 
##                                           still use sar).
##                                           Added check's to see if the db
##                                           is running if checking for db
##                                           information.  User will be allowed
##                                           to continue or cancel.
##                                           Also, added connection test to
##                                           see if user/pwd combination can
##                                           really connect.
##                                           Added commands for NLS environment
##                                           checking.
##                                           Added variable for number of lines
##                                           to tail from alert log.
##                                           Added parms to svmon and sar check
##                                           for permissions for AIX.
##                                           Added variables for HTML tagging.
##                                           Added links to SuSE webpages for
##                                           support.
##  03/25/2002     fkobylan   Setup_OS       Added code to limit amount of info
##   3.01                                    returned from system error log.
##  02/18/2002     fkobylan                  created original version 
##                                           based on code from original rda.sh.
##                                           for execution display.
#############################################################################

#############################################################################
##   Program Explanation:
##   ===================
##   The script is not intended to be a stand alone program.  Its function
##   is to handle the operating system setup for the RDA process.  It will 
##   determine platform and operating system version and set environment
##   variables for appropriate commands to be used by the other functions of
##   RDA.
#############################################################################

##################################
### Start of Setup_OS Function ###
##################################

Setup_OS ()
{
## Procedure: Setup_OS ()
## Called to setup all the env variables ...
## OS Specific and Command Specific Issues:OS
#############################################################################
## Variables Used that are OS Specifice go in here
## They are based on the OS_NAME from uname...
#############################################################################

TOP="/usr/local/bin/top 40 1"

##  Since SID can now be specified in setup.txt, at least make sure the $O_H/bin
##  selected is part of the path.
case "$PATH" in
   *${ORACLE_HOME}/bin*)
      PATH=`echo $PATH`
   ;;
   *:)
      PATH=${ORACLE_HOME}/bin:${PATH}
   ;;
   "")
      PATH=${ORACLE_HOME}/bin:
   ;;
   *)
      PATH=${ORACLE_HOME}/bin:$PATH:
   ;;
esac
##  Make sure /usr/sbin, /usr/bin, /etc and /sbin are part of path.  If they aren't there, add them.
case "$PATH" in
   */usr/sbin*)
      PATH=`echo $PATH`
   ;;
   *:)
      PATH=${PATH}/usr/sbin:
   ;;
   "")
      PATH=/usr/sbin:
   ;;
   *)
      PATH=$PATH:/usr/sbin:
   ;;
esac
##  No need to check for non-existent path as, at a minimum, it has /usr/sbin from
##  the previous case statement.
case "$PATH" in
   */usr/bin*)
      PATH=`echo $PATH`
   ;;
   *:)
      PATH=${PATH}/usr/bin:
   ;;
   *)
      PATH=$PATH:/usr/bin:
   ;;
esac
 
case "$PATH" in
   */etc*)
      PATH=`echo $PATH`
   ;;
   *:)
      PATH=${PATH}/etc:
   ;;
   *)
      PATH=$PATH:/etc:
   ;;
esac
 
#  Need to do some special stuff for /sbin since /usr/sbin is also possible.  
# /sbin has to either be the first entry in the path or should be preceded by
# a colon (:)
case "$PATH" in
   /sbin*)
      PATH=`echo $PATH`
   ;;
   *:/sbin*)
      PATH=`echo $PATH`
   ;;
   *:)
      PATH=${PATH}/sbin:
   ;;
   *)
      PATH=$PATH:/sbin:
   ;;
esac

export PATH 

##  Also, make sure that $O_H/lib is part of LD_LIBRARY_PATH.
if [ -z "$LD_LIBRARY_PATH" ]; then
   LD_LIBRARY_PATH=${ORACLE_HOME}/lib:
   export LD_LIBRARY_PATH
else
   case "$LD_LIBRARY_PATH" in
      *${ORACLE_HOME}/lib*)
         LD_LIBRARY_PATH=`echo $LD_LIBRARY_PATH`
         export LD_LIBRARY_PATH
      ;;
      *:)
         LD_LIBRARY_PATH=${ORACLE_HOME}/lib:${LD_LIBRARY_PATH} 
         export LD_LIBRARY_PATH
      ;;
      "")
         LD_LIBRARY_PATH=${ORACLE_HOME}/lib:
         export LD_LIBRARY_PATH
      ;;
      *)                        
         LD_LIBRARY_PATH=${ORACLE_HOME}/lib:$LD_LIBRARY_PATH:
         export LD_LIBRARY_PATH
      ;;
   esac
fi

##  Moved these next two chunks here to make sure they have the correct
##  PRD variable value.

##
## OUT_FILE is the text output for the Results when output=text 
##   or        the default: rda.txt
## Consider naming it $0_out  ie. automatic...
##    OUT_FILE=rda_out
##
   OUT_FILE=${PRD}.Report; export OUT_FILE
##
## Main Right-hand frame Report Overview file name
## It actually will be written to: OUT_DIR/$HeaderReport
## HeaderReport=RDA_right_frame.htm
## 
  HeaderReport=${PRD}_right_frame.htm

##  We need to check if the database is actually running and give the user
##  the opportunity to cancel the script or pause the script and start the
##  database.  If they want to continue, they will need to be warned that
##  information will be missing from the output and the job may need to be
##  run again.  If the user has pressed enter and the DB is not up, set a
##  flag to bypass connections to the database.  A message will be displayed
##  again later on stating the connections were skipped.

Connect_to_DB=Y
if [ "$DATABASE_INSTALLED" = "Y" ]; then
   DB_Up=`ps -ef|grep ora_pmon_$ORACLE_SID| grep -v grep`
   if [ -n "$DB_Up" ]; then
      true
   else
      echo 
      echo "  The database to be analyzed ($ORACLE_SID) does not appear to be"
      echo "  running.  rda.sh cannot find the pmon process."
      echo "  Please do one of the following:"
      echo 
      echo "     -  Start the database in another session then press enter to"
      echo "        continue this script (after the database has been started)"
      echo "     -  Cancel out of this script by pressing ctl-c, start the"
      echo "        database and re-run rda.sh"
      echo "     -  Hit enter to continue this script without gathering information"
      echo "        from the database."
      echo 
      echo "  If you choose to continue without starting the database, some"
      echo "  information will be missing and Oracle Support may request that"
      echo "  rda.sh be rerun."
      read junk
      DB_Up=`ps -ef|grep ora_pmon_$ORACLE_SID| grep -v grep`
      if [ -n "$DB_Up" ]; then
         echo "  Database is now running"
         echo
      else
         echo "  ${BOLD}Database is still not running, no connections will be made to database${OFF}"
         echo "  ${BOLD}will be performed.${OFF}"
         echo
         Connect_to_DB=N
         Connect_to_DB_Message="Database was not running.  No attempt was made to run SQL."
      fi
   fi
fi
##
##  Since there are multiple sections that will connect to the database, we
##  need to get the password early on in the process.  The script is set up
##  to need the password only if there is a database to gather data from.  
##  Check to see if we have the db AND the user wants to be prompted for a
##  password.  Keep the password prompt contents invisible, let them confirm
##  the password and bail after (how many?) tries.  Only do the request if the
##  db is up.
##

if [ "$DATABASE_INSTALLED" = "Y" -a "$Connect_to_DB" = "Y" ]; then
#  Set sysdba message for prompt
   if [ "$SYSDBA_USER" = "Y" ]; then
      SYSDBA_Msg="connecting as sysdba"
   else
      SYSDBA_Msg=""
   fi
   if [ "$PROMPT_FOR_SQL_PASSWORD" = "Y" ]; then
      PWD_MESSAGE="Please enter the sqlplus password for $SQL_Login $SYSDBA_Msg"
      Module_Password="SQL_Login_Password"
      Get_Password
      if [ "$SYSDBA_USER" = "Y" ]; then
         SQL_Login_Password="`echo $SQL_Login`/`echo $SQL_Login_Password` `echo as sysdba`"
      else
         SQL_Login_Password=`echo $SQL_Login`/`echo $SQL_Login_Password`
      fi
   else
      if [ "$SYSDBA_USER" = "Y" ]; then
         SQL_Login_Password="`echo $SQL_Login`/`echo $SQL_Password` `echo as sysdba`"
      else
         SQL_Login_Password=`echo $SQL_Login`/`echo $SQL_Password`
      fi
   fi
fi

##  Start setting up commands that are different for each OS.  Make them
##  unknown to begin with to allow skipping when attempting to execute.
##  Correct command syntax should be set under each OS setup.
Physical_Memory_Available=Y
SHOWREV=''
Java_Version="java -version"
ECHO_SHOWREV=N
ECHO_PKGINFO=N
LISTENER_FOUND_IN=3
SAR_u_EXEC=
NET_TUNING_Cat=N
USE_NDD=N
UDP_TUNING_Cat=N
UDP_TUNING_Err=N
USE_NDD_UDP=N
UDP_TUNING_Cat_One_File=N
UDP_TUNING_Not_Implemented=N
JOBS_LIST=n
OS_NAME=`uname`
Hang_CTR=0
Alert_Log_Tail=30000
Tail_Limit=N
Top_on_Platform=Y
Get_ISM_Info=N
Which_Available=Y
SYSDEF_Extensions=N
Bits=32
DOMAIN_NAME_print=$DOMAIN_NAME
unset TWO_TASK

################################################################
## Formatting tags for SQL statements
################################################################

## SQL Plus settings for HTML files
RDA_sqlset1="SET pagesize 100 heading off termout off echo off verify off linesize 250 feedback off define ~"
RDA_sqlset2="SET pagesize 20000 heading off termout off echo off verify off linesize 250 feedback off define ~"

## Font 
RDA_html_font="<FONT COLOR=\"#336699\">"
RDA_html_end_font="</FONT>"

## Heading3 
RDA_html_h31="<H3> <FONT COLOR=\"#336699\">"
RDA_html_h32="</FONT></H3>"

## Heading4 
RDA_html_h41="<H4> <FONT COLOR=\"#336699\">"
RDA_html_h42="</FONT></H4>"

## Table1
RDA_html_tab1="<TABLE BORDER  CELLPADDING=2>"

## Table column/data heading
RDA_html_tdh1="<TH BGCOLOR=#cccc99 ><B><FONT FACE=\"ARIAL\" COLOR=\"#336699\" SIZE=2>"
RDA_html_tdh2="</B></FONT></TH>"

## Table Data
RDA_html_td1="'<TD BGCOLOR=#f7f7e7><FONT FACE=\"ARIAL\" SIZE=2>'"
RDA_html_td2="'</FONT></TD>'"

RDA_apos="'"

##  At this point, we should have the uid/pwd to connect to the db and also
##  know whether the db is up or not.  Let's make sure we can connect to the
##  db using the uid/pwd provided.  We need to be after the above settings so
##  Hang_CTR can be set for Run_SQL to work right.
if [ "$DATABASE_INSTALLED" = "Y" -a "$Connect_to_DB" = "Y" ]; then
   Connected=Y
   echo 
   echo "  Testing connection to database with userid $SQL_Login $SYSDBA_Msg"
   SQL="select * from dual;"
   Connect_Test=Y
   Run_SQL
   Connect_Test=N
   SQL_Output=`grep  'X' $OUT_DIR/$OUT_FILE.txt`
   if [ -z "$SQL_Output" ]; then
      Connected=N
#  We're going to make an assumption the user is having a problem and will
#  bail out here, so from a debugging standpoint, it's beneficial to have more
#  info to help determine why the connection failed.  Let's append some data
#  to the spool file to help with debugging.  Also, since we will have the 
#  connection information in there, let's change the permissions on the file.
      chmod 600 $OUT_DIR/${OUT_FILE}.txt
      echo "uname -a is `uname -a`" >> $OUT_DIR/${OUT_FILE}.txt
      echo "id is `id`" >> $OUT_DIR/${OUT_FILE}.txt
      echo "ls of oracle executable is" >> $OUT_DIR/${OUT_FILE}.txt
      ls -l $ORACLE_HOME/bin/oracle >> $OUT_DIR/${OUT_FILE}.txt 2>&1
      echo "ORACLE_SID is `echo $ORACLE_SID`" >> $OUT_DIR/${OUT_FILE}.txt
      echo "ORACLE_HOME is `echo $ORACLE_HOME`" >> $OUT_DIR/${OUT_FILE}.txt
      echo "SQL_Login is `echo $SQL_Login`" >> $OUT_DIR/${OUT_FILE}.txt
      echo "SYSDBA_USER is `echo $SYSDBA_USER`" >> $OUT_DIR/${OUT_FILE}.txt
      echo "TWO_TASK is `echo $TWO_TASK`" >> $OUT_DIR/${OUT_FILE}.txt
      echo
      echo "   ${BOLD}Could not connect to the database with userid $SQL_Login ${SYSDBA_Msg}${OFF}"
      echo
      echo "   - Ensure there are no prompts being made by \$ORACLE_HOME/sqlplus/admin/glogin.sql"
      echo "     or \$HOME/login.sql."
      echo
      echo "   - If the userid is incorrect, cancel this run of rda.sh by pressing ctl-c and:"
      echo "      - either rerun setup.sh to recreate setup.txt with correct values "
      echo "      -or-"
      echo "      - manually edit setup.txt to supply the correct value for the user."
      echo
      echo "   - If the userid is correct, it's possible an incorrect password was specified."
      echo "   - If the password is incorrect:"
      echo "     Please cancel out of rda.sh by hitting ctl-c"
      if [ "$PROMPT_FOR_SQL_PASSWORD" = "Y" ]; then
         echo "      re-run rda.sh, providing a valid password for $SQL_Login when prompted."
         echo
      else
         echo "      - either rerun setup.sh to recreate setup.txt with correct values "
         echo "      -or-"
         echo "      - manually edit setup.txt to supply the correct value for the password."
         echo
      fi
      if [ "$SYSDBA_USER" = "Y" ]; then
         echo
         echo "   ${BOLD}Remember that for sysdba users, the password used should${OFF}"
         echo "   ${BOLD}be the database password for the user, not the password stored${OFF}"
         echo "   ${BOLD}in the password file.${OFF}"
         echo
      fi
      read junk
##  If we've gotten here, they just pressed enter even though we couldn't connect
##  warn them and continue.
      echo "  You have chosen to continue without correcting the userid/password,"
      echo "  no attempts to connect to the database will be made."
      echo "  Some information will be missing and Oracle Support may request that"
      echo "  rda.sh be rerun."
      Connect_to_DB=N
      Connect_to_DB_Message="Invalid Userid/Password was specified.  No attempt was made to run SQL."
      echo
   else
      echo "   Connection test successful"
      echo
   fi
fi

##
## The following is a call to the function that gets the OESDBA password
## which is used by the OLAP module to connect to the Oracle Express Server
##
Get_OESDBA_Pwd

##
## The following is a call to the function that gets the APPS system password
## which is used by the OLAP module to connect to the Demand Planning Server
##
Get_APPS_Pwd

case $OS_NAME in 
   SunOS) echo "${BOLD}Setting up for Sun${OFF}"
      Platform=Sun
      Physical_Memory_Print="prtconf |grep 'Memory size'"
      Physical_Memory=`prtconf |grep 'Memory size'`
      SYSDEF=`/usr/sbin/sysdef|grep -v instance |grep -v drv |tail -77`
      SYSDEF_print="/usr/sbin/sysdef|grep -v instance |grep -v drv |tail -77"
      OS_Version=`uname -r | sed s!^5!2!`
#  Check for bits of platform.  If 2.7 or higher, it might be 64 bit.
      if [ `echo $OS_Version | cut -f2 -d.`  -ge 7 ]; then
         Get_Bits=`isainfo -v |grep ^64-bit`
         if [ -z "$Get_Bits" ]; then
            true
         else
            Bits=64
         fi
      fi
##  Version 2.8 of Solaris starts identifying ISM attachments correctly.
      if [ `echo $OS_Version | cut -f2 -d.`  -ge 8 ]; then
         Get_ISM_Info=Y
         ISM_Info="ipcs -im"
         ISM_Msg="To determine Intimate Shared Memory (ISM) usage use the instructions in <a href=http://metalink.oracle.com/metalink/plsql/showdoc?db=NOT&id=68281.1&blackframe=0 target=_new>Note 68281.1</a>\nto determine the Shared Memory Segment for the Oracle instance.  Look at the associated line\nfrom the $ISM_Info command output.  The ISMATTCH column shows the number of ISM\nattaches to shared memory segments, so a value greater than 0 means ISM is in use."
      fi 
      UCB_PS="/usr/ucb/ps aux"
      JOBS_LIST=y
      PS_EF="ps -ef"
      PS_O="ps -ef -o"
      PKGINFO="pkginfo -l"
      SHOWREV="showrev -p"
      CPU_STATS="mpstat 1 3 -v"
      Memory_Stats="vmstat -s"
      SYS_ERROR=`dmesg 2>&1 | tail -1000`
      SYS_ERROR_print="dmesg | tail -1000"
      CPU_INFO=`psrinfo -v`
      CPU_INFO_print="psrinfo -v"
      IOSTAT_M="iostat -M 10 3"
      IOSTAT_d="iostat -d 10 3"
      IOSTAT_xe="iostat -xe 10 3"
      IOSTAT_e="iostat -e"
      SAR_g_EXEC=Y
      SAR_EXEC=Y
      SAR_g=`sar -g 1 4 2>&1|grep -v $OS_NAME`
      SAR_g_print="sar -g 1 4|grep -v $OS_NAME"
      SAR_u=`sar -u 1 4 2>&1|grep -v $OS_NAME`
      SAR_u_print="sar -u 1 4|grep -v $OS_NAME"
      SAR_c=`sar -c 1 4 2>&1|grep -v $OS_NAME`
      SAR_c_print="sar -c 1 4|grep -v $OS_NAME"
      SAR_m=`sar -m 1 4 2>&1|grep -v $OS_NAME`
      SAR_m_print="sar -m 1 4|grep -v $OS_NAME"
      SWAP_l="swap -l"
      SWAP_s="swap -s"
      NETWORKS="/etc/networks"
      USE_NDD=Y
      NET_TUNING="ndd"
      USE_NDD_UDP=Y
      UDP_TUNING="ndd"
      if [ "$NETWORK_PING_TESTS" = "Y" ]; then
         Ping_MACHINE_NANE="ping -s -v -R $MACHINE_NAME 1280 10"
         Ping_WAN_NODE="ping -s -v -R $WAN_NODE 1280 10"
         Ping_RDBMS_NODE="ping -s -v -R $RDBMS_NODE 1280 10"
         Ping_WEB_NODE="ping -s -v -R $WEB_NODE 1280 10"
         Ping_CLIENT_NODE="ping -s -v -R $CLIENT_NODE 1280 10"
      fi
      Ping_print="ping -s -v -R <machine_name> 1280 10"
      IFCONFIG_a=`ifconfig -a 2>&1`
      IFCONFIG_a_print="ifconfig -a"
      NLS_NLS_ENV=`env|grep -i NLS`
      NLS_TZ_ENV=`env|grep -i TZ`
      NLS_Char_Set=`echo -n "" > $OUT_TMP/testcharset.$$ ; od -xc $OUT_TMP/testcharset.$$`
      rm $OUT_TMP/testcharset.$$
      Config_Extension=s
      if [ -r "$ORACLE_HOME/rdbms/lib/config.s" ]; then
         Config_Grep=`grep "ascii" $ORACLE_HOME/rdbms/lib/config.s | head -1`
         DBA_Group=`echo "$Config_Grep" | cut -f2 -d'"' | cut -f1 -d'"'`
         OPER_Group=`echo "$Config_Grep" | cut -f2 -d'"' | cut -f1 -d'"'`
      fi
      LINK_System="http://www.sun.com/products-n-solutions/hardware/index.html"
      LINK_Patches="http://sunsolve.Sun.COM/pub-cgi/show.pl?target=patches/patch-access"
      LINK_Doc="http://docs.sun.com"
   ;;
   HP*) echo "${BOLD}Setting up for HP${OFF}"
      Platform=HPUX
#  Removing the following code message.  Getting values from cstm.  Just 
#  commenting out just in case needs to be added back by version.
#     Physical_Memory_Available=N
#     Physical_Memory_Msg="<P><B>Physical Memory is not easily gathered on this platform with a simple command.<br>Please review documentation on the <a href=http://docs.hp.com//hpux/onlinedocs/diag/stm/sto_summ.htm target=_new>Support Tools Manager</a> product to learn how to determine physical memory on HP.</B></P>"
      TOP="/usr/bin/top -s1 -d2 -n40"
      SYSDEF_Extensions=Y
      SYSDEF_Extension_Cat[0]=Y
      echo "selall;info;wait;infolog;view;done" | /usr/sbin/cstm > $OUT_TMP/SYSDEF_Extension1.$$
      SYSDEF_Extension[0]="$OUT_TMP/SYSDEF_Extension1.$$"
      SYSDEF_Extension_Print[0]='echo "selall;info;wait;infolog;view;done" | /usr/sbin/cstm'
#  This needs to be done after running the extension command above
      Physical_Memory_Print="echo 'selall;info;wait;infolog;view;done' | /usr/sbin/cstm |grep 'Total Configured Memory'"
      Physical_Memory=`grep 'Total Configured Memory' $OUT_TMP/SYSDEF_Extension1.$$`
      UCB_PS="ps -f -u `whoami`"
      PS_EF="ps -ef"
#  Setting for UNIX95 needs to be in place to allow use of ps -o.  It will be
      UNIX95=;export UNIX95
      PS_O="ps -ef -o"
      PKGINFO="swlist -lbundle"
      Tail_Limit=Y
# Get 11.0 vs. 10.20 specific commands
      OS_Version=`uname -r|cut -c 3-7`
#  show_patches is used in 11.0 to show revisions, while swlist is used in 10.20
#  ndd does not exists on 10.20 of HP, nettune is used instead.
      if [ `echo $OS_Version | cut -c1-2`  -eq 11 ]; then
         SHOWREV="/usr/contrib/bin/show_patches"
         NET_TUNING="ndd"
         USE_NDD=Y
         JOBS_LIST=y
         SYSDEF=`/usr/sbin/kmtune -l`
         SYSDEF_print="/usr/sbin/kmtune -l"
#  Check for bits of platform.  If 11 or higher, it might be 64 bit.
         Get_Bits=`getconf KERNEL_BITS |grep ^64`
         if [ -z "$Get_Bits" ]; then
            true
         else
            Bits=64
         fi
      else
         SYSDEF=`/usr/sbin/sysdef|grep -v instance |grep -v drv |tail -77`
         SYSDEF_print="/usr/sbin/sysdef|grep -v instance |grep -v drv |tail -77"
         SHOWREV=`swlist -lproduct PH\*`
         SHOWREV_print="swlist -lproduct PH\*"
         ECHO_SHOWREV=Y
         NET_TUNING="/usr/contrib/bin/nettune -l"
         FIND_BITS=N
         BITS_MSG="Based on the O/S version found ($HP_VER), this has been determined to be a 32 bit installation"
      fi
#  To get UDP data for HP, check for existence of /opt/clic/lib/skgxp/skclic/conf.
#  If it's available, cat the file, else display a message to that effect.
ls /opt/clic/lib/skgxp/skclic.conf >/dev/null 2>&1
if [ $? -eq 0 ]; then
   if [ -r /opt/clic/lib/skgxp/skclic.conf ]; then
      UDP_TUNING=`cat /opt/clic/lib/skgxp/skclic.conf`
   else
      UDP_TUNING_Err=Y
      UDP_TUNING_Err_Msg="/opt/clic/lib/skgxp/skclic.conf not readable.\nPermissions are `ls -al /opt/clic/lib/skgxp/skclic.conf`\nUserid is `id`"
   fi
else
   UDP_TUNING_Err=Y
   UDP_TUNING_Err_Msg="/opt/clic/lib/skgxp/skclic.conf does not exist.  UDP apparantly not installed."
fi
      Memory_Stats="vmstat -s"
      SYS_ERROR=`/usr/sbin/dmesg 2>&1 | tail -1000`
      SYS_ERROR_print="/usr/sbin/dmesg | tail -1000"
      CPU_STATS="sar -u 1 3"
      CPU_INFO=`ioscan -fnkC processor`
      CPU_INFO_print="ioscan -fnkC processor"
      IOSTAT_M="iostat 10 3"
      IOSTAT_d="iostat"
      IOSTAT_xe="iostat"
      IOSTAT_e="iostat"
      SAR_g_EXEC=Y
      SAR_EXEC=Y
      SAR_g=`sar -w 1 4 2>&1|grep -v $OS_NAME`
      SAR_g_print="sar -w 1 4|grep -v $OS_NAME"
      SAR_u=`sar -u 1 4 2>&1|grep -v $OS_NAME`
      SAR_u_print="sar -u 1 4|grep -v $OS_NAME"
      SAR_c=`sar -c 1 4 2>&1|grep -v $OS_NAME`
      SAR_c_print="sar -c 1 4|grep -v $OS_NAME"
      SAR_m=`sar -m 1 4 2>&1|grep -v $OS_NAME`
      SAR_m_print="sar -m 1 4|grep -v $OS_NAME"
#  Test to see if we can execute swapinfo.  If we can, use it to get the
#  swap information, if not, fall back on sar.
      junk=`swapinfo 2>/dev/null`
      if [ $? -eq 0 ]; then
         SWAP_s="swapinfo -m"
         SWAP_l="swapinfo -t"
      else
         SWAP_s="sar -w 2 2 "
         SWAP_l="sar -w 2 2 "
      fi
      NETWORKS="/etc/networks"
## Usage:  ping [-oprv] [-i address] [-t ttl] host [-n count]
##        ping [-oprv] [-i address] [-t ttl] host packet-size [[-n] count]
## -o records the route..
      if [ "$NETWORK_PING_TESTS" = "Y" ]; then
         Ping_MACHINE_NANE="ping -o $MACHINE_NAME 1280 10"
         Ping_WAN_NODE="ping -o $WAN_NODE 1280 10"
         Ping_RDBMS_NODE="ping -o $RDBMS_NODE 1280 10"
         Ping_WEB_NODE="ping -o $WEB_NODE 1280 10"
         Ping_CLIENT_NODE="ping -o $CLIENT_NODE 1280 10"
      fi
      Ping_print="ping -o <machine_name> 1280 10"
      IFCONFIG_a=`lanscan -i | cut -d" " -f1 | xargs -n1 ifconfig 2>&1`
      IFCONFIG_a_print="lanscan -i | xargs -n1 ifconfig"
      NLS_NLS_ENV=`env|grep -i NLS`
      NLS_TZ_ENV=`env|grep -i TZ`
      NLS_Char_Set=`echo -n "" > $OUT_TMP/testcharset.$$ ; od -xc $OUT_TMP/testcharset.$$`
      rm $OUT_TMP/testcharset.$$
      Config_Extension=c
      if [ -r "$ORACLE_HOME/rdbms/lib/config.c" ]; then
         Config_Grep=`grep "#define.*[SS_DBA_GRP|SS_OPER_GRP]" $ORACLE_HOME/rdbms/lib/config.c`
         DBA_Group=`echo "$Config_Grep" | grep SS_DBA_GRP | cut -f2 -d'"' | cut -f1 -d'"'`
         OPER_Group=`echo "$Config_Grep" | grep SS_OPER_GRP | cut -f2 -d'"' | cut -f1 -d'"'`
      fi
      LINK_System="http://europe-support2.external.hp.com/emse/bin/doc.pl/screen=emseHome/sid=964ab34f15d3f6ea46"
      LINK_Patches="http://europe-support2.external.hp.com/common/bin/doc.pl/distrib_redir=1+988379627|*"
      LINK_Doc="http://docs.hp.com/"
   ;;
   AIX) echo "${BOLD}Setting up for AIX${OFF}"
      Platform=AIX
      Physical_Memory_Print="lsattr -E -O -l sys0 -a realmem"
      Physical_Memory=`lsattr -E -O -l sys0 -a realmem`
      Top_on_Platform=N
      SYSDEF=`/usr/sbin/lsattr -El sys0`
      SYSDEF_print="/usr/sbin/lsattr -El sys0"
      UCB_PS="ps -f -u `whoami`"
      PS_EF="ps -ef"
      PS_O="ps -ef -o"
      PKGINFO="lslpp -h"
      Memory_Stats="vmstat -s"
      SYS_ERROR=`/bin/errpt 2>&1 | head -1000`
      SYS_ERROR_print="/bin/errpt | head -1000"
      CPU_STATS="iostat -t 1 3"
      CPU_INFO=`pstat -S`
      CPU_INFO_print="pstat -S"
      SHOWREV="/usr/sbin/instfix -a"
      IOSTAT_M="iostat"
      IOSTAT_d="iostat -d 10 3"
      IOSTAT_xe="iostat"
      IOSTAT_e="iostat"
      SWAP_s="lsps -a"
      SWAP_l="lsps -a"
      LISTENER_FOUND_IN=4
      NETWORKS="/etc/hosts"
#  This is an attempt to determine if 32 or 64 bit AIX is installed. The
#  gist is, locale64 is used to determine the bits, but 64 bit wasn't
#  available until 4.3.1.  Use oslevel to determine the version, grab the
#  individual pieces of version, and if the version is 431 or greater, check
#  locale64, otherwise it has to be 32 bit.
      OS_Version=`oslevel`
      AIX_Ver1=`echo $OS_Version| cut -c1`
      AIX_Ver2=`echo $OS_Version| cut -c3`
      AIX_Ver3=`echo $OS_Version| cut -c5`
      AIX_Ver=`echo $AIX_Ver1$AIX_Ver2$AIX_Ver3`
#  Only check for 64 bit if version is greater than 430.  If we find "not
#  installed", it's a 32 bit installation, if we find nothing, it's 64 bit.
      if [ $AIX_Ver -gt 430 ]; then
         Get_Bits=`lslpp -l bos.64bit 2>&1|grep 'not installed'`
         if [ -z "$Get_Bits" ]; then
            Bits=64
         fi
      fi
      BITS_MSG="Based on the O/S version found ($AIX_VER), this has been determined to be a 32 bit installation"
#  ndd does not exist on AIX, no is used instead.
      NET_TUNING="no -a"
      UDP_TUNING="no -a"
## Usage:  ping [-d] [ -n ] [ -q ] [-r] [-v] [ -R ] [ -c Count ] [ -f |
## -i Wait ] [ -l
##  Preload ] [ -p Pattern ] [ -s PacketSize ] [ -L ] [ - I a.b.c.d. ] 
##  [ -T ttl ]
## Host  [ PacketSize [ Count ] ]
## -R records the route..
      if [ "$NETWORK_PING_TESTS" = "Y" ]; then
         Ping_MACHINE_NANE="ping -R $MACHINE_NAME 1280 10"
         Ping_WAN_NODE="ping -R $WAN_NODE 1280 10"
         Ping_RDBMS_NODE="ping -R $RDBMS_NODE 1280 10"
         Ping_WEB_NODE="ping -R $WEB_NODE 1280 10"
         Ping_CLIENT_NODE="ping -R $CLIENT_NODE 1280 10"
      fi
      Ping_print="ping -R <machine_name> 1280 10"
      IFCONFIG_a=`ifconfig -a 2>&1`
      IFCONFIG_a_print="ifconfig -a"
      NLS_NLS_ENV=`env|grep -i NLS`
      NLS_TZ_ENV=`env|grep -i TZ`
      NLS_Char_Set=`echo -n "" > $OUT_TMP/testcharset.$$ ; od -xc $OUT_TMP/testcharset.$$`
      rm $OUT_TMP/testcharset.$$
      Config_Extension=s
      if [ -r "$ORACLE_HOME/rdbms/lib/config.s" ]; then
         Config_Grep=`grep "string" $ORACLE_HOME/rdbms/lib/config.s | head -1`
         DBA_Group=`echo "$Config_Grep" | cut -f2 -d'"' | cut -f1 -d'"'`
         OPER_Group=`echo "$Config_Grep" | cut -f2 -d'"' | cut -f1 -d'"'`
      fi
      LINK_System="http://www-1.ibm.com/servers/support/"
      LINK_Patches="http://techsupport.services.ibm.com/rs6k/fixdb.html"
      LINK_Doc="http://techsupport.services.ibm.com/rs6000/aix.CAPARdb"

#  sar and svmon are not usually readily executable on AIX systems.  Do a which
#  to find an executable version of each.  If they are executable, let it fly
#  otherwise, throw a blurb back warning that some info may not be obtained.
#  The blurb is a warning, not a showstopper.
      junk=`sar -c 1 1 2>/dev/null`
      if [ $? -eq 0 ]; then
         SAR_EXEC=Y
      else
         SAR_EXEC=N
      fi
      junk=`svmon -G -i 1 1 2>/dev/null`
      if [ $? -eq 0 ]; then
         SVMON_EXEC=Y
      else
         SVMON_EXEC=N
      fi
      SAR_g_print="svmon -G"
      NO_SAR_g_MSG="No paging information available, no permissions or could not find $SAR_g to execute "
      SAR_u_print="sar -u 1 4 |grep -v $OS_NAME"
      NO_SAR_u_MSG="No CPU usage information available, no permissions or could not find $SAR_u to execute "
      SAR_c_print="sar -c 1 4 |grep -v $OS_NAME"
      NO_SAR_c_MSG="No system call information available, no permissions or could not find $SAR_c to execute "
      SAR_m_print="sar -m 1 4|grep -v $OS_NAME"
      NO_SAR_m_MSG="No message and semaphore information available, no permissions or could not find $SAR_m to execute "
      if [ "$SAR_EXEC" = "Y" ]; then
         SAR_u=`sar -u 1 4 2>&1|grep -v $OS_NAME`
         SAR_c=`sar -c 1 4 2>&1|grep -v $OS_NAME`
         SAR_m=`sar -m 1 4 2>&1|grep -v $OS_NAME`
         if [ "$SVMON_EXEC" = "Y" ]; then
            SAR_g=`svmon -G -i 1 4 2>&1`
         else
            echo "svmon information cannot be gathered"
            echo "check permissions or run this script as root"
            SAR_g_EXEC=N
         fi
      else
         if [ "$SVMON_EXEC" = "Y" ]; then
            SAR_g=`svmon -G -i 1 4 2>&1`
            echo "sar information cannot be gathered"
            echo "check permissions or run this script as root"
         else
            echo "sar and svmon information cannot be gathered"
            echo "check permissions or run this script as root"
            SAR_g_EXEC=N
         fi
      fi
   ;;
   OSF1) echo "${BOLD}Setting up for Tru64${OFF}"
      Platform="Compaq Tru64"
      Physical_Memory_Print="vmstat -P |grep '^Total Physical Memory ='"
      Physical_Memory=`vmstat -P |grep '^Total Physical Memory ='`
      Top_on_Platform=N
      SYSDEF=`cat /etc/sysconfigtab`
      SYSDEF_print="cat /etc/sysconfigtab"
      SYSDEF_Extensions=Y
      SYSDEF_Extension_Cat[0]=N
      SYSDEF_Extension_Cat[1]=N
      SYSDEF_Extension_Cat[2]=N
      SYSDEF_Extension[0]="sysconfig -q ipc"
      SYSDEF_Extension[1]="sysconfig -q vm"
      SYSDEF_Extension[2]="sysconfig -q proc"
      UCB_PS="ps -f -u `whoami`"
      JOBS_LIST=y
      PS_EF="ps -ef"
      PS_O="ps -ef -o"
      PKGINFO=`setld -i|grep installed|grep -v Patch`
      PKGINFO_print="setld -i|grep installed|grep -v Patch"
      ECHO_PKGINFO=Y
      OS_Version=`uname -r|cut -dV -f2`
      Bits=64
      Memory_Stats="vmstat -s"
      SYS_ERROR=`/usr/sbin/uerf -R 2>&1 | head -1000`
      SYS_ERROR_print="/usr/sbin/uerf -R | head -1000"
      CPU_STATS="/usr/sbin/pset_info"
      CPU_INFO=`psrinfo -v`
      CPU_INFO_print="psrinfo -v"
      SHOWREV=`/usr/sbin/setld -i|grep Patch`
      ECHO_SHOWREV=Y
      BITS_MSG="Based on the O/S, this has been determined to be a 64 bit installation"
      SHOWREV_print="/usr/sbin/setld -i|grep Patch"
      IOSTAT_M="iostat 10 3"
      IOSTAT_d="iostat"
      IOSTAT_xe="iostat"
      IOSTAT_e="iostat"
#  sar does not exist on Dec, vmstat is best found so far
      SAR_g_EXEC=Y
      SAR_EXEC=Y
      SAR_g=`vmstat -s 2>&1`
      SAR_g_print="vmstat -s"
      SAR_u=`vmstat -s 2>&1`
      SAR_u_print="vmstat -s"
      SAR_c=`vmstat -s 2>&1`
      SAR_c_print="vmstat -s"
      SAR_m=`vmstat -s 2>&1`
      SAR_m_print="vmstat -s"
      SWAP_s="swapon -s "
      SWAP_l="swapon -s"
      NETWORKS="/etc/networks"
      NET_TUNING="/sbin/sysconfig -q inet"
#  UDP info is a little screwy for Tru64 as it requires 3 different commands
#  to be executed.  Since this is the only out of the ordinary platform,
#  it makes more sense to just build a temp file here to be cat'ed out rather
#  then trying to set up the whole thing to handle one odd-ball.
#  Two of them are for cluster only.  Need to skip around them if not on a
#  cluster (no cluster identification done yet).
      UDP_TUNING="/sbin/sysconfig -q ipc"
      UDP_TUNING_Cat_One_File=Y
      UDP_TUNING_File_Name=$OUT_TMP/udp_tuning.$$
      echo "<B>${RDA_html_font}Output from /sbin/sysconfig -q ipc${RDA_html_end_font}</B>" > $UDP_TUNING_File_Name
      echo "<PRE>" >> $UDP_TUNING_File_Name
      /sbin/sysconfig -q ipc >> $UDP_TUNING_File_Name 2>&1
      echo "</PRE>" >> $UDP_TUNING_File_Name
#     UDP_TUNING="/sbin/sysconfig -q rdg, /sbin/sysconfig -q ipc, /sbin/sysconfig -q clubase"
#     UDP_TUNING_Cat_One_File=Y
#     UDP_TUNING_File_Name=$OUT_TMP/udp_tuning.$$
#     echo "<a name=00></a>" > $UDP_TUNING_File_Name
#     echo "<p><a href="#01">Output from /sbin/sysconfig -q rdg</a><br>" >> $UDP_TUNING_File_Name
#     echo "<a href="#02">Output from /sbin/sysconfig -q ipc</a><br>" >> $UDP_TUNING_File_Name
#     echo "<a href="#03">Output from /sbin/sysconfig -q clubase</a></p><br>" >> $UDP_TUNING_File_Name
#     echo "<a name=01></a>" >> $UDP_TUNING_File_Name
#     echo "<B>${RDA_html_font}Output from /sbin/sysconfig -q rdg${RDA_html_end_font}</B>" >> $UDP_TUNING_File_Name
#     echo "<PRE>" >> $UDP_TUNING_File_Name
#     /sbin/sysconfig -q rdg >> $UDP_TUNING_File_Name 2>&1
#     echo "</PRE>" >> $UDP_TUNING_File_Name
#     echo "<a href="#00">Back to top</a><br><br>" >> $UDP_TUNING_File_Name
#     echo "<a name=02></a>" >> $UDP_TUNING_File_Name
#     echo "<B>${RDA_html_font}Output from /sbin/sysconfig -q ipc${RDA_html_end_font}</B>" >> $UDP_TUNING_File_Name
#     echo "<PRE>" >> $UDP_TUNING_File_Name
#     /sbin/sysconfig -q ipc >> $UDP_TUNING_File_Name 2>&1
#     echo "</PRE>" >> $UDP_TUNING_File_Name
#     echo "<a href="#00">Back to top</a><br><br>" >> $UDP_TUNING_File_Name
#     echo "<a name=03></a>" >> $UDP_TUNING_File_Name
#     echo "<B>${RDA_html_font}Output from /sbin/sysconfig -q clubase${RDA_html_end_font}</B>" >> $UDP_TUNING_File_Name
#     echo "<PRE>" >> $UDP_TUNING_File_Name
#     /sbin/sysconfig -q clubase >> $UDP_TUNING_File_Name 2>&1
#     echo "</PRE>" >> $UDP_TUNING_File_Name
#     echo "<a href="#00">Back to top</a><br><br>" >> $UDP_TUNING_File_Name
## Usage:  /usr/sbin/ping [-dfnqruvLR] [-c count] [-i wait] [-l preload]
## [-p pattern] [-s packetsize] [-t number] host
## -R records the route.
      if [ "$NETWORK_PING_TESTS" = "Y" ]; then
         Ping_MACHINE_NANE="ping -R -c 10 -s 1280 $MACHINE_NAME"
         Ping_WAN_NODE="ping -R -c 10 -s 1280 $WAN_NODE"
         Ping_RDBMS_NODE="ping -R -c 10 -s 1280 $RDBMS_NODE"
         Ping_WEB_NODE="ping -R -c 10 -s 1280 $WEB_NODE"
         Ping_CLIENT_NODE="ping -R -c 10 -s 1280 $CLIENT_NODE"
      fi
      Ping_print="ping -R -c 10 -s 1280 <machine_name>"
      IFCONFIG_a=`ifconfig -a 2>&1`
      IFCONFIG_a_print="ifconfig -a"
      NLS_NLS_ENV=`env|grep -i NLS`
      NLS_TZ_ENV=`env|grep -i TZ`
      NLS_Char_Set=`echo -n "" > $OUT_TMP/testcharset.$$ ; od -xc $OUT_TMP/testcharset.$$`
      rm $OUT_TMP/testcharset.$$
      Config_Extension=c
      if [ -r "$ORACLE_HOME/rdbms/lib/config.c" ]; then
         Config_Grep=`grep "#define.*[SS_DBA_GRP|SS_OPER_GRP]" $ORACLE_HOME/rdbms/lib/config.c`
         DBA_Group=`echo "$Config_Grep" | grep SS_DBA_GRP | cut -f2 -d'"' | cut -f1 -d'"'`
         OPER_Group=`echo "$Config_Grep" | grep SS_OPER_GRP | cut -f2 -d'"' | cut -f1 -d'"'`
      fi
      LINK_System="http://www.compaq.com/support/index.shtml"
      LINK_Patches="http://ftp1.support.compaq.com/public/Digital_UNIX/"
      LINK_Doc="http://www.tru64unix.compaq.com/docs/"
   ;;
   Linux) echo "${BOLD}Setting up for Linux${OFF}"
      Physical_Memory_Print="cat /proc/meminfo |head -2"
      Physical_Memory=`cat /proc/meminfo |head -2`
      TOP="/usr/bin/top -d 1 -n 2 b"
      SYSDEF=`ipcs -l`
      SYSDEF_print="ipcs -l"
      PS_EF="ps -ef"
      PS_ELF="ps -elf"
      PS_O="ps -eo"
      CPU_INFO=`cat /proc/cpuinfo`
      CPU_INFO_print="cat /proc/cpuinfo"
      PKGINFO="rpm -qa"
      CPU_STATS="procinfo"
      Memory_Stats="cat /proc/meminfo"
      SYS_ERROR=`dmesg 2>&1 | tail -1000`
      SYS_ERROR_print="dmesg | tail -1000"
      OS_Version=`uname -r|cut -d"-" -f1`
      Linux_Issue=`cat /etc/issue`
      case $Linux_Issue in
         *[Rr][Ee][Dd]*[Hh[Aa][Tt]* ) 
            Linux_Flavor="Red Hat"
         ;;
         *[Ss][Uu][Ss][Ee]* ) 
            Linux_Flavor=SuSE
         ;;
         *[Dd][Ee][Bb][Ii][Aa][Nn]* ) 
            Linux_Flavor=Debian
         ;;
         * ) 
            Linux_Flavor=Unknown
         ;;
      esac
      Platform="$Linux_Flavor Linux"
#  Linux right now is always 32 bit, so no need to change from default
      BITS_MSG="Based on the O/S, this has been determined to be a 32 bit installation"
#  sar doesn't exist so need some way to get this stuff
      SAR_g_EXEC=Y
      SAR_u_EXEC=Y
      SAR_EXEC=N
      SAR_g=`cat /proc/stat 2>&1`                   # paging activity
      SAR_g_print="cat /proc/stat"                   # paging activity
      SAR_u=`/usr/bin/top -d 1 -n 4 b 2>&1|grep "CPU states:"` # cpu usage
      SAR_u_print="/usr/bin/top -d 1 -n 4 b|grep CPU states:"
      SAR_c=`sar -c 1 4 2>&1|grep -v $OS_NAME`  # system calls
      SAR_c_print="Not Available"  # system calls
      NO_SAR_c_MSG="sar is not available, there is no identified method for gathering system call statistics."
#              SAR_m=`sar -m 1 4 2>&1|grep -v $OS_NAME`  # message and semaphore
      SAR_m_print="Not Available"  # message and semaphore
      NO_SAR_m_MSG="sar is not available, there is no identified method for gathering messaging and semaphore statistics."
      SWAP_s="free -t"
      SWAP_l="cat /proc/swaps"
#  iostat does not exist on Linux.  vmstat is best I can find so far.
      IOSTAT_M="vmstat 10 3"  # disk thruput in MB
      IOSTAT_d="vmstat"  # disk thruput in bytes
      IOSTAT_xe="vmstat" # disk extended statistics
      IOSTAT_e="vmstat"  # disk errors
      NETWORKS="/etc/networks"
#  New method for getting the tcp parameter settings.  The data is located in
#  /proc/sys/net/ipv4/tcp* files, we need to get the list of files, then
#  print the contents of the files.  A different way of doing things.....
      NET_TUNING_Cat=Y
      NET_TUNING="ls /proc/sys/net/ipv4/tcp*"
#              NET_TUNING="grep -i tcp /usr/src/linux/include/net/tcp.h"
#  New method for getting the tcp parameter settings.  The data is located in
#  /proc/sys/net/ipv4/tcp* files, we need to get the list of files, then
#  print the contents of the files.  A different way of doing things.....
      UDP_TUNING_Cat=Y
      UDP_TUNING="ls /proc/sys/net/core/*mem*"
      GET_GNU_LIBC="Y"
      SUSERELEASE="/etc/SuSE-release"
      if [ -f $SUSERELEASE -a -r $SUSERELEASE ]; then
         true
      else
         unset SUSERELEASE
      fi
#    ping [-dfLnqRrv] [-c count] [-I ifaddr] [-i wait] [-l preload] [-p
#         pattern] [-S ifaddr] [-s packetsize] [-t ttl] [-w maxwait] host
## -R records the route.
      if [ "$NETWORK_PING_TESTS" = "Y" ]; then
         Ping_MACHINE_NANE="ping -R -c 10 -s 1280 $MACHINE_NAME"
         Ping_WAN_NODE="ping -R -c 10 -s 1280 $WAN_NODE"
         Ping_RDBMS_NODE="ping -R -c 10 -s 1280 $RDBMS_NODE"
         Ping_WEB_NODE="ping -R -c 10 -s 1280 $WEB_NODE"
         Ping_CLIENT_NODE="ping -R -c 10 -s 1280 $CLIENT_NODE"
      fi
      Ping_print="ping -R -c 10 -s 1280 <machine_name>"
      IFCONFIG_a=`ifconfig -a 2>&1`
      IFCONFIG_a_print="ifconfig -a"
      NLS_NLS_ENV=`env|grep -i NLS`
      NLS_TZ_ENV=`env|grep -i TZ`
      NLS_Char_Set=`echo -n "" > $OUT_TMP/testcharset.$$ ; od -xc $OUT_TMP/testcharset.$$`
      rm $OUT_TMP/testcharset.$$
      Config_Extension=c
      if [ -r "$ORACLE_HOME/rdbms/lib/config.c" ]; then
         Config_Grep=`grep "#define.*[SS_DBA_GRP|SS_OPER_GRP]" $ORACLE_HOME/rdbms/lib/config.c`
         DBA_Group=`echo "$Config_Grep" | grep SS_DBA_GRP |cut -f2 -d'"' | cut -f1 -d'"'`
         OPER_Group=`echo "$Config_Grep" | grep SS_OPER_GRP | cut -f2 -d'"' | cut -f1 -d'"'`
      fi
      if [ -n "$SUSERELEASE" ]; then
         LINK_System="http://hardwaredb.suse.de/index.php?LANG=en_UK"
         LINK_Patches="http://www.suse.de/en/support/index.html"
         LINK_Doc="http://sdb.suse.de/en/sdb/html/"
      else
         LINK_System="http://www.linux.com/enhance/hardware/"
         LINK_Patches="http://www.redhat.com/support/errata/"
         LINK_Doc="http://www.redhat.com/support/manuals/"
      fi
   ;;
   DYNIX/ptx) echo "${BOLD}Setting up for Sequent${OFF}"
      Platform=Sequent
#  The which command is not available on PTX....
      Which_Available=N
      JOBS_LIST=y
      Physical_Memory_Print="/etc/showquads |grep 'Total memory'"
      Physical_Memory=`/etc/showquads |grep 'Total memory'`
      TOP="/usr/bin/top -s1 -d2 40"
      SYSDEF=`/etc/sysdef|grep -v instance |grep -v drv |tail -77`
      SYSDEF_print="/etc/sysdef|grep -v instance |grep -v drv |tail -77"
      UCB_PS="ps -f -u `who am i|awk '{print $1}'`"
      PS_EF="ps -ef"
      PS_O="ps -ef -o"
      PKGINFO="pkginfo -i"
      SHOWREV="cat /etc/versionlog"
      Memory_Stats="sar -cwmpr"
      SYS_ERROR=`/etc/ktmesg 2>&1 | head -1000`
      SYS_ERROR_print="/etc/ktmesg | head -1000"
      OS_Version=`uname -v`
      Platform=Sequent
      BITS_MSG="Based on the O/S, this has been determined to be a 32 bit installation"
      CPU_STATS="sar -qwu 1 3"
      CPU_INFO=`/etc/showcfg|grep PROC`
      CPU_INFO_print="/etc/showcfg|grep PROC"
      IOSTAT_M="sar -d 10 3"
      IOSTAT_d="sar -d"
      IOSTAT_xe="sar -d"
      IOSTAT_e="sar -d"
      SAR_g_EXEC=Y
      SAR_EXEC=Y
      SAR_g=`sar -w 1 4 2>&1|grep -v $OS_NAME`
      SAR_g_print="sar -w 1 4|grep -v $OS_NAME"
      SAR_u=`sar -u 1 4 2>&1|grep -v $OS_NAME`
      SAR_u_print="sar -u 1 4|grep -v $OS_NAME"
      SAR_c=`sar -c 1 4 2>&1|grep -v $OS_NAME`
      SAR_c_print="sar -c 1 4|grep -v $OS_NAME"
      SAR_m=`sar -m 1 4 2>&1|grep -v $OS_NAME`
      SAR_m_print="sar -m 1 4|grep -v $OS_NAME"
      SWAP_s="sar -w 2 2 "
      SWAP_l="sar -w 2 2 "
      NETWORKS="/etc/networks"
#  No known method of doing UDP on Sequent yet.  Just skip it for now.
      UDP_TUNING_Not_Implemented=Y
      NET_TUNING="grep -i tcp /usr/conf/uts/symmetry.$MACHINE_NAME/config.h"
## Usage:  ping [ -dfnqrvR ] [ -c count ] [ -i wait ] [ -l preload ] [ -p pattern ] [ -s packetsize ] host 
## -R records the route
      if [ "$NETWORK_PING_TESTS" = "Y" ]; then
         Ping_MACHINE_NANE="ping -R -s 1280 -c 10 $MACHINE_NAME"
         Ping_WAN_NODE="ping -R -s 1280 -c 10 $WAN_NODE"
         Ping_RDBMS_NODE="ping -R -s 1280 -c 10 $RDBMS_NODE"
         Ping_WEB_NODE="ping -R -s 1280 -c 10 $WEB_NODE"
         Ping_CLIENT_NODE="ping -R -s 1280 -c 10 $CLIENT_NODE"
      fi
      Ping_print="ping -R -s 1280 -c 10 <machine_name>"
      IFCONFIG_a=`ifconfig -a 2>&1`
      IFCONFIG_a_print="ifconfig -a"
      NLS_NLS_ENV=`env|grep -i NLS`
      NLS_TZ_ENV=`env|grep -i TZ`
      NLS_Char_Set=`echo -n "" > $OUT_TMP/testcharset.$$ ; od -xc $OUT_TMP/testcharset.$$`
      rm $OUT_TMP/testcharset.$$
      Config_Extension=c
      if [ -r "$ORACLE_HOME/rdbms/lib/config.c" ]; then
         Config_Grep=`grep "#define.*[SS_DBA_GRP|SS_OPER_GRP]" $ORACLE_HOME/rdbms/lib/config.c`
         DBA_Group=`echo "$Config_Grep" | grep SS_DBA_GRP | cut -f2 -d'"' | cut -f1 -d'"'`
         OPER_Group=`echo "$Config_Grep" | grep SS_OPER_GRP | cut -f2 -d'"' | cut -f1 -d'"'`
      fi
      LINK_System="http://www-1.ibm.com/eserver/support/"
      LINK_System="http://www-1.ibm.com/eserver/support/"
      LINK_Patches="http://techsupport.services.ibm.com/eserver/fixes"
      LINK_Doc="http://webdocs.numaq.ibm.com"
   ;;
   *) echo "Not sure what OS to use"
# Always NEED some COMMAND IN A CASE STATEMENT EVEN DO NOTHING
      junk=nothingYET 
esac
}

##
## This function gets the APPS system password for the OLAP Module
##
Get_APPS_Pwd ()
{
  if [ "$DPE_INSTALLED" = "Y" ]; then
   if [ "$DPE_DPS_SQL_PASSWORD_PROMPT" = "Y" ]; then
      PWD_MESSAGE="Please enter the APPS \"system\" password for the Demand Planning Server"
      Module_Password="DPE_DPS_SQL_PASSWORD"
      Get_Password;
   fi
  fi
}

##
## This function gets the OESDBA password for the OLAP Module
##
Get_OESDBA_Pwd ()
{
  if [ "$EXPRESS_INSTALLED" = "Y" ]; then
   if [ "$OES_DBA_PWD_PROMPT" = "Y" ]; then
      PWD_MESSAGE="Please enter OES DBA Role User password for Oracle Express Server"
      Module_Password="OES_DBA_PWD"
      Get_Password;
   fi
  fi
}

Setup_OS
