Test=`env|grep RDA_Program_Version`

##  The previous line MUST be the first line in the script.  If not, the check
##  for determining if this is called or started straight from command line
##  will not work (it will throw errors back to the screen).

if [ -z "$Test" ]; then
   echo "This script cannot be run standalone"
   echo "It must be called from the main RDA rda.sh"
   echo "Exiting from rda.sh"
   exit
fi
###########################################################################
##    Name: rda.sh                                Version: 3.09
##      By: Oracle Corp.                    Last Modified: September 04, 2002
##                                                Written: 2/19/02  
##
## Purpose: This is the source script for handling the gathering of operating
##          system configuration information (e.g. directory lists, specific 
##          file contents, packages and patches installed, etc.).  This is
##          not intended to be a standalone script, it should be sourced from
##          an executable script.
##
##   Usage: Source from a script
##             . ./RDA_script_0002_RVW_OS/rda.sh
##
###########################################################################

##############################################################################
##  Modifications Section:
##############################################################################
##     Date        Author     Function       Changes
##############################################################################
##  08/30/2002     fkobylan   Review_OS      Mods to SYSDEF extension code to
##    V3.09                                  handle different types of cmds.
##                                           Removed code to do O/S bits. Now
##                                           showing up in Report Header.  
##                                           Display message to point to new
##                                           location.
##  07/29/2002     fkobylan   Review_OS      Cleaned up various html tagging
##    V3.08                                  issues (issue 172).
##                                           Chgd name and location of os_files.
##                                           Added code to display physical 
##                                           memory on server (issue 134).
##                                           Added a redirect of stderr to
##                                           hide problems with CPU_Stats when
##                                           command not found or generates
##                                           errors.
##                                           Added ability to get further 
##                                           system definition type information.
##                                           This is only for Tru64 at this
##                                           time but can be expanded to other
##                                           platforms.
##                            RVW_OS_Build_Links
##                                           Chgd bg color for left frame links.
##                                           Added link for physical memory 
##                                           data.
##  06/28/2002     fkobylan   Review_OS      Added content for intimate shared
##    V3.07                                  memory.
##                            RVW_OS_Build_Links
##                                           Added link for ISM info.
##  06/14/2002     fkobylan   Review_OS      Chgd check for 64 bit Oracle dirs.
##    V3.06                                  Using -a to check for existence
##                                           of the dirs caused errors in some
##                                           ct's environments.  Chgd to -d.
##                                           Added links to different dir's
##                                           in $O_H listings.
##  05/20/2002     fkobylan   Review_OS      Added code to get version of java.
##   V3.04                    RVW_OS_Build_Links
##                                           Added link for Java version info.
##  04/04/2002     fkobylan   Review_OS      Added search for Oracle 64 bit
##    V3.02                                  library listings.
##                                           Added NLS settings information.
##                                           Chgd to limit data length being
##                                           returned by showrev to not cause
##                                           awk "too many fields" errors.
##                            RVW_OS_Build_Links
##                                           Added link for NLS info.
##  03/26/2002     fkobylan   Review_OS      Chgd to print specific "dot" files
##    V3.01                                  from the user's $HOME directory.
##                            RVW_OS_Build_Links
##                                           Added code to handle links for new
##                                           output files.
##  02/19/2002     fkobylan                  created original version 
##                                           based on code from original rda.sh.
##                                           for execution display.
#############################################################################

#############################################################################
##   Program Explanation:
##   ===================
##   The script is not intended to be a stand alone program.  Its function
##   is to gather specific operating system configuration information and
##   display for the RDA process.  It will search for specific files to
#    display contents, show directory listings and execute commands set by the 
##   SETUP_OS function, formatting the output into files for display through
##   a web browser.
#############################################################################

##################################
### Start of Review_OS Function ###
##################################

Review_OS ()
{
## Procedure Name: Review_OS
################################################################
## This is the main procedure called from MAIN to run all the
## OS specific items.
##

### OS Specific

DebugMessage="DDEBUG: Starting Review_OS"
Debug
		  
echo "${BOLD}Processing: OS${OFF}"

# This is Linux only
if [ -n "$SUSERELEASE" ]; then
   echo "Output of file $SUSERELEASE" > $OUT_DIR/${PRD}_suse-release.txt
   echo "=====================================" >> $OUT_DIR/${PRD}_suse-release.txt
   cat $SUSERELEASE >> $OUT_DIR/${PRD}_suse-release.txt
fi

#  again, Linux only
#  Try to find the Linux libc version
#  The GNU C Library prints its version when it is directly called.
#  Unfortunately, Linux distribtuions seems to have different ideas about
#  the exact file name of the C Library, so we just try everything starting
#  with libc.so, even if we may get duplicate information this way.
if [ -n "$GET_GNU_LIBC" ]; then
         echo "==========================================================" > $OUT_DIR/${PRD}_libc.txt
   for libc in /lib/libc.so*; do
      if [ -f $libc -a -x $libc ]; then
         echo "Trying to execute $libc to get version information" >>$OUT_DIR/${PRD}_libc.txt
         echo "==========================================================" >> $OUT_DIR/${PRD}_libc.txt
         $libc >> $OUT_DIR/${PRD}_libc.txt 2>&1
         if [ -n $? ]; then
            echo "=====> successful" >> $OUT_DIR/${PRD}_libc.txt
         else
            echo "=====> failed" >> $OUT_DIR/${PRD}_libc.txt
         fi
         echo "==========================================================" >> $OUT_DIR/${PRD}_libc.txt
      fi
   done
fi

echo "${BOLD}Processing: Unix Environment${OFF}"

#  Bits has now been moved to the report header.  Put a display here to point
#  to the new location, then remove in a future release.
echo "###############################################" > $OUT_DIR/${PRD}_Machine.txt
echo "Operating System Bits has been moved to the Reports Settings section." >> $OUT_DIR/${PRD}_Machine.txt
echo "###############################################" >> $OUT_DIR/${PRD}_Machine.txt
echo  >> $OUT_DIR/${PRD}_Machine.txt

if [ -x ${ORACLE_HOME}/bin/unixenv ];then
  echo "unixenv was found in $ORACLE_HOME/bin" >> $OUT_DIR/${PRD}_Machine.txt
  ${ORACLE_HOME}/bin/unixenv >> $OUT_DIR/${PRD}_Machine.txt
else
   if [ -x ${ORACLE_HOME}/install/utl/unixenv ];then
      #  strip out strace from the list of tracing utilities to check
      #  to stop unixenv from hanging.
      sed s/strace// $ORACLE_HOME/install/utl/unixenv > $OUT_TMP/unixenv$$
      chmod 777 $OUT_TMP/unixenv$$
      echo "unixenv was found in $ORACLE_HOME/install/utl" >> $OUT_DIR/${PRD}_Machine.txt
      $OUT_TMP/unixenv$$ >> $OUT_DIR/${PRD}_Machine.txt
      rm -f $OUT_TMP/unixenv$$ 2>/dev/null
   else
      echo "Note: unixenv was not found or is not Executable."  >> $OUT_DIR/${PRD}_Machine.txt
      echo "      Typically it is found in ORACLE_HOME." >> $OUT_DIR/${PRD}_Machine.txt
      echo "      Using unixenv.sh shipped with RDA."  >> $OUT_DIR/${PRD}_Machine.txt
      ./unixenv.sh  >> $OUT_DIR/${PRD}_Machine.txt
   fi
fi
#  Strip out the sql_login password from Machine.txt
#  Since pwd1 and pwd2 are not exported, there is no need to strip them out
#  as they won't show up in the unixenv output (it's an executed script).
#  The password will be in either SQL_Password or SQL_Login_Password, this sed
#  should remove both.
sed /SQL.*Password/d $OUT_DIR/${PRD}_Machine.txt > $OUT_TMP/mach$$
mv $OUT_TMP/mach$$ $OUT_DIR/${PRD}_Machine.txt 2>/dev/null

DebugMessage=" Inside Review_OS, doing ls of Oracle Home files"
Debug

echo "<a name=00></a>" > $OUT_DIR/${PRD}_oracle_home.htm
echo "<Center><H3>${RDA_html_font}Listing of files from primary \$ORACLE_HOME directories ${RDA_html_end_font}</H3></Center>"  >> $OUT_DIR/${PRD}_oracle_home.htm

echo >> $OUT_DIR/${PRD}_oracle_home.htm
echo "<p><a href="#01">$ORACLE_HOME/bin</a><br>" >> $OUT_DIR/${PRD}_oracle_home.htm
echo "<a href="#02">$ORACLE_HOME/lib</a><br>" >> $OUT_DIR/${PRD}_oracle_home.htm
if [ -d $ORACLE_HOME/lib64 ]; then
   echo "<a href="#03">$ORACLE_HOME/lib64</a><br>" >> $OUT_DIR/${PRD}_oracle_home.htm
fi
echo "<a href="#04">$ORACLE_HOME/rdbms/lib</a><br>" >> $OUT_DIR/${PRD}_oracle_home.htm
if [ -d $ORACLE_HOME/rdbms/lib64 ]; then
   echo "<a href="#05">$ORACLE_HOME/rdbms/lib64</a><br>" >> $OUT_DIR/${PRD}_oracle_home.htm
fi
echo "</p>" >> $OUT_DIR/${PRD}_oracle_home.htm

echo "<a name=01></a>" >> $OUT_DIR/${PRD}_oracle_home.htm
echo "<B>${RDA_html_font}Listing of $ORACLE_HOME/bin${RDA_html_end_font}</B>"  >> $OUT_DIR/${PRD}_oracle_home.htm

echo "<PRE>" >> $OUT_DIR/${PRD}_oracle_home.htm
echo >> $OUT_DIR/${PRD}_oracle_home.htm
ls -al $ORACLE_HOME/bin >/dev/null 2>/dev/null
if [ $? -eq 0 ]; then
   ls -al $ORACLE_HOME/bin >> $OUT_DIR/${PRD}_oracle_home.htm 
else
   echo "Could not list files in $ORACLE_HOME/bin" >> $OUT_DIR/${PRD}_oracle_home.htm
fi
echo "</PRE>" >> $OUT_DIR/${PRD}_oracle_home.htm

echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${PRD}_oracle_home.htm
echo >> $OUT_DIR/${PRD}_oracle_home.htm

echo "<a name=02></a>" >> $OUT_DIR/${PRD}_oracle_home.htm
echo "<B>${RDA_html_font}Listing of $ORACLE_HOME/lib${RDA_html_end_font}</B>"  >> $OUT_DIR/${PRD}_oracle_home.htm

echo "<PRE>" >> $OUT_DIR/${PRD}_oracle_home.htm
echo >> $OUT_DIR/${PRD}_oracle_home.htm
ls -al $ORACLE_HOME/lib >/dev/null 2>/dev/null
if [ $? -eq 0 ]; then
   ls -al $ORACLE_HOME/lib >> $OUT_DIR/${PRD}_oracle_home.htm 
else
   echo "Could not list files in $ORACLE_HOME/lib" >> $OUT_DIR/${PRD}_oracle_home.htm
fi
echo "</PRE>" >> $OUT_DIR/${PRD}_oracle_home.htm
echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${PRD}_oracle_home.htm
echo >> $OUT_DIR/${PRD}_oracle_home.htm

if [ -d $ORACLE_HOME/lib64 ]; then
   echo "<a name=03></a>" >> $OUT_DIR/${PRD}_oracle_home.htm
   echo "<B>${RDA_html_font}Listing of $ORACLE_HOME/lib64${RDA_html_end_font}</B>"  >> $OUT_DIR/${PRD}_oracle_home.htm
   echo "<PRE>" >> $OUT_DIR/${PRD}_oracle_home.htm
   ls -al $ORACLE_HOME/lib64 >/dev/null 2>/dev/null
   if [ $? -eq 0 ]; then
      ls -al $ORACLE_HOME/lib64 >> $OUT_DIR/${PRD}_oracle_home.htm 
   else
      echo "Could not list files in $ORACLE_HOME/lib64" >> $OUT_DIR/${PRD}_oracle_home.htm
   fi
   echo "</PRE>" >> $OUT_DIR/${PRD}_oracle_home.htm
   echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${PRD}_oracle_home.htm
   echo >> $OUT_DIR/${PRD}_oracle_home.htm
fi

echo "<a name=04></a>" >> $OUT_DIR/${PRD}_oracle_home.htm
echo "<B>${RDA_html_font}Listing of $ORACLE_HOME/rdbms/lib${RDA_html_end_font}</B>"  >> $OUT_DIR/${PRD}_oracle_home.htm

echo "<PRE>" >> $OUT_DIR/${PRD}_oracle_home.htm
echo >> $OUT_DIR/${PRD}_oracle_home.htm
ls -al $ORACLE_HOME/rdbms/lib >/dev/null 2>/dev/null
if [ $? -eq 0 ]; then
   ls -al $ORACLE_HOME/rdbms/lib >> $OUT_DIR/${PRD}_oracle_home.htm 
else
   echo "Could not list files in $ORACLE_HOME/rdbms/lib" >> $OUT_DIR/${PRD}_oracle_home.htm
fi
echo "</PRE>" >> $OUT_DIR/${PRD}_oracle_home.htm

echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${PRD}_oracle_home.htm
echo >> $OUT_DIR/${PRD}_oracle_home.htm

if [ -d $ORACLE_HOME/rdbms/lib64 ]; then
   echo "<a name=05></a>" >> $OUT_DIR/${PRD}_oracle_home.htm
   echo "<B>${RDA_html_font}Listing of $ORACLE_HOME/rdbms/lib64${RDA_html_end_font}</B>"  >> $OUT_DIR/${PRD}_oracle_home.htm
   echo "<PRE>" >> $OUT_DIR/${PRD}_oracle_home.htm
   ls -al $ORACLE_HOME/rdbms/lib64 >/dev/null 2>/dev/null
   if [ $? -eq 0 ]; then
      ls -al $ORACLE_HOME/rdbms/lib64 >> $OUT_DIR/${PRD}_oracle_home.htm 
   else
      echo "Could not list files in $ORACLE_HOME/rdbms/lib64" >> $OUT_DIR/${PRD}_oracle_home.htm
   fi
   echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${PRD}_oracle_home.htm
   echo >> $OUT_DIR/${PRD}_oracle_home.htm
   echo "</PRE>" >> $OUT_DIR/${PRD}_oracle_home.htm
fi

DebugMessage="Inside Review_OS, gathering Java Version"
Debug

echo "$RDA_html_h31 Java Version $RDA_html_h32 <br>"  > $OUT_DIR/${PRD}_java_version.htm

echo "$RDA_html_h41 Gathered by Running \"$Java_Version\" $RDA_html_h42"  >> $OUT_DIR/${PRD}_java_version.htm
echo "<PRE>" >> $OUT_DIR/${PRD}_java_version.htm
`$Java_Version  >> $OUT_DIR/${PRD}_java_version.htm 2>&1`
echo "</PRE>" >> $OUT_DIR/${PRD}_java_version.htm

DebugMessage="Inside Review_OS, gathering NLS information"
Debug

echo "$RDA_html_h31 National Language Support Settings $RDA_html_h32 <br>"  > $OUT_DIR/${PRD}_nls_env.htm

echo "$RDA_html_h41 National Language Support NLS Environment Settings $RDA_html_h42"  >> $OUT_DIR/${PRD}_nls_env.htm
echo "<PRE>" >> $OUT_DIR/${PRD}_nls_env.htm
echo "$NLS_NLS_ENV"  >> $OUT_DIR/${PRD}_nls_env.htm
echo "</PRE><br>" >> $OUT_DIR/${PRD}_nls_env.htm

echo "$RDA_html_h41 National Language Support TZ Environment Settings $RDA_html_h42 "  >> $OUT_DIR/${PRD}_nls_env.htm
echo "<PRE>" >> $OUT_DIR/${PRD}_nls_env.htm
echo "$NLS_TZ_ENV"  >> $OUT_DIR/${PRD}_nls_env.htm
echo "</PRE><br>" >> $OUT_DIR/${PRD}_nls_env.htm

echo "$RDA_html_h41 National Language Support Character Set Test $RDA_html_h42"  >> $OUT_DIR/${PRD}_nls_env.htm
echo "<PRE>" >> $OUT_DIR/${PRD}_nls_env.htm
echo "$NLS_Char_Set"  >> $OUT_DIR/${PRD}_nls_env.htm
echo "</PRE>" >> $OUT_DIR/${PRD}_nls_env.htm
echo "<br><p>Note:  The above output was generated by echoing the character e with" >> $OUT_DIR/${PRD}_nls_env.htm
echo "       an accent grave.  Depending on the language setting of the browser being used" >> $OUT_DIR/${PRD}_nls_env.htm
echo "       to view the output, this may show up as an unprintable character on the second line." >> $OUT_DIR/${PRD}_nls_env.htm
echo "       This display should not be considered a problem with the script.</p>" >> $OUT_DIR/${PRD}_nls_env.htm

echo "CPUs Overview: $CPU_INFO_print " > $OUT_DIR/${PRD}_CPUs.txt
echo "$CPU_INFO" >> $OUT_DIR/${PRD}_CPUs.txt 

echo "" >> $OUT_DIR/${PRD}_CPUs.txt 

echo "Basic CPU Utilization: ${CPU_STATS}" >> $OUT_DIR/${PRD}_CPUs.txt 
  `${CPU_STATS} 2>&1 | grep -v $OS_NAME >> $OUT_DIR/${PRD}_CPUs.txt`

if [ "${ECHO_PKGINFO}" = "Y" ]; then
   echo "$PKGINFO_print ===============================" > $OUT_DIR/${PRD}_OS_Packages.txt   
  echo "${PKGINFO}" >> $OUT_DIR/${PRD}_OS_Packages.txt
else
   echo "$PKGINFO ===============================" > $OUT_DIR/${PRD}_OS_Packages.txt   
   `${PKGINFO} >> $OUT_DIR/${PRD}_OS_Packages.txt 2>&1`
fi
  
DebugMessage="Inside Review_OS, about to do ISM, Get_ISM_Info is $Get_ISM_Info
ISM_Info"
Debug

if [ "$Get_ISM_Info" = "Y" ]; then
   echo "$RDA_html_h31 Intimate Shared Memory (ISM) Usage $RDA_html_h32 <br>"  > $OUT_DIR/${PRD}_ism_info.htm

   echo "$RDA_html_h41 Gathered by Running \"$ISM_Info\" $RDA_html_h42"  >> $OUT_DIR/${PRD}_ism_info.htm
   echo "<PRE>" >> $OUT_DIR/${PRD}_ism_info.htm
   echo  >> $OUT_DIR/${PRD}_ism_info.htm
   $ECHO $ISM_Msg >> $OUT_DIR/${PRD}_ism_info.htm
   echo  >> $OUT_DIR/${PRD}_ism_info.htm
   `$ISM_Info  >> $OUT_DIR/${PRD}_ism_info.htm 2>&1`
   echo "</PRE>" >> $OUT_DIR/${PRD}_ism_info.htm
fi
  
DebugMessage="Inside Review_OS, about to do Physical Memory,
Physical_Memory_Available is $Physical_Memory_Available"
Debug

echo "$RDA_html_h31 Physical Memory Installed $RDA_html_h32 <br>"  > $OUT_DIR/${PRD}_memory_info.htm

if [ "$Physical_Memory_Available" = "Y" ]; then
   echo "$RDA_html_h41 Gathered by Running \"$Physical_Memory_Print\" $RDA_html_h42"  >> $OUT_DIR/${PRD}_memory_info.htm
   echo "<PRE>" >> $OUT_DIR/${PRD}_memory_info.htm
   echo  >> $OUT_DIR/${PRD}_memory_info.htm
   $ECHO "$Physical_Memory" >> $OUT_DIR/${PRD}_memory_info.htm
   echo "</PRE>" >> $OUT_DIR/${PRD}_memory_info.htm
else
   echo $Physical_Memory_Msg >> $OUT_DIR/${PRD}_memory_info.htm
fi

echo "Output from $SYS_ERROR_print ===============================" > $OUT_DIR/${PRD}_system_error_log.txt   
echo "$SYS_ERROR" >> $OUT_DIR/${PRD}_system_error_log.txt
  
if [ -n "$SHOWREV" ]; then
   if [ $OS_NAME = SunOS ]; then
      echo "<HTML><PRE> $SHOWREV ===============================" > $OUT_DIR/${PRD}_OS_Patches.htm   
#  We've run into problems with some Sun patches having long requirement lists
#  causing awk to throw "too many fields" errors.  Since we are just grabbing
#  data from the first 7 fields, limiting the output from showrev to 200 bytes
#  should cover the data need and stop the errors.
      ${SHOWREV} 2>/dev/null | cut -c1-200 | awk '{print $1, "<a  href=http://sunsolve.Sun.COM/pub-cgi/retrieve.pl?patchid="$2"&collection=fpatches&mode=results>"$2"</a>", $4, $5, $6, $7}' >> $OUT_DIR/${PRD}_OS_Patches.htm
   else
      if [ "$ECHO_SHOWREV" = "Y" ]; then
         echo "<HTML><PRE> $SHOWREV_print ===============================" > $OUT_DIR/${PRD}_OS_Patches.htm   
         echo "${SHOWREV}" >> $OUT_DIR/${PRD}_OS_Patches.htm
      else
         echo "<HTML><PRE> $SHOWREV ===============================" > $OUT_DIR/${PRD}_OS_Patches.htm   
         `${SHOWREV} >> $OUT_DIR/${PRD}_OS_Patches.htm`
      fi
   fi
else
   echo "Show revisions not yet implemented" >> $OUT_DIR/${PRD}_OS_Patches.htm
fi

echo "</PRE></HTML>"  >> $OUT_DIR/${PRD}_OS_Patches.htm
  
echo "HOME Directory Hidden Files: " > $OUT_DIR/${PRD}_Profiles.txt
echo "=================================================" >> $OUT_DIR/${PRD}_Profiles.txt
ls -a $HOME | grep "^\." >> $OUT_DIR/${PRD}_Profiles.txt

#  This will process all the OS files related to profile that are requested.
#  The file format is:
#  Section (e.g. OS)
#  Type (e.g. PROFILE - basically the menu level subsection)
#  Relative_to_oh (Y/N, is the directory structure relative to $ORACLE_HOME)
#  Directory (The sub-directory under $O_H or the direct path to the file)
#  File_wanted (the file name being looked for)
#  Display_name (the name that should appear in the left frame for the link)
#  Tail_it (Y/N, should the file be tailed, if N, cat the whole thing)
#  Tail_amount (if it should be tailed, how many lines)
#  Optional (Y/N is the file optional, if not and the file is not found, still
#            create a file with a missing blurb.
#  Partial_file_name (Y/N - Is the name provided the full file name) 
#  Some files may not be required based on questions answered when running
#  setup.sh.  These files need to be skipped if their corresponding product
#  is either not installed or not being analyzed.

# create the variables to hold the file name/link name combinations for later
# building of the left frame
HIDDEN_FILE=""
PROFILE_FILE=""

while read SECTION TYPE RELATIVE_TO_OH DIRECTORY FILE_WANTED DISPLAY_NAME TAIL_IT TAIL_AMOUNT OPTIONAL PARTIAL_FILE_NAME; do
   if [ "$SECTION" = "OS" ]; then
      if [ "$TYPE" = "HIDDEN" ]; then
         Cat_File
      elif
         [ "$TYPE" = "PROFILE" ]; then
         Cat_File
      fi
   fi
done < ./RDA_script_0002_RVW_OS/files.txt

echo "/etc/ conf Files: " > $OUT_DIR/${PRD}_etc_conf.txt
echo "=================================================" >> $OUT_DIR/${PRD}_etc_conf.txt
pr /etc/*.conf >> $OUT_DIR/${PRD}_etc_conf.txt 2>&1

Cleanup_SYSDEF=N
echo "<a name=00></a>" > $OUT_DIR/${PRD}_sysdef.htm
echo "<Center><H3>${RDA_html_font}Output from Platform Dependent System Definition List Command ${RDA_html_end_font}</H3></Center>"  >> $OUT_DIR/${PRD}_sysdef.htm
if [ "$SYSDEF_Extensions" = "Y" ]; then
   echo "<p><a href="#01">Output from $SYSDEF_print</a><br>" >> $OUT_DIR/${PRD}_sysdef.htm
   Ext_Ctr=1
   Ext_Element=0
   Anchor=2
   while [ `print ${#SYSDEF_Extension[*]}` -ge $Ext_Ctr ]
   do
      if [ "`print ${SYSDEF_Extension_Cat[$Ext_Element]}`" = "N" ]; then
         echo "<a href="#0${Anchor}">Output from `print ${SYSDEF_Extension[$Ext_Element]}`</a><br>" >> $OUT_DIR/${PRD}_sysdef.htm
      else
         echo "<a href="#0${Anchor}">Output from `print ${SYSDEF_Extension_Print[$Ext_Element]}`</a><br>" >> $OUT_DIR/${PRD}_sysdef.htm
      fi
      Ext_Element=`expr $Ext_Element + 1`
      Ext_Ctr=`expr $Ext_Ctr + 1`
      Anchor=`expr $Anchor + 1`
   done
   echo "</p>" >> $OUT_DIR/${PRD}_sysdef.htm
fi

echo "<a name=01></a>" >> $OUT_DIR/${PRD}_sysdef.htm
echo "<B>Output from $SYSDEF_print</B>" >> $OUT_DIR/${PRD}_sysdef.htm
echo "<PRE>" >> $OUT_DIR/${PRD}_sysdef.htm
echo "====================================================" >> $OUT_DIR/${PRD}_sysdef.htm
echo "$SYSDEF" >> $OUT_DIR/${PRD}_sysdef.htm
echo "</PRE>" >> $OUT_DIR/${PRD}_sysdef.htm

if [ "$SYSDEF_Extensions" = "Y" ]; then
   echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${PRD}_sysdef.htm
#  We need to do the following since array index entries start at 0.
   Ext_Ctr=1
   Ext_Element=0
   Anchor=2

   while [ `print ${#SYSDEF_Extension[*]}` -ge $Ext_Ctr ]
   do
      Ext=`print ${SYSDEF_Extension[$Ext_Element]}`
      echo "<a name=0${Anchor}></a>" >> $OUT_DIR/${PRD}_sysdef.htm
      echo "<PRE>" >> $OUT_DIR/${PRD}_sysdef.htm
      echo "====================================================" >> $OUT_DIR/${PRD}_sysdef.htm
      if [ "`print ${SYSDEF_Extension_Cat[$Ext_Element]}`" = "Y" ]; then
         echo "<B>Output from `print ${SYSDEF_Extension_Print[$Ext_Element]}`</B>" >> $OUT_DIR/${PRD}_sysdef.htm
         cat $Ext >> $OUT_DIR/${PRD}_sysdef.htm
#  Since we're in here, we know we have a temp file to cleanup, set a flag
         Cleanup_SYSDEF=Y
      else
         echo "<B>Output from `print ${SYSDEF_Extension[$Ext_Element]}`</B>" >> $OUT_DIR/${PRD}_sysdef.htm
         echo "`$Ext`" >> $OUT_DIR/${PRD}_sysdef.htm
      fi
      echo "</PRE>" >> $OUT_DIR/${PRD}_sysdef.htm
      echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${PRD}_sysdef.htm
      Ext_Element=`expr $Ext_Element + 1`
      Ext_Ctr=`expr $Ext_Ctr + 1`
      Anchor=`expr $Anchor + 1`
   done
fi

#  Clean up any files in temp associated with SYSDEF Extensions
if [ "$Cleanup_SYSDEF" = "Y" ]; then
   rm -f $OUT_TMP/SYSDEF* 2>/dev/null
fi
}

RVW_OS_Build_Links ()
{
(
cat << EOF
<ul>
<li>
OS Setup
<table bgcolor="lightblue" width="100%">
<tr><td>
<ul>
<li><a href="${HeaderReport}" target="right_frame">Report Settings</a></li>
<li><a href="${PRD}_Machine.txt" target="right_frame">Machine Configuration</a></li>
<li><a href="${PRD}_oracle_home.htm" target="right_frame">Oracle_Home files</a></li>
EOF
if [ "$Get_ISM_Info" = "Y" ]; then
   echo "<li><a href="${PRD}_ism_info.htm" target="right_frame">Intimate Shared Memory</a></li>"
fi
cat << EOF
<li><a href="${PRD}_memory_info.htm" target="right_frame">Physical Memory Installed</a></li>
<li><a href="${PRD}_CPUs.txt" target="right_frame">CPUs</a></li>
<li><a href="${PRD}_OS_Patches.htm" target="right_frame">OS Patches</a></li>
<li><a href="${PRD}_OS_Packages.txt" target="right_frame">OS Packages</a></li>
<li><a href="${PRD}_system_error_log.txt" target="right_frame">System Error Log</a></li>
EOF
 
if [ -n "$SUSERELEASE" ]; then
   echo "<li><a href=\"${PRD}_suse-release.txt\" target=\"right_frame\">SuSE $OS_NAME Release</a></li>"
fi
if [ -n "$GET_GNU_LIBC" ]; then
   echo "<li><a href=\"${PRD}_libc.txt\" target=\"right_frame\">$OS_NAME GNU Libc</a></li>"
fi

cat << EOF
    <li><a href="${PRD}_nls_env.htm" target="right_frame">NLS Environment Info</a></li>
    <li><a href="${PRD}_java_version.htm" target="right_frame">Java Version</a></li>
    <li><a href="${PRD}_Profiles.txt" target="right_frame">Hidden Files in HOME</a></li>
EOF

#  handle the hidden files of interest that were found.
if [ -n "$HIDDEN_FILE" ]; then
   cat << EOF
   <li>
   Hidden files of Interest in $HOME
   <ul>
EOF

   for h in $HIDDEN_FILE; do
      FILE_NAME=`echo $h|cut -f1 -d#`
      DISPLAY_NAME=`echo $h|cut -f2 -d#`
      echo "<li><a href=\"$FILE_NAME\" target=\"right_frame\">$DISPLAY_NAME</a></li>"
   done
   echo " </ul></li>"
fi

#  handle the profile files of interest that were found.
if [ -n "$PROFILE_FILE" ]; then
   cat << EOF
   <li>
   Profile files of Interest
   <ul>
EOF

   for p in $PROFILE_FILE; do
      FILE_NAME=`echo $p|cut -f1 -d#`
      DISPLAY_NAME=`echo $p|cut -f2 -d#`
      echo "<li><a href=\"$FILE_NAME\" target=\"right_frame\">$DISPLAY_NAME</a></li>"
   done
   echo " </ul></li>"
fi

cat << EOF
    <li><a href="${PRD}_etc_conf.txt" target="right_frame">/etc/*conf Files</a></li>
    <li><a href="${PRD}_etc_hosts.htm" target="right_frame">/etc/hosts...Files</a></li>
    <li><a href="${PRD}_sysdef.htm" target="right_frame">sysdef </a></li>
    <li><a href="${LINK_System}"  target="right_frame">Links</a> <a href="${LINK_Patches}" target="_new">(patches)</a>  <a href="${LINK_Doc}"target="_new">(docs)</a></li>
    </ul>
    </td></tr>
    </table>
    </li>
EOF
) > $OUT_TMP/rvw_os_left_frame.$$
echo "$OUT_TMP/rvw_os_left_frame.$$" >> $OUT_TMP/output_frames.txt.$$
}

########################################
#  Execute the functions defined here  #
########################################
Review_OS
RVW_OS_Build_Links
