Test=`env|grep RDA_Program_Version`

##  The previous line MUST be the first line in the script.  If not, the check
##  for determining if this is called or started straight from command line
##  will not work (it will throw errors back to the screen).

if [ -z "$Test" ]; then
   echo "This script cannot be run standalone"
   echo "It must be called from the main RDA rda.sh"
   echo "Exiting from rda.sh"
   exit
fi
###########################################################################
##    Name: rda.sh                                Version: 3.08
##      By: Oracle Corp.                    Last Modified: July 23, 2002
##                                                Written: 2/19/02  
##
## Purpose: This is the source script for handling the gathering of operating
##          system information (e.g. cpu, I/O, memory, disk configuration,
##          processes, etc.).  This is not intended to be a standalone script,
##          it should be sourced from an executable script.
##
##   Usage: Source from a script
##             . ./RDA_script_0003_RVW_PERF/rda.sh
##
###########################################################################

##############################################################################
##  Modifications Section:
##############################################################################
##     Date        Author     Function       Changes
##############################################################################
##    3.08                                   Cleaned up HTML tagging that had
##                                           caused display probs in some
##                                           browsers (issue 172).
##                                           Added some redirects of stderr
##                                           for IOSTAT, Memory_Stats and
##                                           CPU_STATS when commands not found
##                                           or cause problems.
##                            RVW_Perf_Build_Links
##                                           Chgd bg color for left frame links.
##  06/19/2002     fkobylan   Review_Performance
##    3.06                                   Chgd processing for TOP.  Can't
##                                           guarantee AIX version of TOP
##                                           (it would be customer whim freeware
##                                           from anywhere).  Not going to allow
##                                           top on AIX.
##  05/20/2002     fkobylan                  No chgs, just keeping versions in
##    3.04                                   sync.
##  04/09/2002     fkobylan                  Removed more apps related code.
##    3.02                                   Split out commands so that they
##                                           can be diagnosed individually in
##                                           case of hangs/errors/issues.
##  02/19/2002     fkobylan                  created 
##                                           based on code from original rda.sh.
#############################################################################

#############################################################################
##   Program Explanation:
##   ===================
##   The script is not intended to be a stand alone program.  Its function
##   is to handle the operating system performance information gathering and
##   display for the RDA process.  It will execute commands determined by the 
##   SETUP_OS function, formatting the output into files for display through
##   a web browser.
#############################################################################

##################################
### Start of Review_Performance Function ###
##################################

Review_Performance ()
{
## Procedure Name: Review_Performance
################################################################

TOP_PROGRAM=`echo "$TOP"| awk '{print $1}'`
if [ "$Top_on_Platform" = "Y" ]; then
   if [ -x $TOP_PROGRAM ];then
      `$TOP > $OUT_TMP/top$$ 2>&1`
   else
      `echo "The $TOP program was either not available or not executable" > $OUT_TMP/top$$`
   fi
else
   `echo "The top program is generally not available on this platform" > $OUT_TMP/top$$`
fi

NumUsers=`who | grep -v grep | wc | awk '{print $1}'`
TotalProcesses=`$PS_EF | grep -v grep | wc | awk '{print $1}'`
OracleProcesses=`$PS_EF | grep oracle | grep -v grep | wc | awk '{print $1}'`
ListenerProcesses=`$PS_EF | grep tnslsn | grep -v grep | wc | awk '{print $1}'`
BackgroundProcesses=`$PS_EF | grep "DESCRIPTION="| grep -v grep | wc | awk '{print $1}'`
RootProcesses=`$PS_EF | grep root | grep -v grep | wc | awk '{print $1}'`

echo "<HTML>
<B> Uptime - 5 10 15 Minute Load: </B>
<PRE>
    `uptime`
</PRE>

<B><H2>  Process Overview</H2></B> 
<PRE>
           Oracle: $OracleProcesses          Background: $BackgroundProcesses  
        Listeners: $ListenerProcesses 
             Root: $RootProcesses          Number Users: $NumUsers  
<B>  Total Processes: </B>$TotalProcesses" >> $OUT_DIR/${PRD}_perf_over.htm

echo "
<B> Databases Running: (Note: the CPU Usage in Minutes) </B>
`$PS_EF | head -n 1`
`$PS_EF | grep pmon | grep -v grep | sort -n -r +7`
" >> $OUT_DIR/${PRD}_perf_over.htm

echo "
<B> Who is logged on:</B>
`who | sort`
" >> $OUT_DIR/${PRD}_perf_over.htm

echo "
<B> Current CPU HOGS: (top 15 by CPU time)</B>
`$PS_EF | head -n 1`
`$PS_EF | sort -n -r +7 | head -15`
" >> $OUT_DIR/${PRD}_perf_over.htm

echo "
<B>Current TOP 10 CPU by % CPU (via $UCB_PS)</B>
`$UCB_PS | head -11` 
" >> $OUT_DIR/${PRD}_perf_over.htm

echo "
<B> root  CPU Hogs </B>
`$PS_EF | head -n 1`
`$PS_EF | grep root | grep -v grep | grep -v ckunix | sort -n -r +7 | head -5`
</PRE>
" >> $OUT_DIR/${PRD}_perf_over.htm

echo "
<B><H2> Disk Related </H2></B>
<B><H2>File System Free Space in KB</H2></B>
<PRE>
      `df -k |  awk '{printf \"%-35s %-9s %-9s %-9s %-9s %-6s\n\",$1,$2,$3,$4,$5,$6}'`
" >> $OUT_DIR/${PRD}_perf_over.htm

echo "
<B>throughput MB/sec, transfers/sec, avg service time milliseconds("$IOSTAT_M")</B>
`$IOSTAT_M 2>&1` 
" >> $OUT_DIR/${PRD}_perf_over.htm

echo "
<I>Current Disks (see iostat -E) run 7200rpm @@100 random I/O /sec or 500 sequential/sec</I>
<I>100 I/O per sec imples seek time 10 ms since most access is seek time</I>
<I>Disks on PC capable of sustaned 8-16 MBit/sec and Unix 32-40 Mbit/sec</I>

<B>throughput KB/sec, transfers/sec, avg service time milliseconds($IOSTAT_d)</B>
`$IOSTAT_d 2>&1`
" >> $OUT_DIR/${PRD}_perf_over.htm

echo "
<B>extended disk statistics("$IOSTAT_xe")</B>
<I>look for disks more than 30 % busy and service times of more than 50ms
iostat -x.b > 30% && iostat -x.svc_t > 50ms == busy disk
look for overloaded scsi bus
iostat -x.w >= 5% == busy scsi bus
striping filesytems and tablespaces over multiple disks and 
controllers can spread i/o over multiple spindles
</I>
`$IOSTAT_xe 2>&1`
" >> $OUT_DIR/${PRD}_perf_over.htm

echo "
<B>disk error reports("$IOSTAT_e")</B>
`$IOSTAT_e 2>&1`
" >> $OUT_DIR/${PRD}_perf_over.htm

echo "
<B>paging activities("$SAR_g_print")</B>" >> $OUT_DIR/${PRD}_perf_over.htm
if [ "$SAR_g_EXEC" = "Y" ]; then
   echo "$SAR_g" >> $OUT_DIR/${PRD}_perf_over.htm
else
    echo $NO_SAR_g_MSG >> $OUT_DIR/${PRD}_perf_over.htm
fi

echo "
<B>swap activities("$SWAP_l" & "$SWAP_s")</B>
`$SWAP_l`
`$SWAP_s`
</PRE>
" >> $OUT_DIR/${PRD}_perf_over.htm

echo "
<B><H2>CPU Overview</H2></B>
<PRE>
<B> General CPU Information($CPU_INFO_print) </B>
`echo "$CPU_INFO"`
" >> $OUT_DIR/${PRD}_perf_over.htm

echo "
<B> CPU per-processor statistics($CPU_STATS) </B>
`$CPU_STATS 2>&1`
" >> $OUT_DIR/${PRD}_perf_over.htm

echo "
<B> Sar CPU Usage("$SAR_u_print") </B>" >> $OUT_DIR/${PRD}_perf_over.htm
if [ "$SAR_EXEC" = "Y" ]; then
   echo "$SAR_u" >> $OUT_DIR/${PRD}_perf_over.htm 
elif
  [ "$SAR_u_EXEC" = "Y" ]; then
   echo "$SAR_u" >> $OUT_DIR/${PRD}_perf_over.htm 
else
   echo $NO_SAR_u_MSG >> $OUT_DIR/${PRD}_perf_over.htm 
fi

echo "

<B> Top Report Usage: </B>
`cat $OUT_TMP/top$$`

" >> $OUT_DIR/${PRD}_perf_over.htm

rm -f $OUT_TMP/top$$ 2>/dev/null
 
echo "
<B>system calls("$SAR_c_print")</B>
" >> $OUT_DIR/${PRD}_perf_over.htm

if [ "$SAR_EXEC" = "Y" ]; then
   echo "$SAR_c" >> $OUT_DIR/${PRD}_perf_over.htm 
else
   echo $NO_SAR_c_MSG >> $OUT_DIR/${PRD}_perf_over.htm 
fi

echo "
</PRE>
<B><H2> Memory Statistics("$Memory_Stats")</H2></B>
<PRE>
 `$Memory_Stats 2>&1`

<B> message and semaphore("$SAR_m_print")</B>
" >> $OUT_DIR/${PRD}_perf_over.htm
if [ "$SAR_EXEC" = "Y" ]; then
   echo "$SAR_m" >> $OUT_DIR/${PRD}_perf_over.htm 
else
   echo $NO_SAR_m_MSG >> $OUT_DIR/${PRD}_perf_over.htm 
fi

echo "</PRE></HTML>" >> $OUT_DIR/${PRD}_perf_over.htm


if [ "$DATABASE_INSTALLED" = "Y" ]; then
   #     Get session/status/latch/wait-event information
   #     Get the top 10 SQL statements in the SQL area
   ## Top 10 SQL:
   ##
   SQL="$RDA_sqlset2
   prompt $RDA_html_h31 Top Resource SQL Statements $RDA_html_h32
   prompt $RDA_html_font SQL in Shared Pool with High Disk Reads to Executions Ratio $RDA_html_font_end<br>
   prompt $RDA_html_font SQL Where: (disk_reads/executions)/50 > 100 $RDA_html_font_end<br>
   prompt $RDA_html_font     Order: by executions DESC $RDA_html_font_end<br>
   prompt $RDA_html_tab1
   prompt $RDA_html_tdh1 SQL Text $RDA_html_tdh2
   prompt $RDA_html_tdh1 Executions $RDA_html_tdh2
   prompt $RDA_html_tdh1 Expected Response Time (in Seconds) $RDA_html_tdh2

   SELECT '<TR>' || $RDA_html_td1 || sql_text || $RDA_html_td2,
          $RDA_html_td1 || executions || $RDA_html_td2,
          $RDA_html_td1 || disk_reads / decode(executions,0,1, executions) / 50|| $RDA_html_td2 || '</TR>'
   FROM V\$sqlarea
   where  disk_reads / decode(executions,0,1, executions) / 50 > 100
   order  by executions desc;
   prompt </TABLE>

   prompt <br>
   prompt $RDA_html_font SQL in Shared Pool with High Buffer Gets to Executions Ratio $RDA_html_font_end<br>
   prompt $RDA_html_font SQL Where: (buffer_gets/executions)/500 > 100 $RDA_html_font_end<br>
   prompt $RDA_html_font     Order: by executions DESC $RDA_html_font_end<br>
   prompt $RDA_html_tab1
   prompt $RDA_html_tdh1 SQL Text $RDA_html_tdh2
   prompt $RDA_html_tdh1 Executions $RDA_html_tdh2
   prompt $RDA_html_tdh1 Expected Response Time (in Seconds) $RDA_html_tdh2

   SELECT '<TR>' || $RDA_html_td1 || sql_text || $RDA_html_td2,
          $RDA_html_td1 || executions || $RDA_html_td2,
          $RDA_html_td1 || buffer_gets / decode(executions,0,1, executions) / 500 || $RDA_html_td2 || '</TR>'
   FROM V\$sqlarea
   where  buffer_gets / decode(executions,0,1, executions) / 500 > 100
   order  by executions desc;
   prompt </TABLE>

   prompt <br>
   prompt $RDA_html_font SQL Where: in Shared Pool with > 15 Loads $RDA_html_font_end<br>
   prompt $RDA_html_font     Order: by loads DESC $RDA_html_font_end<br>
   prompt $RDA_html_tab1
   prompt $RDA_html_tdh1 SQL Text $RDA_html_tdh2
   prompt $RDA_html_tdh1 Executions $RDA_html_tdh2
   prompt $RDA_html_tdh1 Expected Response Time (in Seconds) $RDA_html_tdh2

   SELECT '<TR>' || $RDA_html_td1 || sql_text || $RDA_html_td2,
          $RDA_html_td1 || loads || $RDA_html_td2 || '</TR>'
   FROM V\$sqlarea
   where  loads >15
   order  by loads desc;
   prompt </TABLE>"

   Run_SQL
   cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_top_sql.htm

fi

}

RVW_Perf_Build_Links ()
{
(
cat << EOF
<li>
Performance
<table bgcolor="lightblue"  width="100%">
<tr><td>
<ul>
<li><a href="${PRD}_perf_over.htm" target="right_frame">Overview</a></li>
EOF
if [ "$DATABASE_INSTALLED" = "Y" ]; then
   echo "<li><a href="${PRD}_top_sql.htm" target="right_frame">Top SQL</a></li>"
fi
cat << EOF
    </ul>
    </td></tr>
    </table>
    </li>
EOF
) > $OUT_TMP/perf_left_frame.$$
echo "$OUT_TMP/perf_left_frame.$$" >> $OUT_TMP/output_frames.txt.$$
}

########################################
#  Execute the functions defined here  #
########################################
Review_Performance
RVW_Perf_Build_Links
