Test=`env|grep RDA_Program_Version`

##  The previous line MUST be the first line in the script.  If not, the check
##  for determining if this is called or started straight from command line
##  will not work (it will throw errors back to the screen).

if [ -z "$Test" ]; then
   echo "This script cannot be run standalone"
   echo "It must be called from the main RDA rda.sh"
   echo "Exiting from rda.sh"
   exit
fi
###########################################################################
##    Name: rda.sh                                Version: 3.10
##      By: Oracle Corp.                    Last Modified: November 08, 2002
##                                                Written: 2/19/02  
##
## Purpose: This is the source script for handling the gathering of network
##          information (e.g. Listener status, network statistics, kernel   
##          params, etc.).  This is not intended to be a standalone script,
##          it should be sourced from an executable script.
##
##   Usage: Source from a script
##             . ./RDA_script_0004_RVW_NETWORK/rda.sh
##
###########################################################################

##############################################################################
##  Modifications Section:
##############################################################################
##     Date        Author     Function       Changes
##############################################################################
##  11/08/2002     fkobylan   Review_Network Removed duplicate references to
##    V3.10                                  domain name and ifconfig.
##                                           Added code for to display UDP
##                                           settings.
##                            Rvw_Network_Build_Links
##                                           Removed link builds for files 
##                                           moved to separate modules.
##                                           Added code for to display UDP
##                                           settings.
##  09/02/2002     fkobylan   Review_Network Removed references to TWO_TASK.
##    V3.09                                  Added output from O_H/bin/adapters
##                                           command.
##                                           Added anchors/links to Environment,
##                                           Performance and etc files.
##                            Rvw_Network_Build_Links
##                                           Added link for adapters output.
##  08/30/2002     fkobylan   Cat_SQLNET     Chgd some of the HTML tagging that
##    V3.08                                  caused probs in certain browers
##                                           (issue 172).
##                            Review_Network Moved processing of IA, OID, OMS 
##                                           and EMail Server to their own
##                                           modules (issue 86).
##                                           Chgd file name for source of config
##                                           files to gather.
##                                           Added new method of processing tcp
##                                           config parms to handle Linux
##                                           correctly (issue 163).
##                                           Added code to create links/anchors
##                                           for each of the listener processes
##                                           being reported on.
##                            Cat_SQLNET     Moved code to common module.
##                            Use_lsnrctl    Moved code to common module.
##  05/20/2002     fkobylan   Review_Network No chgs, just keeping versions in
##    V3.04                                  sync.
##  04/20/2002     fkobylan   Review_Network Minor cosmetic chgs to make display
##    V3.02                                  of listener status progress more 
##                                           readable.
##  03/27/2002     fkobylan   Get_non_SQLNET Moved code to common module.
##    V3.01                   Review_Network Chgd to call Cat_File instead of
##                                           Get_non_SQLNET after move of
##                                           function to common module.
##                                           Chgd listing of /etc/*.ora files
##                                           to no longer sort (112).
##                            Cat_SQLNET     Added search of $O_H/bin for
##                                           the files.
##  02/19/2002     fkobylan                  created 
##                                           based on code from original rda.sh.
#############################################################################

#############################################################################
##   Program Explanation:
##   ===================
##   The script is not intended to be a stand alone program.  Its function
##   is to handle the network information gathering and display for the RDA
##   RDA process.  It will execute commands determined by the SETUP_OS
##   function, formatting the output into files for display through a web
##   browser.
#############################################################################

##################################
### Start of Review_Network Function ###
##################################
Review_Network ()
{
## Procedure Name: Review_Network
################################################################
## This is a general Networking Module to collect all the General
## Oracle Related Networking files and configurations.
##
##   Note: This module will be used with many scripts.
#################################################################

if [ "$NETWORK_PING_TESTS" = "Y" ]; then
   echo "${BOLD}Processing: Networking Information (pings, network files, SQL*Net files)...${OFF}"
   echo "${BOLD}Listener and Network checks may take a few minutes.  Please be patient...${OFF}"
else
   echo "${BOLD}Processing: Networking Information (network files, SQL*Net files)...${OFF}"
   echo "${BOLD}Listener checks may take a few minutes.  Please be patient...${OFF}"
fi

DebugMessage=" Inside Review_Network, running ifconfig"
Debug

echo "<H4>Output from $IFCONFIG_a_print </H4>"  > $OUT_DIR/${PRD}_ifconfig.htm
echo "<PRE>"  >> $OUT_DIR/${PRD}_ifconfig.htm
echo ""  >> $OUT_DIR/${PRD}_ifconfig.htm

echo "$IFCONFIG_a" >> $OUT_DIR/${PRD}_ifconfig.htm
echo "</PRE>"  >> $OUT_DIR/${PRD}_ifconfig.htm

DebugMessage=" Inside Review_Network, getting tcpip settings
 USE_NDD = $USE_NDD
 NET_TUNING = $NET_TUNING
 NET_TUNING_Cat = $NET_TUNING_Cat"
Debug

if [ "$NET_TUNING_Cat" = "Y" ]; then
   echo "<H4> tcp/ip settings gathered from file contents of $NET_TUNING </H4>" > $OUT_DIR/${PRD}_tcpip_settings.htm
   echo "<PRE>"  >> $OUT_DIR/${PRD}_tcpip_settings.htm
#  Get the file names to cat
   NET_TUNING_Files=`$NET_TUNING`
#  Cycle thru the filenames, cat them out along with the file name to denote
#  which parm it is.
   for n in $NET_TUNING_Files
   do
      TCP_Value=`cat $n`
      TCP_Parm_Name=`basename $n`
      echo "$TCP_Parm_Name = $TCP_Value" >> $OUT_DIR/${PRD}_tcpip_settings.htm
   done
else
   echo "<H4> tcp/ip settings gathered using $NET_TUNING </H4>" > $OUT_DIR/${PRD}_tcpip_settings.htm
   echo "<PRE>"  >> $OUT_DIR/${PRD}_tcpip_settings.htm
   if [ $USE_NDD = "N" ]; then
      echo ""  >> $OUT_DIR/${PRD}_tcpip_settings.htm
      echo "`$NET_TUNING`" | grep -v tcpstatus | grep -v tcp_bind_hash | grep -v tcp_listen_hash | grep -v tcp_queue_hash >> $OUT_DIR/${PRD}_tcpip_settings.htm
   else
      echo "Note: See the actual value settings after the Permissions (read/read write overview)"  >> $OUT_DIR/${PRD}_tcpip_settings.htm
      echo    "     TEST They will be listed in Name=Value pairs."  >> $OUT_DIR/${PRD}_tcpip_settings.htm

      echo ""  >> $OUT_DIR/${PRD}_tcpip_settings.htm
	
      for i in `ndd /dev/tcp \? | awk '{print $1}'`
      do
         echo "$i=\c " >> $OUT_DIR/${PRD}_tcpip_settings.htm
         SKIP_THESE="tcp_status tcp_bind_hash tcp_listen_hash tcp_queue_hash"
         RUN=YES
         for j in $SKIP_THESE
         do
            if [ "$j" = "$i" ];then
               RUN=NO
               break
            fi
         done
         if [ "$RUN" = "YES" ];then
            ndd -get /dev/tcp $i >> $OUT_DIR/${PRD}_tcpip_settings.htm
         fi
      done
   fi
fi
echo "</PRE>"  >> $OUT_DIR/${PRD}_tcpip_settings.htm

DebugMessage=" Inside Review_Network, getting udp settings
 USE_NDD_UDP = $USE_NDD_UDP
 UDP_TUNING_Err = $UDP_TUNING_Err
 UDP_TUNING_Err_Msg = $UDP_TUNING_Err_Msg
 UDP_TUNING = $UDP_TUNING
 UDP_TUNING_Not_Implemented = $UDP_TUNING_Not_Implemented
 UDP_TUNING_Cat_One_File = $UDP_TUNING_Cat_One_File
 UDP_TUNING_File_Name = $UDP_TUNING_File_Name
 UDP_TUNING_Cat = $UDP_TUNING_Cat"
Debug

if [ "$UDP_TUNING_Not_Implemented" = "N" ]; then
   if [ "$UDP_TUNING_Err" = "Y" ]; then
      echo "<Center><H4>${RDA_html_font}udp settings gathered from file contents of $UDP_TUNING${RDA_html_end_font}</H4></Center>" > $OUT_DIR/${PRD}_udp_settings.htm
      echo "<PRE>"  >> $OUT_DIR/${PRD}_udp_settings.htm
      $ECHO "$UDP_TUNING_Err_Msg" >> $OUT_DIR/${PRD}_udp_settings.htm
   else
      if [ "$UDP_TUNING_Cat_One_File" = "Y" ]; then
         echo "<Center><H4>${RDA_html_font}udp settings gathered from output of $UDP_TUNING${RDA_html_end_font}</H4></Center>" > $OUT_DIR/${PRD}_udp_settings.htm
         cat $UDP_TUNING_File_Name >> $OUT_DIR/${PRD}_udp_settings.htm
         if [ "$DebugMode" = "n" ]; then
            rm $UDP_TUNING_File_Name
         fi
      else
         if [ "$UDP_TUNING_Cat" = "Y" ]; then
            echo "<Center><H4>${RDA_html_font}udp settings gathered from file contents of $UDP_TUNING${RDA_html_end_font}</H4></Center>" > $OUT_DIR/${PRD}_udp_settings.htm
            echo "<PRE>"  >> $OUT_DIR/${PRD}_udp_settings.htm
#  Get the file names to cat
            UDP_TUNING_Files=`$UDP_TUNING`
#  Cycle thru the filenames, cat them out along with the file name to denote
#  which parm it is.
            for n in $UDP_TUNING_Files
            do
               UDP_Value=`cat $n`
               UDP_Parm_Name=`basename $n`
               echo "$UDP_Parm_Name = $UDP_Value" >> $OUT_DIR/${PRD}_udp_settings.htm
            done
         else
            echo "<Center><H4>${RDA_html_font}udp settings gathered using $UDP_TUNING${RDA_html_end_font}</H4></Center>" > $OUT_DIR/${PRD}_udp_settings.htm
            echo "<PRE>"  >> $OUT_DIR/${PRD}_udp_settings.htm
            if [ $USE_NDD_UDP = "N" ]; then
               echo ""  >> $OUT_DIR/${PRD}_udp_settings.htm
               echo "`$UDP_TUNING`" | grep -v tcpstatus | grep -v tcp_bind_hash | grep -v tcp_listen_hash | grep -v tcp_queue_hash >> $OUT_DIR/${PRD}_udp_settings.htm
            else
               echo "Note: See the actual value settings after the Permissions (read/read write overview)"  >> $OUT_DIR/${PRD}_udp_settings.htm
               echo    "     TEST They will be listed in Name=Value pairs."  >> $OUT_DIR/${PRD}_udp_settings.htm

               echo ""  >> $OUT_DIR/${PRD}_udp_settings.htm
	
               for i in `ndd /dev/udp \? | awk '{print $1}'`
               do
                  echo "$i=\c " >> $OUT_DIR/${PRD}_udp_settings.htm
                  ndd -get /dev/udp $i >> $OUT_DIR/${PRD}_udp_settings.htm
               done
            fi
         fi
      fi
   fi
   echo "</PRE>"  >> $OUT_DIR/${PRD}_udp_settings.htm
fi

#  Execute $O_H/bin/adapters command

echo "<Center><H3>${RDA_html_font}Output from adapters in \$ORACLE_HOME/bin${RDA_html_end_font}</H3></Center>" > $OUT_DIR/${PRD}_adapters.htm
echo "<a name=00></a>" >> $OUT_DIR/${PRD}_adapters.htm
if [ -x "$ORACLE_HOME/bin/adapters" ]; then
   DebugMessage=" Inside Review_Network, about to run adapters command"
   Debug
   echo >> $OUT_DIR/${PRD}_adapters.htm
   echo "<p><a href="#01">Installed Protocol adapters (adapters command run without argument) </a><br>" >> $OUT_DIR/${PRD}_adapters.htm
   echo "<a href="#02">Protocol adapters for oracle executable</a></p><br>" >> $OUT_DIR/${PRD}_adapters.htm
   echo "<a name=01></a>" >> $OUT_DIR/${PRD}_adapters.htm
   echo "<B>${RDA_html_font}Listing of Installed Protocol Adapters${RDA_html_end_font}</B>" >> $OUT_DIR/${PRD}_adapters.htm
   echo "<PRE>" >> $OUT_DIR/${PRD}_adapters.htm
   $ORACLE_HOME/bin/adapters >> $OUT_DIR/${PRD}_adapters.htm 2>&1
   echo "</PRE>" >> $OUT_DIR/${PRD}_adapters.htm
   echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${PRD}_adapters.htm
   echo "<a name=02></a>" >> $OUT_DIR/${PRD}_adapters.htm
   echo "<B>${RDA_html_font}Listing of Protocol Adapters Linked into oracle Executable${RDA_html_end_font}</B>" >> $OUT_DIR/${PRD}_adapters.htm
   echo "<PRE>" >> $OUT_DIR/${PRD}_adapters.htm
   $ORACLE_HOME/bin/adapters $ORACLE_HOME/bin/oracle >> $OUT_DIR/${PRD}_adapters.htm 2>&1
   echo "</PRE>" >> $OUT_DIR/${PRD}_adapters.htm
   echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${PRD}_adapters.htm
else
   DebugMessage=" Inside Review_Network, adapters command not executable"
   Debug
   echo "<BR><P>$ORACLE_HOME/bin/adapters not executable" >> $OUT_DIR/${PRD}_adapters.htm
   echo "Permissions for $ORACLE_HOME/bin/adapters are:</P><BR>" >> $OUT_DIR/${PRD}_adapters.htm
   echo "<PRE>" >> $OUT_DIR/${PRD}_adapters.htm
   ls -al $ORACLE_HOME/bin/adapters >> $OUT_DIR/${PRD}_adapters.htm 2>&1
   echo "</PRE>" >> $OUT_DIR/${PRD}_adapters.htm
fi
   

# Network Settings...
# Checking where the networking setup files for SQL*NET are located::
 
if [ -z "$TNS_ADMIN" ]; then
   NET_HOME=$ORACLE_HOME/network/admin
else
   NET_HOME=$TNS_ADMIN
fi

#  This will process all the network files that are requested.  Some of the
#  sqlnet files can reside in multiple well known locations so they are handled
#  separately.  The function will determine if the file should be processed.
#  The file format is:
#  Section (e.g. NETWORK, WAS, OAS, iAS, etc)
#  Type (e.g. AGENT, SQLNET, OMS, OID - basically the menu level subsection)
#  Relative_to_oh (Y/N, is the directory structure relative to $ORACLE_HOME)
#  Directory (The sub-directory under $O_H or the direct path to the file)
#  File_wanted (the file name being looked for)
#  Display_name (the name that should appear in the left frame for the link)
#  Tail_it (Y/N, should the file be tailed, if N, cat the whole thing)
#  Tail_amount (if it should be tailed, how many lines)
#  Optional (Y/N is the file optional, if not and the file is not found, still
#            create a file with a missing blurb.)
#  Partial_File_Name (Y/N is the name name provided only a partial file name
#            to cause searching for all files like this name.)
#  Some files may not be required based on questions answered when running
#  setup.sh.  These files need to be skipped if their corresponding product
#  is either not installed or not being analyzed.

# create the variables to hold the file name/link name combinations for later
# building of the left frame
NAMES_FILE=""
SQLNET_FILE=""
HS_FILE=""

while read SECTION TYPE RELATIVE_TO_OH DIRECTORY FILE_WANTED DISPLAY_NAME TAIL_IT TAIL_AMOUNT OPTIONAL PARTIAL_FILE_NAME; do
   if [ "$TYPE" = "SQLNET" -a "$DIRECTORY" = "SEARCH" ]; then
      Cat_SQLNET
   else
      Cat_File
   fi
done < ./RDA_script_0004_RVW_NETWORK/files.txt

#  Need to do some different stuff here.  Output from AIX ps, the listener name
#  is in a different spot, so we need to changed the print command accordingly.
#  On Linux, ps elf must be used to get the listener name (short listing doesn't
#  provide the extra output).  Only way to do it here is by a platform check.
#  It is possible that more than one listener can be started with the same name
#  potentially using a different $O_H.  Since we can't query them individually
#  using the lsnrctl that started them (we only use the PATH setup in the env 
#  when this script is started), we will sort unique on the listener name to
#  only query the status of each once.

DebugMessage=" Inside Review_Network, looking for running listeners
 LISTENER_FOUND_IN = $LISTENER_FOUND_IN"
Debug

#  Check to see if ps -o works on the platform.  If it does, use it to get
#  the listener name, otherwise, default to the old way.  We need the argument
#  on the end of the command, otherwise it will error and we won't use it.

$PS_O comm > /dev/null 2>&1
if [ $? -eq 0 ]; then
   DebugMessage=" Inside Review_Network, using ps -o to find listener name
    PS_O = $PS_O"
   Debug
   Listeners=`$PS_O comm,args|grep -v grep|grep tnslsnr|awk '{print $3}'|sort -u`
else
   if [ $OS_NAME = "Linux" ]; then
      DebugMessage=" Inside Review_Network, using ps -elf to find listener name
       PS_ELF = $PS_ELF"
      Debug
      if [ -n "$SUSERELEASE" ]; then
         Listeners=`$PS_ELF | grep -v grep |grep tnslsnr | grep inherit | cut -c40- | awk '{print $7}' | sort -u`
      else
         Listeners=`$PS_ELF | grep -v grep |grep tnslsnr | grep inherit | cut -c40- | awk '{print $8}' | sort -u`
      fi
   else
      DebugMessage=" Inside Review_Network, using ps -ef to find listener name
       PS_EF = $PS_EF"
      Debug
      if [ $LISTENER_FOUND_IN -eq 4 ]; then
         Listeners=`$PS_EF | grep -v grep |grep tnslsnr | cut -c40- | awk '{print $4}' | sort -u`
      else
         Listeners=`$PS_EF | grep -v grep |grep tnslsnr | cut -c43- | awk '{print $3}' | sort -u`
      fi
   fi
fi

#  Need to loop thru all the listeners named ... can find here:

DebugMessage=" Inside Review_Network, going to get the listener status
 Listeners = $Listeners"
Debug

Lsnrctl_File=${PRD}_lstatus.htm
echo "<a name=00></a>" > $OUT_DIR/${Lsnrctl_File}
echo "<Center><H3>${RDA_html_font}Listener Status, Log and Services Information ${RDA_html_end_font}</H3></Center>" >> $OUT_DIR/${Lsnrctl_File}

echo "<P><B>Are the listeners running?<br>"  >> $OUT_DIR/${Lsnrctl_File}
echo "If no info appears, either there are no listeners running<br>" >> $OUT_DIR/${Lsnrctl_File}
echo "or there are no listeners running from $ORACLE_HOME/bin</B></P>" >> $OUT_DIR/${Lsnrctl_File}

#  Build the links at the top to locate each listener
Lsnr_Ctr=1
echo "<P>" >> $OUT_DIR/${Lsnrctl_File}
for list_of in $Listeners
do
   echo "<a href="#${Lsnr_Ctr}">Data for Listener $list_of</a><br>" >> $OUT_DIR/${Lsnrctl_File}
   Lsnr_Ctr=`expr $Lsnr_Ctr + 1`
done
echo "</P>" >> $OUT_DIR/${Lsnrctl_File}

Lsnr_Ctr=1
for list_of in $Listeners
do
   echo "<a name=${Lsnr_Ctr}></a>" >> $OUT_DIR/${Lsnrctl_File}
   echo "<P>" >> $OUT_DIR/${Lsnrctl_File}
   echo "===================================================================<BR>" >> $OUT_DIR/${Lsnrctl_File}
   echo  "<B>Status for: $list_of</B><BR>" >> $OUT_DIR/${Lsnrctl_File}
   echo "===================================================================<BR>" >> $OUT_DIR/${Lsnrctl_File}
   echo "</P>" >> $OUT_DIR/${Lsnrctl_File}
   echo "<PRE>" >> $OUT_DIR/${Lsnrctl_File}
  

   DebugMessage=" Inside Review_Network, getting the listener status
    list_of = $list_of"
   Debug

#  It's possible to run into problems with lsnrctl status hanging, causing the
#  script to hang.  Rather than allowing this to happen, the status request
#  will be fired off in a background forked process.  Since the status request
#  should be very short by nature, we will sleep for 30 seconds and check the
#  job status.  If a return other than zero is encountered, we will assume it
#  is the status job still running and kill the process.

   echo "  Processing listener status, services and log for listener $list_of"
   LSNR_CMD=status
   GET_LOGS=Y
   Use_lsnrctl &
   Max_Times_to_Try=6
   Hang_Check
   if [ "$Command_Hung" = "Y" ]; then
      echo "Could not get status for listener $list_of" >> $OUT_DIR/${Lsnrctl_File}
      echo "Could not get status for listener $list_of" 
      echo "status check for this listener cancelled" >> $OUT_DIR/${Lsnrctl_File}
      echo "status check for this listener cancelled" 
   fi

   echo "</PRE>"  >> $OUT_DIR/${Lsnrctl_File}
   echo  >> $OUT_DIR/${Lsnrctl_File}

   echo "<P>"  >> $OUT_DIR/${Lsnrctl_File}
   echo "===================================================================<BR>" >> $OUT_DIR/${Lsnrctl_File}
   echo  "<B>Services Info for: $list_of</B><BR>" >> $OUT_DIR/${Lsnrctl_File}
   echo "===================================================================<BR>" >> $OUT_DIR/${Lsnrctl_File}
   echo "</P>"  >> $OUT_DIR/${Lsnrctl_File}
   echo "<PRE>"  >> $OUT_DIR/${Lsnrctl_File}
  

   DebugMessage=" Inside Review_Network, getting the listener services
    list_of = $list_of"
   Debug

   LSNR_CMD=services
   GET_LOGS=N
   Use_lsnrctl &
   Max_Times_to_Try=6
   Hang_Check
   if [ "$Command_Hung" = "Y" ]; then
      echo "Could not get services info for listener $list_of" >> $OUT_DIR/${Lsnrctl_File}
      echo "Could not get services info for listener $list_of" 
      echo "services info check for this listener cancelled" >> $OUT_DIR/${Lsnrctl_File}
      echo "services info check for this listener cancelled" 
   fi

   echo "</PRE>"  >> $OUT_DIR/${Lsnrctl_File}
   echo  >> $OUT_DIR/${Lsnrctl_File}
   echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${Lsnrctl_File}
   Lsnr_Ctr=`expr $Lsnr_Ctr + 1`

done
unset list_of

DebugMessage=" Inside Review_Network, displaying net environment, looking for TNS_ADMIN"
Debug

echo "<H4>Checking to see if TNS_ADMIN is being used</H4>"  > $OUT_DIR/${PRD}_netenv.htm
echo "<PRE>" >> $OUT_DIR/${PRD}_netenv.htm
env | grep TNS_  >> $OUT_DIR/${PRD}_netenv.htm
echo "</PRE>" >> $OUT_DIR/${PRD}_netenv.htm

DebugMessage=" Inside Review_Network, displaying net environment, doing the ls of directories"
Debug

echo "<H4>ls listing of .ora files in the well known locations</H4>"  >> $OUT_DIR/${PRD}_netenv.htm
echo "<PRE>" >> $OUT_DIR/${PRD}_netenv.htm

echo "<B>list of .ora files from /etc</B>" >> $OUT_DIR/${PRD}_netenv.htm
echo >> $OUT_DIR/${PRD}_netenv.htm
ls -al /etc/*.ora >/dev/null 2>/dev/null
if [ $? -eq 0 ]; then
   ls -al /etc/*.ora >> $OUT_DIR/${PRD}_netenv.htm 
else
   echo >> $OUT_DIR/${PRD}_netenv.htm
   echo "there are no .ora files in /etc" >> $OUT_DIR/${PRD}_netenv.htm
fi

echo >> $OUT_DIR/${PRD}_netenv.htm
echo "<B>list of .ora files from /var/opt/oracle</B>" >> $OUT_DIR/${PRD}_netenv.htm
ls -al /var/opt/oracle/*.ora >/dev/null 2>/dev/null
if [ $? -eq 0 ]; then
   ls -al /var/opt/oracle/*.ora | sort >> $OUT_DIR/${PRD}_netenv.htm 
else
   echo "there are no .ora files in /var/opt/oracle" >> $OUT_DIR/${PRD}_netenv.htm
fi

echo >> $OUT_DIR/${PRD}_netenv.htm
echo "<B>List of .ora files from $ORACLE_HOME/network/admin</B>" >> $OUT_DIR/${PRD}_netenv.htm
ls -al $ORACLE_HOME/network/admin/*.ora >/dev/null 2>/dev/null
if [ $? -eq 0 ]; then
   ls -al $ORACLE_HOME/network/admin/*.ora | sort >> $OUT_DIR/${PRD}_netenv.htm
else
   echo "there are no .ora files in $ORACLE_HOME/network/admin" >> $OUT_DIR/${PRD}_netenv.htm
fi

if [ -z "$TNS_ADMIN" ]; then
   true
elif [ "$TNS_ADMIN" = "/etc" -o "$TNS_ADMIN" = "/var/opt/oracle" -o "$TNS_ADMIN" = "$ORACLE_HOME/network/admin" ]; then
   true
else
   echo >> $OUT_DIR/${PRD}_netenv.htm
   echo "<B>list of ora files from $TNS_ADMIN</B>" >> $OUT_DIR/${PRD}_netenv.htm
   ls -al $TNS_ADMIN/*.ora >/dev/null 2>/dev/null
   if [ $? -eq 0 ]; then
      ls -al $TNS_ADMIN/*.ora | sort >> $OUT_DIR/${PRD}_netenv.htm 
   else
      echo "there are no .ora files from $TNS_ADMIN" >> $OUT_DIR/${PRD}_netenv.htm
   fi
fi

echo "</PRE>" >> $OUT_DIR/${PRD}_netenv.htm

DebugMessage=" Inside Review_Network, displaying net environment, looking for tnslsnr processes"
Debug

echo "<H4>Checking for any all tnslsnr PROCESSES: (Look for CPU hogs)</H4>" >> $OUT_DIR/${PRD}_netenv.htm
echo "<PRE>" >> $OUT_DIR/${PRD}_netenv.htm
`$PS_EF | head -n 1 >> $OUT_DIR/${PRD}_netenv.htm`
`$PS_EF | grep tnslsnr |grep -v grep >> $OUT_DIR/${PRD}_netenv.htm`

echo "</PRE>" >> $OUT_DIR/${PRD}_netenv.htm

echo "<H4>Is ORACLE_HOME / SID set:</H4>"  >> $OUT_DIR/${PRD}_netenv.htm
echo "<PRE>" >> $OUT_DIR/${PRD}_netenv.htm
env | grep ORACLE_  >> $OUT_DIR/${PRD}_netenv.htm

echo "</PRE>" >> $OUT_DIR/${PRD}_netenv.htm

DebugMessage=" Inside Review_Network, network performance, about to display Ping results"
Debug

echo "<a name=00></a>" > $OUT_DIR/${PRD}_netperf.htm
echo "<Center><H3>${RDA_html_font}Network Performance${RDA_html_end_font}</H3></Center>" >> $OUT_DIR/${PRD}_netperf.htm

if [ "$NETWORK_PING_TESTS" = "Y" ]; then
   echo "<p><a href="#01">Loopback Ping (to $MACHINE_NAME)</a><br>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "<a href="#02">Ping to Wan Node ($WAN_NODE)</a><br>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "<a href="#03">Ping to RDBMS Server Node ($RDBMS_NODE)</a><br>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "<a href="#04">Ping to Web Server Node ($WEB_NODE)</a><br>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "<a href="#05">Ping to Client PC($CLIENT_NODE)</a><br>" >> $OUT_DIR/${PRD}_netperf.htm
else
   echo "<a href="#01">Network Ping Tests</a><br>" >> $OUT_DIR/${PRD}_netperf.htm
fi
echo "<a href="#06">TNS Listener Processes</a><br>" >> $OUT_DIR/${PRD}_netperf.htm
echo "<a href="#07">Network Connection Report</a><br>" >> $OUT_DIR/${PRD}_netperf.htm
echo "<a href="#08">Contents of /etc/services file</a><br>" >> $OUT_DIR/${PRD}_netperf.htm
echo "<a href="#09">Network Performance Statistics</a></p><br>" >> $OUT_DIR/${PRD}_netperf.htm

echo "<a name=01></a>" >> $OUT_DIR/${PRD}_netperf.htm

if [ "$NETWORK_PING_TESTS" = "Y" ]; then
   echo "<p>=======================================<br>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "<B>Pings Done Using: $Ping_print</B><br>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "=======================================</p><br>" >> $OUT_DIR/${PRD}_netperf.htm


   echo "<B> Ping Report from $MACHINE_NAME (this machine) to $MACHINE_NAME (this machine)</B>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "<PRE>" >> $OUT_DIR/${PRD}_netperf.htm
   Ping=`$Ping_MACHINE_NANE 2>&1`
   echo "$Ping" >> $OUT_DIR/${PRD}_netperf.htm 

   echo "</PRE>" >> $OUT_DIR/${PRD}_netperf.htm

   echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "<a name=02></a>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "<B> Ping Report from $MACHINE_NAME (this machine) to $WAN_NODE (wan)</B>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "<PRE>" >> $OUT_DIR/${PRD}_netperf.htm
   Ping=`$Ping_WAN_NODE 2>&1`
   echo "$Ping" >> $OUT_DIR/${PRD}_netperf.htm 

   echo "</PRE>" >> $OUT_DIR/${PRD}_netperf.htm

   echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "<a name=03></a>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "<B> Ping Report from $MACHINE_NAME (this machine) to $RDBMS_NODE (rdbms)</B>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "<PRE>" >> $OUT_DIR/${PRD}_netperf.htm
   Ping=`$Ping_RDBMS_NODE 2>&1`
   echo "$Ping" >> $OUT_DIR/${PRD}_netperf.htm 

   echo "</PRE>" >> $OUT_DIR/${PRD}_netperf.htm

   echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "<a name=04></a>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "<B> Ping Report from $MACHINE_NAME (this machine) to $WEB_NODE (web)</B>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "<PRE>" >> $OUT_DIR/${PRD}_netperf.htm
   Ping=`$Ping_WEB_NODE 2>&1` 
   echo "$Ping" >> $OUT_DIR/${PRD}_netperf.htm 

   echo "</PRE>" >> $OUT_DIR/${PRD}_netperf.htm

   echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "<a name=05></a>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "<B> Ping Report from $MACHINE_NAME (this machine) to $CLIENT_NODE (client)</B>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "<PRE>" >> $OUT_DIR/${PRD}_netperf.htm
   Ping=`$Ping_CLIENT_NODE 2>&1`
   echo "$Ping" >> $OUT_DIR/${PRD}_netperf.htm 

   echo "</PRE>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${PRD}_netperf.htm
else
   echo "<P><B>###################################<br>"  >> $OUT_DIR/${PRD}_netperf.htm
   echo "#  Ping Tests were not requested  #<br>"  >> $OUT_DIR/${PRD}_netperf.htm
   echo "###################################</B></P>"  >> $OUT_DIR/${PRD}_netperf.htm
   echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${PRD}_netperf.htm
fi

echo "<a name=06></a>" >> $OUT_DIR/${PRD}_netperf.htm
echo "<H4>Are the tns processes running and for what listeners:</H4>" >> $OUT_DIR/${PRD}_netperf.htm
echo "<PRE>" >> $OUT_DIR/${PRD}_netperf.htm
`$PS_EF | head -n 1 >> $OUT_DIR/${PRD}_netperf.htm`
`$PS_EF | grep tnslsnr >> $OUT_DIR/${PRD}_netperf.htm`

echo "</PRE>" >> $OUT_DIR/${PRD}_netperf.htm
echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${PRD}_netperf.htm

echo "<a name=07></a>" >> $OUT_DIR/${PRD}_netperf.htm
Run_Netstat &
Max_Times_to_Try=6
Hang_Check
if [ "$Command_Hung" = "Y" ]; then
   echo "<a name=07></a>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "<H4>Unix netstat</H4> <b>Established Connection Count: </b>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "<PRE>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "There were problems running the netstat command (apparant hang, command took longer than 30 seconds to complete)" >> $OUT_DIR/${PRD}_netperf.htm
   echo "Established connection counts not gathered" >> $OUT_DIR/${PRD}_netperf.htm
   echo >> $OUT_DIR/${PRD}_netperf.htm
   echo "     <B>Waiting Connection Count:</b>  " >> $OUT_DIR/${PRD}_netperf.htm
   echo "There were problems running the netstat command (apparant hang, command took longer than 30 seconds to complete)" >> $OUT_DIR/${PRD}_netperf.htm
   echo "Waiting connections not gathered" >> $OUT_DIR/${PRD}_netperf.htm
   echo "</PRE>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "<B>Established Connection List:</B>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "<PRE>" >> $OUT_DIR/${PRD}_netperf.htm
   echo "There were problems running the netstat command (apparant hang, command took longer than 30 seconds to complete)" >> $OUT_DIR/${PRD}_netperf.htm
   echo "Established connections with state information not gathered" >> $OUT_DIR/${PRD}_netperf.htm
   echo "</PRE>" >> $OUT_DIR/${PRD}_netperf.htm
fi
echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${PRD}_netperf.htm

echo "<a name=08></a>" >> $OUT_DIR/${PRD}_netperf.htm
echo "<H4>Ports Being Used /etc/services</H4>" >> $OUT_DIR/${PRD}_netperf.htm
echo "<PRE>" >> $OUT_DIR/${PRD}_netperf.htm
cat /etc/services >> $OUT_DIR/${PRD}_netperf.htm
echo "</PRE>" >> $OUT_DIR/${PRD}_netperf.htm
echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${PRD}_netperf.htm

echo "<a name=09></a>" >> $OUT_DIR/${PRD}_netperf.htm
echo "<H4>Network Performance - netstat -s:</H4>" >> $OUT_DIR/${PRD}_netperf.htm
echo "<PRE>" >> $OUT_DIR/${PRD}_netperf.htm
netstat -s >> $OUT_DIR/${PRD}_netperf.htm
echo "</PRE>" >> $OUT_DIR/${PRD}_netperf.htm
echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${PRD}_netperf.htm

echo "<H3>Key Files from the /etc Directory: </H3>" > $OUT_DIR/${PRD}_etc_hosts.htm
echo "<PRE>" >> $OUT_DIR/${PRD}_etc_hosts.htm
echo "====================================================" >> $OUT_DIR/${PRD}_etc_hosts.htm
echo "<B>Example: hosts, groups, networks, nodename</B>" >> $OUT_DIR/${PRD}_etc_hosts.htm
echo "====================================================" >> $OUT_DIR/${PRD}_etc_hosts.htm
echo  >> $OUT_DIR/${PRD}_etc_hosts.htm
echo "<B>etc/hosts file</B> " >> $OUT_DIR/${PRD}_etc_hosts.htm
echo "====================================================" >> $OUT_DIR/${PRD}_etc_hosts.htm
  echo "Total Lines: `wc /etc/hosts | awk '{print $1}'`" >> $OUT_DIR/${PRD}_etc_hosts.htm
echo "==TOP 500 LINES=====================================" >> $OUT_DIR/${PRD}_etc_hosts.htm

  head -500 /etc/hosts >> $OUT_DIR/${PRD}_etc_hosts.htm

echo >> $OUT_DIR/${PRD}_etc_hosts.htm
echo "<B>/etc/group file</B>" >> $OUT_DIR/${PRD}_etc_hosts.htm
echo "====================================================" >> $OUT_DIR/${PRD}_etc_hosts.htm
 cat /etc/group >> $OUT_DIR/${PRD}_etc_hosts.htm

echo >> $OUT_DIR/${PRD}_etc_hosts.htm
echo "<B>/etc/nodename file</B>" >> $OUT_DIR/${PRD}_etc_hosts.htm
echo "====================================================" >> $OUT_DIR/${PRD}_etc_hosts.htm

if [ -r /etc/nodename ];then
   cat /etc/nodename >> $OUT_DIR/${PRD}_etc_hosts.htm
else
   echo "Cannot access /etc/nodename on $OS_NAME" >> $OUT_DIR/${PRD}_etc_hosts.htm
fi

echo >> $OUT_DIR/${PRD}_etc_hosts.htm
echo "<B>$NETWORKS file</B>" >> $OUT_DIR/${PRD}_etc_hosts.htm
echo "====================================================" >> $OUT_DIR/${PRD}_etc_hosts.htm
 cat $NETWORKS >> $OUT_DIR/${PRD}_etc_hosts.htm
echo "</PRE>" >> $OUT_DIR/${PRD}_etc_hosts.htm

}

##  We ran into a problem where the netstat command hung on a server.  Rather 
##  than causing confusion should this happen at a customer site, this has now
##  been made into a function to be placed in background and verified by the
##  Hang_Check function.
Run_Netstat ()
{

ESTB=`netstat | grep -c ESTABL`
WAIT=`netstat | grep -c WAIT`
echo "<H4>Unix netstat Data</H4><P><B>Established Connection Count:</B> $ESTB<br>" >> $OUT_DIR/${PRD}_netperf.htm
echo "                 <B>Waiting Connection Count:</B> $WAIT</p>" >> $OUT_DIR/${PRD}_netperf.htm

echo >> $OUT_DIR/${PRD}_netperf.htm

echo "<H4>Established Connection Listing: </H4>" >> $OUT_DIR/${PRD}_netperf.htm
echo "<PRE>" >> $OUT_DIR/${PRD}_netperf.htm
netstat -a | grep ESTABL >> $OUT_DIR/${PRD}_netperf.htm
echo "</PRE>" >> $OUT_DIR/${PRD}_netperf.htm

}

Rvw_Network_Build_Links ()
{
(
cat << EOF
<li>
Network
<table bgcolor="lightblue" width="100%">
<tr><td>
<ul>
<li><a href="${PRD}_ifconfig.htm" target="right_frame">ifconfig</a></li>
<li><a href="${PRD}_tcpip_settings.htm" target="right_frame">tcpip Settings</a></li>
`if [ "$UDP_TUNING_Not_Implemented" = "N" ]; then
echo "<li><a href="${PRD}_udp_settings.htm" target="right_frame">udp Settings</a></li>"
fi`
<li><a href="${PRD}_adapters.htm" target="right_frame">Adapters Output</a></li>
EOF

#  handle the sqlnet files found.  
if [ -n "$SQLNET_FILE" ]; then 
   cat << EOF
   </li>
   <li>
   SQL*Net Config Files
   <ul>
EOF

   for s in $SQLNET_FILE; do
      FILE_NAME=`echo $s|cut -f1 -d#`
      DISPLAY_NAME=`echo $s|cut -f2 -d#`
      echo "<li><a href=\"$FILE_NAME\" target=\"right_frame\">$DISPLAY_NAME</a></li>"
   done
   echo " </ul>"
fi
 
#  handle the Oracle Names files found.  
if [ -n "$NAMES_FILE" ]; then 
   cat << EOF
   </li>
   <li>
   Oracle Names Config Files
   <ul>
EOF

   for n in $NAMES_FILE; do
      FILE_NAME=`echo $n|cut -f1 -d#`
      DISPLAY_NAME=`echo $n|cut -f2 -d#`
      echo "<li><a href=\"$FILE_NAME\" target=\"right_frame\">$DISPLAY_NAME</a></li>"
   done
   echo " </ul>"
fi
 
#  handle the Heterogeneous Services files found.  
if [ -n "$HS_FILE" ]; then 
   cat << EOF
   </li>
   <li>
   Heterogeneous Services Config Files
   <ul>
EOF

   for h in $HS_FILE; do
      FILE_NAME=`echo $h|cut -f1 -d#`
      DISPLAY_NAME=`echo $h|cut -f2 -d#`
      echo "<li><a href=\"$FILE_NAME\" target=\"right_frame\">$DISPLAY_NAME</a></li>"
   done
   echo " </ul>"
fi
 
cat << EOF
</li>
<li><a href="${PRD}_lstatus.htm" target="right_frame">Listener Status and Services</a></li>
<li><a href="${PRD}_netenv.htm" target="right_frame">Environment</a></li>
<li><a href="${PRD}_netperf.htm" target="right_frame">Performance</a></li>
<li><a href="${PRD}_etc_hosts.htm" target="right_frame">/etc/..</a></li>
</ul>
</td></tr>
</table>
</li>
EOF
) > $OUT_TMP/rvw_network_left_frame.$$
echo "$OUT_TMP/rvw_network_left_frame.$$" >> $OUT_TMP/output_frames.txt.$$
}

#########################################
#  Exeucute the functions defined here  #
#########################################
Review_Network
Rvw_Network_Build_Links
