Test=`env|grep Setup_Program_Version`

##  The previous line MUST be the first line in the script.  If not, the check
##  for determining if this is called or started straight from command line
##  will not work (it will throw errors back to the screen).

##############################################################################
###    Name: setup.sh                              Version: 3.09
###      By: Oracle Corp.                    Last Modified: September 05, 2002
###                                                Written: 02/20/2002
### 
### Purpose: Script used to setup the internal variables used for gathering
###          network information as part of the rda process.  It will just
###          be sourced as part of the main setup.sh script.
###
##############################################################################
##  Modifications Section:
##############################################################################
##     Date        Author     Function       Changes
##############################################################################
##  09/05/2002     fkobylan                  Added comments to denote beginning
##    3.09                                   and end of Network variables.
##                                           Chgd to only pull back lines from
##                                           existing setup between beginning
##                                           and end lines found above.
##  07/22/2002     fkobylan                  Removed handling of IA, EMS, OMS
##    3.08                                   and OID (moved to own modules).
##                                           (issue 86). 
##  05/20/2002     fkobylan                  No chgs.  Just matching version to
##    3.04                                   base setup.sh
##  05/06/2002     fkobylan                  No chgs.  Just matching version to
##    3.02                                   base setup.sh
##  02/20/2002     fkobylan                  Created.  Taken from original 
##                                           RDA setup.sh
##############################################################################
###   Program Explanation:
###   ===================
###   This program handles prompting for network parameters during the run of
###   rda.sh.  It can not be run as a standalone script, it will be called 
###   (sourced) by the main setup.sh.
### ###########################################################################
# leave this echo as is.  Since we haven't run the main setup.sh to get here
# $ECHO isn't set and there is no special formatting we have to worry about
# anyway.
if [ -z "$Test" ]; then
   echo "This script cannot be run standalone"
   echo "It must be called from the main RDA setup.sh"
   echo "Exiting from setup.sh"
   exit
fi

Setup_Network_Env ()
{
## Procedure: Setup_Network_Env ()
## Called to setup all the env variables ...
#############################################################################
## Variables Used to Process this script:
#############################################################################

MACHINE1=`uname -n`
MACHINE2=${MACHINE1:=localhost}
Variables_Found=N

if [ "$SETUP_TXT_Found" = "Y" ];then
   Variables_Found=Y
#  The setup.txt should have already been found by the main setup script
#  we just need to know whether to build from scratch or not.

#  Get just the variables that apply to network
   Start_Line=`grep -n 'Beginning of Network Variables' $TEMP_DIR/tmp.$$ | cut -f1 -d:`
   End_Line=`grep -n 'End of Network Variables' $TEMP_DIR/tmp.$$ | cut -f1 -d:`
#  Handle it when the user cancels out of a previous run of setup.  If
#  Start_Line is null, it means they never got to this section at all.  If
#  End_Line is null, then they cancelled in this section.
   if [ -z "$Start_Line" ]; then
      Variables_Found=N
   elif [ -z "$End_Line" ]; then
      Tail_Lines=200
   else
      Tail_Lines=`expr $End_Line - $Start_Line`
   fi
fi

if [ "$Variables_Found" = "Y" ]; then
   tail +$Start_Line $TEMP_DIR/tmp.$$ | head -$Tail_Lines | grep -v '^##' > $TEMP_DIR/tmp.network.$$


# This section of the else should only run when no setup.txt file is present
# Once one is there it is used to pull up the users current settings

else

$ECHO "  NETWORK_PING_TESTS=Y
  MACHINE_NAME=$MACHINE2
  WAN_NODE=wan_node
  RDBMS_NODE=$MACHINE2
  WEB_NODE=web_node
  CLIENT_NODE=client_pc" > $TEMP_DIR/tmp.network.$$
fi

}

Get_Network_Input ()
{
## Procedure: Get_Network_Input ()
## Called to setup all the env variables ...
#############################################################################
## Variables Used to Process this script:
#############################################################################
$ECHO "$BOLD Gathering parameters for the Network Section $OFF"

NO_PROMPT=N
NETWORK_PING_TESTS_Found=N
MACHINE_NAME_Found=N
WAN_NODE_Found=N
RDBMS_NODE_Found=N
WEB_NODE_Found=N
CLIENT_NODE_Found=N

$ECHO "######################################################################
##  Beginning of Network Variables
######################################################################
##" >> setup.txt

Args=`cat $TEMP_DIR/tmp.network.$$`
for CurArg in `$ECHO "$Args"`
do 
   Get_Arguments                     

   case "$NameVar" in

      NETWORK_PING_TESTS) 
         NETWORK_PING_TESTS_Found=Y
         $ECHO
         Description="##  Are Network ping tests are to be done.  If not, skip the variables.\n##"
         Prompt="Should the network ping tests be performed (Y/N)?"
         Append_Setup
            if [ "$ValueVar" = "N" ]; then
            Check_Network=N
         else
            Check_Network=Y
         fi
      ;;
      MACHINE_NAME) 
         MACHINE_NAME_Found=Y 
         $ECHO
         Description="##  Only the LAN_NODE needs to be setup for Unix Installs.\n## This is used for the networking ping times. Generally you would want the times\n## from the Web Server to the RDBMS and Client to the RDBMS and \n## Client to Web Server\n##\n## MACHINE_NAME = the current node the script is running from.\n##"
         Prompt="Enter the Name of the Node the script is running on(used for ping tests)"
         if [ "$Check_Network" = "Y" ]; then
            $ECHO
         else
            NO_PROMPT=Y
         fi
         Append_Setup
      ;;
      WAN_NODE) 
         WAN_NODE_Found=Y
         Description="##     WAN_NODE = a remotely located node that is connecting to apps.\n##"
         Prompt="Enter a WAN_NODE - Remote node that is connecting to this Server\n## (used for ping tests)"
         if [ "$Check_Network" = "Y" ]; then
            $ECHO
         else
            NO_PROMPT=Y
         fi
         Append_Setup
      ;;
      RDBMS_NODE) 
         RDBMS_NODE_Found=Y
         Description="##   RDBMS_NODE = the node that the RDBMS is running on.\n##"
         Prompt="Enter the RDBMS_NODE - the node hosting the database instance\n## (used for ping tests)"
         if [ "$Check_Network" = "Y" ]; then
            $ECHO
         else
            NO_PROMPT=Y
         fi
         Append_Setup
      ;;
      WEB_NODE) 
         WEB_NODE_Found=Y
         Description="##     WEB_NODE = the node that the Web Server and Forms Server are on.\n##"
         Prompt="Enter the WEB_NODE - node that the Web Server/Forms Server are on\n## (used for ping tests)"
         if [ "$Check_Network" = "Y" ]; then
            $ECHO
         else
            NO_PROMPT=Y
         fi
         Append_Setup
      ;;
      CLIENT_NODE) 
         Description="##  CLIENT_NODE = a typical client node ie. machine running the appletviewer.\n##"
         CLIENT_NODE_Found=Y
         Prompt="Enter a CLIENT_NODE - typical client node\n## ie. machine running the application\n## connecting to the DB(used for ping tests)"
         if [ "$Check_Network" = "Y" ]; then
            $ECHO
         else
            NO_PROMPT=Y
         fi
         Append_Setup
      ;;
   esac

done
if [ "$NETWORK_PING_TESTS_Found" = "N" ]; then
   $ECHO
   NameVar="NETWORK_PING_TESTS"
   ValueVar=Y
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="##  Are Network ping tests are to be done.  If not, skip the variables.\n##"
   Prompt="Should the network ping tests be performed (Y/N)?"
   Append_Setup
   if [ "$ValueVar" = "N" ]; then
      Check_Network=N
   else
      Check_Network=Y
   fi
fi
if [ "$MACHINE_NAME_Found" = "N" ]; then
   $ECHO
   NameVar="MACHINE_NAME"
   ValueVar=$MACHINE2
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="##  Only the LAN_NODE needs to be setup for Unix Installs.\n## This is used for the networking ping times. Generally you would want the times\n## from the Web Server to the RDBMS and Client to the RDBMS and \n## Client to Web Server\n##\n## MACHINE_NAME = the current node the script is running from.\n##"
   Prompt="Enter the Name of the Node the script is running on(used for ping tests)"
   if [ "$Check_Network" = "Y" ]; then
      $ECHO
   else
      NO_PROMPT=Y
   fi
   Append_Setup
fi
if [ "$WAN_NODE_Found" = "N" ]; then
   NameVar="WAN_NODE"
   ValueVar=wan_node
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="##     WAN_NODE = a remotely located node that is connecting to apps.\n##"
   Prompt="Enter a WAN_NODE - Remote node that is connecting to Server\n## (used for ping tests)"
   if [ "$Check_Network" = "Y" ]; then
      $ECHO
   else
      NO_PROMPT=Y
   fi
   Append_Setup
fi
if [ "$RDBMS_NODE_Found" = "N" ]; then
   NameVar="RDBMS_NODE"
   ValueVar=$MACHINE2
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="##   RDBMS_NODE = the node that the RDBMS is running on.\n##"
   Prompt="Enter the RDBMS_NODE - the node hosting the database instance\n## (used for ping tests)"
   if [ "$Check_Network" = "Y" ]; then
      $ECHO
   else
      NO_PROMPT=Y
   fi
   Append_Setup
fi
if [ "$WEB_NODE_Found" = "N" ]; then
   NameVar="WEB_NODE"
   ValueVar=web_node
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="##     WEB_NODE = the node that the Web Server and Forms Server are on.\n##"
   Prompt="Enter the WEB_NODE - node that the Web Server/Forms Server are on\n## (used for ping tests)"
   if [ "$Check_Network" = "Y" ]; then
      $ECHO
   else
      NO_PROMPT=Y
   fi
   Append_Setup
fi
if [ "$CLIENT_NODE_Found" = "N" ]; then
   NameVar="CLIENT_NODE"
   ValueVar=client_pc
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="##  CLIENT_NODE = a typical client node ie. machine running the appletviewer.\n##"
   Prompt="Enter a CLIENT_NODE - typical client node\n## ie. machine running the application\n## connecting to the DB(used for ping tests)"
   if [ "$Check_Network" = "Y" ]; then
      $ECHO
   else
      NO_PROMPT=Y
   fi
   Append_Setup
fi

$ECHO "######################################################################
##  End of Network Variables
######################################################################" >> setup.txt


}


#############
##  Main   ##
#############

Setup_Network_Env  # Setup Default Values, if not present, build setup.txt file.

Get_Network_Input  # Get user input on the Values - allow changes, rewrite setup.txt

if [ "$DebugMode" = "n" ]; then
   rm -f $TEMP_DIR/tmp.network.$$ 2>/dev/null
fi
