Test=`env|grep RDA_Program_Version`

##  The previous line MUST be the first line in the script.  If not, the check
##  for determining if this is called or started straight from command line
##  will not work (it will throw errors back to the screen).

if [ -z "$Test" ]; then
   echo "This script cannot be run standalone"
   echo "It must be called from the main RDA rda.sh"
   echo "Exiting from rda.sh"
   exit
fi
###########################################################################
##    Name: rda.sh                                Version: 3.09
##      By: Oracle Corp.                    Last Modified: October 07, 2002
##                                                Written: 2/19/02  
##
## Purpose: This is the source script for handling the gathering of web and
##          http information.  There are two functions in this script, one
##          gathering info for Apache in the old manner (all hard coded), the
##          second being very dynamic in finding the files it wants to display.
##          There hasn't been enough agreement to allow us to remove the old
##          processing.  This is not intended to be a standalone script,
##          it should be sourced from an executable script.
##
##   Usage: As a call from a script
##             . ./RDA_script_0010_RVW_WEB_SRVR/rda.sh
##
###########################################################################

##############################################################################
##  Modifications Section:
##############################################################################
##     Date        Author     Function       Changes
##############################################################################
##  10/07/2002     fkobylan   Review_Web_Server
##    3.09                                   Dltd references to TWO_TASK.
##  07/23/2002     fkobylan   Rvw_Web_Server_Build_Links
##                                           Fixed problems with list and
##                                           unordered list displays.
##  07/23/2002     fkobylan   Rvw_Web_Server_Build_Links
##    3.08                                   Chgd bg color for left frame links.
##  05/20/2002     fkobylan                  No chgs.  Just matching version
##    3.04                                   to base rda.
##  05/06/2002     fkobylan                  No chgs.  Just matching version
##    3.02                                   to base rda.
##  02/19/2002     fkobylan                  created 
##                                           based on code from original rda.sh.
#############################################################################

#############################################################################
##   Program Explanation:
##   ===================
##   The script is not intended to be a stand alone program.  Its function
##   is to gather Web Server information and create display files for the
##   RDA process.  
#############################################################################

###########################################
### Start of Review_Web_Server function ###
###########################################

Review_Web_Server ()
{
## Procedure Name: Review_Web_Server
################################################################
## This is a general Web Server Module to collect all the General
## Oracle Related Web Server files and configurations.
################################################################

echo "${BOLD}Processing: Web Server${OFF}"
#  Let's cleanup some old files here.  Safer than to try it in the body of
#  the code.  If these weren't deleted after the last run, get rid of them.
if [ -r ${OUT_DIR}/${PRD}_cfg_files.txt ]; then
   rm ${OUT_DIR}/${PRD}_cfg_files.txt
fi
if [ -r ${OUT_DIR}/${PRD}_web_processes.txt ]; then
   rm ${OUT_DIR}/${PRD}_web_processes.txt
fi
if [ -r ${OUT_DIR}/${PRD}_jserv_conf.htm ]; then
   rm ${OUT_DIR}/${PRD}_jserv_conf.htm
fi

# Getting Web Server Version: 3.x.x or 4.x.x

if [ -r ${ORAWEB_HOME}/bin/oraweb ];then
   WasVersion=`${ORAWEB_HOME}/bin/oraweb -version 2>/dev/null | grep List | awk '{print $4}'`
   WasCheck=`echo ${WasVersion} | cut -c1-1`
else
   OAS=NOT_INSTALLED; export OAS
   WasVersion=""
   WasCheck=""
fi

if [ "${WasCheck}" = "3" ]; then

## Reporting the Version of the Web Sever 
####################################################
## Creation os _Web_Env.txt IF OAS 3.0 ....
####################################################  
   echo "Web Server Version: $WasVersion" > $OUT_DIR/${PRD}_Web_Env.txt
   echo "`$ORAWEB_HOME/bin/oraweb -version`" >> $OUT_DIR/${PRD}_Web_Env.txt
   echo "LAST RUN ON: `date`" >> $OUT_DIR/${PRD}_Web_Env.txt

   echo "=================================================="  >> $OUT_DIR/${PRD}_Web_Env.txt 
   echo "=================================================="  >> $OUT_DIR/${PRD}_Web_Env.txt     

## number of listeners running
   oraweb_count=`$PS_EF |grep -c oraweb`
   echo "Number of listeners running: $oraweb_count" >> $OUT_DIR/${PRD}_Web_Env.txt
    
## number of Netscape listeners
   netscape_count=`$PS_EF | grep -c httpd-`
   echo "Number of Netscape listeners: $netscape_count" >> $OUT_DIR/${PRD}_Web_Env.txt
    
## number of cartrdige running
## PLSQL
   plsql_count=`$PS_EF | grep wrbc | grep -c PLSQL`
   echo "Number of PLSQL cartrdiges running: $plsql_count" >> $OUT_DIR/${PRD}_Web_Env.txt
   
## JAVA
   java_count=`$PS_EF | grep wrbc | grep -c JAVA`
   echo "Number of JAVA cartrdiges running: $java_count" >> $OUT_DIR/${PRD}_Web_Env.txt
       
## Forms
   f45srv_count=`$PS_EF | grep -c f45srv`
   echo "Number of Forms Servers running: $f45srv_count" >> $OUT_DIR/${PRD}_Web_Env.txt

   echo "===Count and Amounts===" >> $OUT_DIR/${PRD}_Web_Env.txt
## Number of records in the xlf.log file
   xlf_log_count=`wc $ORAWEB_ADMIN/ows/website30/wrb/log/xlf.log | awk '{print $1}'`
   echo "Number of Records in xlf.log: $xlf_log_count" >> $OUT_DIR/${PRD}_Web_Env.txt

   xlf_log_200=`grep " 200 " $ORAWEB_ADMIN/ows/website30/wrb/log/xlf.log | wc | awk '{print $1}'`
   echo "Number STATUS 200 Records in xlf.log: $xlf_log_200" >> $OUT_DIR/${PRD}_Web_Env.txt

   xlf_log_400=`grep " 400 " $ORAWEB_ADMIN/ows/website30/wrb/log/xlf.log | wc | awk '{print $1}'`
   echo "Number STATUS 400 Records in xlf.log: $xlf_log_400" >> $OUT_DIR/${PRD}_Web_Env.txt

   xlf_log_500=`grep " 500 " $ORAWEB_ADMIN/ows/website30/wrb/log/xlf.log | wc | awk '{print $1}'`
   echo "Number STATUS 500 Records in xlf.log: $xlf_log_500" >> $OUT_DIR/${PRD}_Web_Env.txt

## Errors in the Log file:
   error_log_count=`wc $ORAWEB_HOME/log/syserr.log | awk '{print $1}'`
   echo "Number of Errors in syserr.log: $error_log_count" >> $OUT_DIR/${PRD}_Web_Env.txt

   echo "=================================================="  >> $OUT_DIR/${PRD}_Web_Env.txt 
   echo "=================================================="  >> $OUT_DIR/${PRD}_Web_Env.txt 
   echo  >> $OUT_DIR/${PRD}_Web_Env.txt 

## status of WRB
   echo "Status of WRB:"  >> $OUT_DIR/${PRD}_Web_Env.txt
   echo "=================================================="  >> $OUT_DIR/${PRD}_Web_Env.txt 
   owsctl status wrb  2>>$OUT_DIR/${PRD}_Web_Env.txt
 
elif [ "${WasCheck}" = "4" ]; then 

# This sections is CURRENTLY ASSUMING OAS 4.X since NOT 3.x
## Reporting the Version of the Web Sever   
####################################################
## Creation os _Web_Env.txt IF OAS 4.0 ....
####################################################  
   echo "Web Server Version: $WasVersion" > $OUT_DIR/${PRD}_Web_Env.txt
   echo "`$ORAWEB_HOME/bin/owsctl -v`" >> $OUT_DIR/${PRD}_Web_Env.txt
   echo "LAST RUN ON: `date`" >> $OUT_DIR/${PRD}_Web_Env.txt

   echo "=================================================="  >> $OUT_DIR/${PRD}_Web_Env.txt     
## number of listeners running
   oraweb_count=`$PS_EF | grep -c oraweb`
   echo "Number of listeners running: $oraweb_count" >> $OUT_DIR/${PRD}_Web_Env.txt
    
## number of Netscape listeners
   netscape_count=`$PS_EF | grep -c httpd-`
   echo "Number of Netscape listeners: $netscape_count" >> $OUT_DIR/${PRD}_Web_Env.txt
    
## number of cartrdige running
## PLSQL
   plsql_count=`$PS_EF | grep -c wrksf`
   echo "Number of Factories running: $plsql_count" >> $OUT_DIR/${PRD}_Web_Env.txt
   
## Forms
   f45srv_count=`$PS_EF | grep -c f45srv`
   echo "Number of Forms Servers running: $f45srv_count" >> $OUT_DIR/${PRD}_Web_Env.txt

## Errors in the Log file:
   error_log_count=`wc $ORAWEB_HOME/log/syserr.log | awk '{print $1}'`
   echo "Number of Errors in syserr.log: $error_log_count" >> $OUT_DIR/${PRD}_Web_Env.txt

   echo "=================================================="  >> $OUT_DIR/${PRD}_Web_Env.txt 
   echo  >> $OUT_DIR/${PRD}_Web_Env.txt 

## status of WRB
   echo "Status of WRB:"  >> $OUT_DIR/${PRD}_Web_Env.txt
   echo "=================================================="  >> $OUT_DIR/${PRD}_Web_Env.txt 
   owsctl status -w all  2>>$OUT_DIR/${PRD}_Web_Env.txt 

else

   echo "OAS Apparently Not installed" > $OUT_DIR/${PRD}_Web_Env.txt
   OAS=NOT_INSTALLED; export OAS 

fi
###############################################################
####### End of EITHER WAS 3.X or 4.X CHECK, Moving on...
###############################################################


##############################################
## MISC SECTION = COMMON TO WAS 3.X and 4.X ##
##############################################

##############################################
##### ONLY DO IF WAS 3 or 4 is PRESENT #######
##############################################
if [ "${OAS}" != "NOT_INSTALLED" ]; then

   echo  >>  $OUT_DIR/${PRD}_Web_Env.txt

   echo "OAS Web Environment Variables" >>  $OUT_DIR/${PRD}_Web_Env.txt

   echo  >>  $OUT_DIR/${PRD}_Web_Env.txt

   echo "--- Checking for OFA setup: ORAWEB_HOME set ??" >> $OUT_DIR/${PRD}_Web_Env.txt
   echo "=================================================="  >> $OUT_DIR/${PRD}_Web_Env.txt
   env | grep ORAWEB >> $OUT_DIR/${PRD}_Web_Env.txt

   echo  >>  $OUT_DIR/${PRD}_Web_Env.txt

   if [ -r ${ORAWEB_HOME:=X}/bin ];then
      echo "---\$ORAWEB_HOME/bin:  $ORAWEB_HOME/bin File Listing: " >> $OUT_DIR/${PRD}_Web_Env.txt
      echo "=================================================="  >> $OUT_DIR/${PRD}_Web_Env.txt
      ls -lR ${ORAWEB_HOME}/bin >> $OUT_DIR/${PRD}_Web_Env.txt
   fi
 
# Assumes files are under ORAWEB_ADMIN and it is setup
   if [ -r ${ORAWEB_ADMIN:=XX} ]; then
      echo "Web Configuration files ending in .cfg" >>  $OUT_DIR/${PRD}_cfg_files.txt
      echo "=================================================="  >> $OUT_DIR/${PRD}_cfg_files.txt
      echo  >>  $OUT_DIR/${PRD}_cfg_files.txt
      echo  "::: listing then content :::" >>  $OUT_DIR/${PRD}_cfg_files.txt
      find $ORACLE_HOME -name "*.cfg" -exec grep -vl lyn {} \; | grep -v lynx >> $OUT_DIR/${PRD}_cfg_files.txt
      find $ORACLE_HOME -name "*.cfg" -exec grep -vl lyn {} \; | grep -v lynx >  $OUT_DIR/${PRD}_tmp.txt
   else
      echo "Cant find any files for OAS WEB cfg " >>  $OUT_DIR/${PRD}_cfg_files.txt
   fi

   if [ -r $ORAWEB_HOME/log/syserr.log ];then
      echo  >> $OUT_DIR/${PRD}_Web_Env.txt 
      echo "Last 10 errors from file: " >> $OUT_DIR/${PRD}_Web_Env.txt
      echo "=================================================="  >> $OUT_DIR/${PRD}_Web_Env.txt 
      tail -10 $ORAWEB_HOME/log/syserr.log >> $OUT_DIR/${PRD}_Web_Env.txt
   else 
      echo "Cannot Read: $ORAWEB_HOME/log/syserr.log " >> $OUT_DIR/${PRD}_Web_Env.txt
   fi

   if [ -r ${ORACLE_HOME}/ows/admin/ows/website30 ];then
      echo  >> $OUT_DIR/${PRD}_Web_Env.txt 
      echo "Glance at  10 errors from all .err files: " >> $OUT_DIR/${PRD}_Web_Env.txt
      echo "=================================================="  >> $OUT_DIR/${PRD}_Web_Env.txt 
      find $ORACLE_HOME/ows/admin/ows/website30/*/*/log/ -name "*.err" -exec tail {} \; >> $OUT_DIR/${PRD}_Web_Env.txt 

# Connection Log File xlf.log - ALL THE PACKAGES CAN BE COUNTED / Checked Here:
# -- Successfull http transaction and http errors - NON-ORACLE
      echo  >> $OUT_DIR/${PRD}_Web_Env.txt 
      echo "Tail of xlf.log file: " >> $OUT_DIR/${PRD}_Web_Env.txt
      echo "=================================================="  >> $OUT_DIR/${PRD}_Web_Env.txt 
      tail $ORACLE_HOME/ows/admin/ows/website30/wrb/log/xlf.log  >> $OUT_DIR/${PRD}_Web_Env.txt  
   else 
      echo "Cannot Read: $ORACLE_HOME/ows/admin/website30 " >> $OUT_DIR/${PRD}_Web_Env.txt
   fi


   if [ -r $OUT_DIR/${PRD}_tmp.txt ];then
      for i in `cat $OUT_DIR/${PRD}_tmp.txt`
      do
         echo "##########################################################" >>  $OUT_DIR/${PRD}_cfg_files.txt
         pr $i >> $OUT_DIR/${PRD}_cfg_files.txt
      done 
   else
      echo "Apparently could not find any cfg files under ORACLE_HOME" >>  $OUT_DIR/${PRD}_cfg_files.txt
   fi


   if [ "${WasCheck}" = "" ];then
      echo "Not looking for wrb and orb processes, prob. not an OAS installation" >> $OUT_DIR/${PRD}_web_processes.txt
   else
      echo "Web Related Processes: wrbs and orbs" >  $OUT_DIR/${PRD}_web_processes.txt
      echo  >>  $OUT_DIR/${PRD}_web_processes.txt
      echo "== wrbs =================================================="  >> $OUT_DIR/${PRD}_cfg_files.txt
      `$PS_EF | head -n 1 >> $OUT_DIR/${PRD}_web_processes.txt`
      `$PS_EF | grep wrb | grep -v grep >> $OUT_DIR/${PRD}_web_processes.txt`
      echo "== orbs =================================================="  >> $OUT_DIR/${PRD}_cfg_files.txt
      `$PS_EF | grep orb | grep -v grep >> $OUT_DIR/${PRD}_web_processes.txt`
   fi

else
   echo "No configuration information for OAS"  >> $OUT_DIR/${PRD}_cfg_files.txt

   echo "Not looking for wrb and orb processes, prob. not an OAS installation" >> $OUT_DIR/${PRD}_web_processes.txt
fi
#######################################################################
##### WAS != NOT_INSTALLED ##### then WAS 3 or 4 installed, DO ABOVE
##### Writes to Web_Env.txt and web_processes.txt but only if 3 or 4
#######################################################################

#######################################################################
## APACHE CONFIGURATION AND OVERVIEW
#######################################################################
# echo "INSIDE ABOVE Apache Part"
if [ -r ${APACHE_TOP} ];then
#######################################################################
# IF no APACHE_TOP readable, skip this whole section......
#######################################################################
   echo "<PRE><B>Main Apache Configuration Files:</B> $APACHE_TOP " > $OUT_DIR/${PRD}_apache_over.htm 
   echo "==============================================================" >> $OUT_DIR/${PRD}_apache_over.htm 
   ls -lt $APACHE_TOP/conf >/dev/null 2>/dev/null
   if [ $? -eq 0 ]; then
      ls -tl $APACHE_TOP/conf >> $OUT_DIR/${PRD}_apache_over.htm 
   else
      echo "$APACHE_TOP/conf either not readable or does not exist" >> $OUT_DIR/${PRD}_apache_over.htm
   fi

   echo >> $OUT_DIR/${PRD}_apache_over.htm 

   ls -t $APACHE_TOP/conf/*.conf >/dev/null 2>/dev/null
   if [ $? -eq 0 ]; then
      for i in `ls -t $APACHE_TOP/conf/*.conf`
      do
        echo "========================================================================" >> $OUT_DIR/${PRD}_apache_over.htm 
        echo "<B>Currently Showing:</B> $i" >> $OUT_DIR/${PRD}_apache_over.htm 
        echo "========================================================================" >> $OUT_DIR/${PRD}_apache_over.htm 
        cat $i >> $OUT_DIR/${PRD}_apache_over.htm 
        echo >> $OUT_DIR/${PRD}_apache_over.htm 
      done
   fi

   echo "</PRE>" >> $OUT_DIR/${PRD}_apache_over.htm 
#########################################
## End of APACHE OVER additions...
#########################################

## If OAS isnt present, need to add some _cfg_files info. for APACHE
   for i in "$APACHE_TOP" "$APACHE_TOP/../" "$APACHE_TOP/../modplsql/cfg/" "$APACHE_TOP/../Jserv/etc/"
   do
     echo "========================================================================" >> $OUT_DIR/${PRD}_cfg_files.txt 
     echo "Currently Showing: $i" >> $OUT_DIR/${PRD}_cfg_files.txt 
     echo "========================================================================" >> $OUT_DIR/${PRD}_cfg_files.txt  
     ls -l $i >> $OUT_DIR/${PRD}_cfg_files.txt 2>&1
     echo >> $OUT_DIR/${PRD}_cfg_files.txt 
   done

##  VARIABLE is NULL and CANNOT READ IT, ELSE you CAN
   if [ ${FORMS60_WEB_CONFIG_FILE:=X} = "X" ];then
      echo "... FORMS60_WEB_CONFIG_FILE variable not setup. "  >>  $OUT_DIR/${PRD}_cfg_files.txt 
   else
      FileName=`echo ${FORMS60_WEB_CONFIG_FILE} | awk -F"=" '{print $1}'`
      if [ -r ${FileName:=X} ];then       
         echo "<B>Viewing FORMS60_WEB_CONFIG_FILE:</B> $FileName" >> $OUT_DIR/${PRD}_cfg_files.txt 
         echo "================================================================"  >> $OUT_DIR/${PRD}_cfg_files.txt 
         cat ${FileName} >>  $OUT_DIR/${PRD}_cfg_files.txt 
      else
         echo "Warning: Cannot read: ${FileName} " >>  $OUT_DIR/${PRD}_cfg_files.txt 
      fi
   fi


   echo "========================================================================" >> $OUT_DIR/${PRD}_Web_Env.txt 
   echo "Currently Web Environment for APACHE" >> $OUT_DIR/${PRD}_Web_Env.txt 
   echo "========================================================================" >> $OUT_DIR/${PRD}_Web_Env.txt 
   echo "
       APACHE_TOP=$APACHE_TOP
      ORACLE_HOME=$ORACLE_HOME  

  CONNECTIONS
      ORACLE_SID=$ORACLE_SID    TNS_ADMIN=$TNS_ADMIN

  WEB RELATED ENV PARAMETERS
`env | egrep -i 'WEB|FORM|REPORT|JAVA|HTML|JDK|CGI|LD_LIB' | sort`

" >> $OUT_DIR/${PRD}_Web_Env.txt 

   FileName=`find $APACHE_TOP/../ -name "wdb*app" 2>/dev/null`
   if [ -n "$FileName" ]; then
      for f in $FileName
      do
         if [ -r $f ];then       
            echo "<B>Viewing `basename $f`:</B> $f" >> $OUT_DIR/${PRD}_Web_Env.txt 
            echo "================================================================"  >> $OUT_DIR/${PRD}_Web_Env.txt  
            cat $f >>  $OUT_DIR/${PRD}_Web_Env.txt 
         else
            echo "Warning: Cannot read: $f " >> $OUT_DIR/${PRD}_Web_Env.txt 
         fi
      done
   else
      echo "Warning: wdbsvr.app file not found" >> $OUT_DIR/${PRD}_Web_Env.txt 
   fi


# Probably should add logic to get all the correct "pid" file name from http(s).conf
# or go to the processes directly ps -ef | grep http
# Currently checks for either httpds.pid or httpd.pid but they could be in
# a DIFFERENT LOCATION THAN THE DEFAULT..

#################################################
## USING httpds.pid ? else  httpd.pid
#################################################
   echo "<PRE>" > $OUT_DIR/${PRD}_apache_processes.htm
   if [ -r "$APACHE_TOP/logs/httpds.pid" ];then

      PID=`cat $APACHE_TOP/logs/httpds.pid`
      Owner=`$PS_EF | grep ${PID} | grep -v grep | awk '{print $1}' | tail -1`
      Current_User=`$PS_EF | grep $$ | awk '{print $1}' | head -1` 

## Creating this file fresh, cause if APACHE is running, OAS isnt characterized.
      echo "== Apache Web Processes based on PID: $PID ==========================="  > $OUT_DIR/${PRD}_web_processes.txt
      `$PS_EF | grep $PID | grep -v grep >> $OUT_DIR/${PRD}_web_processes.txt`
 
      echo "\nCurrent TOP httpd processes 50 CPU by % CPU Matching: $PID (via $UCB_PS)" >> $OUT_DIR/${PRD}_web_processes.txt  
      `$UCB_PS | head -1 >> $OUT_DIR/${PRD}_web_processes.txt`
      `$UCB_PS | grep $PID | grep -v grep | head -50 >> $OUT_DIR/${PRD}_web_processes.txt`

      for i in `$UCB_PS | grep $PID | grep -v grep | awk '{print $2}'`
      do
         `$UCB_PS | grep $i | grep -v grep >> $OUT_DIR/${PRD}_web_processes.txt`
      done

      if [ "${Owner}" = "${Current_User}" ];then
         echo "<B>Parent Child Process Listing:</B> (Based on httpds.pid) " >> $OUT_DIR/${PRD}_apache_processes.htm
         echo "Note: If nothing on these lines, permissions on /usr/proc/bin/ptree " >> $OUT_DIR/${PRD}_apache_processes.htm
         echo "      OR not on Solaris.. " >> $OUT_DIR/${PRD}_apache_processes.htm
         echo "=========================================================================" >> $OUT_DIR/${PRD}_apache_processes.htm

         /usr/proc/bin/ptree -a $PID >> $OUT_DIR/${PRD}_apache_processes.htm

         echo >> $OUT_DIR/${PRD}_apache_processes.htm

         echo "Memory Map of Parent Process: Based on pmap of httpds.pid " >> $OUT_DIR/${PRD}_apache_processes.htm
         echo "Note: If nothing on these lines, permissions on /usr/proc/bin/ptree " >> $OUT_DIR/${PRD}_apache_processes.htm
         echo "      OR not on Solaris.. " >> $OUT_DIR/${PRD}_apache_processes.htm
         echo "=========================================================================" >> $OUT_DIR/${PRD}_apache_processes.htm

         /usr/proc/bin/pmap -x $PID >> $OUT_DIR/${PRD}_apache_processes.htm

      else 
         echo "Cannot run pmap unless owner of process: PID ${PID}">> $OUT_DIR/${PRD}_apache_processes.htm
      fi

#################################################
## USING httpds.pid ? else  httpd.pid
#################################################
   elif [ -r "$APACHE_TOP/logs/httpd.pid" ]; then

      PID=`cat $APACHE_TOP/logs/httpd.pid`
      Owner=`$PS_EF | grep ${PID} | grep -v grep | awk '{print $1}' | tail -1`
      Current_User=`$PS_EF | grep $$ | awk '{print $1}' | head -1` 

## Creating this file fresh, cause if APACHE is running, OAS isnt characterized.
      echo "== Apache Web Processes based on PID: $PID ==========================="  > $OUT_DIR/${PRD}_web_processes.txt
      `$PS_EF | head -n 1 >> $OUT_DIR/${PRD}_web_processes.txt`
      `$PS_EF | grep $PID | grep -v grep >> $OUT_DIR/${PRD}_web_processes.txt`

# echo "\nCurrent TOP httpd processes 50 CPU by % CPU (via $UCB_PS)" >> $OUT_DIR/${PRD}_web_processes.txt  
      `$UCB_PS | head -n 1 >> $OUT_DIR/${PRD}_web_processes.txt`
      `$UCB_PS | egrep $PID | grep -v grep >> $OUT_DIR/${PRD}_web_processes.txt`
      for i in `$UCB_PS | grep $PID | grep -v grep | awk '{print $2}'`
      do
         `$UCB_PS | grep $i | grep -v grep >> $OUT_DIR/${PRD}_web_processes.txt`
      done

      if [ "${Owner}" = "${Current_User}" ];then
         echo "<B>Parent Child Process Listing:</B> (Based on httpd.pid) " >> $OUT_DIR/${PRD}_apache_processes.htm
         echo "Note: If nothing on these lines, permissions on /usr/proc/bin/ptree " >> $OUT_DIR/${PRD}_apache_processes.htm
         echo "      OR not on Solaris.. " >> $OUT_DIR/${PRD}_apache_processes.htm
         echo "=========================================================================" >> $OUT_DIR/${PRD}_apache_processes.htm
         /usr/proc/bin/ptree -a $PID >> $OUT_DIR/${PRD}_apache_processes.htm

         echo >> $OUT_DIR/${PRD}_apache_processes.htm

         echo "Memory Map of Parent Process: Based on pmap of httpd.pid " >> $OUT_DIR/${PRD}_apache_processes.htm
         echo "Note: If nothing on these lines, permissions on /usr/proc/bin/ptree " >> $OUT_DIR/${PRD}_apache_processes.htm
         echo "      OR not on Solaris.. " >> $OUT_DIR/${PRD}_apache_processes.htm
         echo "==========================================================================" >> $OUT_DIR/${PRD}_apache_processes.htm
         /usr/proc/bin/pmap -x $PID >> $OUT_DIR/${PRD}_apache_processes.htm
      else 
         echo "Cannot run pmap unless owner of process: PID ${PID}">> $OUT_DIR/${PRD}_apache_processes.htm
      fi

   else
      echo "Could not find the httpd.pid or httpds.pid in the $APACHE_TOP/logs directory." >> $OUT_DIR/${PRD}_apache_processes.htm
   fi
#################################################
## END USING httpds.pid ? else  httpd.pid
#################################################


   echo >> $OUT_DIR/${PRD}_apache_processes.htm

   echo "=========================================================================" >> $OUT_DIR/${PRD}_apache_processes.htm
   echo "<B>log Files in: </B>$APACHE_TOP/logs" >> $OUT_DIR/${PRD}_apache_processes.htm
   echo "=========================================================================" >> $OUT_DIR/${PRD}_apache_processes.htm
   ls -lt $APACHE_TOP/logs >> $OUT_DIR/${PRD}_apache_processes.htm 2>&1

   echo >> $OUT_DIR/${PRD}_apache_processes.htm

   echo "=========================================================================" >> $OUT_DIR/${PRD}_apache_processes.htm
   echo "<B>Last 100 Lines of error_log in:</B> $APACHE_TOP/logs/" >> $OUT_DIR/${PRD}_apache_processes.htm
   echo "=========================================================================" >> $OUT_DIR/${PRD}_apache_processes.htm
   if [ -r $APACHE_TOP/logs/*error_log ]; then
      tail -100 $APACHE_TOP/logs/*error_log >> $OUT_DIR/${PRD}_apache_processes.htm
   else
      echo "No error log found in $APACHE_TOP/logs" >> $OUT_DIR/${PRD}_apache_processes.htm
   fi

   echo >> $OUT_DIR/${PRD}_apache_processes.htm

   echo "=========================================================================" >> $OUT_DIR/${PRD}_apache_processes.htm
   echo "<B>Last 100 Lines of access_log in:</B> $APACHE_TOP/logs/" >> $OUT_DIR/${PRD}_apache_processes.htm
   echo "=========================================================================" >> $OUT_DIR/${PRD}_apache_processes.htm
   if [ -r $APACHE_TOP/logs/*access_log ]; then
      tail -100 $APACHE_TOP/logs/*access_log >> $OUT_DIR/${PRD}_apache_processes.htm
   else
      echo "No access log found in $APACHE_TOP/logs" >> $OUT_DIR/${PRD}_apache_processes.htm
   fi

   echo >> $OUT_DIR/${PRD}_apache_processes.htm

   echo "</PRE>" >> $OUT_DIR/${PRD}_apache_processes.htm
#########################################
## End of APACHE PROCESSES additions...
#########################################

#########################################
# Jserv Files and Configuration Section #
#########################################
   echo "<PRE><B>Main JServ Configuration Files:</B> $APACHE_TOP/../Jserv/etc " > $OUT_DIR/${PRD}_jserv_conf.htm 
   echo "=========================================================================" >> $OUT_DIR/${PRD}_jserv_conf.htm  
   ls -tl $APACHE_TOP/../Jserv/etc >> $OUT_DIR/${PRD}_jserv_conf.htm 
   echo >> $OUT_DIR/${PRD}_jserv_conf.htm 
   echo "=========================================================================" >> $OUT_DIR/${PRD}_jserv_conf.htm 

   for i in `ls -t $APACHE_TOP/../Jserv/etc/*.conf $APACHE_TOP/../Jserv/etc/*.properties`
   do
      echo "<B>Currently Showing: $i</B>" >> $OUT_DIR/${PRD}_jserv_conf.htm
      echo "=========================================================================" >> $OUT_DIR/${PRD}_jserv_conf.htm  
      if [ -r "$i" ];then
         cat $i >> $OUT_DIR/${PRD}_jserv_conf.htm
         echo >> $OUT_DIR/${PRD}_jserv_conf.htm
      else
         echo "Error: Could not read or find file: $i" >> $OUT_DIR/${PRD}_jserv_conf.htm
      fi

   done

   echo >> $OUT_DIR/${PRD}_jserv_conf.htm


#  Throw errors to /dev/null (no files found)
   for i in `ls -t $APACHE_TOP/../Jserv/logs/*.log 2>/dev/null`
   do
      echo "=========================================================================" >> $OUT_DIR/${PRD}_jserv_conf.htm  
      echo "<B>Currently Last 100 Lines of:</B> $i" >> $OUT_DIR/${PRD}_jserv_conf.htm
      echo "=========================================================================" >> $OUT_DIR/${PRD}_jserv_conf.htm  
      if [ -r "$i" ];then
         tail -100 $i >> $OUT_DIR/${PRD}_jserv_conf.htm
         echo >> $OUT_DIR/${PRD}_jserv_conf.htm
      else
         echo "Error: Could not read or find file: $i" >> $OUT_DIR/${PRD}_jserv_conf.htm
      fi
   done

   echo >> $OUT_DIR/${PRD}_jserv_conf.htm


## JSERV PROCESSES CHECK
   echo "<B>Manual JServ Processes:</B> " >> $OUT_DIR/${PRD}_jserv_conf.htm 
   echo "=========================================================================" >> $OUT_DIR/${PRD}_jserv_conf.htm 
   FOUND=`$PS_EF | grep JServ | grep -v grep`
   if [ "${FOUND}" != "" ]; then 
      `$PS_EF | head -n 1 >> $OUT_DIR/${PRD}_jserv_conf.htm `
      `$PS_EF | grep JServ | grep -v grep >> $OUT_DIR/${PRD}_jserv_conf.htm `
   else
      echo "Warning: No JServ processes found. Could be not running or not installed on this machine" >> $OUT_DIR/${PRD}_jserv_conf.htm
   fi

   echo "</PRE>" >> $OUT_DIR/${PRD}_jserv_conf.htm
#########################################
## End of JSERV CONF additions...
#########################################

else

 ## APACHE_TOP could not be READ...
   echo "<B>Warning:</B> Could not read Apache_top Directory:  $APACHE_TOP " > $OUT_DIR/${PRD}_apache_over.htm 
   echo "Check Permissions and or re-run setup.sh to correct path." >> $OUT_DIR/${PRD}_apache_over.htm 

##  Make sure ALL files are created from above if Apache is not installed.
   echo "<PRE><B>Parent Child Process Listing:</B> (Based on httpds.pid) " > $OUT_DIR/${PRD}_apache_processes.htm
   echo "Note: If nothing on these lines, check permissions on /usr/proc/bin/ptree " >> $OUT_DIR/${PRD}_apache_processes.htm
   echo "      OR not on Solaris OR not installed " >> $OUT_DIR/${PRD}_apache_processes.htm
   echo "=========================================================================" >> $OUT_DIR/${PRD}_apache_processes.htm

   echo "Warning: No JServ processes found. Jserv is either not running or not installed on this machine" >> $OUT_DIR/${PRD}_jserv_conf.htm
fi
## APACHE_TOP Readable 

## WEB CHECKs VIA SQLPLUS's: 
# The web server checks require the base url and PLSQL to be setup as follows:
#  
# WEB_BASE="http://localhost.us.oracle.com:7777"
# WEB_DCD="http://localhost.us.oracle.com:7777/VIS/plsql"
###########################################################
## If apps use:  OA_HTML/US/VIS.htm
if [ "$DATABASE_INSTALLED" = "N" -o "$WEB_APPS_INSTALLED" = "N" ]; then
   true
else
   usesql=run_http
   name="$WEB_BASE/"
   SET_SQL
   Run_SQL
   echo "<PRE>Main Signon URL: $name =================" >> $OUT_DIR/${PRD}_signon.htm
   echo >> $OUT_DIR/${PRD}_signon.htm
   echo " ------- </PRE>" >> $OUT_DIR/${PRD}_signon.htm
   cat $OUT_DIR/$OUT_FILE.txt >> $OUT_DIR/${PRD}_signon.htm

   usesql=run_http
   name="$WEB_DCD/owa_util.print_cgi_env"
   SET_SQL
   Run_SQL
   echo "<PRE>Main Signon URL: $name =================" > $OUT_DIR/${PRD}_signonp.htm
   echo >> $OUT_DIR/${PRD}_signonp.htm
   echo " ------- </PRE>" >> $OUT_DIR/${PRD}_signonp.htm
   cat $OUT_DIR/$OUT_FILE.txt >> $OUT_DIR/${PRD}_signonp.htm
fi

}

Review_HttpServer () 
{ 
## Procedure Name: Review_HttpServer 
################################################################ 
## Collect all files directly related to Oracle HTTP Server 
## Powered by Apache. 
## This procedure follows a different approach compared to the 
## older Review_HttpServer procedure, so while we are testing and 
## establishing this new way of collecting data we use both 
## procedures to collect data. 
## 
## Defines the following environment variables that may be used 
## by other procedures that are called after this one: 
## $HTTPDCONF - httpd.conf and *all* files that are included in 
##              it. I.e. all files that can contain config 
##              directives. 
## $HTTPDERRLOG - all logfiles from ErrorLog and SSLLog directives 
## $HTTPDREQLOG - all request log files (from TransferLog and 
##                CustomLog directives) 
## $SERVERROOT - Apache's ServerRoot setting. May not be handled 
##               correctly in all cases. 
## $HTTPDSTARTSCRIPTS - Scripts to start apache. apachectl and 
##                      httpdsctl (may have been changed to include 
##                      additional environment variables) 
## $HTTPDMODPLSQLCFG - Heuristically found candidates for 
##                     mod_plsql's wdbsvr.app file 
## $JSERVPROPERTIES - All jserv.properties that are used by 
##                    Apache configurations 
## $JSERVZONEPROPS - The zone.properties of all recognized 
##                   JServ engines 
## $JSERVCFGFILES - Both the jserv properties files plus the 
##                  zone properties files 
## $JSERVLOG - JServ Log files, both from the engines themselves 
##             and from the Apache module 
################################################################ 
 
OLDIFS=$IFS 
IFS=$NL 
export IFS 
 
echo "${BOLD}Processing: HTTP Server${OFF}" 
 
SERVERROOT=$APACHE_TOP 
 
   httpServer_getListenerConf() 
   { 
      ## subroutine to recursively search all httpd.conf included files 
      ## do not output anything on stdout in this function, because
      ## stdout is used to return the names of the config files to
      ## getListenerConf
      ## To debug use something like
      ## echo >&2 $file
      ## to print to stderr instead
      httpServer_readConf() 
      { 
         while [ ! -z "$1" ]; do 
            file=$1 
            if [ -f "$file" -a -r "$file" ]; then 
               echo $file 
               sroot=`egrep -i '^[ $TAB]*ServerRoot[ $TAB]+' $file | sed -e 's/^[ $TAB]*[Ss][Ee][Rr][Vv][Ee][Rr][Rr][Oo][Oo][Tt][ $TAB]*//g' | tr '"' ' ' | sed -e "s/^[ $TAB]*//g" -e "s/[ $TAB]*$//g"` 
               for s in $sroot; do 
                  if [ -d $s -a -r $s ]; then 
                     if [ "$s" != "$SERVERROOT" ]; then 
                        echo >&2 "Warning: Your HTTP server uses ServerRoot configurations that may not be" 
                        echo >&2 "handled properly by RDA." 
                        SERVERROOT=$s 
                     fi 
                  fi 
               done 
               includes=`egrep -i '^[ $TAB]*include[ $TAB]+' $file | sed -e 's/^[ $TAB]*[Ii][Nn][Cc][Ll][Uu][Dd][Ee] [ $TAB]*//g' | tr '"' ' ' | sed -e "s/^[ $TAB]*//g" -e "s/[ $TAB]*$//g"` 
               for inc in $includes; do 
                  if [ ! "`echo $inc | grep '^/'`" ];then 
                     # if non-absolute path then path is 
                     # relative to ServerRoot (see also 
                     # Apache doc - but if customer has 
                     # set ServerRoot in som conf file 
                     # we may process ServerRoot and 
                     # include directives in the "wrong" 
                     # order, so we issue a warning, 
                     # see some lines above). 
                     inc=$SERVERROOT/$inc 
                  fi 
                  httpServer_readConf $inc 
               done 
            elif [ -d "$file" -a -x "$file" ]; then 
               # If included file is a directory then look for all 
               # files in that directory, but do not add the 
               # directory itself to the list of config files. 
               # According to Apache doc this feature exists since 
               # version 1.3.13 of Apache 
               httpServer_readConf `find "$file" -type f -print` 
            fi 
            shift 
         done 
      }

      if [ -f $APACHE_TOP/conf/httpd.conf ]; then 
         MAINCONF=$APACHE_TOP/conf/httpd.conf 
      elif [ -f $APACHE_TOP/conf/httpds.conf ]; then 
         # seems to be an old IAS 1.0.0.0.0, but try to continue collecting, 
         # anyway 
         MAINCONF=$APACHE_TOP/conf/httpds.conf 
      else 
         # Did not find apache main config file in the usual places. Is this 
         # an Oracle installation of Apache? 
         MAINCONF=httpd.conf_not_found_in_usual_places 
      fi 

      HTTPDCONF=`httpServer_readConf $MAINCONF | sort -u` 

      for h in $HTTPDCONF; do 
         echo "Content taken from file $h" > $OUT_DIR/${PRD}_`echo $h | tr '/' $PATH_REPLACE_CHAR`.txt
         cat $h >> $OUT_DIR/${PRD}_`echo $h | tr '/' $PATH_REPLACE_CHAR`.txt 
      done 
   } 

   httpServer_getListenerLogs() 
   { 
      HTTPDERRLOG="" 
      HTTPDREQLOG="" 
      for httpd in $HTTPDCONF; do 
         errorlogs=`egrep -i '^[ $TAB]*ErrorLog[ $TAB]+' $httpd | tr '"' ' ' | sed -e "s/^[ $TAB]*[Ee][Rr][Rr][Oo][Rr][Ll][Oo][Gg][ $TAB]*//g" -e "s/[ $TAB]*$//g"` 
         for e in $errorlogs; do 
            if [ ! "`echo $e | grep '^/'`" ]; then 
               # if non-absolute path then path is relative to Apache's 
               e=$SERVERROOT/$e 
            fi 
            if [ ! "`echo $e | grep '^|'`" ]; then 
               # only try to process the Log if it's not a Pipe log 
               if [ -f $e -a -r $e ]; then 
                  HTTPDERRLOG=$HTTPDERRLOG$NL$e 
               fi 
            fi 
         done 
         ssllogs=`egrep -i '^[ $TAB]*SSLLog[ $TAB]+' $httpd | tr '"' ' ' | sed -e "s/^[ $TAB]*[Ss][Ss][Ll][Ll][Oo][Gg][ $TAB]*//g" -e "s/[ $TAB]*$//g"` 
         for e in $ssllogs; do 
            if [ ! "`echo $e | grep '^/'`" ]; then 
               # if non-absolute path then path is relative to Apache's 
               e=$SERVERROOT/$e 
            fi 
            if [ ! "`echo $e | grep '^|'`" ]; then 
               # only try to process the Log if it's not a Pipe log 
               if [ -f $e -a -r $e ]; then 
                  HTTPDERRLOG=$HTTPDERRLOG$NL$e 
               fi 
            fi 
         done 
         transferlogs=`egrep -i '^[ $TAB]*TransferLog[ $TAB]+' $httpd | tr '"' ' ' | sed -e "s/^[ $TAB]*[Tt][Rr][Aa][Nn][Ss][Ff][Ee][Er][Ll][Oo][Gg][ $TAB]*//g" -e "s/[ $TAB]*$//g"` 
         for t in $transferlogs; do 
            if [ ! "`echo $t | grep '^/'`" ];then 
               # if non-absolute path then path is relative to Apache's ServerRoot 
               t=$SERVERROOT/$t 
            fi 
            if [ ! "`echo $t | grep '^|'`" ]; then 
               # only try to process the Log if it's not a Pipe log 
               if [ -f $t -a -r $t ]; then 
                  HTTPDREQLOG=$HTTPDREQLOG$NL$t 
               fi 
            fi 
         done 
         customlogs=`egrep -i '^[ $TAB]*CustomLog[ $TAB]+' $httpd | tr '"' ' ' | sed -e "s/^[ $TAB]*[Cc][Uu][Ss][Tt][Oo][Mm][Ll][Oo][Gg][ $TAB]*//g" -e"s/^[ $TAB]*//g" -e"s/[ $TAB].*$//g"` 
         # Not sure whether spaces in customlogs filenames are being correctly dealt with here... 
         for c in $customlogs; do 
            if [ ! "`echo $c | grep '^/'`" ];then 
               # if non-absolute path then path is relative to Apache's ServerRoot 
               c=$SERVERROOT/$c 
            fi 
            if [ ! "`echo $c | grep '^|'`" ]; then 
               # only try to process the Log if it's not a Pipe log 
               if [ -f $c -a -r $c ]; then 
                  HTTPDREQLOG=$HTTPDREQLOG$NL$c 
               fi 
            fi 
         done 
      done 
      HTTPDERRLOG=`echo "$HTTPDERRLOG" | sort -u` 
      HTTPDREQLOG=`echo "$HTTPDREQLOG" | sort -u` 
      for e in $HTTPDERRLOG$NL$HTTPDREQLOG; do 
         # create a cut version of the log file 
         echo "Content taken from file $e" >"$OUT_DIR/${PRD}_`echo $e | tr '/' $PATH_REPLACE_CHAR`.txt" 
         tail -$LOGLINES "$e" >>"$OUT_DIR/${PRD}_`echo $e | tr '/' $PATH_REPLACE_CHAR`.txt" 
      done 
   } 

   httpServer_getJServConf() 
   { 
      JSERVPROPERTIES="" 
      JSERVZONEPROPS="" 
      JSERVCFGFILES="" 
      # collect config filles for JServ; getListenerConf must have been 
      # called previously, because $HTTPDCONF is used. 
      for httpd in $HTTPDCONF; do 
         properties=`egrep -i '^[ $TAB]*ApJServProperties[ $TAB]+' $httpd | tr '"' ' ' | sed -e "s/^[ $TAB]*[Aa][Pp][Jj][Ss][Ee][Rr][Vv][Pp][Rr][Oo][Pp][Ee][Rr][Tt][Ii][Ee][Ss][ $TAB]*//g" -e "s/^[ $TAB]*//g" -e "s/[ $TAB]*$//g"` 
         gproperties=`egrep -i '^[ $TAB]*ApJServGroup[ $TAB]+[A-Za-z0-9\-_]+[ $TAB]+[0-9]+[ $TAB]+[0-9]+[ $TAB]+' $httpd | sed -e "s/[ $TAB]*$//g" -e "s/^.*[ $TAB][ $TAB]*//g" -e "s/^[ $TAB]*//g" -e "s/[ $TAB]*$//g"` 
         for p in $properties $gproperties; do 
            if [ -f $p -a -r $p ]; then 
               JSERVPROPERTIES=$JSERVPROPERTIES$NL$p 
            fi; 
         done 
      done 
      JSERVPROPERTIES=`echo "$JSERVPROPERTIES" | sort -u` 
      for p in $JSERVPROPERTIES; do 
         JSERVCFGFILES=$JSERVCFGFILES$NL$p 
         zones=`egrep '^[ $TAB]*zones=' $p | sed -e "s/^[ $TAB]*zones=//g" | tr "," "$NL"` 
         for z in $zones; do 
            zprops=`egrep "^[ $TAB]*$z\.properties=" $p | sed -e "s/^[ $TAB]*$z\.properties=//g" | tr '"' ' '` 
            if [ -f $zprops -a -r $zprops ]; then 
               JSERVZONEPROPS=$JSERVZONEPROPS$NL$zprops 
               JSERVCFGFILES=$JSERVCFGFILES$NL$zprops 
            fi 
         done 
      done 
      JERVZONEPROPS=`echo "$JSERVZONEPROPS" | sort -u` 
      # do *not* make $JSERVCFGFILES unique, because it would mix up the 
      # order of entries 
      for j in $JSERVCFGFILES; do 
         echo "Content taken from file $j" > "$OUT_DIR/${PRD}_`echo $j | tr '/' $PATH_REPLACE_CHAR`.txt" 
         cat "$j" >> "$OUT_DIR/${PRD}_`echo $j | tr '/' $PATH_REPLACE_CHAR`.txt" 
      done 
   } 

   httpServer_getJServJavaVersions() 
   { 
      # Find JDK versions used by JServ engines. 
      # Depends on JSERVPROPERTIES 
      wrapperbin="" 
      for p in $JSERVPROPERTIES; do 
         wbin=`egrep -i '^[ $TAB]*wrapper.bin=' $p | sed -e "s/^[ $TAB]*[Ww][Rr][Aa][Pp][Pp][Ee][Rr]\.[Bb][Ii][Nn]=//g" | tr "," " "` 
         for w in $wbin; do 
            wrapperbin=$wrapperbin$NL$wbin 
         done 
      done 
      ( 
        for w in `echo "$wrapperbin" | sort -u`; do 
           echo $w 
           if [ "`basename \`dirname $w\``" = "bin" ]; then 
              ls -ld `dirname \`dirname $w\`` 
           fi 
           echo "" 
           $w -version 
           echo "" 
           $w -fullversion 
           echo "-----------------------------------------------------------------" 
         done 
       ) >$OUT_DIR/${PRD}_jserv_javaversions.txt 2>&1 
   } 

   httpServer_getJServLogs() 
   { 
      JSERVLOG="" 
      for httpd in $HTTPDCONF; do 
         jservlogs=`egrep -i '^[ $TAB]*ApJServLogFile[ $TAB]+' $httpd | tr '"' ' ' | sed -e "s/^[ $TAB]*[Aa][Pp][Jj][Ss][Ee][Rr][Vv][Ll][Oo][Gg][Ff][Ii][Ll][Ee][ $TAB]*//g" -e "s/[ $TAB]*$//g"` 
         for j in $jservlogs; do 
            if [ ! "`echo $j | grep '^/'`" ]; then 
               # if non-absolute path then path is relative to Apache's 
               j=$SERVERROOT/$j 
            fi 
            if [ ! "`echo $j | grep '^|'`" ]; then 
               # only try to process the Log if it's not a Pipe log 
               if [ -f $j -a -r $j ]; then 
                  JSERVLOG=$JSERVLOG$NL$j 
               fi 
            fi 
         done 
      done 
      for props in $JSERVPROPERTIES; do 
         logs=`egrep '^[ $TAB]*log.file=' $props | tr '"' ' ' | sed -e "s/^[ $TAB]*[Ll][Oo][Gg]\.[Ff][Ii][Ll][Ee]=[ $TAB]*//g" -e "s/[ $TAB]*$//g"` 
         for l in $logs; do 
            if [ -f $l -a -r $l ]; then 
               JSERVLOG=$JSERVLOG$NL$l 
            fi 
         done 
      done 
      JSERVLOG=`echo "$JSERVLOG" | sort -u` 
      for l in $JSERVLOG; do 
         # create a cut version of the log file 
         Log_Name=`echo $l | tr '/' $PATH_REPLACE_CHAR`
         echo "Content taken from file $l" >"$OUT_DIR/${PRD}_${Log_Name}.txt" 
         tail -$LOGLINES "$l" >> "$OUT_DIR/${PRD}_${Log_Name}.txt" 
         if [ -s ${OUT_DIR}/${PRD}_${Log_Name}.txt ]; then
            true
         else 
            echo "$l was empty" >> ${OUT_DIR}/${PRD}_${Log_Name}.txt
         fi
      done 
   } 

   httpServer_getModplsqlConf() 
   { 
      # Trying to find WV_GATEWAY_CFG from apache startup script. 
      # Also trying environment and default location 
      # needs HTTPDSTARTSCRIPTS 
      wdbcfg="" 
      for s in $HTTPDSTARTSCRIPTS; do 
         w=`grep WV_GATEWAY_CFG $s | sed -e "s/^.*WV_GATEWAY_CFG=//g" | sed -e "s/[ $TAB;].*$//g"` 
         if [ -f $w -a -r $w ]; then 
            wdbcfg=$wdbcfg$NL$w 
         fi 
      done 
      if [ -n "$WV_GATEWAY_CFG" ]; then 
         if [ -f $WV_GATEWAY_CFG -a -r $WV_GATEWAY_CFG ]; then 
            wdbcfg=$wdbcfg$NL$WV_GATEWAY_CFG 
         fi 
      fi 
      overapachetop=`dirname $APACHE_TOP` 
      if [ -f $overapachetop/modplsql/cfg/wdbsvr.app -a -r $overapachetop/modplsql/cfg/wdbsvr.app ]; then 
         wdbcfg=$wdbcfg$NL$overapachetop/modplsql/cfg/wdbsvr.app 
      fi 
      HTTPDMODPLSQLCFG=`echo "$wdbcfg" | sort -u` 
      for c in $HTTPDMODPLSQLCFG; do 
         echo "Content taken from file $c" > "$OUT_DIR/${PRD}_`echo $c | tr '/' $PATH_REPLACE_CHAR`.txt" 
         cat "$c" >>"$OUT_DIR/${PRD}_`echo $c | tr '/' $PATH_REPLACE_CHAR`.txt" 
      done 
   } 
 
   httpServer_getStartScripts() 
   { 
      # Trying to find WV_GATEWAY_CFG from apache startup script. 
      # Also trying environment and default location 
      apactl=$APACHE_TOP/bin/apachectl 
      htsctl=$APACHE_TOP/bin/httpdsctl 
      HTTPDSTARTSCRIPTS="" 
      if [ -f $apactl -a -r $apactl ]; then 
         HTTPDSTARTSCRIPTS=$apactl 
      fi 
      if [ -f $htsctl -a -r $htsctl ]; then 
         HTTPDSTARTSCRIPTS=$HTTPDSTARTSCRIPTS$NL$htsctl 
      fi 
      for s in $HTTPDSTARTSCRIPTS; do 
         echo "Content taken from file $s" > "$OUT_DIR/${PRD}_`echo $s | tr '/' $PATH_REPLACE_CHAR`.txt" 
         cat "$s" >> "$OUT_DIR/${PRD}_`echo $s | tr '/' $PATH_REPLACE_CHAR`.txt" 
      done 
   } 
 
   httpServer_getListenerConf 
   httpServer_getListenerLogs 
   httpServer_getStartScripts 
   httpServer_getModplsqlConf 
   httpServer_getJServConf 
   httpServer_getJServLogs 
   httpServer_getJServJavaVersions 
 
   # restore original Inter-Field-Separator setting 
   IFS=$OLDIFS 
   export IFS 
} 

Rvw_Web_Server_Build_Links ()
{
(
cat << EOF
<li>
Webserver (old)
<table bgcolor="lightblue"  width="100%">
<tr><td>
<ul>
<li><a href="${PRD}_Web_Env.txt" target="right_frame">Web Environment</a></li>
<li><a href="${PRD}_cfg_files.txt" target="right_frame">cfg files</a></li>
<li><a href="${PRD}_web_processes.txt" target="right_frame">Web Processes</a></li>
<li><a href="${PRD}_apache_over.htm" target="right_frame">Apache Over</a></li>
<li><a href="${PRD}_apache_processes.htm" target="right_frame">Apache Processes</a></li>
<li><a href="${PRD}_jserv_conf.htm" target="right_frame">JServ Over</a></li>
EOF

if [ "$DATABASE_INSTALLED" = "Y" ] ; then
   echo "<li><a href="${PRD}_signon.htm" target="right_frame">Signon - static</a></li>"
   echo "<li><a href="${PRD}_signonp.htm" target="right_frame">owa_util.print_cgi_env</a></li>"
fi
cat << EOF
</ul>
</td></tr>
</table>
</li>
EOF

if [ -n "$HTTPDCONF" ]; then
   cat << EOF
   <li>
   HTTP Server (new)
   <table bgcolor="lightblue" width="100%">
   <tr><td>
   <ul>
   <li>
   Listener config
   <ul>
EOF
  
   for h in $HTTPDCONF; do
      echo "<li><a href=\"${PRD}_`echo $h | tr '/' $PATH_REPLACE_CHAR`.txt\" target=\"right_frame\">$h</a></li>"
   done

   cat << EOF
   </ul>
   </li>
   <li>
   Listener Logs
   <ul>
EOF

   for h in $HTTPDERRLOG $HTTPDREQLOG; do
      echo "<li><a href=\"${PRD}_`echo $h | tr '/' $PATH_REPLACE_CHAR`.txt\" target=\"right_frame\">$h</a></li>"
   done
 
   cat << EOF
   </ul>
   </li>
   <li>
   HTTP Server start scripts
   <ul>
EOF
 
   for h in $HTTPDSTARTSCRIPTS; do
      echo "<li><a href=\"${PRD}_`echo $h | tr '/' $PATH_REPLACE_CHAR`.txt\" target=\"right_frame\">$h</a></li>"
   done
 
   cat << EOF
   </ul>
   </li>
EOF

   if [ -n "$HTTPDMODPLSQLCFG" ]; then
      cat << EOF
      <li>
      Possible candidates for mod_plsql config files
      <ul>
EOF
      for c in $HTTPDMODPLSQLCFG; do
         echo "<li><a href=\"${PRD}_`echo $c | tr '/' $PATH_REPLACE_CHAR`.txt\" target=\"right_frame\">$c</a></li>"
      done
   fi # modplsql

   cat << EOF
   </ul>
   </li>
EOF

   if [ -n "$JSERVCFGFILES" ]; then
  
      cat << EOF
      <li>
      JServ config
      <ul>
EOF

      for j in $JSERVCFGFILES; do
         echo "<li><a href=\"${PRD}_`echo $j | tr '/' $PATH_REPLACE_CHAR`.txt\" target=\"right_frame\">$j</a></li>"
      done
    
      cat << EOF
      </ul>
      </li>
      <li>
      JServ logs
      <ul>
EOF

      for j in $JSERVLOG; do
         echo "<li><a href=\"${PRD}_`echo $j | tr '/' $PATH_REPLACE_CHAR`.txt\" target=\"right_frame\">$j</a></li>"
      done
   
      cat << EOF
      </ul>
      </li>
      <li>
      <a href="${PRD}_jserv_javaversions.txt" target="right_frame">
      Java versions used by JServ
      </a>
      </li>
EOF

   fi # JServ

   cat << EOF
   </ul>
   </td></tr>
   </table>
   </li>
EOF
fi
) > $OUT_TMP/web_srvr_left_frame.$$
echo "$OUT_TMP/web_srvr_left_frame.$$" >> $OUT_TMP/output_frames.txt.$$

}

########################################
#  Execute the functions defined here  #
########################################
Review_Web_Server
Review_HttpServer
Rvw_Web_Server_Build_Links
