Test=`env|grep Setup_Program_Version`

##  The previous line MUST be the first line in the script.  If not, the check
##  for determining if this is called or started straight from command line
##  will not work (it will throw errors back to the screen).

##############################################################################
###    Name: setup.sh                              Version: 3.09
###      By: Oracle Corp.                    Last Modified: September 05, 2001
###                                                Written: 02/20/2002
### 
### Purpose: Script used to setup the internal variables used to gather
###          Web Server information as part of the RDA process.  This
###          script is not meant to be standalone, it will be called/sourced
###          from the main setup.sh of RDA.
###
##############################################################################
##  Modifications Section:
##############################################################################
##     Date        Author     Function       Changes
##############################################################################
##  09/05/2002     fkobylan                  Added comments to denote beginning
##    3.09                                   and end of Web Server variables.
##                                           Chgd to only pull back lines from
##                                           existing setup between beginning
##                                           and end lines found above.
##  05/20/2002     fkobylan                  No chgs.  Just matching version to
##    3.04                                   base setup.sh.
##  05/06/2002     fkobylan                  No chgs.  Just matching version to
##    3.02                                   base setup.sh.
##  02/20/2002     fkobylan                  Created.  Taken from original
##                                           setup.sh used for RDA
##############################################################################
###   Program Explanation:
###   ===================
###   This program prompts for parameters specific to Web Server/IAS installation.
###   It will store the answers in the main setup.txt file.  It is not intended
###   to be a standalone program, it must be sourced.
### ###########################################################################
# leave this echo as is.  Since we haven't run the main setup.sh to get here
# $ECHO isn't set and there is no special formatting we have to worry about
# anyway.
if [ -z "$Test" ]; then
   echo "This script cannot be run standalone"
   echo "It must be called from the main RDA setup.sh"
   echo "Exiting from setup.sh"
   exit
fi

Setup_Web_Env ()
{
## Procedure: Setup_Env ()
## Called to setup all the env variables ...
#############################################################################
## Variables Used to Process this script:
#############################################################################

ORAWEB_ADMIN_SET=${ORAWEB_ADMIN:=${ORACLE_HOME}/admin}
ORAWEB_SITE_SET=${ORAWEB_SITE:=web_site_name}
Variables_Found=N
if [ "$SETUP_TXT_Found" = "Y" ];then
    Variables_Found=Y
##  Get only the variables that apply to web
   Start_Line=`grep -n 'Beginning of Web Variables' $TEMP_DIR/tmp.$$ | cut -f1 -d:`
   End_Line=`grep -n 'End of Web Variables' $TEMP_DIR/tmp.$$ | cut -f1 -d:`
#  Handle it when the user cancels out of a previous run of setup.  If
#  Start_Line is null, it means they never got to this section at all.  If
#  End_Line is null, then they cancelled in this section.
   if [ -z "$Start_Line" ]; then
      Variables_Found=N
   elif [ -z "$End_Line" ]; then
      Tail_Lines=200
   else
      Tail_Lines=`expr $End_Line - $Start_Line`
   fi
fi

if [ "$Variables_Found" = "Y" ]; then
   tail +$Start_Line $TEMP_DIR/tmp.$$ | head -$Tail_Lines | grep -v '^##' > $TEMP_DIR/tmp.web.$$


# This section of the else should only run when no setup.txt file is present
# Once one is there it is used to pull up the users current settings
else

$ECHO "  WEB_APPS_INSTALLED=Y
`if [ -d $ORACLE_HOME/Apache/Apache -a -x $ORACLE_HOME/Apache/Apache ]; then 
    $ECHO APACHE_TOP=$ORACLE_HOME/Apache/Apache 
 else 
    $ECHO APACHE_TOP=/home/oracle/iasprod/Apache/Apache 
 fi` 
  WEB_BASE=http://${MACHINE2}:7777
  WEB_DCD=http://${MACHINE2}:7777/pls/DAD" > $TEMP_DIR/tmp.web.$$
fi

}

Get_Web_Input ()
{
## Procedure: Setup_Env ()
## Called to setup all the env variables ...
#############################################################################
## Variables Used to Process this script:
#############################################################################
$ECHO "$BOLD Gathering parameters for the Web Server section $OFF"

NO_PROMPT=N
WEB_APPS_INSTALLED_Found=N
APACHE_TOP_Found=N
WEB_BASE_Found=N
WEB_DCD_Found=N

$ECHO "########################################################################
##  Beginning of Web Variables
########################################################################
##" >> setup.txt

Args=`cat $TEMP_DIR/tmp.web.$$`
for CurArg in `$ECHO "$Args"`
do 
   Get_Arguments

   case "$NameVar" in
 
      WEB_APPS_INSTALLED)
         WEB_APPS_INSTALLED_Found=Y
         $ECHO
         Description="##  Is Oracle Web Applications (IAS, WAS, OAS) information requested?\n##"
         Prompt="Are Oracle Web Applications (OAS, WAS, iAS) installed and should\n## they be analyzed (Y/N)?"
         Append_Setup
         if [ "$ValueVar" = "N" ]; then
            Check_WebApps=N
         else
            Check_WebApps=Y
         fi
      ;;
      APACHE_TOP)
         APACHE_TOP_Found=Y
         Description="## WEB Section Variables:\n##\n## APACHE_TOP is the Location for the Apache Installed files and\n## Directories such as: conf and log\n##"
         Prompt="Enter the APACHE_TOP - Location of apache conf and log files\n## (used for config review)"
         if [ "$Check_WebApps" = "Y" ]; then
            $ECHO
         else
            NO_PROMPT=Y
         fi
         Append_Setup
      ;;
      WEB_BASE)
         WEB_BASE_Found=Y
         Description="## The web server checks require the base url and PLSQL to be setup as follows:\n##\n## These are used to run a test url with utl_http via SQLPLUS to test the\n## web servers plsql mod_plsql /pls/DAD or oas /DAD/plsql/\n##\n## WEB_BASE = the base url for the web server.\n##"
         Prompt="Enter the base url for the web server\n## (used for config review)"
         if [ "$Check_WebApps" = "Y" ]; then
            $ECHO
         else
            NO_PROMPT=Y
         fi
         Append_Setup
      ;;
      WEB_DCD) 
         WEB_DCD_Found=Y
         Prompt="Enter the WEB_DCD - base url or DCD to connect to database\n## (used to test plsql)"
         Description="##  WEB_DCD = the base url for the DCD to connect to the database\n##"
         if [ "$Check_WebApps" = "Y" ]; then
            $ECHO
         else
            NO_PROMPT=Y
         fi
         Append_Setup
      ;;

      *)  junk=NoOpHere
      ;;
   esac

done

if [ "$WEB_APPS_INSTALLED_Found" = "N" ]; then
   NameVar="WEB_APPS_INSTALLED"
   ValueVar=Y
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="##  Is Oracle Web Applications (IAS, WAS, OAS) information requested?\n##"
   Prompt="Are Oracle Web Applications (OAS, WAS, iAS) installed and should they be analyzed (Y/N)?"
   Append_Setup
   if [ "$ValueVar" = "N" ]; then
      Check_WebApps=N
   else
      Check_WebApps=Y
   fi
fi
if [ "$APACHE_TOP_Found" = "N" ]; then
   NameVar="APACHE_TOP"
   if [ -d $ORACLE_HOME/Apache/Apache -a -x $ORACLE_HOME/Apache/Apache ]; then 
      ValueVar=$ORACLE_HOME/Apache/Apache 
   else 
      ValueVar=/home/oracle/iasprod/Apache/Apache 
   fi
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="## WEB Section Variables:\n##\n## APACHE_TOP is the Location for the Apache Installed files and\n## Directories such as: conf and log\n##"
   Prompt="Enter the APACHE_TOP - Location of apache conf and log files\n## (used for config review)"
   if [ "$Check_WebApps" = "Y" ]; then
      $ECHO
   else
      NO_PROMPT=Y
   fi
   Append_Setup
fi
if [ "$WEB_BASE_Found" = "N" ]; then
   NameVar="WEB_BASE"
   ValueVar=http://${MACHINE2}:7777
   eval  `$ECHO "$NameVar=$ValueVar"`
   Prompt="Enter the base url for the web server\n## (used for config review)"
   Description="## The web server checks require the base url and PLSQL to be setup as follows:\n##\n## These are used to run a test url with utl_http via SQLPLUS to test the\n## web servers plsql mod_plsql /pls/DAD or oas /DAD/plsql/\n##\n## WEB_BASE = the base url for the web server.\n##"
   if [ "$Check_WebApps" = "Y" ]; then
      $ECHO
   else
      NO_PROMPT=Y
   fi
   Append_Setup
fi
if [ "$WEB_DCD_Found" = "N" ]; then
   NameVar="WEB_DCD"
   ValueVar=http://${MACHINE2}:7777/pls/DAD
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="##  WEB_DCD = the base url for the DCD to connect to the database\n##"
   Prompt="Enter the WEB_DCD - base url or DCD to connect to database\n## (used to test plsql)"
   if [ "$Check_WebApps" = "Y" ]; then
      $ECHO
   else
      NO_PROMPT=Y
   fi
   Append_Setup
fi

$ECHO "########################################################################
##  End of Web Variables
########################################################################" >> setup.txt


}


#############
##  Main   ##
#############

Setup_Web_Env   # Setup Default Values, if not present, build setup.txt file.

Get_Web_Input   # Get user input on the Values - allow changes, rewrite setup.txt

if [ "$Check_WebApps" = "Y" ]; then
   $ECHO $m >> mods_to_run.txt
fi

if [ "$DebugMode" = "n" ]; then
   rm -f $TEMP_DIR/tmp.web.$$ 2>/dev/null
fi
