Test=`env|grep RDA_Program_Version`

##  The previous line MUST be the first line in the script.  If not, the check
##  for determining if this is called or started straight from command line
##  will not work (it will throw errors back to the screen).

if [ -z "$Test" ]; then
   echo "This script cannot be run standalone"
   echo "It must be called from the main RDA rda.sh"
   echo "Exiting from rda.sh"
   exit
fi
###########################################################################
##    Name: rda.sh                                Version: 3.10
##      By: Oracle Corp.                    Last Modified: November 12, 2002
##                                                Written: 2/19/02  
##
## Purpose: This is the source script for handling the gathering of RDBMS
##          information (e.g. various db selects, alert log info, traces,
##          etc.).  This is not intended to be a standalone script,
##          it should be sourced from an executable script.
##
##   Usage: As a call from a script

##             . ./RDA_script_0020_RVW_RDBMS/rda.sh
##
###########################################################################

##############################################################################
##  Modifications Section:
##############################################################################
##     Date        Author     Function       Changes
##############################################################################
##  11/12/2002     fkobylan   Review_RDBMS   Added ls -l of /etc/password for
##    3.10                                   security files listing.
##  09/11/2002     fkobylan   Review_RDBMS   Dltd references to TWO_TASK.
##    3.09                                   Added data collection for security.
##                                           Added code to check for the 2
##                                           releases of 9i.
##                                           Cleaned up error displays when
##                                           pfile not found.
##                            Rvw_RDBMS_Build_Links
##                                           Added links for new security data.
##                            Process_Versions
##                                           Added code to differentiate 
##                                           between the two releases of 9i.
##  07/29/2002     fkobylan   Rvw_RDBMS_Build_Links
##    3.08                                   Chgd bg color for links.
##                            Review_RDBMS   Added code for replication data.
##                                           (Issue 148).
##                                           Added code for DBA_JOBS (issue 92).
##                                           Did some cleanup on sql to reduce
##                                           the number of DB connections.
##                                           Also added anchors to files with
##                                           multiple sql results.
##                                           Added query to get undocumented
##                                           parameters, but only if sysdba
##                                           user has been chosen (issue 85).
##  06/26/2002     fkobylan   Process_Versions
##    3.07                                   Removed unix.rgs from 9i and higher
##                                           since the info it contains is no
##                                           longer useful.
##  06/14/2002     fkobylan   Apps_Tables    Chgd all_errors to point to dba_
##    3.06                                   instead to match dba_objects query.
##                            Process_Versions
##                                           Chgd to determine location of 
##                                           unix.rgs by version.  (enhc 152).
##                                           Also added code to more fully 
##                                           parse out version for dealing with
##                                           NLS queries (timezones are not
##                                           available until 817). 
##                            Look_For_Parms Implemented a MUCH faster way of
##                                           parsing to get parm values.
##  05/20/2002     fkobylan   Review_RDBMS   Removed section for creating WebIV
##    3.04                                   link doc.
##                            Rvw_RDBMS_Build_Links
##                                           Removed link to WebIV doc.
##  03/25/2002     abardeen                  Added html tagging to output from
##    3.02                                   sql statements
##                 fkobylan                  Removed Run_SQL* functions.  They
##                                           are in the common module.
##                                           Added listings of bdump, udump,
##                                           cdump $O_H/rdbms/log and $O_H/dbs
##                                           directories.  Chgd method for
##                                           getting from v$parameter file
##                                           due to html chg.
##                                           Added selects for v$controlfile,
##                                           v$rollstat, dba_rollback_segs
##                                           v$undostat and dba_undo_extents.
##                                           Rollback/undo will be parameter and
##                                           version dependent.
##                                           Removed error and trace file listing
##                                           from alert log processing.
##                                           Chgd to use variable from Setup_OS
##                                           to determine number of lines to
##                                           display.
##                                           Chgd to handle tail limit for HP.
##                                           Increased number of lines from trace
##                                           file to 1000.
##                                           Added code to gather NLS info from
##                                           Added code to gather JVM info from
##                                           the db.
##  02/19/2002     fkobylan                  created 
##                                           based on code from original rda.sh.
#############################################################################

#############################################################################
##   Program Explanation:
##   ===================
##   The script is not intended to be a stand alone program.  Its function
##   is to handle the RDBMS information gathering and display for the RDA
##   RDA process.  It will execute SQL statements against the database
##   and gather files pertaining to the database install.  The output will
##   be formatted into files for display through a web browser.
#############################################################################

######################################
### Start of Review_RDBMS Function ###
######################################

Review_RDBMS ()
{
## Procedure Name: Review_RDBMS
################################################################
## Collects the Basic RDBMS Related configurations
################################################################

echo "${BOLD}Processing: Review_RDBMS ...${OFF}"

################################################################
### Get init.ora

DebugMessage=" Inside Review_RDBMS, processing init.ora"
Debug

if [ "$PFILE_LOCAL" = "Y" ]; then
   if [ -r "$PFILE_LOCATION" ]; then
#  Cat out the init.ora's and track any IFILE's
      PFILE_GOOD=Y
      echo "contents of init.ora $PFILE_LOCATION =============" > $OUT_DIR/${PRD}_init_ora.txt
      echo  >> $OUT_DIR/${PRD}_init_ora.txt
      cat $PFILE_LOCATION >> $OUT_DIR/${PRD}_init_ora.txt
   #  Grep out the IFILE and remove single ticks (just in case) and get rid of the 
   #  comments contained in the Oracle supplied init.ora
      IFILE=`grep -i ifile $PFILE_LOCATION |grep -iv '#.*ifile'| awk -F"=" '{print $2}'|sed s/\'//g|sed s!?!$ORACLE_HOME!`
   #  While we have an ifile, go get it and cat it to output
      while [ -n "$IFILE" ]; do
         echo " " >> $OUT_DIR/${PRD}_init_ora.txt
         echo "contents of IFILE $IFILE  ================" >> $OUT_DIR/${PRD}_init_ora.txt
         echo " " >> $OUT_DIR/${PRD}_init_ora.txt
         cat $IFILE >> $OUT_DIR/${PRD}_init_ora.txt
         NEXT_IFILE=$IFILE
         IFILE=`grep -i ifile $NEXT_IFILE |grep -iv '#.*ifile'| awk -F"=" '{print $2}'|sed s/\'//g|sed s!?!$ORACLE_HOME!`
      done
   else
      PFILE_GOOD=N
      echo "#######  $PFILE_LOCATION is not readable or does not exist #######" > $OUT_DIR/${PRD}_init_ora.txt
      echo "#######  File permissions are as follows (via ls)          #######" >> $OUT_DIR/${PRD}_init_ora.txt
      ls -al $PFILE_LOCATION >> $OUT_DIR/${PRD}_init_ora.txt 2>&1
      echo "#######  Review Database Parameters output in RDBMS        #######" >> $OUT_DIR/${PRD}_init_ora.txt
      echo "#######  section for parameter settings                    #######" >> $OUT_DIR/${PRD}_init_ora.txt
   fi
else
   echo "#######  Init.ora not located on this server         #######" > $OUT_DIR/${PRD}_init_ora.txt
   echo "#######  Review Database Parameter output in RDBMS   #######" >> $OUT_DIR/${PRD}_init_ora.txt
   echo "#######  section for parameter settings              #######" >> $OUT_DIR/${PRD}_init_ora.txt
fi

################################################################
### Get Product Versions

DebugMessage=" Inside Review_RDBMS, processing product versions"
Debug
## This output is parsed to get the version of the database.  It skips around
## the html tagging to determine which version is being dealt with, so any
## changes to the format of the output could break the parsing.  Tread VEWY
## cawefuwwy.

SQL="$RDA_sqlset1
prompt $RDA_html_h31 Product Versions from V\$Version $RDA_html_h32 
prompt $RDA_html_tab1
prompt $RDA_html_tdh1 Banner $RDA_html_tdh2
SELECT '<TR>' || $RDA_html_td1 || banner || $RDA_html_td2 || '</TR>'
FROM v\$version;
prompt </TABLE>"
 Run_SQL
cat $OUT_DIR/$OUT_FILE.txt > $OUT_TMP/${PRD}_versions.htm$$

 version=all        # Uses unix.rgs Versions/date or put =product
 Process_Versions   # RDBMS Version Information. Creates _Versions.txt

## Merge the OS and database versions
echo "<br><br>" >> $OUT_TMP/${PRD}_versions.htm$$
echo "<pre>" >> $OUT_TMP/${PRD}_versions.htm$$

if [ "$Do_UnixRgs" = "Y" ]; then
   echo "From: ORACLE_HOME/${Install_Dir}/unix.rgs" >> $OUT_TMP/${PRD}_versions.htm$$
fi
echo "==============================================================" >> $OUT_TMP/${PRD}_versions.htm$$
cat $OUT_DIR/${PRD}_Versions.htm >> $OUT_TMP/${PRD}_versions.htm$$
mv $OUT_TMP/${PRD}_versions.htm$$ $OUT_DIR/${PRD}_Versions.htm 2>/dev/null

################################################################
### Database Queries - GENERIC (same on all versions from 7 - 9)
################################################################

DebugMessage=" Inside Review_RDBMS, processing database queries"
Debug
echo "   processing database queries"


################################################################
### Processing Invalid Objects
DebugMessage=" Inside Review_RDBMS, processing invalid objects"
Debug

echo "$RDA_html_h31 Invalid Objects for ${ORACLE_SID} $RDA_html_h32" > $OUT_DIR/${PRD}_Invalids.htm 
echo "$RDA_html_tab1" >> $OUT_DIR/${PRD}_Invalids.htm 
echo "$RDA_html_tdh1 Owner $RDA_html_tdh2" >> $OUT_DIR/${PRD}_Invalids.htm 
echo "$RDA_html_tdh1 Object_Name $RDA_html_tdh2" >> $OUT_DIR/${PRD}_Invalids.htm 
echo "$RDA_html_tdh1 Object_Type $RDA_html_tdh2" >> $OUT_DIR/${PRD}_Invalids.htm 
echo "$RDA_html_tdh1 Created $RDA_html_tdh2" >> $OUT_DIR/${PRD}_Invalids.htm 
echo "$RDA_html_tdh1 Last_DDL_Time (M) $RDA_html_tdh2" >> $OUT_DIR/${PRD}_Invalids.htm 
echo "$RDA_html_tdh1 Status $RDA_html_tdh2" >> $OUT_DIR/${PRD}_Invalids.htm 

apps=invalid  #  Sets SQL so Run_SQL gets invalid objects
Apps_Tables
Run_SQL         
cat $OUT_DIR/$OUT_FILE.txt >> $OUT_DIR/${PRD}_Invalids.htm

################################################################
### Processing ALL_ERRORS
DebugMessage=" Inside Review_RDBMS, processing dba_errors"
Debug

echo "$RDA_html_h31 Errors for Invalid Objects for $ORACLE_SID $RDA_html_h32" > $OUT_DIR/${PRD}_ALL_Errors.htm
echo "$RDA_html_tab1" >> $OUT_DIR/${PRD}_ALL_Errors.htm
echo "$RDA_html_tdh1 Owner $RDA_html_tdh2" >> $OUT_DIR/${PRD}_ALL_Errors.htm 
echo "$RDA_html_tdh1 Object Name $RDA_html_tdh2" >> $OUT_DIR/${PRD}_ALL_Errors.htm 
echo "$RDA_html_tdh1 Line/Pos $RDA_html_tdh2" >> $OUT_DIR/${PRD}_ALL_Errors.htm 
echo "$RDA_html_tdh1 Error Text $RDA_html_tdh2" >> $OUT_DIR/${PRD}_ALL_Errors.htm 

   apps=invalid_errors  # sets SQL so Run_SQL gets all_errors info
   Apps_Tables
   Run_SQL
   cat $OUT_DIR/$OUT_FILE.txt >> $OUT_DIR/${PRD}_ALL_Errors.htm

################################################################
### Processing V$OPTION
DebugMessage=" Inside Review_RDBMS, processing v\$option"
Debug

SQL="$RDA_sqlset1
prompt $RDA_html_h31 Database Options $RDA_html_h32
prompt $RDA_html_tab1
prompt $RDA_html_tdh1 Parameter $RDA_html_tdh2
prompt $RDA_html_tdh1 Value $RDA_html_tdh2

SELECT '<TR>' || $RDA_html_td1 || o.parameter || $RDA_html_td2,
       $RDA_html_td1 || o.value || $RDA_html_td2 || '</TR>'
FROM v\$option o order by o.parameter;
prompt </TABLE>"
 
Run_SQL
cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_voption.htm

################################################################
### Processing SGA Information
DebugMessage=" Inside Review_RDBMS, processing sga information"
Debug

if [ "$ORACLE_VERSION" = "7" ]; then
   SGAStat_SQL="
   prompt <a name=02></a>
   prompt $RDA_html_h31 V\$SGASTAT $RDA_html_h32
   prompt $RDA_html_tab1
   prompt $RDA_html_tdh1 Name $RDA_html_tdh2
   prompt $RDA_html_tdh1 Bytes $RDA_html_tdh2

   SELECT '<TR>' || $RDA_html_td1 || v.name || $RDA_html_td2, 
       $RDA_html_td1 || v.bytes || $RDA_html_td2 || '</TR>'
   FROM V\$sgastat v;
   prompt </TABLE> 
   prompt <a href="#00">Back to top</a>"
else
   SGAStat_SQL="
   prompt <a name=02></a>
   prompt $RDA_html_h31 V\$SGASTAT $RDA_html_h32
   prompt $RDA_html_tab1
   prompt $RDA_html_tdh1 Pool $RDA_html_tdh2
   prompt $RDA_html_tdh1 Name $RDA_html_tdh2
   prompt $RDA_html_tdh1 Bytes $RDA_html_tdh2

   SELECT '<TR>' || $RDA_html_td1 || nvl(v.pool,'<i>null value</i>') || $RDA_html_td2,
       $RDA_html_td1 || v.name || $RDA_html_td2, 
       $RDA_html_td1 || v.bytes || $RDA_html_td2 || '</TR>'
   FROM V\$sgastat v;
   prompt </TABLE> 
   prompt <a href="#00">Back to top</a>"
fi

SQL="$RDA_sqlset1
prompt <a name=00></a>
prompt <Center>$RDA_html_h31 Information from V\$SGA and V\$SGAStat $RDA_html_h32 </Center>
prompt <p><a href="#01">V\$SGA</a><br>
prompt <a href="#02">V\$SGAStat</a></p><br>
prompt <a name=01></a>
prompt $RDA_html_h31 V\$SGA $RDA_html_h32
prompt $RDA_html_tab1
prompt $RDA_html_tdh1 Name # $RDA_html_tdh2
prompt $RDA_html_tdh1 Value $RDA_html_tdh2

SELECT '<TR>' || $RDA_html_td1 || s.name || $RDA_html_td2,
       $RDA_html_td1 || s.value || $RDA_html_td2 || '</TR>'
FROM v\$sga s;
prompt </TABLE>
prompt <a href="#00">Back to top</a>

$SGAStat_SQL"

Run_SQL
cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_sga_info.htm

################################################################
### Processing V$License
DebugMessage=" Inside Review_RDBMS, processing v\$license"
Debug

SQL="$RDA_sqlset1
prompt $RDA_html_h31 V\$License $RDA_html_h32
prompt $RDA_html_tab1

SELECT  '<TR>' || $RDA_apos $RDA_html_tdh1 $RDA_apos || 'Max Sessions' || $RDA_apos $RDA_html_tdh2 $RDA_apos || 
    $RDA_html_td1|| l.sessions_max || $RDA_html_td2 || '</TR>' || 
  '<TR>' || $RDA_apos $RDA_html_tdh1 $RDA_apos || 'Warning Sessions' || $RDA_apos $RDA_html_tdh2 $RDA_apos  || 
    $RDA_html_td1 || l.sessions_warning || $RDA_html_td2 || '</TR>' || 
  '<TR>' ||  $RDA_apos $RDA_html_tdh1 $RDA_apos || 'Current Sessions' || $RDA_apos $RDA_html_tdh2 $RDA_apos  || 
    $RDA_html_td1 || l.sessions_current || $RDA_html_td2 || '</TR>' || 
  '<TR>' ||  $RDA_apos $RDA_html_tdh1 $RDA_apos || 'Highwater Sessions' || $RDA_apos $RDA_html_tdh2 $RDA_apos || 
    $RDA_html_td1 || l.sessions_highwater || $RDA_html_td2 || '</TR>' ||
  '<TR>' || $RDA_apos $RDA_html_tdh1 $RDA_apos || 'Max Users' || $RDA_apos $RDA_html_tdh2 $RDA_apos || 
    $RDA_html_td1 || l.users_max || $RDA_html_td2 || '</TR>' 
  FROM v\$license l;
prompt </TABLE>"

Run_SQL
cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_vlicense.htm

################################################################
### Processing V$Compatibility
DebugMessage=" Inside Review_RDBMS, processing v\$compatibility"
Debug

SQL="$RDA_sqlset1
prompt $RDA_html_h31 V\$Compatibility $RDA_html_h32
prompt $RDA_html_tab1
prompt $RDA_html_tdh1 Type ID $RDA_html_tdh2
prompt $RDA_html_tdh1 Release $RDA_html_tdh2
prompt $RDA_html_tdh1 Description $RDA_html_tdh2

SELECT '<TR>' || $RDA_html_td1 || c.type_id || $RDA_html_td2,
       $RDA_html_td1 || c.release || $RDA_html_td2,
       $RDA_html_td1 || c.description || $RDA_html_td2 || '</TR>'
FROM v\$compatibility c order by c.type_id;
prompt </TABLE>"

 Run_SQL
cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_vcompatibility.htm

################################################################
### Processing V$Logfile & V$Log
DebugMessage="Inside Review_RDBMS, processing log information"
Debug

#  In Oracle 7, first time in V$Log is a varchar2 field, we need to not try
#  to format it, otherwise it throws and invalid number error.
if [ "$ORACLE_VERSION" = "7" ]; then
   VLog_Line9_SQL="$RDA_html_td1 || l.first_time || $RDA_html_td2 || '</TR>'"
else
   VLog_Line9_SQL="$RDA_html_td1 || to_char(l.first_time,'dd-mon-yy hh24:mi') || $RDA_html_td2 || '</TR>'"
fi

SQL="$RDA_sqlset1
prompt <a name=00></a>
prompt <Center>$RDA_html_h31 Information from V\$Logfile and V\$Log $RDA_html_h32 </Center>
prompt <p><a href="#01">V\$Logfile</a><br>
prompt <a href="#02">V\$Log</a></p><br>
prompt <a name=01></a>
prompt $RDA_html_h31 V\$Logfile $RDA_html_h32
prompt $RDA_html_tab1
prompt $RDA_html_tdh1 Group # $RDA_html_tdh2
prompt $RDA_html_tdh1 Status $RDA_html_tdh2
prompt $RDA_html_tdh1 Member $RDA_html_tdh2

SELECT '<TR>' || $RDA_html_td1 || l.group# || $RDA_html_td2,
       $RDA_html_td1 || nvl(l.status,'<i>null value</i>') || $RDA_html_td2,
       $RDA_html_td1 || l.member || $RDA_html_td2 || '</TR>'
FROM v\$logfile l order by l.group#,l.member;
prompt </TABLE>
prompt <a href="#00">Back to top</a>

prompt <a name=02></a>
prompt $RDA_html_h31 V\$Log $RDA_html_h32
prompt $RDA_html_tab1
prompt $RDA_html_tdh1 Group # $RDA_html_tdh2
prompt $RDA_html_tdh1 Thread # $RDA_html_tdh2
prompt $RDA_html_tdh1 Sequence # $RDA_html_tdh2
prompt $RDA_html_tdh1 Bytes $RDA_html_tdh2
prompt $RDA_html_tdh1 Members $RDA_html_tdh2
prompt $RDA_html_tdh1 Archived $RDA_html_tdh2
prompt $RDA_html_tdh1 Status $RDA_html_tdh2
prompt $RDA_html_tdh1 First Change # $RDA_html_tdh2
prompt $RDA_html_tdh1 First Time $RDA_html_tdh2

SELECT '<TR>' || $RDA_html_td1 || l.group# || $RDA_html_td2,
       $RDA_html_td1 || l.thread# || $RDA_html_td2,
       $RDA_html_td1 || l.sequence# || $RDA_html_td2,
       $RDA_html_td1 || l.bytes || $RDA_html_td2,
       $RDA_html_td1 || l.members || $RDA_html_td2,
       $RDA_html_td1 || l.archived || $RDA_html_td2,
       $RDA_html_td1 || nvl(l.status,'<i>null value</i>') || $RDA_html_td2,
       $RDA_html_td1 || l.first_change# || $RDA_html_td2,
       $VLog_Line9_SQL
FROM v\$log l order by l.group#,l.thread#;
prompt </TABLE>
prompt <a href="#00">Back to top</a>"

Run_SQL
cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_log_info.htm

################################################################
### Processing V$System_event
DebugMessage=" Inside Review_RDBMS, processing v\$system_event"
Debug

SQL="$RDA_sqlset1
prompt $RDA_html_h31 V\$System_Event $RDA_html_h32
prompt $RDA_html_tab1
prompt $RDA_html_tdh1 Wait Event $RDA_html_tdh2
prompt $RDA_html_tdh1 Waits $RDA_html_tdh2
prompt $RDA_html_tdh1 Timeouts $RDA_html_tdh2
prompt $RDA_html_tdh1 Time Waited $RDA_html_tdh2
prompt $RDA_html_tdh1 Average Wait $RDA_html_tdh2

SELECT '<TR>' || $RDA_html_td1 || s.event || $RDA_html_td2,
       $RDA_html_td1 || s.total_waits || $RDA_html_td2,
       $RDA_html_td1 || s.total_timeouts || $RDA_html_td2,
       $RDA_html_td1 || s.time_waited || $RDA_html_td2,
       $RDA_html_td1 || round(s.average_wait,2) || $RDA_html_td2 || '</TR>'
FROM v\$system_event s order by s.time_waited desc,s.event;
prompt </TABLE>"

 Run_SQL
cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_vsystem_event.htm

################################################################
### Processing V$session_wait
DebugMessage=" Inside Review_RDBMS, processing v\$session_wait"
Debug

SQL="$RDA_sqlset1
prompt $RDA_html_h31 Summary of Sessions Currently Waiting (from V\$Session_Wait) $RDA_html_h32
prompt $RDA_html_tab1
prompt $RDA_html_tdh1 Wait Event $RDA_html_tdh2
prompt $RDA_html_tdh1 Total Sessions Waiting $RDA_html_tdh2

SELECT '<TR>' || $RDA_html_td1 || w.event || $RDA_html_td2,
       $RDA_html_td1 || count(*) || $RDA_html_td2 || '</TR>'
FROM v\$session_wait w where wait_time=0 group by event order by 2 desc;
prompt </TABLE>"

 Run_SQL
cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_vsession_wait.htm

################################################################
### Processing V$Latch and V$Latchholder
DebugMessage=" Inside Review_RDBMS, processing latch information"
Debug

SQL="$RDA_sqlset1
prompt <a name=00></a>
prompt <Center>$RDA_html_h31 Information from V\$Latch and V\$Latchholder $RDA_html_h32 </Center>
prompt <p><a href="#01">V\$Latch</a><br>
prompt <a href="#02">V\$Latchholder</a></p><br>
prompt <a name=01></a>
prompt $RDA_html_h31 V\$Latch $RDA_html_h32
prompt $RDA_html_tab1
prompt $RDA_html_tdh1 Latch # $RDA_html_tdh2
prompt $RDA_html_tdh1 Name $RDA_html_tdh2
prompt $RDA_html_tdh1 Gets $RDA_html_tdh2
prompt $RDA_html_tdh1 Misses $RDA_html_tdh2
prompt $RDA_html_tdh1 Sleeps $RDA_html_tdh2
prompt $RDA_html_tdh1 Immediate Gets $RDA_html_tdh2
prompt $RDA_html_tdh1 Immediate Misses $RDA_html_tdh2

SELECT '<TR>' || $RDA_html_td1 || l.latch# || $RDA_html_td2,
       $RDA_html_td1 || l.name || $RDA_html_td2,
       $RDA_html_td1 || l.gets || $RDA_html_td2,
       $RDA_html_td1 || l.misses || $RDA_html_td2,
       $RDA_html_td1 || l.sleeps || $RDA_html_td2,
       $RDA_html_td1 || l.immediate_gets || $RDA_html_td2,
       $RDA_html_td1 || l.immediate_misses || $RDA_html_td2 || '</TR>'
FROM v\$latch l order by sleeps desc;
prompt </TABLE>
prompt <a href="#00">Back to top</a>

prompt <a name=02></a>
prompt $RDA_html_h31 V\$LatchHolder $RDA_html_h32
prompt $RDA_html_tab1
prompt $RDA_html_tdh1 PID # $RDA_html_tdh2
prompt $RDA_html_tdh1 SID $RDA_html_tdh2
prompt $RDA_html_tdh1 Latch Address $RDA_html_tdh2
prompt $RDA_html_tdh1 Name $RDA_html_tdh2

SELECT '<TR>' || $RDA_html_td1 || l.pid|| $RDA_html_td2,
       $RDA_html_td1 || l.sid || $RDA_html_td2,
       $RDA_html_td1 || l.laddr || $RDA_html_td2,
       $RDA_html_td1 || l.name || $RDA_html_td2 || '</TR>'
FROM v\$latchholder l;
prompt </TABLE>
prompt <a href="#00">Back to top</a>"

Run_SQL
cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_latch_info.htm

################################################################
### Processing V$controlfile 

DebugMessage=" Inside Review_RDBMS, processing v\$controlfile"
Debug

SQL="$RDA_sqlset1
prompt $RDA_html_h31 V\$CONTROLFILE $RDA_html_h32
prompt $RDA_html_tab1
prompt $RDA_html_tdh1 Name $RDA_html_tdh2
prompt $RDA_html_tdh1 Status $RDA_html_tdh2

SELECT '<TR>' || $RDA_html_td1 || v.name || $RDA_html_td2, 
    $RDA_html_td1 || nvl(v.status,'<i>null value</i>') || $RDA_html_td2 || '</TR>'
FROM V\$controlfile v;
prompt </TABLE>"

Run_SQL
cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_vcontrolfile.htm

################################################################
### Processing NLS Parameters
###  Timezone does not exist until 8i, so we need to code around it
DebugMessage=" Inside Review_RDBMS, processing nls parms, Do_TimeZone=$Do_TimeZone"
Debug

#  Timezone did not exist until 817.  The Do_TimeZone flag should be set to N
#  for all versions prior to 817, and set to Y for 817 and higher.
if [ "$Do_TimeZone" = "N" ]; then
   SQL="$RDA_sqlset1
   prompt <a name=00></a>
   prompt $RDA_html_h31 NLS Database Settings $RDA_html_h32
   prompt <p><a href="#01">NLS Database Parameters</a><br>
   prompt <a href="#02">NLS Instance Parameters</a><br>
   prompt <a href="#03">NLS Session Parameters</a><br>
   prompt <a name=01></a>
   prompt $RDA_html_h31 NLS_Database_Parameters $RDA_html_h32
   prompt $RDA_html_tab1
   prompt $RDA_html_tdh1 Parameter Name $RDA_html_tdh2
   prompt $RDA_html_tdh1 Value $RDA_html_tdh2

   SELECT '<TR>' || $RDA_html_td1 || n.parameter || $RDA_html_td2,
       $RDA_html_td1 || n.value || $RDA_html_td2 || '</TR>'
   FROM nls_database_parameters n  order by n.parameter;
   prompt </TABLE>
   prompt <a href="#00">Back to top</a>

   prompt <a name=02></a>
   prompt $RDA_html_h31 NLS_Instance_Parameters $RDA_html_h32
   prompt $RDA_html_tab1
   prompt $RDA_html_tdh1 Parameter Name $RDA_html_tdh2
   prompt $RDA_html_tdh1 Value $RDA_html_tdh2
   
   SELECT '<TR>' || $RDA_html_td1 || n.parameter || $RDA_html_td2,
       $RDA_html_td1 || nvl(n.value,'<i>null value</i>') || $RDA_html_td2 || '</TR>'
   FROM nls_instance_parameters n  order by n.parameter;
   prompt </TABLE>
   prompt <a href="#00">Back to top</a>

   prompt <a name=03></a>
   prompt $RDA_html_h31 NLS_Session_Parameters $RDA_html_h32
   prompt $RDA_html_tab1
   prompt $RDA_html_tdh1 Parameter Name $RDA_html_tdh2
   prompt $RDA_html_tdh1 Value $RDA_html_tdh2

   SELECT '<TR>' || $RDA_html_td1 || n.parameter || $RDA_html_td2,
       $RDA_html_td1 || n.value || $RDA_html_td2 || '</TR>'
   FROM nls_session_parameters n  order by n.parameter;
   prompt </TABLE>
   prompt <a href="#00">Back to top</a>

   prompt $RDA_html_h31 TimeZone Values do not Exist in this Database Version $RDA_html_h32
   prompt <a href="#00">Back to top</a>"
else
   SQL="$RDA_sqlset1
   prompt <a name=00></a>
   prompt $RDA_html_h31 NLS Database Settings $RDA_html_h32
   prompt <p><a href="#01">NLS Database Parameters</a><br>
   prompt <a href="#02">NLS Instance Parameters</a><br>
   prompt <a href="#03">NLS Session Parameters</a><br>
   prompt <a href="#04">NLS Session TimeZone</a><br>
   prompt <a href="#05">NLS Database TimeZone</a></p>
   prompt <a name=01></a>
   prompt $RDA_html_h31 NLS_Database_Parameters $RDA_html_h32
   prompt $RDA_html_tab1
   prompt $RDA_html_tdh1 Parameter Name $RDA_html_tdh2
   prompt $RDA_html_tdh1 Value $RDA_html_tdh2

   SELECT '<TR>' || $RDA_html_td1 || n.parameter || $RDA_html_td2,
       $RDA_html_td1 || n.value || $RDA_html_td2 || '</TR>'
   FROM nls_database_parameters n  order by n.parameter;
   prompt </TABLE>
   prompt <a href="#00">Back to top</a>

   prompt <a name=02></a>
   prompt $RDA_html_h31 NLS_Instance_Parameters $RDA_html_h32
   prompt $RDA_html_tab1
   prompt $RDA_html_tdh1 Parameter Name $RDA_html_tdh2
   prompt $RDA_html_tdh1 Value $RDA_html_tdh2
   
   SELECT '<TR>' || $RDA_html_td1 || n.parameter || $RDA_html_td2,
       $RDA_html_td1 || nvl(n.value,'<i>null value</i>') || $RDA_html_td2 || '</TR>'
   FROM nls_instance_parameters n  order by n.parameter;
   prompt </TABLE>
   prompt <a href="#00">Back to top</a>

   prompt <a name=03></a>
   prompt $RDA_html_h31 NLS_Session_Parameters $RDA_html_h32
   prompt $RDA_html_tab1
   prompt $RDA_html_tdh1 Parameter Name $RDA_html_tdh2
   prompt $RDA_html_tdh1 Value $RDA_html_tdh2

   SELECT '<TR>' || $RDA_html_td1 || n.parameter || $RDA_html_td2,
       $RDA_html_td1 || n.value || $RDA_html_td2 || '</TR>'
   FROM nls_session_parameters n  order by n.parameter;
   prompt </TABLE>
   prompt <a href="#00">Back to top</a>

   prompt <a name=04></a>
   prompt $RDA_html_h31 Session TimeZone $RDA_html_h32
   prompt $RDA_html_tab1
   prompt $RDA_html_tdh1 TimeZone $RDA_html_tdh2

   SELECT '<TR>' || $RDA_html_td1 || d.sessiontimezone || $RDA_html_td2 || '</TR>'
   from (select sessiontimezone from dual) d;
   prompt </TABLE>
   prompt <a href="#00">Back to top</a>

   prompt <a name=05></a>
   prompt $RDA_html_h31 Database TimeZone $RDA_html_h32
   prompt $RDA_html_tab1
   prompt $RDA_html_tdh1 TimeZone $RDA_html_tdh2

   SELECT '<TR>' || $RDA_html_td1 || d.dbtimezone || $RDA_html_td2 || '</TR>'
   from (select dbtimezone from dual) d;
   prompt </TABLE>
   prompt <a href="#00">Back to top</a>"
fi

Run_SQL
cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_nls_parms.htm

################################################################
### Database Queries
###
### Due to the html tagging, we've had to separate the queries
### against views that have changed among releases 7 - 9.
### 
### This section is for queries that are different in 7, but
### the same in 8-9.
###


if [ "$ORACLE_VERSION" = "7" ]; then

  ################################################################
  ### Processing V$PARAMETER for V7
  ###   Be very careful with any changes to the v$parameter output
  ###   it is parsed to get cdbump, bdump and udump locations and
  ###   any changes could have serious impact on the parsing.

   DebugMessage=" Inside Review_RDBMS, processing v\$parameter for V7"
   Debug

   SQL="$RDA_sqlset1
   prompt <A NAME="V\$Parameter"></A>
   prompt $RDA_html_h31 Initialization Parameters $RDA_html_h32
   prompt $RDA_html_tab1
   prompt $RDA_html_tdh1 Parameter Name $RDA_html_tdh2
   prompt $RDA_html_tdh1 Value $RDA_html_tdh2
   prompt $RDA_html_tdh1 Default $RDA_html_tdh2

   SELECT '<TR>' || $RDA_html_td1 || substr(name,0,512) || $RDA_html_td2,
   $RDA_html_td1 || NVL(SUBSTR(value,0,512), '<i>null value</i>') || $RDA_html_td2 ,  
   $RDA_html_td1 || isdefault || $RDA_html_td2 || '</TR>'
   FROM v\$parameter 
   ORDER BY name;
   prompt </TABLE>"

   Run_SQL
   cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_vparameters.htm

else

  ################################################################
  ### Version 8-9 queries

  ################################################################
  ### Processing V$PARAMETER for V8-9
  ###   Be very careful with any changes to the v$parameter output
  ###   it is parsed to get cdbump, bdump and udump locations and
  ###   any changes could have serious impact on the parsing.

   DebugMessage=" Inside Review_RDBMS, processing v\$parameter for V8-9
   SYSDBA_USER=$SYSDBA_USER"
   Debug

#  Determine if we can go after the hidden parameters.  The only userid to
#  be guaranteed access to the x$ tables will be someone logged in as sysdba.
#  Check for SYSDBA_USER being = Y, if it is, go after the undocumented parms,
#  otherwise, throw a blurb.
   if [ "$SYSDBA_USER" = "Y" ]; then
      Undoc_Parms="
      prompt <a name=02></a>
      prompt $RDA_html_h31 Undocumented Parameters $RDA_html_h32
      prompt $RDA_html_tab1
      prompt $RDA_html_tdh1 Parameter Name $RDA_html_tdh2
      prompt $RDA_html_tdh1 Session Value $RDA_html_tdh2
      prompt $RDA_html_tdh1 System Value $RDA_html_tdh2

      SELECT '<TR>' || $RDA_html_td1 || substr(a.ksppinm,0,512) || $RDA_html_td2,
      $RDA_html_td1 || NVL(SUBSTR(b.ksppstvl,0,512), '<i>null value</i>') || $RDA_html_td2 ,  
      $RDA_html_td1 || NVL(SUBSTR(c.ksppstvl,0,512), '<i>null value</i>') || $RDA_html_td2 || '</TR>' 
      FROM x\$ksppi a,
           x\$ksppcv b,
           x\$ksppsv c 
      where a.indx = b.indx
         and a.indx = c.indx
         and substr(a.ksppinm,1,1) = '_' 
      ORDER BY a.ksppinm;
      prompt </TABLE>
      prompt <a href="#00">Back to top</a>"
   else
      Undoc_Parms="
      prompt <a name=02></a>
      prompt <p><b>Undocumented parameters are only available to SYSDBA user.<br>
      prompt The SYSDBA user option was not selected during setup.<br>
      prompt Undocumented parameters not gathered.</b></p>
      prompt <a href="#00">Back to top</a>"
   fi

   SQL="$RDA_sqlset1
   prompt <a name=00></a>
   prompt $RDA_html_h31 Database Parameter Settings $RDA_html_h32
   prompt <p><a href="#01">V\$Parameter</a><br>
   prompt <a href="#02">Undocumented Parameters</a><br>
   prompt <a name=01></a>
   prompt $RDA_html_h31 V\$Parameter $RDA_html_h32
   prompt $RDA_html_tab1
   prompt $RDA_html_tdh1 Parameter Name $RDA_html_tdh2
   prompt $RDA_html_tdh1 Value $RDA_html_tdh2
   prompt $RDA_html_tdh1 Default $RDA_html_tdh2
   prompt $RDA_html_tdh1 Modified $RDA_html_tdh2

   SELECT '<TR>' || $RDA_html_td1 || substr(name,0,512) || $RDA_html_td2,
   $RDA_html_td1 || NVL(SUBSTR(value,0,512), '<i>null value</i>') || $RDA_html_td2 ,  
   $RDA_html_td1 || isdefault || $RDA_html_td2 , 
   $RDA_html_td1 || ismodified || $RDA_html_td2 || '</TR>' 
   FROM v\$parameter 
   ORDER BY name;
   prompt </TABLE> 
   prompt <a href="#00">Back to top</a>

   $Undoc_Parms"

   Run_SQL
   cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_vparameters.htm
fi

#  This needs to be put here, after we've gotten the v$parameter and before
#  we do any processing needing parameter values.

#  Let's look thru the output from the query of v$parameters for various parms
if [ -r $OUT_DIR/${PRD}_vparameters.htm ]; then
   DebugMessage=" Inside Review_RDBMS, found v$parameter output, get some parms"
   Debug
   AUM_Setting=manual
   Look_For_Parms
fi
 
################################################################
### Processing JVM Information
DebugMessage=" Inside Review_RDBMS, processing jvm info"
Debug

#  JVM info should only be 8i and higher
if [ "$ORACLE_VERSION" = "7" -o "$ORACLE_VERSION" = "80" ];then
   true
else
   SQL="$RDA_sqlset1
   prompt <a name=00></a>
   prompt $RDA_html_h31 Java Specific Information $RDA_html_h32
   prompt <p><a href="#01">Java Objects</a><br>
   prompt <a href="#02">Java Roles</a><br>
   prompt <a href="#03">Oracle Supplied Java Users</a><br>
   prompt <a name=01></a>
   prompt $RDA_html_h31 Java Objects $RDA_html_h32
   prompt $RDA_html_tab1
   prompt $RDA_html_tdh1 Owner $RDA_html_tdh2
   prompt $RDA_html_tdh1 Total Objects $RDA_html_tdh2
   prompt $RDA_html_tdh1 Invalid Objects $RDA_html_tdh2

   SELECT '<TR>' || $RDA_html_td1 || o.owner || $RDA_html_td2,
          $RDA_html_td1 || o.objects || $RDA_html_td2,
          $RDA_html_td1 || nvl(i.invalids,0) || $RDA_html_td2 || '</TR>'
   FROM (SELECT owner, count(*) objects
         FROM dba_objects 
         WHERE object_type like 'JAVA%'
         GROUP by owner) o,
        (SELECT owner, count(*) invalids
         FROM dba_objects 
         WHERE object_type like 'JAVA%'
            and status = 'INVALID' 
         GROUP by owner) i
   WHERE o.owner=i.owner(+);
   prompt </TABLE>
   prompt <a href="#00">Back to top</a>

   prompt <a name=02></a>
   prompt $RDA_html_h31 Java Roles $RDA_html_h32
   prompt $RDA_html_tab1
   prompt $RDA_html_tdh1 Role Name $RDA_html_tdh2

   SELECT '<TR>' || $RDA_html_td1 || r.role || $RDA_html_td2 || '</TR>'
   FROM dba_roles r
   WHERE role like 'JAVA%';
   prompt </TABLE>
   prompt <a href="#00">Back to top</a>
   
   prompt <a name=03></a>
   prompt $RDA_html_h31 Oracle Supplied Java Users $RDA_html_h32
   prompt $RDA_html_tab1
   prompt $RDA_html_tdh1 User Name $RDA_html_tdh2
   prompt $RDA_html_tdh1 User ID $RDA_html_tdh2
   prompt $RDA_html_tdh1 Creation Date $RDA_html_tdh2

   SELECT '<TR>' || $RDA_html_td1 || u.username || $RDA_html_td2,
          $RDA_html_td1 || u.user_id || $RDA_html_td2,
          $RDA_html_td1 || to_char(created, 'dd-mon-rr hh:mi:ss') || $RDA_html_td2 || '</TR>'
   FROM dba_users u
   where username like 'OSE%'
      or username like 'AURORA%';
   prompt </TABLE>
   prompt <a href="#00">Back to top</a>"

   Run_SQL
   cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_jvm_info.htm
fi

#  We want to get rollback information, but with the advent of Automatic
#  Undo Management, things are a little different.  With the way the script
#  is setup, we can determine whether to grab the old rollback information or
#  Undo information based on a variable, AUM_Setting.  The script has the
#  default value set to manual, which is using old RBS.  A setting of auto
#  means we have found undo and should display accordingly.  Since auto can
#  only show up in 9i db's and is controlled by an init parameter, we can
#  key off of the existence of the init parm to set AUM_Setting.

if [ "$AUM_Setting" = "manual" ]; then
#  RBS get, v$rollstat and dba_rollback_segs.
   DebugMessage=" Inside Review_RDBMS, processing v\$rollstat"
   Debug

#  Relative file no did not exist in version 7, account for it.
   if [ "$ORACLE_VERSION" = "7" ]; then
      Rollback_Segs_SQL="
      SELECT '<TR>' || $RDA_html_td1 || v.segment_name || $RDA_html_td2,
          $RDA_html_td1 || v.segment_id || $RDA_html_td2, 
          $RDA_html_td1 || v.owner || $RDA_html_td2, 
          $RDA_html_td1 || v.tablespace_name || $RDA_html_td2, 
          $RDA_html_td1 || v.file_id || $RDA_html_td2, 
          $RDA_html_td1 || v.block_id || $RDA_html_td2, 
          $RDA_html_td1 || v.initial_extent || $RDA_html_td2, 
          $RDA_html_td1 || v.next_extent || $RDA_html_td2, 
          $RDA_html_td1 || v.min_extents || $RDA_html_td2, 
          $RDA_html_td1 || v.max_extents || $RDA_html_td2, 
          $RDA_html_td1 || v.pct_increase || $RDA_html_td2, 
          $RDA_html_td1 || v.status || $RDA_html_td2, 
          $RDA_html_td1 || nvl(v.instance_num, '<i>null value</i>')  || $RDA_html_td2 || '</TR>'"
   else
      Rollback_Segs_SQL="
      prompt $RDA_html_tdh1 Relative File Number $RDA_html_tdh2
      SELECT '<TR>' || $RDA_html_td1 || v.segment_name || $RDA_html_td2,
          $RDA_html_td1 || v.segment_id || $RDA_html_td2, 
          $RDA_html_td1 || v.owner || $RDA_html_td2, 
          $RDA_html_td1 || v.tablespace_name || $RDA_html_td2, 
          $RDA_html_td1 || v.file_id || $RDA_html_td2, 
          $RDA_html_td1 || v.block_id || $RDA_html_td2, 
          $RDA_html_td1 || v.initial_extent || $RDA_html_td2, 
          $RDA_html_td1 || v.next_extent || $RDA_html_td2, 
          $RDA_html_td1 || v.min_extents || $RDA_html_td2, 
          $RDA_html_td1 || v.max_extents || $RDA_html_td2, 
          $RDA_html_td1 || v.pct_increase || $RDA_html_td2, 
          $RDA_html_td1 || v.status || $RDA_html_td2, 
          $RDA_html_td1 || nvl(v.instance_num, '<i>null value</i>')  || $RDA_html_td2, 
          $RDA_html_td1 || v.relative_fno || $RDA_html_td2 || '</TR>'"
   fi

   SQL="$RDA_sqlset1
   prompt <a name=00></a>
   prompt <Center>$RDA_html_h31 Information from V\$RollStat and DBA_Rollback_Segs $RDA_html_h32 </Center>
   prompt <p><a href="#01">V\$RollStat</a><br>
   prompt <a href="#02">DBA_Rollback_Segs</a></p><br>
   prompt <a name=01></a>
   prompt $RDA_html_h31 V\$ROLLSTAT $RDA_html_h32
   prompt $RDA_html_tab1
   prompt $RDA_html_tdh1 Undo Segment Number $RDA_html_tdh2
   prompt $RDA_html_tdh1 Extents $RDA_html_tdh2
   prompt $RDA_html_tdh1 Segment Size $RDA_html_tdh2
   prompt $RDA_html_tdh1 Active Xacts $RDA_html_tdh2
   prompt $RDA_html_tdh1 Optimal $RDA_html_tdh2
   prompt $RDA_html_tdh1 High Water Mark $RDA_html_tdh2
   prompt $RDA_html_tdh1 Shrinks $RDA_html_tdh2
   prompt $RDA_html_tdh1 Wraps $RDA_html_tdh2
   prompt $RDA_html_tdh1 Extends $RDA_html_tdh2
   prompt $RDA_html_tdh1 Status $RDA_html_tdh2
   prompt $RDA_html_tdh1 Current Extent $RDA_html_tdh2
   prompt $RDA_html_tdh1 Current Block $RDA_html_tdh2

   SELECT '<TR>' || $RDA_html_td1 || v.usn || $RDA_html_td2,
       $RDA_html_td1 || v.extents || $RDA_html_td2, 
       $RDA_html_td1 || v.rssize || $RDA_html_td2, 
       $RDA_html_td1 || v.xacts || $RDA_html_td2, 
       $RDA_html_td1 || nvl(v.optsize,0)  || $RDA_html_td2, 
       $RDA_html_td1 || v.hwmsize || $RDA_html_td2, 
       $RDA_html_td1 || v.shrinks || $RDA_html_td2, 
       $RDA_html_td1 || v.wraps || $RDA_html_td2, 
       $RDA_html_td1 || v.extends || $RDA_html_td2, 
       $RDA_html_td1 || v.status || $RDA_html_td2, 
       $RDA_html_td1 || v.curext || $RDA_html_td2, 
       $RDA_html_td1 || v.curblk || $RDA_html_td2 || '</TR>'
   FROM V\$rollstat v;
   prompt </TABLE>
   prompt <a href="#00">Back to top</a>

   prompt <a name=02></a>
   prompt $RDA_html_h31 DBA_ROLLBACK_SEGS $RDA_html_h32
   prompt $RDA_html_tab1
   prompt $RDA_html_tdh1 Segment Name $RDA_html_tdh2
   prompt $RDA_html_tdh1 Segment ID $RDA_html_tdh2
   prompt $RDA_html_tdh1 Owner $RDA_html_tdh2
   prompt $RDA_html_tdh1 Tablespace Name $RDA_html_tdh2
   prompt $RDA_html_tdh1 File ID $RDA_html_tdh2
   prompt $RDA_html_tdh1 Block ID $RDA_html_tdh2
   prompt $RDA_html_tdh1 Initial $RDA_html_tdh2
   prompt $RDA_html_tdh1 Next $RDA_html_tdh2
   prompt $RDA_html_tdh1 Min Extents $RDA_html_tdh2
   prompt $RDA_html_tdh1 Max Extents $RDA_html_tdh2
   prompt $RDA_html_tdh1 PCT Increase $RDA_html_tdh2
   prompt $RDA_html_tdh1 Status $RDA_html_tdh2
   prompt $RDA_html_tdh1 Instance Number $RDA_html_tdh2

   $Rollback_Segs_SQL
   FROM dba_rollback_segs v;
   SELECT '</TABLE>' from dual;
   prompt <a href="#00">Back to top</a>"

   Run_SQL
   cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_rollback_info.htm
else

#  We're running AUM, so look for undostat and dba_undo_extents

   DebugMessage=" Inside Review_RDBMS, processing v\$undostat"
   Debug

   SQL="$RDA_sqlset1
   prompt <a name=00></a>
   prompt <Center>$RDA_html_h31 Information from V\$UndoStat and DBA_Undo_Extents $RDA_html_h32 </Center>
   prompt <p><a href="#01">V\$UndoStat</a><br>
   prompt <a href="#02">DBA_Undo_Extents</a></p><br>
   prompt <a name=01></a>
   prompt $RDA_html_h31 V\$UNDOSTAT $RDA_html_h32
   prompt $RDA_html_tab1
   prompt $RDA_html_tdh1 Begin Time $RDA_html_tdh2
   prompt $RDA_html_tdh1 End Time $RDA_html_tdh2
   prompt $RDA_html_tdh1 Undo Tablespace Number $RDA_html_tdh2
   prompt $RDA_html_tdh1 Undo Blocks Used $RDA_html_tdh2
   prompt $RDA_html_tdh1 Xact Count $RDA_html_tdh2
   prompt $RDA_html_tdh1 Max Query Length $RDA_html_tdh2
   prompt $RDA_html_tdh1 Max Concurrency $RDA_html_tdh2
   prompt $RDA_html_tdh1 Unexpired Steal Count $RDA_html_tdh2
   prompt $RDA_html_tdh1 Unexpired Block Release Count $RDA_html_tdh2
   prompt $RDA_html_tdh1 Unexpired Block Reuse Count $RDA_html_tdh2
   prompt $RDA_html_tdh1 Expired Steal Count $RDA_html_tdh2
   prompt $RDA_html_tdh1 Expired Block Release Count $RDA_html_tdh2
   prompt $RDA_html_tdh1 Expired Block Reuse Count $RDA_html_tdh2
   prompt $RDA_html_tdh1 Snapshot Too Old Errors Count $RDA_html_tdh2
   prompt $RDA_html_tdh1 No Space Errors Count $RDA_html_tdh2

   SELECT '<TR>' || $RDA_html_td1 || to_char(v.begin_time,'dd-mon-yy hh24:mi:ss') || $RDA_html_td2,
       $RDA_html_td1 || to_char(v.end_time,'dd-mon-yy hh24:mi:ss') || $RDA_html_td2, 
       $RDA_html_td1 || v.undotsn || $RDA_html_td2, 
       $RDA_html_td1 || v.undoblks || $RDA_html_td2, 
       $RDA_html_td1 || v.txncount || $RDA_html_td2, 
       $RDA_html_td1 || v.maxquerylen || $RDA_html_td2, 
       $RDA_html_td1 || v.maxconcurrency || $RDA_html_td2, 
       $RDA_html_td1 || v.unxpstealcnt || $RDA_html_td2, 
       $RDA_html_td1 || v.unxpblkrelcnt || $RDA_html_td2, 
       $RDA_html_td1 || v.unxpblkreucnt || $RDA_html_td2, 
       $RDA_html_td1 || v.expstealcnt || $RDA_html_td2, 
       $RDA_html_td1 || v.expblkrelcnt || $RDA_html_td2, 
       $RDA_html_td1 || v.expblkreucnt || $RDA_html_td2, 
       $RDA_html_td1 || v.ssolderrcnt || $RDA_html_td2, 
       $RDA_html_td1 || v.nospaceerrcnt || $RDA_html_td2 || '</TR>'
   FROM V\$undostat v;
   prompt </TABLE> 
   prompt <a href="#00">Back to top</a>

   prompt <a name=02></a>
   prompt $RDA_html_h31 DBA_UNDO_EXTENTS $RDA_html_h32
   prompt $RDA_html_tab1
   prompt $RDA_html_tdh1 Owner $RDA_html_tdh2
   prompt $RDA_html_tdh1 Segment Name $RDA_html_tdh2
   prompt $RDA_html_tdh1 Tablespace Name $RDA_html_tdh2
   prompt $RDA_html_tdh1 Extent ID $RDA_html_tdh2
   prompt $RDA_html_tdh1 File ID $RDA_html_tdh2
   prompt $RDA_html_tdh1 Block ID $RDA_html_tdh2
   prompt $RDA_html_tdh1 Bytes $RDA_html_tdh2
   prompt $RDA_html_tdh1 Blocks $RDA_html_tdh2
   prompt $RDA_html_tdh1 Relative File Number $RDA_html_tdh2
   prompt $RDA_html_tdh1 Commit Time (Julian) $RDA_html_tdh2
   prompt $RDA_html_tdh1 Commit Time (Wall Clock) $RDA_html_tdh2
   prompt $RDA_html_tdh1 Status $RDA_html_tdh2
   SELECT '<TR>' || $RDA_html_td1 || v.owner || $RDA_html_td2,
       $RDA_html_td1 || v.segment_name || $RDA_html_td2, 
       $RDA_html_td1 || v.tablespace_name || $RDA_html_td2, 
       $RDA_html_td1 || v.extent_id || $RDA_html_td2, 
       $RDA_html_td1 || v.file_id || $RDA_html_td2, 
       $RDA_html_td1 || v.block_id || $RDA_html_td2, 
       $RDA_html_td1 || v.bytes || $RDA_html_td2, 
       $RDA_html_td1 || v.blocks || $RDA_html_td2, 
       $RDA_html_td1 || v.relative_fno || $RDA_html_td2, 
       $RDA_html_td1 || v.commit_jtime || $RDA_html_td2, 
       $RDA_html_td1 || nvl(v.commit_wtime,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || v.status || $RDA_html_td2 || '</TR>'
   FROM dba_undo_extents v;
   prompt </TABLE>
   prompt <a href="#00">Back to top</a>"

   Run_SQL
   cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_undo_info.htm
fi


################################################################
### The following queries are in a case statement to separate
### them into queries for 7, 8.0, 8.1, and 9
###

case "$ORACLE_VERSION" in
   7)

  ################################################################
  ### Version 7 queries

      DebugMessage=" Inside Review_RDBMS, processing v7 queries"
      Debug

      SQL="$RDA_sqlset1
      prompt $RDA_html_h31 Tablespaces $RDA_html_h32
      prompt $RDA_html_tab1
      prompt $RDA_html_tdh1 Status $RDA_html_tdh2
      prompt $RDA_html_tdh1 Name $RDA_html_tdh2
      prompt $RDA_html_tdh1 Type $RDA_html_tdh2
      prompt $RDA_html_tdh1 Size (M) $RDA_html_tdh2
      prompt $RDA_html_tdh1 Used (M) $RDA_html_tdh2
      prompt $RDA_html_tdh1 Used % $RDA_html_tdh2
      prompt $RDA_html_tdh1 Initial Extent $RDA_html_tdh2
      prompt $RDA_html_tdh1 Next Extent $RDA_html_tdh2
      prompt $RDA_html_tdh1 Largest Free Extent $RDA_html_tdh2

      SELECT '<TR>' || $RDA_html_td1 || d.status || $RDA_html_td2,
       $RDA_html_td1 || d.tablespace_name || $RDA_html_td2, 
       $RDA_html_td1 || d.contents || $RDA_html_td2, 
       $RDA_html_td1 || TO_CHAR(NVL(a.bytes / 1024 / 1024, 0),'99G999G990D900') || $RDA_html_td2,
       $RDA_html_td1 || TO_CHAR(NVL(a.bytes - NVL(f.bytes, 0), 0)/1024/1024 ,'99G999G990D900') || $RDA_html_td2,
       $RDA_html_td1 || TO_CHAR(NVL((a.bytes - NVL(f.bytes, 0)) / a.bytes * 100, 0), '990D00') || $RDA_html_td2, 
       $RDA_html_td1 || d.initial_extent || $RDA_html_td2, 
       $RDA_html_td1 || NVL(d.next_extent, 0) || $RDA_html_td2,
       $RDA_html_td1 || TO_CHAR(NVL(f.largest_free / 1024 / 1024, 0),'99G999G990D900') || $RDA_html_td2 || '</TR>'
      FROM sys.dba_tablespaces d, 
           (select tablespace_name, sum(bytes) bytes from dba_data_files group by tablespace_name) a, 
           (select tablespace_name, sum(bytes) bytes, max(bytes) largest_free from dba_free_space group by tablespace_name) f 
      WHERE d.tablespace_name = a.tablespace_name 
        AND d.tablespace_name = f.tablespace_name;
      prompt </TABLE>"
      Run_SQL
      cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_tablespace.htm

#   V7 Datafiles

      SQL="$RDA_sqlset1
      prompt $RDA_html_h31 Database Files $RDA_html_h32
      prompt $RDA_html_tab1
      prompt $RDA_html_tdh1 Status $RDA_html_tdh2
      prompt $RDA_html_tdh1 Name $RDA_html_tdh2
      prompt $RDA_html_tdh1 Tablespace $RDA_html_tdh2
      prompt $RDA_html_tdh1 Size $RDA_html_tdh2
      prompt $RDA_html_tdh1 Used (M) $RDA_html_tdh2
      prompt $RDA_html_tdh1 Used (%) $RDA_html_tdh2
      prompt $RDA_html_tdh1 Autoextensible  $RDA_html_tdh2

         SELECT '<TR>'|| $RDA_html_td1 || v.status || $RDA_html_td2,
         $RDA_html_td1 || d.file_name || $RDA_html_td2,
         $RDA_html_td1 || d.tablespace_name || $RDA_html_td2,
         $RDA_html_td1 || TO_CHAR((d.bytes / 1024 / 1024), '99999990D000') || $RDA_html_td2,
         $RDA_html_td1 || TO_CHAR(NVL((d.bytes - NVL(s.bytes, 0))/1024/1024, 0), '99999990D000') || $RDA_html_td2,
         $RDA_html_td1 || TO_CHAR((NVL(d.bytes - s.bytes, d.bytes) / d.bytes * 100), '990D00') || $RDA_html_td2,
         $RDA_html_td1 || NVL(f.autoextensible, 'NO') || $RDA_html_td2 ||'</TR>'
         FROM sys.dba_data_files d,
              v\$datafile v,
              (SELECT file_id, SUM(bytes) bytes  FROM sys.dba_free_space  GROUP BY file_id) s,
              (select file#, 'YES' autoextensible from sys.filext\$) f
         WHERE (s.file_id (+)= d.file_id) 
           AND (d.file_name = v.name)
           and (f.file# (+)= d.file_id);
         prompt </TABLE>"

      Run_SQL
      cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_datafile.htm

   ;;
   80)
  
  ################################################################
  ### Version 8.0 queries

      DebugMessage=" Inside Review_RDBMS, processing v8.0 queries"
      Debug

      SQL="$RDA_sqlset1
      prompt $RDA_html_h31 Tablespaces $RDA_html_h32
      prompt $RDA_html_tab1
      prompt $RDA_html_tdh1 Status $RDA_html_tdh2
      prompt $RDA_html_tdh1 Name $RDA_html_tdh2
      prompt $RDA_html_tdh1 Type $RDA_html_tdh2
      prompt $RDA_html_tdh1 Size (M) $RDA_html_tdh2
      prompt $RDA_html_tdh1 Used (M) $RDA_html_tdh2
      prompt $RDA_html_tdh1 Used % $RDA_html_tdh2
      prompt $RDA_html_tdh1 Initial Extent $RDA_html_tdh2
      prompt $RDA_html_tdh1 Next Extent $RDA_html_tdh2
      prompt $RDA_html_tdh1 Largest Free Extent $RDA_html_tdh2

      SELECT '<TR>' || $RDA_html_td1 || d.status || $RDA_html_td2,
       $RDA_html_td1 || d.tablespace_name || $RDA_html_td2, 
       $RDA_html_td1 || d.contents || $RDA_html_td2, 
       $RDA_html_td1 || TO_CHAR(NVL(a.bytes / 1024 / 1024, 0),'99G999G990D900') || $RDA_html_td2,
       $RDA_html_td1 || TO_CHAR(NVL(a.bytes - NVL(f.bytes, 0), 0)/1024/1024 ,'99G999G990D900') || $RDA_html_td2,
       $RDA_html_td1 || TO_CHAR(NVL((a.bytes - NVL(f.bytes, 0)) / a.bytes * 100, 0), '990D00') || $RDA_html_td2, 
       $RDA_html_td1 || d.initial_extent || $RDA_html_td2, 
       $RDA_html_td1 || NVL(d.next_extent, 0) || $RDA_html_td2,
       $RDA_html_td1 || TO_CHAR(NVL(f.largest_free / 1024 / 1024, 0),'99G999G990D900') || $RDA_html_td2 || '</TR>'
      FROM sys.dba_tablespaces d, 
           (select tablespace_name, sum(bytes) bytes from dba_data_files group by tablespace_name) a, 
           (select tablespace_name, sum(bytes) bytes, max(bytes) largest_free from dba_free_space group by tablespace_name) f 
      WHERE d.tablespace_name = a.tablespace_name 
        AND d.tablespace_name = f.tablespace_name;
      prompt </TABLE>"
      Run_SQL
      cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_tablespace.htm

#   V8.0 Datafiles

      SQL="$RDA_sqlset1
      prompt $RDA_html_h31 Database Files $RDA_html_h32
      prompt $RDA_html_tab1
      prompt $RDA_html_tdh1 Status $RDA_html_tdh2
      prompt $RDA_html_tdh1 Name $RDA_html_tdh2
      prompt $RDA_html_tdh1 Tablespace $RDA_html_tdh2
      prompt $RDA_html_tdh1 Size $RDA_html_tdh2
      prompt $RDA_html_tdh1 Used (M) $RDA_html_tdh2
      prompt $RDA_html_tdh1 Used (%) $RDA_html_tdh2
      prompt $RDA_html_tdh1 Autoextensible $RDA_html_tdh2

         SELECT '<TR>'|| $RDA_html_td1 || v.status || $RDA_html_td2,
         $RDA_html_td1 || d.file_name || $RDA_html_td2,
         $RDA_html_td1 || d.tablespace_name || $RDA_html_td2,
         $RDA_html_td1 || TO_CHAR((d.bytes / 1024 / 1024), '99999990D000') || $RDA_html_td2,
         $RDA_html_td1 || TO_CHAR(NVL((d.bytes - NVL(s.bytes, 0))/1024/1024, 0), '99999990D000') || $RDA_html_td2,
         $RDA_html_td1 || TO_CHAR((NVL(d.bytes - s.bytes, d.bytes) / d.bytes * 100), '990D00') || $RDA_html_td2,
         $RDA_html_td1 || NVL(d.autoextensible, 'NO') || $RDA_html_td2 ||'</TR>'
         FROM sys.dba_data_files d,
              v\$datafile v,
              (SELECT file_id, SUM(bytes) bytes  FROM sys.dba_free_space  GROUP BY file_id) s 
         WHERE (s.file_id (+)= d.file_id) 
           AND (d.file_name = v.name);
         prompt </TABLE>"

      Run_SQL
      cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_datafile.htm

   ;;
   81)

  ################################################################
  ### Version 8.1 queries

  ################################################################
  ### Processing tablespaces for V8.1

      DebugMessage=" Inside Review_RDBMS, processing tablespaces for V8.1"
      Debug

      SQL="$RDA_sqlset1
      prompt <a name=00></a>
      prompt <Center>$RDA_html_h31 Tablespace Information $RDA_html_h32 </Center>
      prompt <p><a href="#01">Permanent Tablespaces</a><br>
      prompt <a href="#02">Locally Managed Temporary Tablespaces </a><br>
      prompt <a name=01></a>
      prompt $RDA_html_h31 Tablespaces $RDA_html_h32
      prompt $RDA_html_tab1
      prompt $RDA_html_tdh1 Status $RDA_html_tdh2
      prompt $RDA_html_tdh1 Name $RDA_html_tdh2
      prompt $RDA_html_tdh1 Type $RDA_html_tdh2
      prompt $RDA_html_tdh1 Extent Management $RDA_html_tdh2
      prompt $RDA_html_tdh1 Size (M) $RDA_html_tdh2
      prompt $RDA_html_tdh1 Used (M) $RDA_html_tdh2
      prompt $RDA_html_tdh1 Used % $RDA_html_tdh2
      prompt $RDA_html_tdh1 Initial Extent $RDA_html_tdh2
      prompt $RDA_html_tdh1 Next Extent $RDA_html_tdh2
      prompt $RDA_html_tdh1 Largest Free Extent $RDA_html_tdh2

      SELECT '<TR>' || $RDA_html_td1 || d.status || $RDA_html_td2,
       $RDA_html_td1 || d.tablespace_name || $RDA_html_td2, 
       $RDA_html_td1 || d.contents || $RDA_html_td2, 
       $RDA_html_td1 || d.extent_management || $RDA_html_td2, 
       $RDA_html_td1 || TO_CHAR(NVL(a.bytes / 1024 / 1024, 0),'99G999G990D900') || $RDA_html_td2,
       $RDA_html_td1 || TO_CHAR(NVL(a.bytes - NVL(f.bytes, 0), 0)/1024/1024 ,'99G999G990D900') || $RDA_html_td2,
       $RDA_html_td1 || TO_CHAR(NVL((a.bytes - NVL(f.bytes, 0)) / a.bytes * 100, 0), '990D00') || $RDA_html_td2, 
       $RDA_html_td1 || d.initial_extent || $RDA_html_td2, 
       $RDA_html_td1 || NVL(d.next_extent, 0) || $RDA_html_td2,
       $RDA_html_td1 || TO_CHAR(NVL(f.largest_free / 1024 / 1024, 0),'99G999G990D900') || $RDA_html_td2 || '</TR>'
      FROM sys.dba_tablespaces d, 
           (select tablespace_name, sum(bytes) bytes from dba_data_files group by tablespace_name) a, 
           (select tablespace_name, sum(bytes) bytes, max(bytes) largest_free from dba_free_space group by tablespace_name) f 
      WHERE d.tablespace_name = a.tablespace_name 
        AND d.tablespace_name = f.tablespace_name;
      prompt </TABLE>
      prompt <a href="#00">Back to top</a>

      prompt <a name=02></a>
      prompt <BR>$RDA_html_h31 Locally Managed Temporary Tablespaces $RDA_html_h32
      prompt $RDA_html_tab1
      prompt $RDA_html_tdh1 Status $RDA_html_tdh2
      prompt $RDA_html_tdh1 Name $RDA_html_tdh2
      prompt $RDA_html_tdh1 Size (M) $RDA_html_tdh2

      SELECT '<TR>' || $RDA_html_td1 || d.status || $RDA_html_td2,
       $RDA_html_td1 || d.tablespace_name || $RDA_html_td2, 
       $RDA_html_td1 || TO_CHAR(NVL(a.bytes / 1024 / 1024, 0),'99G999G990D900') ||
       $RDA_html_td2 || '</TR>'
      FROM sys.dba_tablespaces d, 
           (select tablespace_name, sum(bytes) bytes from dba_temp_files group by tablespace_name) a
      WHERE d.tablespace_name = a.tablespace_name;
      prompt </TABLE>
      prompt <a href="#00">Back to top</a>"
      Run_SQL
      cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_tablespace.htm

#  V8i Datafiles

      SQL="$RDA_sqlset1
      prompt <a name=00></a>
      prompt <Center>$RDA_html_h31 Datafile Information $RDA_html_h32 </Center>
      prompt <p><a href="#01">Database Files</a><br>
      prompt <a href="#02">TempFiles</a><br>
      prompt <a name=01></a>
      prompt $RDA_html_h31 Database Files $RDA_html_h32
      prompt $RDA_html_tab1
      prompt $RDA_html_tdh1 Status $RDA_html_tdh2
      prompt $RDA_html_tdh1 Name $RDA_html_tdh2
      prompt $RDA_html_tdh1 Tablespace $RDA_html_tdh2
      prompt $RDA_html_tdh1 Size $RDA_html_tdh2
      prompt $RDA_html_tdh1 Used (M) $RDA_html_tdh2
      prompt $RDA_html_tdh1 Used (%) $RDA_html_tdh2
      prompt $RDA_html_tdh1 Autoextensible $RDA_html_tdh2

      SELECT '<TR>'|| $RDA_html_td1 || v.status || $RDA_html_td2,
         $RDA_html_td1 || d.file_name || $RDA_html_td2,
         $RDA_html_td1 || d.tablespace_name || $RDA_html_td2,
         $RDA_html_td1 || TO_CHAR((d.bytes / 1024 / 1024), '99999990D000') || $RDA_html_td2,
         $RDA_html_td1 || TO_CHAR(NVL((d.bytes - NVL(s.bytes, 0))/1024/1024, 0), '99999990D000') || $RDA_html_td2,
         $RDA_html_td1 || TO_CHAR((NVL(d.bytes - s.bytes, d.bytes) / d.bytes * 100), '990D00') || $RDA_html_td2,
         $RDA_html_td1 || NVL(d.autoextensible, 'NO') || $RDA_html_td2 ||'</TR>'
      FROM sys.dba_data_files d,
           v\$datafile v,
           (SELECT file_id, SUM(bytes) bytes  FROM sys.dba_free_space  GROUP BY file_id) s 
      WHERE (s.file_id (+)= d.file_id) 
        AND (d.file_name = v.name);
      prompt </TABLE>
      prompt <a href="#00">Back to top</a>

      prompt <a name=02></a>
      prompt $RDA_html_h31 Tempfiles $RDA_html_h32
      prompt $RDA_html_tab1
      prompt $RDA_html_tdh1 Status $RDA_html_tdh2
      prompt $RDA_html_tdh1 Name $RDA_html_tdh2
      prompt $RDA_html_tdh1 Tablespace $RDA_html_tdh2
      prompt $RDA_html_tdh1 Size (M) $RDA_html_tdh2

      SELECT '<TR>' || $RDA_html_td1 || v.status || $RDA_html_td2, 
             $RDA_html_td1 || d.file_name || $RDA_html_td2, 
             $RDA_html_td1 || d.tablespace_name || $RDA_html_td2, 
             $RDA_html_td1 || TO_CHAR((d.bytes / 1024 / 1024), '99999990D000') || $RDA_html_td2 || '</TR>' 
      FROM sys.dba_temp_files d, 
           v\$tempfile v
      WHERE (d.file_name = v.name);
      prompt </TABLE>
      prompt <a href="#00">Back to top</a>"

      Run_SQL
      cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_datafile.htm
   ;;
   9*)
  ################################################################
  ### Version 9 queries

  ################################################################
  ### Processing tablespaces for V9.0

      DebugMessage=" Inside Review_RDBMS, processing tablespaces for V9.0"
      Debug

      SQL="$RDA_sqlset1
      prompt <a name=00></a>
      prompt <Center>$RDA_html_h31 Tablespace Information $RDA_html_h32 </Center>
      prompt <p><a href="#01">Permanent Tablespaces</a><br>
      prompt <a href="#02">Locally Managed Temporary Tablespaces </a><br>
      prompt <a name=01></a>
      prompt $RDA_html_h31 Tablespaces $RDA_html_h32
      prompt $RDA_html_tab1
      prompt $RDA_html_tdh1 Status $RDA_html_tdh2
      prompt $RDA_html_tdh1 Name $RDA_html_tdh2
      prompt $RDA_html_tdh1 Type $RDA_html_tdh2
      prompt $RDA_html_tdh1 Extent Management $RDA_html_tdh2
      prompt $RDA_html_tdh1 Size (M) $RDA_html_tdh2
      prompt $RDA_html_tdh1 Used (M) $RDA_html_tdh2
      prompt $RDA_html_tdh1 Used % $RDA_html_tdh2
      prompt $RDA_html_tdh1 Initial Extent $RDA_html_tdh2
      prompt $RDA_html_tdh1 Next Extent $RDA_html_tdh2
      prompt $RDA_html_tdh1 Largest Free Extent $RDA_html_tdh2

      SELECT '<TR>' || $RDA_html_td1 || d.status || $RDA_html_td2,
       $RDA_html_td1 || d.tablespace_name || $RDA_html_td2, 
       $RDA_html_td1 || d.contents || $RDA_html_td2, 
       $RDA_html_td1 || d.extent_management || $RDA_html_td2, 
       $RDA_html_td1 || TO_CHAR(NVL(a.bytes / 1024 / 1024, 0),'99G999G990D900') || $RDA_html_td2,
       $RDA_html_td1 || TO_CHAR(NVL(a.bytes - NVL(f.bytes, 0), 0)/1024/1024 ,'99G999G990D900') || $RDA_html_td2,
       $RDA_html_td1 || TO_CHAR(NVL((a.bytes - NVL(f.bytes, 0)) / a.bytes * 100, 0), '990D00') || $RDA_html_td2, 
       $RDA_html_td1 || d.initial_extent || $RDA_html_td2, 
       $RDA_html_td1 || NVL(d.next_extent, 0) || $RDA_html_td2,
       $RDA_html_td1 || TO_CHAR(NVL(f.largest_free / 1024 / 1024, 0),'99G999G990D900') || $RDA_html_td2 || '</TR>'
      FROM sys.dba_tablespaces d, 
           (select tablespace_name, sum(bytes) bytes from dba_data_files group by tablespace_name) a, 
           (select tablespace_name, sum(bytes) bytes, max(bytes) largest_free from dba_free_space group by tablespace_name) f 
      WHERE d.tablespace_name = a.tablespace_name 
        AND d.tablespace_name = f.tablespace_name;
      prompt </TABLE>
      prompt <a href="#00">Back to top</a>

      prompt <a name=02></a>
      prompt <BR>$RDA_html_h31 Locally Managed Temporary Tablespaces $RDA_html_h32
      prompt $RDA_html_tab1
      prompt $RDA_html_tdh1 Status $RDA_html_tdh2
      prompt $RDA_html_tdh1 Name $RDA_html_tdh2
      prompt $RDA_html_tdh1 Size (M) $RDA_html_tdh2

      SELECT '<TR>' || $RDA_html_td1 || d.status || $RDA_html_td2,
       $RDA_html_td1 || d.tablespace_name || $RDA_html_td2, 
       $RDA_html_td1 || TO_CHAR(NVL(a.bytes / 1024 / 1024, 0),'99G999G990D900') ||
       $RDA_html_td2 || '</TR>'
      FROM sys.dba_tablespaces d, 
           (select tablespace_name, sum(bytes) bytes from dba_temp_files group by tablespace_name) a
      WHERE d.tablespace_name = a.tablespace_name;
      prompt </TABLE>
      prompt <a href="#00">Back to top</a>"

      Run_SQL
      cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_tablespace.htm

#  9i Datafiles 

      SQL="$RDA_sqlset1
      prompt <a name=00></a>
      prompt <Center>$RDA_html_h31 Datafile Information $RDA_html_h32 </Center>
      prompt <p><a href="#01">Database Files</a><br>
      prompt <a href="#02">TempFiles</a><br>
      prompt <a name=01></a>
      prompt $RDA_html_h31 Database Files $RDA_html_h32
      prompt $RDA_html_tab1
      prompt $RDA_html_tdh1 Status $RDA_html_tdh2
      prompt $RDA_html_tdh1 Name $RDA_html_tdh2
      prompt $RDA_html_tdh1 Tablespace $RDA_html_tdh2
      prompt $RDA_html_tdh1 Size $RDA_html_tdh2
      prompt $RDA_html_tdh1 Used (M) $RDA_html_tdh2
      prompt $RDA_html_tdh1 Used (%) $RDA_html_tdh2
      prompt $RDA_html_tdh1 Autoextensible $RDA_html_tdh2

      SELECT '<TR>'|| $RDA_html_td1 || v.status || $RDA_html_td2,
         $RDA_html_td1 || d.file_name || $RDA_html_td2,
         $RDA_html_td1 || d.tablespace_name || $RDA_html_td2,
         $RDA_html_td1 || TO_CHAR((d.bytes / 1024 / 1024), '99999990D000') || $RDA_html_td2,
         $RDA_html_td1 || TO_CHAR(NVL((d.bytes - NVL(s.bytes, 0))/1024/1024, 0), '99999990D000') || $RDA_html_td2,
         $RDA_html_td1 || TO_CHAR((NVL(d.bytes - s.bytes, d.bytes) / d.bytes * 100), '990D00') || $RDA_html_td2,
         $RDA_html_td1 || NVL(d.autoextensible, 'NO') || $RDA_html_td2 ||'</TR>'
      FROM sys.dba_data_files d,
           v\$datafile v,
           (SELECT file_id, SUM(bytes) bytes  FROM sys.dba_free_space  GROUP BY file_id) s 
      WHERE (s.file_id (+)= d.file_id) 
        AND (d.file_name = v.name);
      prompt </TABLE>
      prompt <a href="#00">Back to top</a>

      prompt <a name=02></a>
      prompt $RDA_html_h31 Tempfiles $RDA_html_h32
      prompt $RDA_html_tab1
      prompt $RDA_html_tdh1 Status $RDA_html_tdh2
      prompt $RDA_html_tdh1 Name $RDA_html_tdh2
      prompt $RDA_html_tdh1 Tablespace $RDA_html_tdh2
      prompt $RDA_html_tdh1 Size (M) $RDA_html_tdh2

      SELECT '<TR>' || $RDA_html_td1 || v.status || $RDA_html_td2, 
             $RDA_html_td1 || d.file_name || $RDA_html_td2, 
             $RDA_html_td1 || d.tablespace_name || $RDA_html_td2, 
             $RDA_html_td1 || TO_CHAR((d.bytes / 1024 / 1024), '99999990D000') || $RDA_html_td2 || '</TR>' 
      FROM sys.dba_temp_files d, 
           v\$tempfile v
      WHERE (d.file_name = v.name);
      prompt </TABLE>
      prompt <a href="#00">Back to top</a>"

      Run_SQL
      cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_datafile.htm
   ;;
   *)
  
      DebugMessage=" database version could not be properly determined"
      Debug
      echo "database version could not be properly determined"
   ;;
esac

#  Replication data
#
#  Check replication environment using replication views
#

DebugMessage=" Inside Review_RDBMS, processing replication data"
Debug

SQL="$RDA_sqlset1
prompt <a name=00></a>
prompt <Center>$RDA_html_h31 Replication Information $RDA_html_h32 </Center>
prompt <p><a href="#01">DBA_RepSites Information</a><br>
prompt <a href="#02">DBA_RepGroup Information</a><br>
prompt <a href="#03">DBA_RepObject Information</a><br>
prompt <a href="#04">DBA_RepCatlog Information</a><br>
prompt <a href="#05">Replication Environment Transaction Counts</a></p><br>
prompt <a name=01></a>
prompt $RDA_html_h31 DBA_RepSites $RDA_html_h32
prompt $RDA_html_tab1
prompt $RDA_html_tdh1 Group Name $RDA_html_tdh2
prompt $RDA_html_tdh1 DB Link $RDA_html_tdh2
prompt $RDA_html_tdh1 Master Site (Y/N) $RDA_html_tdh2
prompt $RDA_html_tdh1 Master Definition DB Link $RDA_html_tdh2

SELECT '<TR>' || $RDA_html_td1 || r.gname || $RDA_html_td2, 
       $RDA_html_td1 || r.dblink || $RDA_html_td2, 
       $RDA_html_td1 || r.master || $RDA_html_td2, 
       $RDA_html_td1 || r.masterdef || $RDA_html_td2 || '</TR>' 
FROM sys.dba_repsites r;
prompt </TABLE>
prompt <a href="#00">Back to top</a>

prompt <a name=02></a>
prompt $RDA_html_h31 DBA_RepGroup $RDA_html_h32
prompt $RDA_html_tab1
prompt $RDA_html_tdh1 Schema Name $RDA_html_tdh2
prompt $RDA_html_tdh1 Master Site (Y/N) $RDA_html_tdh2
prompt $RDA_html_tdh1 Status $RDA_html_tdh2
prompt $RDA_html_tdh1 Group Name $RDA_html_tdh2

SELECT '<TR>' || $RDA_html_td1 || r.sname || $RDA_html_td2, 
       $RDA_html_td1 || r.master || $RDA_html_td2, 
       $RDA_html_td1 || r.status || $RDA_html_td2, 
       $RDA_html_td1 || r.gname || $RDA_html_td2 || '</TR>' 
FROM sys.dba_repgroup r;
prompt </TABLE>
prompt <a href="#00">Back to top</a>

prompt <a name=03></a>
prompt $RDA_html_h31 DBA_RepObject $RDA_html_h32
prompt $RDA_html_tab1
prompt $RDA_html_tdh1 Schema Name $RDA_html_tdh2
prompt $RDA_html_tdh1 Object Name $RDA_html_tdh2
prompt $RDA_html_tdh1 Status $RDA_html_tdh2
prompt $RDA_html_tdh1 Generation Status $RDA_html_tdh2
prompt $RDA_html_tdh1 Group Name $RDA_html_tdh2

SELECT '<TR>' || $RDA_html_td1 || r.sname || $RDA_html_td2, 
       $RDA_html_td1 || r.oname || $RDA_html_td2, 
       $RDA_html_td1 || r.status || $RDA_html_td2, 
       $RDA_html_td1 || r.generation_status || $RDA_html_td2, 
       $RDA_html_td1 || r.gname || $RDA_html_td2 || '</TR>' 
FROM sys.dba_repobject r;
prompt </TABLE>
prompt <a href="#00">Back to top</a>

prompt <a name=04></a>
prompt $RDA_html_h31 DBA_RepCatlog $RDA_html_h32
prompt $RDA_html_tab1
prompt $RDA_html_tdh1 Status $RDA_html_tdh2
prompt $RDA_html_tdh1 ID $RDA_html_tdh2
prompt $RDA_html_tdh1 Object Name $RDA_html_tdh2
prompt $RDA_html_tdh1 Object Type Status $RDA_html_tdh2
prompt $RDA_html_tdh1 Error Number $RDA_html_tdh2

SELECT '<TR>' || $RDA_html_td1 || r.status || $RDA_html_td2, 
       $RDA_html_td1 || r.id || $RDA_html_td2, 
       $RDA_html_td1 || r.oname || $RDA_html_td2, 
       $RDA_html_td1 || r.type || $RDA_html_td2, 
       $RDA_html_td1 || r.errnum || $RDA_html_td2 || '</TR>' 
FROM sys.dba_repcatlog r;
prompt </TABLE>
prompt <a href="#00">Back to top</a>

prompt <a name=05></a>
prompt <Center>$RDA_html_h31 Replication Environment Transaction Counts $RDA_html_h32</Center>
prompt $RDA_html_h31 DefCall Count $RDA_html_h32
prompt $RDA_html_tab1
prompt $RDA_html_tdh1 Count $RDA_html_tdh2

SELECT '<TR>' || $RDA_html_td1 || count(*) || $RDA_html_td2 || '</TR>'
FROM sys.defcall; 
prompt </TABLE>
prompt $RDA_html_h31 DefTran Count $RDA_html_h32
prompt $RDA_html_tab1
prompt $RDA_html_tdh1 Count $RDA_html_tdh2

SELECT '<TR>' || $RDA_html_td1 || count(*) || $RDA_html_td2 || '</TR>'
FROM sys.deftran; 
prompt </TABLE>
prompt $RDA_html_h31 DefCallDest Count $RDA_html_h32
prompt $RDA_html_tab1
prompt $RDA_html_tdh1 Count $RDA_html_tdh2

SELECT '<TR>' || $RDA_html_td1 || count(*) || $RDA_html_td2 || '</TR>'
FROM sys.defcalldest; 
prompt </TABLE>
prompt $RDA_html_h31 DefTranDest Count $RDA_html_h32
prompt $RDA_html_tab1
prompt $RDA_html_tdh1 Count $RDA_html_tdh2

SELECT '<TR>' || $RDA_html_td1 || count(*) || $RDA_html_td2 || '</TR>'
FROM sys.deftrandest; 
prompt </TABLE>
prompt $RDA_html_h31 DefError Count $RDA_html_h32
prompt $RDA_html_tab1
prompt $RDA_html_tdh1 Count $RDA_html_tdh2

SELECT '<TR>' || $RDA_html_td1 || count(*) || $RDA_html_td2 || '</TR>'
FROM sys.deferror; 
prompt </TABLE>
prompt <a href="#00">Back to top</a>"

Run_SQL
cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_replication.htm

#  DBA_Jobs

DebugMessage=" Inside Review_RDBMS, gathering dba_jobs data"
Debug
      SQL="$RDA_sqlset1
      prompt $RDA_html_h31 DBA_Jobs $RDA_html_h32
      prompt $RDA_html_tab1
      prompt $RDA_html_tdh1 Job Number $RDA_html_tdh2
      prompt $RDA_html_tdh1 Logged In User $RDA_html_tdh2
      prompt $RDA_html_tdh1 Privilege User $RDA_html_tdh2
      prompt $RDA_html_tdh1 Schema User $RDA_html_tdh2
      prompt $RDA_html_tdh1 Date Last Run $RDA_html_tdh2
      prompt $RDA_html_tdh1 Date Next Run $RDA_html_tdh2
      prompt $RDA_html_tdh1 Broken(Y/N) $RDA_html_tdh2
      prompt $RDA_html_tdh1 Failures $RDA_html_tdh2
      prompt $RDA_html_tdh1 Interval $RDA_html_tdh2

      SELECT '<TR>' || $RDA_html_td1 || j.job || $RDA_html_td2, 
             $RDA_html_td1 || j.log_user || $RDA_html_td2, 
             $RDA_html_td1 || j.priv_user || $RDA_html_td2, 
             $RDA_html_td1 || j.schema_user || $RDA_html_td2, 
             $RDA_html_td1 || to_char(j.last_date, 'mm/dd/yyyy hh24:mi:ss') || $RDA_html_td2, 
             $RDA_html_td1 || to_char(j.next_date, 'mm/dd/yyyy hh24:mi:ss') || $RDA_html_td2, 
             $RDA_html_td1 || j.broken || $RDA_html_td2, 
             $RDA_html_td1 || j.failures || $RDA_html_td2, 
             $RDA_html_td1 || to_char(j.interval, 'mm/dd/yyyy hh24:mi:ss') || $RDA_html_td2 || '</TR>' 
      FROM sys.dba_jobs j
      prompt </TABLE>"

      Run_SQL
      cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_jobs.htm


##################################################
#  Process DB data for security/passwords/auditing
##################################################
DebugMessage=" Inside Review_RDBMS, gathering security data"
Debug

#  Set up sql that is different by DB version. We have to be careful here.
#  Any variable embebbed in a sql statement CANNOT be blank or empty.  SQLPLUS
#  assumes a blank line is end of statement and spits up on it.  Therefore,
#  even though we duplicate lines in many cases, we HAVE to have something
#  for a value in the variable.  This is not the case with the prompts, nor
#  will it apply if the entire sql statement should be skipped.

DBA_Profiles_Hdgs="prompt $RDA_html_tab1
                   prompt $RDA_html_tdh1 Profile $RDA_html_tdh2
                   prompt $RDA_html_tdh1 Resource Name $RDA_html_tdh2
                   prompt $RDA_html_tdh1 Limit $RDA_html_tdh2"
DBA_Profiles_SQL="SELECT '<TR>' || $RDA_html_td1 || p.profile || $RDA_html_td2, 
                     $RDA_html_td1 || p.resource_name || $RDA_html_td2, 
                     $RDA_html_td1 || nvl(p.limit,'<i>null value</i>') || $RDA_html_td2 || '</TR>' 
              FROM sys.dba_profiles p
              WHERE p.resource_type = 'PASSWORD'
              ORDER BY p.profile;
              prompt </TABLE>"
DBA_Users_Hdgs="prompt $RDA_html_tab1
                prompt $RDA_html_tdh1 User Name $RDA_html_tdh2
                prompt $RDA_html_tdh1 Lock Date $RDA_html_tdh2
                prompt $RDA_html_tdh1 Expiry Date $RDA_html_tdh2
                prompt $RDA_html_tdh1 Profile $RDA_html_tdh2"
DBA_Users_SQL="SELECT '<TR>' || $RDA_html_td1 || u.username || $RDA_html_td2, 
                     $RDA_html_td1 || nvl(to_char(u.lock_date,'dd-mon-rr hh:mi:ss'),'<i>null value</i>') || $RDA_html_td2, 
                     $RDA_html_td1 || nvl(to_char(u.expiry_date,'dd-mon-rr hh:mi:ss'),'<i>null value</i>') || $RDA_html_td2, 
                     $RDA_html_td1 || u.profile || $RDA_html_td2 || '</TR>' 
              FROM sys.dba_users u
              WHERE u.lock_date is not null
                 or u.expiry_date is not null
              ORDER BY u.username;
              prompt </TABLE>"

case "$ORACLE_VERSION" in
   80)
      Obj_Opts_Hdgs="prompt $RDA_html_tdh1 Create Name $RDA_html_tdh2
                     prompt $RDA_html_tdh1 Read Name $RDA_html_tdh2
                     prompt $RDA_html_tdh1 Write Name $RDA_html_tdh2"
      Obj_Opts_SQL1="$RDA_html_td1 || nvl(o.cre,'<i>null value</i>') || $RDA_html_td2,
                     $RDA_html_td1 || nvl(o.rea,'<i>null value</i>') || $RDA_html_td2,
                     $RDA_html_td1 || nvl(o.wri,'<i>null value</i>') || $RDA_html_td2,
       $RDA_html_td1 || nvl(o.exe,'<i>null value</i>') || $RDA_html_td2 || '</TR>' "
      Obj_Opts_SQL2="   or o.cre not in ('-/-','/  ')
                        or o.rea not in ('-/-','/  ')
                        or o.wri not in ('-/-','/  ')
                        or o.exe not in ('-/-','/  '))"
      Stmt_Opts_Hdgs=""
      Stmt_Opts_SQL="$RDA_html_td1 || s.audit_option || $RDA_html_td2,"
      Priv_Opts_Hdgs=""
      Priv_Opts_SQL="$RDA_html_td1 || p.privilege || $RDA_html_td2,"
   ;;
   81)
      Obj_Opts_Hdgs="prompt $RDA_html_tdh1 Create Name $RDA_html_tdh2
                     prompt $RDA_html_tdh1 Read Name $RDA_html_tdh2
                     prompt $RDA_html_tdh1 Write Name $RDA_html_tdh2"
      Obj_Opts_SQL1="$RDA_html_td1 || nvl(o.cre,'<i>null value</i>') || $RDA_html_td2,
                    $RDA_html_td1 || nvl(o.rea,'<i>null value</i>') || $RDA_html_td2,
                    $RDA_html_td1 || nvl(o.wri,'<i>null value</i>') || $RDA_html_td2,
       $RDA_html_td1 || nvl(o.exe,'<i>null value</i>') || $RDA_html_td2 || '</TR>' "
      Obj_Opts_SQL2="   or o.cre not in ('-/-','/  ')
                        or o.rea not in ('-/-','/  ')
                        or o.wri not in ('-/-','/  ')
                        or o.exe not in ('-/-','/  '))"
      Stmt_Opts_Hdgs="prompt $RDA_html_tdh1 Proxy Name $RDA_html_tdh2"
      Stmt_Opts_SQL="$RDA_html_td1 || nvl(s.proxy_name,'<i>null value</i>') || $RDA_html_td2,
                     $RDA_html_td1 || s.audit_option || $RDA_html_td2,"
      Priv_Opts_Hdgs="prompt $RDA_html_tdh1 Proxy Name $RDA_html_tdh2"
      Priv_Opts_SQL="$RDA_html_td1 || nvl(p.proxy_name,'<i>null value</i>') || $RDA_html_td2,
                     $RDA_html_td1 || p.privilege || $RDA_html_td2,"
   ;;
   90)
      Obj_Opts_Hdgs="prompt $RDA_html_tdh1 Create Name $RDA_html_tdh2
                     prompt $RDA_html_tdh1 Read Name $RDA_html_tdh2
                     prompt $RDA_html_tdh1 Write Name $RDA_html_tdh2"
      Obj_Opts_SQL1="$RDA_html_td1 || nvl(o.cre,'<i>null value</i>') || $RDA_html_td2,
                    $RDA_html_td1 || nvl(o.rea,'<i>null value</i>') || $RDA_html_td2,
                    $RDA_html_td1 || nvl(o.wri,'<i>null value</i>') || $RDA_html_td2,
       $RDA_html_td1 || nvl(o.exe,'<i>null value</i>') || $RDA_html_td2 || '</TR>' "
      Obj_Opts_SQL2="   or o.cre not in ('-/-','/  ')
                        or o.rea not in ('-/-','/  ')
                        or o.wri not in ('-/-','/  ')
                        or o.exe not in ('-/-','/  '))"
      Stmt_Opts_Hdgs="prompt $RDA_html_tdh1 Proxy Name $RDA_html_tdh2"
      Stmt_Opts_SQL="$RDA_html_td1 || nvl(s.proxy_name,'<i>null value</i>') || $RDA_html_td2,
                     $RDA_html_td1 || s.audit_option || $RDA_html_td2,"
      Priv_Opts_Hdgs="prompt $RDA_html_tdh1 Proxy Name $RDA_html_tdh2"
      Priv_Opts_SQL="$RDA_html_td1 || nvl(p.proxy_name,'<i>null value</i>') || $RDA_html_td2,
                     $RDA_html_td1 || p.privilege || $RDA_html_td2,"
   ;;
   92)
      Obj_Opts_Hdgs="prompt $RDA_html_tdh1 Read Name $RDA_html_tdh2"
      Obj_Opts_SQL1="$RDA_html_td1 || nvl(o.rea,'<i>null value</i>') || $RDA_html_td2,
       $RDA_html_td1 || nvl(o.exe,'<i>null value</i>') || $RDA_html_td2 || '</TR>' "
      Obj_Opts_SQL2="   or o.rea not in ('-/-', '/  ')
                        or o.exe not in ('-/-','/  '))"
      Stmt_Opts_Hdgs="prompt $RDA_html_tdh1 Proxy Name $RDA_html_tdh2"
      Stmt_Opts_SQL="$RDA_html_td1 || nvl(s.proxy_name,'<i>null value</i>') || $RDA_html_td2,
                     $RDA_html_td1 || s.audit_option || $RDA_html_td2,"
      Priv_Opts_Hdgs="prompt $RDA_html_tdh1 Proxy Name $RDA_html_tdh2"
      Priv_Opts_SQL="$RDA_html_td1 || nvl(p.proxy_name,'<i>null value</i>') || $RDA_html_td2,
                     $RDA_html_td1 || p.privilege || $RDA_html_td2,"
   ;;
   *)
      Obj_Opts_Hdgs=""
      Obj_Opts_SQL1="$RDA_html_td1 || nvl(o.exe,'<i>null value</i>') || $RDA_html_td2 || '</TR>' "
      Obj_Opts_SQL2="or o.exe not in ('-/-','/  '))"
      Stmt_Opts_Hdgs=" "
      Stmt_Opts_SQL="$RDA_html_td1 || s.audit_option || $RDA_html_td2,"
      Priv_Opts_Hdgs=""
      Priv_Opts_SQL="$RDA_html_td1 || p.privilege || $RDA_html_td2,"
      DBA_Profiles_Hdgs="prompt Password expiration profiles are not available in this database version."
      DBA_Profiles_SQL=""
      DBA_Users_Hdgs="prompt Password expiration data for users is not available in this database version."
      DBA_Users_SQL=""
   ;;
esac
SQL="$RDA_sqlset1
prompt <a name=00></a>
prompt <Center>$RDA_html_h31 Information Related to Passwords and Auditing $RDA_html_h32 </Center>
prompt <p><a href="#01">V\$PWFile_Users Information</a><br>
prompt <a href="#02">DBA_Obj_Audit_Opts Information</a><br>
prompt <a href="#03">DBA_Stmt_Audit_Opts Information</a><br>
prompt <a href="#04">DBA_Priv_Audit_Opts Information</a><br>
prompt <a href="#05">All_Def_Audit_Opts Information</a><br>
prompt <a href="#06">DBA_Profiles Information</a><br>
prompt <a href="#07">DBA_Users Information</a></p><br>
prompt <a name=01></a>
prompt $RDA_html_h31 V\$PWFile_Users $RDA_html_h32
prompt $RDA_html_tab1
prompt $RDA_html_tdh1 User Name $RDA_html_tdh2
prompt $RDA_html_tdh1 SYSDBA Privs $RDA_html_tdh2
prompt $RDA_html_tdh1 SYSOPER Privs (Y/N) $RDA_html_tdh2

SELECT '<TR>' || $RDA_html_td1 || p.username || $RDA_html_td2, 
       $RDA_html_td1 || nvl(p.sysdba,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(p.sysoper,'<i>null value</i>') || $RDA_html_td2 || '</TR>' 
FROM v\$pwfile_users p;
prompt </TABLE>
prompt <a href="#00">Back to top</a>

prompt <a name=02></a>
prompt $RDA_html_h31 DBA_Obj_Audit_Opts $RDA_html_h32
prompt $RDA_html_tab1
prompt $RDA_html_tdh1 Owner $RDA_html_tdh2
prompt $RDA_html_tdh1 Object Name $RDA_html_tdh2
prompt $RDA_html_tdh1 Object Type $RDA_html_tdh2
prompt $RDA_html_tdh1 Alter $RDA_html_tdh2
prompt $RDA_html_tdh1 Audit $RDA_html_tdh2
prompt $RDA_html_tdh1 Comment $RDA_html_tdh2
prompt $RDA_html_tdh1 Delete $RDA_html_tdh2
prompt $RDA_html_tdh1 Grant $RDA_html_tdh2
prompt $RDA_html_tdh1 Index $RDA_html_tdh2
prompt $RDA_html_tdh1 Insert $RDA_html_tdh2
prompt $RDA_html_tdh1 Lock $RDA_html_tdh2
prompt $RDA_html_tdh1 Rename $RDA_html_tdh2
prompt $RDA_html_tdh1 Select $RDA_html_tdh2
prompt $RDA_html_tdh1 Update $RDA_html_tdh2
prompt $RDA_html_tdh1 Reference $RDA_html_tdh2
$Obj_Opts_Hdgs
prompt $RDA_html_tdh1 Execute $RDA_html_tdh2

SELECT '<TR>' || $RDA_html_td1 || nvl(o.owner,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(o.object_name,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(o.object_type,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(o.alt,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(o.aud,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(o.com,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(o.del,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(o.gra,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(o.ind,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(o.ins,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(o.loc,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(o.ren,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(o.sel,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(o.upd,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(o.ref,'<i>null value</i>') || $RDA_html_td2, 
       $Obj_Opts_SQL1
FROM sys.dba_obj_audit_opts o
WHERE (o.alt not in ('-/-','/  ')
   or o.aud not in ('-/-','/  ')
   or o.com not in ('-/-','/  ')
   or o.del not in ('-/-','/  ')
   or o.gra not in ('-/-','/  ')
   or o.ind not in ('-/-','/  ')
   or o.ins not in ('-/-','/  ')
   or o.loc not in ('-/-','/  ')
   or o.ren not in ('-/-','/  ')
   or o.sel not in ('-/-','/  ')
   or o.upd not in ('-/-','/  ')
   or o.ref not in ('-/-','/  ')
   $Obj_Opts_SQL2
   and object_name not like 'SYS_IOT_OVER%';
prompt </TABLE>
prompt <a href="#00">Back to top</a>

prompt <a name=03></a>
prompt $RDA_html_h31 DBA_Stmt_Audit_Opts $RDA_html_h32
prompt $RDA_html_tab1
prompt $RDA_html_tdh1 User Name $RDA_html_tdh2
$Stmt_Opts_Hdgs
prompt $RDA_html_tdh1 Audit Option $RDA_html_tdh2
prompt $RDA_html_tdh1 Success $RDA_html_tdh2
prompt $RDA_html_tdh1 Failure $RDA_html_tdh2

SELECT '<TR>' || $RDA_html_td1 || nvl(s.user_name,'<i>null value</i>') || $RDA_html_td2, 
       $Stmt_Opts_SQL
       $RDA_html_td1 || nvl(s.success,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(s.failure,'<i>null value</i>') || $RDA_html_td2 || '</TR>' 
FROM sys.dba_stmt_audit_opts s;
prompt </TABLE>
prompt <a href="#00">Back to top</a>

prompt <a name=04></a>
prompt $RDA_html_h31 DBA_Priv_Audit_Opts $RDA_html_h32
prompt $RDA_html_tab1
prompt $RDA_html_tdh1 User Name $RDA_html_tdh2
$Priv_Opts_Hdgs
prompt $RDA_html_tdh1 Privilege $RDA_html_tdh2
prompt $RDA_html_tdh1 Success $RDA_html_tdh2
prompt $RDA_html_tdh1 Failure $RDA_html_tdh2

SELECT '<TR>' || $RDA_html_td1 || nvl(p.user_name,'<i>null value</i>') || $RDA_html_td2, 
       $Priv_Opts_SQL
       $RDA_html_td1 || nvl(p.success,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(p.failure,'<i>null value</i>') || $RDA_html_td2 || '</TR>' 
FROM sys.dba_priv_audit_opts p;
prompt </TABLE>
prompt <a href="#00">Back to top</a>

prompt <a name=05></a>
prompt <Center>$RDA_html_h31 All_Def_Audit_Opts $RDA_html_h32</Center>
prompt $RDA_html_tab1
prompt $RDA_html_tdh1 Alter $RDA_html_tdh2
prompt $RDA_html_tdh1 Audit $RDA_html_tdh2
prompt $RDA_html_tdh1 Comment $RDA_html_tdh2
prompt $RDA_html_tdh1 Delete $RDA_html_tdh2
prompt $RDA_html_tdh1 Grant $RDA_html_tdh2
prompt $RDA_html_tdh1 Index $RDA_html_tdh2
prompt $RDA_html_tdh1 Insert $RDA_html_tdh2
prompt $RDA_html_tdh1 Lock $RDA_html_tdh2
prompt $RDA_html_tdh1 Rename $RDA_html_tdh2
prompt $RDA_html_tdh1 Select $RDA_html_tdh2
prompt $RDA_html_tdh1 Update $RDA_html_tdh2
prompt $RDA_html_tdh1 Reference $RDA_html_tdh2
prompt $RDA_html_tdh1 Execute $RDA_html_tdh2

SELECT '<TR>' || $RDA_html_td1 || nvl(a.alt,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(a.aud,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(a.com,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(a.del,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(a.gra,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(a.ind,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(a.ins,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(a.loc,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(a.ren,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(a.sel,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(a.upd,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(a.ref,'<i>null value</i>') || $RDA_html_td2, 
       $RDA_html_td1 || nvl(a.exe,'<i>null value</i>') || $RDA_html_td2 || '</TR>' 
FROM sys.all_def_audit_opts a;
prompt </TABLE>
prompt <a href="#00">Back to top</a>

prompt <a name=06></a>
prompt <Center>$RDA_html_h31 DBA_Profiles $RDA_html_h32</Center>
$DBA_Profiles_Hdgs
$DBA_Profiles_SQL

prompt <a href="#00">Back to top</a>

prompt <a name=07></a>
prompt <Center>$RDA_html_h31 DBA_Users $RDA_html_h32</Center>
prompt $RDA_html_h41 NOTE: Only display users who have expiration data set. $RDA_html_h42
$DBA_Users_Hdgs
$DBA_Users_SQL

prompt <a href="#00">Back to top</a>"

Run_SQL
cat $OUT_DIR/$OUT_FILE.txt > $OUT_DIR/${PRD}_security.htm

############################################################################
#  END OF SQL PROCESSING
############################################################################

echo "   processing alert log and trace files"

# ##########################################
# #### ALERT_SID.LOG FILE ##################
# ##########################################
#  If we don't have a dump dir yet, then it's because we either couldn't read
#  the vparameter outputfile, or we couldn't connect to the db, therefore,
#  we shouldn't have found the cdump or udump dir's either.  Follow the same
#  series of searches to get cdump and udump as we do for bdump.
if [ -z "$DUMP_DIR" ]; then
#  okay, no v$parameter output, need to go searching thru the init.ora, if we
#  have it.
   if [ "$PFILE_LOCAL" = "Y" -a "$PFILE_GOOD" = "Y" ]; then
      DebugMessage=" Inside Review_RDBMS, looking for dump dir in ORACLE_HOME"
      Debug

#  Look for the init.ora, then start searching thru it and any ifiles to
#  find the bg_dump_dest.
      DUMP_DIR=`grep -i background_dump_dest $PFILE_LOCATION |grep -iv '#.*background_dump_dest' | awk -F"=" '{print $2}'|sed s/\'//g|sed s!?!$ORACLE_HOME!`
      CDUMP_DIR=`grep -i core_dump_dest $PFILE_LOCATION |grep -iv '#.*core_dump_dest' | awk -F"=" '{print $2}'|sed s/\'//g|sed s!?!$ORACLE_HOME!`
      UDUMP_DIR=`grep -i user_dump_dest $PFILE_LOCATION |grep -iv '#.*user_dump_dest' | awk -F"=" '{print $2}'|sed s/\'//g|sed s!?!$ORACLE_HOME!`

   # If any dir value is still empty at this point, check for the IFILE parameter and scan for background_dump_dest.
      if [ -z "$DUMP_DIR" -o -z "$CDUMP_DIR" -o -z "$UDUMP_DIR" ]; then
         DebugMessage=" Inside Review_RDBMS, grepping for ifile for dump dirs in ORACLE_HOME"
         Debug
         IFILE=`grep -i ifile $PFILE_LOCATION |grep -iv '#.*ifile'| awk -F"=" '{print $2}'|sed s/\'//g|sed s!?!$ORACLE_HOME!`
   #  If we have an ifile, grep for bg_dump_dest, else, bail
         if [ -n "$IFILE" ]; then
            DebugMessage=" Inside Review_RDBMS, found ifile $IFILE for dump dirs in ORACLE_HOME"
            Debug
            if [ -z "$DUMP_DIR" ]; then
               DUMP_DIR=`grep -i background_dump_dest ${IFILE} |grep -iv '#.*background_dump_dest'| awk -F"=" '{print $2}'|sed s/\'//g|sed s!?!$ORACLE_HOME!`
            fi
            if [ -z "$CDUMP_DIR" ]; then
               CDUMP_DIR=`grep -i core_dump_dest ${IFILE} |grep -iv '#.*core_dump_dest'| awk -F"=" '{print $2}'|sed s/\'//g|sed s!?!$ORACLE_HOME!`
            fi
            if [ -z "$UDUMP_DIR" ]; then
               UDUMP_DIR=`grep -i user_dump_dest ${IFILE} |grep -iv '#.*user_dump_dest'| awk -F"=" '{print $2}'|sed s/\'//g|sed s!?!$ORACLE_HOME!`
            fi
	 # if still missing a dump dir, look for nested ifiles and check them for bg_dump_dir
            if [ -z "$DUMP_DIR" -o -z "$CDUMP_DIR" -o -z "$UDUMP_DIR" ]; then
               DebugMessage=" Inside Review_RDBMS, need to keep looping for ifile for dump dirs in ORACLE_HOME"
               Debug
               NEXT_IFILE=$IFILE
               IFILE=`grep -i ifile $NEXT_IFILE | grep -iv '#.*ifile' |awk -F"=" '{print $2}'|sed s/\'//g|sed s!?!$ORACLE_HOME!`
	       OVER=N
	       while [ "$OVER" = "N" ]; do
	          if [ -n "$IFILE" ]; then
                     DebugMessage=" Inside Review_RDBMS, found ifile $IFILE looping dump dirs in ORACLE_HOME"
                     Debug
		     if [ -z "$DUMP_DIR" ]; then
                        DUMP_DIR=`grep -i background_dump_dest ${IFILE} |grep -iv '#.*background_dump_dest'| awk -F"=" '{print $2}'|sed s/\'//g|sed s!?!$ORACLE_HOME!`
                     fi
		     if [ -z "$CDUMP_DIR" ]; then
                        CDUMP_DIR=`grep -i core_dump_dest ${IFILE} |grep -iv '#.*core_dump_dest'| awk -F"=" '{print $2}'|sed s/\'//g|sed s!?!$ORACLE_HOME!`
                     fi
		     if [ -z "$UDUMP_DIR" ]; then
                        UDUMP_DIR=`grep -i user_dump_dest ${IFILE} |grep -iv '#.*user_dump_dest'| awk -F"=" '{print $2}'|sed s/\'//g|sed s!?!$ORACLE_HOME!`
                     fi
                     if [ -z "$DUMP_DIR" -o -z "$CDUMP_DIR" -o -z "$UDUMP_DIR" ]; then
                        IFILE=`grep -i ifile $NEXT_IFILE |grep -iv '#.*ifile'| awk -F"=" '{print $2}'|sed s/\'//g|sed s!?!$ORACLE_HOME!`
	             else
		        OVER=Y
	             fi
                  else
                     OVER=Y
                  fi
               done
            fi
         fi
      fi
   fi
fi
#  If we still don't have the bg_dump_dest, try a couple of other well known
#  spots, OFA location or default.

if [ -z "$DUMP_DIR" ]; then
   DebugMessage=" Inside Review_RDBMS, still no dump dir, look in basic spots"
   Debug
   if [ -r "$ORACLE_BASE/admin/${ORACLE_SID}/bdump/alert_${ORACLE_SID}.log" ]; then
      DUMP_DIR=$ORACLE_BASE/admin/${ORACLE_SID}/bdump

   elif [ -r "$ORACLE_HOME/rdbms/log/alert_${ORACLE_SID}.log" ]; then
      DUMP_DIR=$ORACLE_HOME/rdbms/log
   fi
fi

#  If we still don't have the core_dump_dest, try a couple of other well known
#  spots, OFA location or default.

if [ -z "$CDUMP_DIR" ]; then
   DebugMessage=" Inside Review_RDBMS, still no core dump dir, look in basic spots"
   Debug
   if [ -a "$ORACLE_BASE/admin/${ORACLE_SID}/cdump" ]; then
      CDUMP_DIR=$ORACLE_BASE/admin/${ORACLE_SID}/cdump
   else
      CDUMP_DIR=$ORACLE_HOME/dbs
   fi
fi

#  If we still don't have the user_dump_dest, try a couple of other well known
#  spots, OFA location or default.

if [ -z "$UDUMP_DIR" ]; then
   DebugMessage=" Inside Review_RDBMS, still no user dump dir, look in basic spots"
   Debug
   if [ -a "$ORACLE_BASE/admin/${ORACLE_SID}/udump" ]; then
      UDUMP_DIR=$ORACLE_BASE/admin/${ORACLE_SID}/udump
   else
      UDUMP_DIR=$ORACLE_HOME/rdbms/log
   fi
fi

#  If we finally have the log, start gathering info
if [ -n "$DUMP_DIR" ]; then
   if [ -a $DUMP_DIR/alert_${ORACLE_SID}.log ]; then
      DebugMessage=" Inside Review_RDBMS, found dumpdir $DUMP_DIR, get log info"
      Debug

# In the alert_SID_trace.txt file ## 
      DebugMessage=" Inside Review_RDBMS, most recent trace file name "
      Debug
      File_View=`grep "Errors in file" ${DUMP_DIR}/alert_${ORACLE_SID}.log | tail -1 | awk '{print $4}' | tr ":" " "`
      echo "##### Top 1000 lines of Most Recent Trace file ##### " > $OUT_DIR/${PRD}_alert_${ORACLE_SID}_trace.txt 
      DebugMessage=" Inside Review_RDBMS, most recent trace file top 100 lines"
      Debug
      if [ -r ${File_View:=X} ];then
         echo "=================================================================================" >> $OUT_DIR/${PRD}_alert_${ORACLE_SID}_trace.txt
         echo "File: $File_View" >> $OUT_DIR/${PRD}_alert_${ORACLE_SID}_trace.txt
         echo "=================================================================================" >> $OUT_DIR/${PRD}_alert_${ORACLE_SID}_trace.txt
         head -1000 $File_View >> $OUT_DIR/${PRD}_alert_${ORACLE_SID}_trace.txt
      else
         echo "Cannot read trace file: $File_View" >> $OUT_DIR/${PRD}_alert_${ORACLE_SID}_trace.txt
         echo "Check permissions on: $File_View or user_dump directory" >> $OUT_DIR/${PRD}_alert_${ORACLE_SID}_trace.txt
         echo "ls -l of that file: "  >> $OUT_DIR/${PRD}_alert_${ORACLE_SID}_trace.txt
      fi  

#  at a minimum, take the alert log back to the last instance startup.  if
#  it is less than variable, go to variable, if it is more than variable lines, start
#  there.
      DebugMessage=" Inside Review_RDBMS, determine line count for alert log display"
      Debug
      TOTAL_LINE_COUNT=`wc -l ${DUMP_DIR}/alert_${ORACLE_SID}.log|awk '{print $1}'`

      STARTUP_COUNT=`grep -n "Starting ORACLE instance" ${DUMP_DIR}/alert_${ORACLE_SID}.log|tail -1|cut  -f1 -d\:`

#  if startup info is found, compare the line count, if not found, set to Alert_Log_Tail
      if [ -n "$STARTUP_COUNT" ]; then
      let LINE_COUNT=$TOTAL_LINE_COUNT-$STARTUP_COUNT+1
         if [ $TOTAL_LINE_COUNT -lt $Alert_Log_Tail ]; then
            LINE_COUNT=$TOTAL_LINE_COUNT
            All_Log_Displayed=Y
         elif [ $LINE_COUNT -lt $Alert_Log_Tail ]; then
            LINE_COUNT=$Alert_Log_Tail
            All_Log_Displayed=N
         fi
      else
         LINE_COUNT=$Alert_Log_Tail
      fi
      echo "$RDA_html_h31 ##### <br>" >> $OUT_DIR/${PRD}_alert_${ORACLE_SID}_log.htm
      echo "##### Last $LINE_COUNT lines of ALERT.log <br>" >> $OUT_DIR/${PRD}_alert_${ORACLE_SID}_log.htm
      if [ "$All_Log_Displayed" = "Y" ]; then
         echo "##### Entire log Contents Displayed <br>" >> $OUT_DIR/${PRD}_alert_${ORACLE_SID}_log.htm
      fi
      echo "##### $RDA_html_h32 <br>" >> $OUT_DIR/${PRD}_alert_${ORACLE_SID}_log.htm
      echo "<pre>" >> $OUT_DIR/${PRD}_alert_${ORACLE_SID}_log.htm
      if [ "$Tail_Limit" = "Y" ]; then
         LINES=100000
         let More_Start=$TOTAL_LINE_COUNT-$LINE_COUNT
         more +n$More_Start ${DUMP_DIR}/alert_${ORACLE_SID}.log >> $OUT_DIR/${PRD}_alert_${ORACLE_SID}_log.htm
      else
         tail -$LINE_COUNT ${DUMP_DIR}/alert_${ORACLE_SID}.log >> $OUT_DIR/${PRD}_alert_${ORACLE_SID}_log.htm
      fi
      echo "</pre>" >> $OUT_DIR/${PRD}_alert_${ORACLE_SID}_log.htm
   else
      echo "Could not find the alert_${ORACLE_SID}.log file or could not read."   > $OUT_DIR/${PRD}_alert_${ORACLE_SID}_log.htm
      echo "Could not find the alert_${ORACLE_SID}.log file or could not read."   > $OUT_DIR/${PRD}_alert_${ORACLE_SID}_trace.txt
      echo "This could be because of permissions or an include file pointer in the init.ora "   >> $OUT_DIR/${PRD}_alert_${ORACLE_SID}_log.htm
      echo "This could be because of permissions or an include file pointer in the init.ora "   >> $OUT_DIR/${PRD}_alert_${ORACLE_SID}_trace.txt
   fi
else
   echo "$RDA_html_h31 Could not find the background dump destination. $RDA_html_h32"   > $OUT_DIR/${PRD}_alert_${ORACLE_SID}_log.htm
   echo "$RDA_html_h31 Could not find the background dump destination. $RDA_html_h32"   > $OUT_DIR/${PRD}_alert_errors.htm
   echo "Could not find the background dump destination."   > $OUT_DIR/${PRD}_alert_${ORACLE_SID}_trace.txt
   echo "This could be because of permissions or an include file pointer in the init.ora "   >> $OUT_DIR/${PRD}_alert_${ORACLE_SID}_log.htm
   echo "This could be because of permissions or an include file pointer in the init.ora "   >> $OUT_DIR/${PRD}_alert_${ORACLE_SID}_trace.txt
fi

#  List the contents of trace/dump directories
DebugMessage=" Inside Review_RDBMS, doing ls of Oracle Trace/log Directories"
Debug

echo "<a name=00></a>" > $OUT_DIR/${PRD}_log_trace.htm
echo "<Center><H3>${RDA_html_font}Listing of files from Oracle Log/Trace directories${RDA_html_end_font}</H3></Center>"  >> $OUT_DIR/${PRD}_log_trace.htm

echo >> $OUT_DIR/${PRD}_log_trace.htm
echo "<p><a href="#01">Background Dump Destination (from background_dump_dest setting)</a><br>" >> $OUT_DIR/${PRD}_log_trace.htm
if [ "$DUMP_DIR" != "$ORACLE_HOME/rdbms/log" ]; then
   echo "<a href="#02">Default Background Dump Destination</a><br>" >> $OUT_DIR/${PRD}_log_trace.htm
fi
echo "<a href="#03">Core Dump Destination (from core_dump_dest setting)</a><br>" >> $OUT_DIR/${PRD}_log_trace.htm
if [ "$CDUMP_DIR" != "$ORACLE_HOME/dbs" ]; then
   echo "<a href="#04">Default Core Dump Destination</a><br>" >> $OUT_DIR/${PRD}_log_trace.htm
fi
echo "<a href="#05">User Dump Destination</a></p>" >> $OUT_DIR/${PRD}_log_trace.htm

echo "<a name=01></a>" >> $OUT_DIR/${PRD}_log_trace.htm
echo "<B>${RDA_html_font}Listing of Background Dump Destination${RDA_html_end_font}</B>"  >> $OUT_DIR/${PRD}_log_trace.htm

echo "<PRE>" >> $OUT_DIR/${PRD}_log_trace.htm
echo >> $OUT_DIR/${PRD}_log_trace.htm
if [ -n "$DUMP_DIR" ]; then
   ls -al $DUMP_DIR >/dev/null 2>/dev/null
   if [ $? -eq 0 ]; then
      echo "Listing from $DUMP_DIR" >> $OUT_DIR/${PRD}_log_trace.htm
      ls -alt $DUMP_DIR >> $OUT_DIR/${PRD}_log_trace.htm 
   else
      echo "Could not list files in $DUMP_DIR" >> $OUT_DIR/${PRD}_log_trace.htm
   fi
else
   echo "Background Dump Destination could not be determined" >> $OUT_DIR/${PRD}_log_trace.htm
fi
echo "</PRE>" >> $OUT_DIR/${PRD}_log_trace.htm
echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${PRD}_log_trace.htm
echo >> $OUT_DIR/${PRD}_log_trace.htm

if [ "$DUMP_DIR" != "$ORACLE_HOME/rdbms/log" ]; then
   echo "<a name=02></a>" >> $OUT_DIR/${PRD}_log_trace.htm
   echo "<B>${RDA_html_font}Listing of Default Background Dump Destination${RDA_html_end_font}</B>"  >> $OUT_DIR/${PRD}_log_trace.htm
   echo >> $OUT_DIR/${PRD}_log_trace.htm
   echo "<PRE>" >> $OUT_DIR/${PRD}_log_trace.htm
   ls -al $ORACLE_HOME/rdbms/log >/dev/null 2>/dev/null
   if [ $? -eq 0 ]; then
      echo "Listing from $ORACLE_HOME/rdbms/log" >> $OUT_DIR/${PRD}_log_trace.htm
      ls -alt $ORACLE_HOME/rdbms/log >> $OUT_DIR/${PRD}_log_trace.htm 
   else
      echo "Could not list files in $ORACLE_HOME/rdbms/log" >> $OUT_DIR/${PRD}_log_trace.htm
   fi
   echo "</PRE>" >> $OUT_DIR/${PRD}_log_trace.htm
   echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${PRD}_log_trace.htm
   echo >> $OUT_DIR/${PRD}_log_trace.htm
fi

echo "<a name=03></a>" >> $OUT_DIR/${PRD}_log_trace.htm
echo "<B>${RDA_html_font}Listing of Core Dump Destination${RDA_html_end_font}</B>"  >> $OUT_DIR/${PRD}_log_trace.htm

echo "<PRE>" >> $OUT_DIR/${PRD}_log_trace.htm
echo >> $OUT_DIR/${PRD}_log_trace.htm
if [ -n "$CDUMP_DIR" ]; then
   ls -al $CDUMP_DIR >/dev/null 2>/dev/null
   if [ $? -eq 0 ]; then
      echo "Listing from $CDUMP_DIR" >> $OUT_DIR/${PRD}_log_trace.htm
      ls -alt $CDUMP_DIR >> $OUT_DIR/${PRD}_log_trace.htm 
   else
      echo "Could not list files in $CDUMP_DIR" >> $OUT_DIR/${PRD}_log_trace.htm
   fi
else
   echo "Core Dump Destination could not be determined" >> $OUT_DIR/${PRD}_log_trace.htm
fi
echo "</PRE>" >> $OUT_DIR/${PRD}_log_trace.htm
echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${PRD}_log_trace.htm
echo >> $OUT_DIR/${PRD}_log_trace.htm

if [ "$CDUMP_DIR" != "$ORACLE_HOME/dbs" ]; then
   echo "<a name=04></a>" >> $OUT_DIR/${PRD}_log_trace.htm
   echo "<B>${RDA_html_font}Listing of Default Core Dump Destination${RDA_html_end_font}</B>"  >> $OUT_DIR/${PRD}_log_trace.htm
   echo "<PRE>" >> $OUT_DIR/${PRD}_log_trace.htm
   echo >> $OUT_DIR/${PRD}_log_trace.htm
   ls -al $ORACLE_HOME/dbs >/dev/null 2>/dev/null
   if [ $? -eq 0 ]; then
      echo "Listing from $ORACLE_HOME/dbs" >> $OUT_DIR/${PRD}_log_trace.htm
      ls -alt $ORACLE_HOME/dbs >> $OUT_DIR/${PRD}_log_trace.htm 
   else
      echo "Could not list files in $ORACLE_HOME/dbs" >> $OUT_DIR/${PRD}_log_trace.htm
   fi
   echo "</PRE>" >> $OUT_DIR/${PRD}_log_trace.htm
   echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${PRD}_log_trace.htm
   echo >> $OUT_DIR/${PRD}_log_trace.htm
fi

echo "<a name=05></a>" >> $OUT_DIR/${PRD}_log_trace.htm
echo "<B>${RDA_html_font}Listing of User Dump Destination${RDA_html_end_font}</B>"  >> $OUT_DIR/${PRD}_log_trace.htm

echo "<PRE>" >> $OUT_DIR/${PRD}_log_trace.htm
echo >> $OUT_DIR/${PRD}_log_trace.htm
if [ -n "$UDUMP_DIR" ]; then
   if [ "$UDUMP_DIR" = "$DUMP_DIR" ]; then
      echo "User Dump Destination and Background Dump Destination are the same" >> $OUT_DIR/${PRD}_log_trace.htm
      echo "Please see Background Dump Destination for listing" >> $OUT_DIR/${PRD}_log_trace.htm
   else
      ls -al $UDUMP_DIR >/dev/null 2>/dev/null
      if [ $? -eq 0 ]; then
         echo "Listing from $UDUMP_DIR" >> $OUT_DIR/${PRD}_log_trace.htm
         ls -alt $UDUMP_DIR >> $OUT_DIR/${PRD}_log_trace.htm 
      else
         echo "Could not list files in $UDUMP_DIR" >> $OUT_DIR/${PRD}_log_trace.htm
      fi
   fi
else
   echo "User Dump Destination could not be determined" >> $OUT_DIR/${PRD}_log_trace.htm
fi
echo "</PRE>" >> $OUT_DIR/${PRD}_log_trace.htm
echo "<a href="#00">Back to top</a>" >> $OUT_DIR/${PRD}_log_trace.htm

echo "</PRE>" >> $OUT_DIR/${PRD}_log_trace.htm

#  List the data for O/S authentication and Password Files.
DebugMessage=" Inside Review_RDBMS, doing cat of files to check O/S authentication"
Debug

echo "<a name=00></a>" > $OUT_DIR/${PRD}_security_files.htm
echo "<Center><H3>${RDA_html_font}File Content and Directory Listings Related to Security Configuration${RDA_html_end_font}</H3></Center>"  >> $OUT_DIR/${PRD}_security_files.htm

echo "<p><a href="#01">Group Related Data from $ORACLE_HOME/rdbms/lib/config.${Config_Extension}</a><br>" >> $OUT_DIR/${PRD}_security_files.htm
echo "<a href="#02">/etc/group Oracle Group Settings</a><br>" >> $OUT_DIR/${PRD}_security_files.htm
echo "<a href="#03">\$ORACLE_HOME/dbs Directory Listing</a><br>" >> $OUT_DIR/${PRD}_security_files.htm
echo "<a href="#04">Unix File Permissions on /etc/passwd</a><br></p>" >> $OUT_DIR/${PRD}_security_files.htm

echo "<a name=01></a>" >> $OUT_DIR/${PRD}_security_files.htm

if [ -r "$ORACLE_HOME/rdbms/lib/config.${Config_Extension}" ]; then
#  process it here as a "found"
   echo "<B>${RDA_html_font}Data from $ORACLE_HOME/rdbms/lib/config.${Config_Extension}${RDA_html_end_font}</B>"  >> $OUT_DIR/${PRD}_security_files.htm
   echo "<PRE>" >> $OUT_DIR/${PRD}_security_files.htm
   echo "Group Data is:<br>" >> $OUT_DIR/${PRD}_security_files.htm
   echo "$Config_Grep" >> $OUT_DIR/${PRD}_security_files.htm
else
   echo "Could not read $ORACLE_HOME/rdbms/lib/config.${Config_Extension}" >> $OUT_DIR/${PRD}_security_files.htm
fi
echo "</PRE>" >> $OUT_DIR/${PRD}_security_files.htm
echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${PRD}_security_files.htm

echo "<a name=02></a>" >> $OUT_DIR/${PRD}_security_files.htm
echo "<B>${RDA_html_font}/etc/group Oracle Group Settings${RDA_html_end_font}</B>"  >> $OUT_DIR/${PRD}_security_files.htm

echo "<PRE>" >> $OUT_DIR/${PRD}_security_files.htm
if [ -r "/etc/group" ]; then
   echo "Group Values from /etc/group" >> $OUT_DIR/${PRD}_security_files.htm
   grep $DBA_Group /etc/group >> $OUT_DIR/${PRD}_security_files.htm 
   if [ "$DBA_Group" = "$OPER_Group" ]; then
      echo >> $OUT_DIR/${PRD}_security_files.htm
      echo "note:  dba Group and oper Group are the same" >> $OUT_DIR/${PRD}_security_files.htm
      echo >> $OUT_DIR/${PRD}_security_files.htm
   else
      echo "oper Group Values from /etc/group" >> $OUT_DIR/${PRD}_security_files.htm
      grep $OPER_Group /etc/group >> $OUT_DIR/${PRD}_security_files.htm 
   fi
else
   echo "Could not read /etc/group" >> $OUT_DIR/${PRD}_security_files.htm
fi
echo "</PRE>" >> $OUT_DIR/${PRD}_security_files.htm
echo "<a href="#00">Back to top</a><br><br>" >> $OUT_DIR/${PRD}_security_files.htm

echo "<a name=03></a>" >> $OUT_DIR/${PRD}_security_files.htm
echo "<B>${RDA_html_font}\$ORACLE_HOME/dbs Directory Listing${RDA_html_end_font}</B>"  >> $OUT_DIR/${PRD}_security_files.htm

echo "<PRE>" >> $OUT_DIR/${PRD}_security_files.htm
ls -l $ORACLE_HOME/dbs >/dev/null 2>/dev/null
if [ $? -eq 0 ]; then 
   echo "File listing from $ORACLE_HOME/dbs directory" >> $OUT_DIR/${PRD}_security_files.htm
   ls -al $ORACLE_HOME/dbs >> $OUT_DIR/${PRD}_security_files.htm 
else
   echo "Could not read $ORACLE_HOME/dbs" >> $OUT_DIR/${PRD}_security_files.htm
fi
echo "</PRE>" >> $OUT_DIR/${PRD}_security_files.htm
echo "<a href="#00">Back to top</a>" >> $OUT_DIR/${PRD}_security_files.htm

echo "<a name=04></a>" >> $OUT_DIR/${PRD}_security_files.htm
echo "<B>${RDA_html_font}Unix File Permissions on /etc/passwd${RDA_html_end_font}</B>"  >> $OUT_DIR/${PRD}_security_files.htm

echo "<PRE>" >> $OUT_DIR/${PRD}_security_files.htm
ls -l /etc/passwd >> $OUT_DIR/${PRD}_security_files.htm
echo "</PRE>" >> $OUT_DIR/${PRD}_security_files.htm
echo "<a href="#00">Back to top</a>" >> $OUT_DIR/${PRD}_security_files.htm

if [ -r "$ORACLE_HOME/orainst/install.log" ]; then
    echo "#####" >> $OUT_DIR/${PRD}_orainst.txt
    echo "##### Install Log from orainst: " > $OUT_DIR/${PRD}_orainst.txt
    echo "#####" >> $OUT_DIR/${PRD}_orainst.txt
    cat $ORACLE_HOME/orainst/install.log >> $OUT_DIR/${PRD}_orainst.txt
    echo "" >> $OUT_DIR/${PRD}_orainst.txt    
 else
    echo "Could not find the install.log file or could not read." >> $OUT_DIR/${PRD}_orainst.txt
fi

if [ -r "$ORACLE_HOME/install/make.log" ]; then
    echo "#####" >> $OUT_DIR/${PRD}_orainst.txt
    echo "##### Make Log from install (Probably 8i Database): " > $OUT_DIR/${PRD}_orainst.txt
    echo "#####" >> $OUT_DIR/${PRD}_orainst.txt
    cat $ORACLE_HOME/install/make.log >> $OUT_DIR/${PRD}_orainst.txt
    echo "" >> $OUT_DIR/${PRD}_orainst.txt    
 else
    echo "Could not find the make.log file in ORACLE_HOME/install (only 8i) or could not read." >> $OUT_DIR/${PRD}_orainst.txt
fi


}

Process_Versions ()
{
## Procedure Name: Process_Versions
################################################################
## 
## Currently only Processing: ORACLE_HOME Products, patches done in
## another module.
##

#  As long as we're here, let's find out what version the db says we're dealing
#  with.
Do_TimeZone=N
Do_UnixRgs=Y

#  Grep for "Oracle" to get the version line from the banner, then cut line to
#  get the short version format.

VERSION_CUT=`grep Oracle $OUT_TMP/${PRD}_versions.htm$$ |cut -f4 -d\> | cut -f1 -d" "`
Full_Version=`grep Oracle $OUT_TMP/${PRD}_versions.htm$$ | cut -f4 -d\> | cut -f5 -d" "`
#  Since we now have to deal with HTML tagging, lets get to the spot where
#  version is actually displayed. 
case "$VERSION_CUT" in
   Oracle7)
      ORACLE_VERSION=7
      Install_Dir=orainst
      Print_Version=Y
   ;;
   Oracle8)
      ORACLE_VERSION=80
      Install_Dir=orainst
      Print_Version=Y
   ;;
   Oracle8i)
      ORACLE_VERSION=81
      Install_Dir=install
      Print_Version=N
#  Timezone wasn't available until 817.  Get the full blown version and 
#  determine if we are 817 or higher.  If so, we want to run the timezone
#  queries, otherwise, we don't want them.
      case "$Full_Version" in
         8.1.7*)
            Do_TimeZone=Y
         ;;
         *)
            Do_TimeZone=N
         ;;
      esac
   ;;
   Oracle9i)
      case "$Full_Version" in
         9.2*)
            ORACLE_VERSION=92
         ;;
         *)
            ORACLE_VERSION=90
         ;;
      esac
      Do_TimeZone=Y
      Do_UnixRgs=N
   ;;
   *)
      junk=WHATEVER   # keep searching
      Install_Dir=install # let's default to the new version
      Print_Version=N
   ;;
esac

## The new installer puts this in a new spot.  Need to control directory
## looking at by version.  Also, the format isn't near the same in 8i and above
## (not as much detail) so it's going to be easier to just cat it.  Lastly, in
## 9i, it really doesn't show anything worthwhile, so best bet is to skip.

if [ "$Do_UnixRgs" = "Y" ]; then
   if [ -r  $ORACLE_HOME/${Install_Dir}/unix.rgs ];then

      if [ "$Print_Version" = "Y" ]; then
         awk -F\" '{printf("%-45s %-10s %-20s\n",$6, $4, $8)}' $ORACLE_HOME/${Install_Dir}/unix.rgs > $OUT_DIR/${PRD}_Versions.htm
      else
         cat $ORACLE_HOME/${Install_Dir}/unix.rgs > $OUT_DIR/${PRD}_Versions.htm
      fi

   else
      echo " " > $OUT_DIR/${PRD}_Versions.htm
      echo "Could not read: $ORACLE_HOME/${Install_Dir}/unix.rgs" >> $OUT_DIR/${PRD}_Versions.htm
      if [ -a /var/opt/oracle ]; then
         echo "Look in /var/opt/oracle" >> $OUT_DIR/${PRD}_Versions.htm
         echo " " >> $OUT_DIR/${PRD}_Versions.htm
         echo "===== List of files in /var/opt/oracle ===========" >> $OUT_DIR/${PRD}_Versions.htm
         ls /var/opt/oracle/ >> $OUT_DIR/${PRD}_Versions.htm
      fi
   fi
else
   echo " " > $OUT_DIR/${PRD}_Versions.htm
   echo "The content in unix.rgs in this version is no longer useful." >> $OUT_DIR/${PRD}_Versions.htm
   echo "Contents not being displayed." >> $OUT_DIR/${PRD}_Versions.htm
fi
}

Apps_Tables ()
{

if [ "$apps" = "invalid" ]; then

   SQL="SET pagesize 100 heading off termout off echo off verify off
   SET linesize 250 feedback off
   SELECT '<TR>' || $RDA_html_td1 || o.owner || $RDA_html_td2,
    $RDA_html_td1 || o.object_name || $RDA_html_td2, 
    $RDA_html_td1 || o.object_type || $RDA_html_td2, 
    $RDA_html_td1 || to_char(o.created,'dd-mon-yy hh24:mi') || $RDA_html_td2, 
    $RDA_html_td1 || to_char(o.last_ddl_time,'dd-mon-yy hh24:mi')|| $RDA_html_td2, 
    $RDA_html_td1 || o.status || $RDA_html_td2 || '</TR>'
   FROM sys.dba_objects o
   WHERE status !='VALID'
   ORDER BY o.owner, o.object_name;
   prompt </TABLE>"

elif [ "$apps" = "invalid_errors" ]; then

   SQL="SET pagesize 100 heading off termout off echo off verify off
   SET linesize 250 feedback off
   SELECT '<TR>' || $RDA_html_td1 || e.owner || $RDA_html_td2,
    $RDA_html_td1 || e.name || $RDA_html_td2,
    $RDA_html_td1 || to_char(e.line) || '/' || to_char(e.position) || $RDA_html_td2, 
    $RDA_html_td1 || e.text || $RDA_html_td2 || '</TR>'
   FROM dba_errors e
   ORDER BY e.owner, e.name, e.sequence;
   prompt </TABLE>"

else
   echo "Should not be here"
fi

export SQL
 
}

Rvw_RDBMS_Build_Links ()
{
(
cat << EOF
<li>
RDBMS
<table bgcolor="lightblue" width="100%">
<tr><td>
<ul>
<li><a href="${PRD}_Versions.htm" target="right_frame">Product Versions</a></li>
<li><a href="${PRD}_init_ora.txt" target="right_frame">init.ora</a></li>
<li><a href="${PRD}_vparameters.htm" target="right_frame">Database Parameters</a></li>
<li><a href="${PRD}_voption.htm" target="right_frame">V\$Option</a></li>
<li><a href="${PRD}_sga_info.htm" target="right_frame">SGA Information</a></li>
<li><a href="${PRD}_vlicense.htm" target="right_frame">V\$License Information</a></li>
<li><a href="${PRD}_vcompatibility.htm" target="right_frame">V\$Compatibility Information</a></li>
<li><a href="${PRD}_nls_parms.htm" target="right_frame">NLS Information</a></li>
EOF

if [ "$ORACLE_VERSION" = "7" -o "$ORACLE_VERSION" = "80" ]; then
   true
else
   echo "<li><a href="${PRD}_jvm_info.htm" target="right_frame">Java Information</a></li>"
fi

cat << EOF
<li><a href="${PRD}_vcontrolfile.htm" target="right_frame">V\$Controlfile Information</a></li>
<li><a href="${PRD}_log_info.htm" target="right_frame">Log Information</a></li>
EOF

#  Handle undo/rollback segments
if [ "$AUM_Setting" = "auto" ]; then
   echo "<li><a href="${PRD}_undo_info.htm" target="right_frame">Undo Information</a></li>" 
else
   echo "<li><a href="${PRD}_rollback_info.htm" target="right_frame">Rollback Information </a></li>" 
fi

cat << EOF
<li><a href="${PRD}_vsystem_event.htm" target="right_frame">V\$System_Event</a></li>
<li><a href="${PRD}_vsession_wait.htm" target="right_frame">V\$Session_Wait</a></li>
<li><a href="${PRD}_latch_info.htm" target="right_frame">Latch Information</a></li>
<li><a href="${PRD}_tablespace.htm" target="right_frame">Tablespaces</a></li>
<li><a href="${PRD}_datafile.htm" target="right_frame">Database Files</a></li>
<li><a href="${PRD}_replication.htm" target="right_frame">Replication Information</a></li>
<li><a href="${PRD}_jobs.htm" target="right_frame">DBA Jobs Information</a></li>
<li><a href="${PRD}_security.htm" target="right_frame">Auditing and Password Information</a></li>
<li><a href="${PRD}_Invalids.htm" target="right_frame">Invalid Objects</a></li>
<li><a href="${PRD}_ALL_Errors.htm" target="right_frame">All_Errors</a></li>
<li><a href="${PRD}_orainst.txt" target="right_frame">Install logs</a></li>
<li><a href="${PRD}_alert_${ORACLE_SID}_log.htm" target="right_frame">Last $LINE_COUNT Lines of Alert Log</a></li>
<li><a href="${PRD}_alert_${ORACLE_SID}_trace.txt" target="right_frame">Last Trace File</a></li>
<li><a href="${PRD}_log_trace.htm" target="right_frame">Trace/Log Directory Listings</a></li>
<li><a href="${PRD}_security_files.htm" target="right_frame">Security Related Directory Listings and File Contents</a></li>
</ul>
</td></tr>
</table>
</li>
EOF
) > $OUT_TMP/rvw_rdbms_left_frame.$$
echo "$OUT_TMP/rvw_rdbms_left_frame.$$" >> $OUT_TMP/output_frames.txt.$$
}

#  This function will parse through the v$parameter file to get the various
#  parameters.  Since the v$parameter file now has html tagging in it, the
#  parsing is much more complex.  The parameter name is on a separate line from
#  the parameter value, so you have to find the name first, then know to grab
#  the next line and only the next line to parse it for the value.  The parse
#  keys off of the tagging using the > to split the fields the first time, 
#  then the < to get rid of the tagging after the name.  If ANY OF THE TAGGING
#  CHANGES, this function needs to be revisited to assess impact.
Look_For_Parms ()
{
#  Grep with line location for each parm.  Then parse the line location out
#  and bump it's value by 1 to position us at the next line for the tail.
#  Pipe the output from the tail command to head to get just the first line
#  in the tail, and parse the parm value out of it.

#  An example of the value line would be:
# <TD BGCOLOR=#f7f7e7><FONT FACE="ARIAL" SIZE=2>/u02/app/oracle/product/9.0.1/admin/V901/udump</FONT>
#  The parse keys off of the ">" to determine the first cut (the value shows up
#  in the 3rd field using ">" as the delimiter), but then we need to remove the
#  end of the tagging which do by using the "<" as a delimiter.

#  Start with bg_dump_dest
string="background_dump_dest"
line=`grep -n $string $OUT_DIR/${PRD}_vparameters.htm | cut -d: -f1`
nextline=`expr $line + 1`
#  Run into problems with bg_dump_dest having a space on the end, need to clip
#  that out too.
DUMP_DIR=`tail +$nextline $OUT_DIR/${PRD}_vparameters.htm| head -1 | cut -f3 -d \>| cut -f1 -d\< | cut -f1 -d" "| sed s/\'//g | sed s!?!$ORACLE_HOME!`

#  Now core_dump_dest
string="core_dump_dest"
line=`grep -n $string $OUT_DIR/${PRD}_vparameters.htm | cut -d: -f1`
nextline=`expr $line + 1`
CDUMP_DIR=`tail +$nextline $OUT_DIR/${PRD}_vparameters.htm| head -1 | cut -f3 -d \>| cut -f1 -d\< | cut -f1 -d" "|sed s/\'//g|sed s!?!$ORACLE_HOME!`

#  Now user_dump_dest
string="user_dump_dest"
line=`grep -n $string $OUT_DIR/${PRD}_vparameters.htm | cut -d: -f1`
nextline=`expr $line + 1`
UDUMP_DIR=`tail +$nextline $OUT_DIR/${PRD}_vparameters.htm| head -1 | cut -f3 -d \>| cut -f1 -d\< | cut -f1 -d" "|sed s/\'//g|sed s!?!$ORACLE_HOME!`

#  And undo_management.  There is no need to do the $O_H sed for AUM, but this
#  parameter may not exist.  Check for not null on line before attempting to
#  set it.  It also needs to be converted to all lower case for use by the
#  rest of the script.
string="undo_management"
line=`grep -n $string $OUT_DIR/${PRD}_vparameters.htm | cut -d: -f1`
if [ -z "$line" ]; then
   true
else
   nextline=`expr $line + 1`
   AUM_Setting=`tail +$nextline $OUT_DIR/${PRD}_vparameters.htm| head -1 | cut -f3 -d \>| cut -f1 -d\< | sed -e /.*/y/ABCDEFGHIJKLMNOPQRSTUVWXYZ/abcdefghijklmnopqrstuvwxyz/`
fi
}

########################################
########################################
#  Execute the functions defined here  #
########################################
Review_RDBMS
Rvw_RDBMS_Build_Links
