Test=`env|grep Setup_Program_Version`
##  The previous line MUST be the first line in the script.  If not, the check
##  for determining if this is called or started straight from command line
##  will not work (it will throw errors back to the screen).
##############################################################################
###    Name: setup.sh                              Version: 3.09
###      By: Oracle Corp.                    Last Modified: September 05, 2001
###                                                Written: 02/20/2002
### 
### Purpose: Script used to setup the internal variables used for the RDBMS
###          gathering function of the RDA process.
###
##############################################################################
##  Modifications Section:
##############################################################################
##     Date        Author     Function       Changes
##############################################################################
##  09/05/2002     fkobylan                  Added comments to denote beginning
##    3.09                                   and end of RDBMS variables.
##                                           Chgd to only pull back lines from
##                                           existing setup between beginning
##                                           and end lines found above.
##  05/20/2002     fkobylan                  No chgs, just keeping version 
##     3.04                                  numbers in sync.
##  04/17/2002     fkobylan                  Added prompt for SYSDBA for userid.
##     3.02
##  02/20/2002     fkobylan                  Created.  Taken from original
##                                           setup.sh from RDA.
##############################################################################
###   Program Explanation:
###   ===================
###   This program handles the response section for RDBMS.  It will scan thru
###   values found in the setup.txt (if found) and allow changing from default
###   or previously entered values.  If a value is not found (due to cancelling
###   an earlier run of setup), it will prompt for new values using defaults.
### ###########################################################################
# leave this echo as is.  Since we haven't run the main setup.sh to get here
# $ECHO isn't set and there is no special formatting we have to worry about
# anyway.
if [ -z "$Test" ]; then
   echo "This script cannot be run standalone"
   echo "It must be called from the main RDA setup.sh"
   echo "Exiting from setup.sh"
   exit
fi

Setup_RDBMS_Env ()
{
## Procedure: Setup_Env ()
## Called to setup all the env variables ...
#############################################################################
## Variables Used to Process this script:
#############################################################################

ORACLE_SID_SET=${ORACLE_SID:=ORCL}
Variables_Found=N
if [ "$SETUP_TXT_Found" = "Y" ];then
   Variables_Found=Y
##  Get only the variables that apply to RDBMS
   Start_Line=`grep -n 'Beginning of RDBMS Variables' $TEMP_DIR/tmp.$$ | cut -f1 -d:`
   End_Line=`grep -n 'End of RDBMS Variables' $TEMP_DIR/tmp.$$ | cut -f1 -d:`
#  Handle it when the user cancels out of a previous run of setup.  If
#  Start_Line is null, it means they never got to this section at all.  If
#  End_Line is null, then they cancelled in this section.
   if [ -z "$Start_Line" ]; then
      Variables_Found=N
   elif [ -z "$End_Line" ]; then
      Tail_Lines=200
   else
      Tail_Lines=`expr $End_Line - $Start_Line`
   fi
fi

if [ "$Variables_Found" = "Y" ]; then
   tail +$Start_Line $TEMP_DIR/tmp.$$ | head -$Tail_Lines | grep -v '^##' > $TEMP_DIR/tmp.rdbms.$$


# This section of the else should only run when no setup.txt file is present
# Once one is there it is used to pull up the users current settings

else

$ECHO "   DATABASE_INSTALLED=Y
   ORACLE_SID=${ORACLE_SID_SET}
   PFILE_LOCAL=Y
   PFILE_LOCATION=${ORACLE_SET}/dbs/init${ORACLE_SID_SET}.ora
   SQL_Login=system
   PROMPT_FOR_SQL_PASSWORD=Y
   SQL_Password=junk
   SYSDBA_USER=Y" > $TEMP_DIR/tmp.rdbms.$$
fi

}

Get_RDBMS_Input ()
{
## Procedure: Setup_Env ()
## Called to setup all the env variables ...
#############################################################################
## Variables Used to Process this script:
#############################################################################
$ECHO "$BOLD Gathering parameters for the RDBMS section $OFF"

NO_PROMPT=N
DATABASE_INSTALLED_Found=N
ORACLE_SID_Found=N
PFILE_LOCAL_Found=N
PFILE_LOCATION_Found=N
SQL_Login_Found=N
PROMPT_FOR_SQL_PASSWORD_Found=N
SQL_Password_Found=N
SYSDBA_USER_Found=N

$ECHO "###########################################################################
##  Beginning of RDBMS Variables
###########################################################################
##"  >> setup.txt
Args=`cat $TEMP_DIR/tmp.rdbms.$$`
for CurArg in `$ECHO "$Args"`
do 
   Get_Arguments

   case "$NameVar" in
 
   DATABASE_INSTALLED)
      DATABASE_INSTALLED_Found=Y
      $ECHO
      Description="## Is there a Database installed on this node? (Y/N)\n## If not, don't prompt for SID and don't let DB scripts run\n##"
      Prompt="Is there a database on this node to be analyzed (Y/N)?"
      Append_Setup
      if [ "$ValueVar" = "N" ]; then
         Check_Database=N
      else
         Check_Database=Y
      fi
   ;;
   ORACLE_SID) 
      ORACLE_SID_Found=Y
      Description="## ORACLE_SID to be Analyzed:\n##"
      Prompt="Enter the Oracle SID to be analyzed"
      if [ "$Check_Database" = "Y" ]; then
         true
      else
         NO_PROMPT=Y
      fi
      Append_Setup
   ;;
   PFILE_LOCAL) 
      PFILE_LOCAL_Found=Y
      Local_PFILE=N
      Description="## PFILE_LOCAL - is the init.ora on this server?:\n##"
      Prompt="Is the init.ora for the database to be analyzed located on this machine(Y/N)?"
      if [ "$Check_Database" = "Y" ]; then
         true
      else
         NO_PROMPT=Y
         ValueVar=N
      fi
      Append_Setup
      if [ "$ValueVar" = "Y" ]; then
         Local_PFILE=Y
      fi
   ;;
   PFILE_LOCATION) 
      PFILE_LOCATION_Found=Y
      Description="## PFILE_LOCATION - where is the init.ora located and what is it's name?:\n##"
      Prompt="Enter the location of the init.ora (including the directory and file name)"
      if [ "$Local_PFILE" = "Y" ]; then
         true
      else
         NO_PROMPT=Y
      fi
      Append_Setup
   ;; 
   SQL_Login)
      SQL_Login_Found=Y
      Description="## This is used to connect to sqlplus for any Run_SQL or Run_SQL_File Calls\n##"
      Prompt="Enter a SQL_Login - Oracle User_id (userid only) to view DBA_ and V$ tables"
      if [ "$Check_Database" = "Y" ]; then
         true
      else
         NO_PROMPT=Y
      fi
      Append_Setup
   ;;
   PROMPT_FOR_SQL_PASSWORD)
      PROMPT_FOR_SQL_PASSWORD_Found=Y
      if [ "$Check_Database" = "Y" ]; then
         $ECHO
         $ECHO "You have the option of specifying a password for your sqlplus user now"
         $ECHO "which means it will be stored in the setup.txt file in an un-encrypted"
         $ECHO "format, or being prompted for it during rda.sh runtime.  If you wish to be"
         $ECHO "prompted, the value for the password will not be stored anywhere, it will"
         $ECHO "just be available to the rda.sh process during its runtime."
         $ECHO
      fi
      Description="## This parameter will allow users to be prompted for the database connect\n## password at runtime rather than storing it in a text file.\n##"
      Prompt="Do you wish to be prompted for the pwd of your sqlplus user at rda runtime (Y/N)?"
      if [ "$Check_Database" = "Y" ]; then
         true
      else
         NO_PROMPT=Y
      fi
      Append_Setup
      if [ "$ValueVar" = "N" ]; then
         Prompt_Password=N
         if [ "$Check_Database" = "Y" ]; then
            $ECHO
            $ECHO "*** WARNING ***"
            $ECHO " Any passwords entered as part of setup.sh are stored as plain text in setup.txt"
            $ECHO " You may wish to either remove setup.txt or edit it to remove the passwords"
            $ECHO " after rda.sh execution."
            $ECHO
         fi
      else
         Prompt_Password=Y
      fi
   ;;
   SQL_Password)
      SQL_Password_Found=Y
      Description="## This is password for the above user.  It will default to <junk>.\n##"
      Prompt="Enter the password for the user specified in the previous response"
      if [ "$Check_Database" = "N" -o "$Prompt_Password" = "Y" ]; then
         NO_PROMPT=Y
      fi
      Append_Setup_Hidden
   ;;
   SYSDBA_USER)
      SYSDBA_USER_Found=Y
      Description="## This parameter will allow users to specify that the login id from above\n## should be treated as a sysdba id, meaning \"as sysdba\" will be appended to the\n## login when connecting to the database.\n##"
      Prompt="Is the SQL Login User specified above a sysdba user (will connect as sysdba)(Y/N)?"
      if [ "$Check_Database" = "Y" ]; then
         true
      else
         NO_PROMPT=Y
      fi
      Append_Setup
   ;;

   *)  junk=NoOpHere
   ;;
   esac

done

if [ "$DATABASE_INSTALLED_Found" = "N" ]; then
   NameVar="DATABASE_INSTALLED"
   ValueVar=Y
   eval  `$ECHO "$NameVar=$ValueVar"`
   $ECHO
   Description="## Is there a Database installed on this node? (Y/N)\n## If not, don't prompt for SID and don't let DB scripts run\n##"
   Prompt="Is there a database on this node to be analyzed (Y/N)?"
   Append_Setup
   if [ "$ValueVar" = "N" ]; then
      Check_Database=N
   else
      Check_Database=Y
   fi
fi
if [ "$ORACLE_SID_Found" = "N" ]; then
   NameVar="ORACLE_SID"
   ValueVar=$ORACLE_SID_SET
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="## ORACLE_SID to be Analyzed:\n##"
   Prompt="Enter the Oracle SID to be analyzed"
   if [ "$Check_Database" = "Y" ]; then
      $ECHO
   else
      NO_PROMPT=Y
   fi
   Append_Setup
fi
if [ "$PFILE_LOCAL_Found" = "N" ]; then
   NameVar="PFILE_LOCAL"
   ValueVar=Y
   eval  `$ECHO "$NameVar=$ValueVar"`
   Local_PFILE=N
   Description="## PFILE_LOCAL - is the init.ora on this server?:\n##"
   Prompt="Is the init.ora for the database to be analyzed located on this machine(Y/N)?"
   if [ "$Check_Database" = "Y" ]; then
      $ECHO
   else
      NO_PROMPT=Y
      ValueVar=N
   fi
   Append_Setup
   if [ "$ValueVar" = "Y" ]; then
      Local_PFILE=Y
   fi
fi
if [ "$PFILE_LOCATION_Found" = "N" ]; then
   NameVar="PFILE_LOCATION"
   ValueVar=${ORACLE_SET}/dbs/init${ORACLE_SID_SET}.ora
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="## PFILE_LOCATION - where is the init.ora located and what is it's name?:\n##"
   Prompt="Enter the location of the init.ora (including the directory and file name)"
   if [ "$Local_PFILE" = "Y" ]; then
      $ECHO
   else
      NO_PROMPT=Y
   fi
   Append_Setup
fi
if [ "$SQL_Login_Found" = "N" ]; then
   NameVar="SQL_Login"
   ValueVar=system
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="## This is used to connect to sqlplus for any Run_SQL or Run_SQL_File Calls\n##"
   Prompt="Enter a SQL_Login - Oracle User_id (userid only) to view DBA_ and V$ tables"
   if [ "$Check_Database" = "Y" ]; then
      $ECHO
   else
      NO_PROMPT=Y
   fi
   Append_Setup
fi
if [ "$PROMPT_FOR_SQL_PASSWORD_Found" = "N" ]; then
   NameVar="PROMPT_FOR_SQL_PASSWORD"
   ValueVar=Y
   eval  `$ECHO "$NameVar=$ValueVar"`
   if [ "$Check_Database" = "Y" ]; then
      $ECHO "You have the option of specifying a password for your sqlplus user now"
      $ECHO "which means it will be stored in the setup.txt file in an un-encrypted"
      $ECHO "format, or being prompted for it during rda.sh runtime.  If you wish to be"
      $ECHO "prompted, the value for the password will not be stored anywhere, it will"
      $ECHO "just be available to the rda.sh process during its runtime."
   fi
   Description="## This parameter will allow users to be prompted for the database connect\n## password at runtime rather than storing it in a text file.\n##"
   Prompt="Do you wish to be prompted for the password of your sqlplus user at rda runtime (Y/N)?"
   if [ "$Check_Database" = "Y" ]; then
      true
   else
      NO_PROMPT=Y
   fi
   Append_Setup
   if [ "$ValueVar" = "N" ]; then
      Prompt_Password=N
   else
      Prompt_Password=Y
   fi
fi
if [ "$SQL_Password_Found" = "N" ]; then
   NameVar="SQL_Password"
   ValueVar=junk
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="## This is password for the above user.  It will default to <junk>.\n##"
   Prompt="Enter the password for the user specified in the previous response"
   if [ "$Check_Database" = "N" -o "$Prompt_Password" = "Y" ]; then
      NO_PROMPT=Y
   fi
   Append_Setup_Hidden
fi
if [ "$SYSDBA_USER_Found" = "N" ]; then
   NameVar="SYSDBA_USER"
   ValueVar=Y
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="## This parameter will allow users to specify that the login id from above\n## should be treated as a sysdba id, meaning "as sysdba" will be appended to the\n## login when connecting to the database.\n##"
   Prompt="Is the SQL Login User specified above a sysdba user (will connect as sysdba)(Y/N)?"
   if [ "$Check_Database" = "Y" ]; then
      true
   else
      NO_PROMPT=Y
   fi
   Append_Setup
fi
$ECHO "###########################################################################
##  End of RDBMS Variables
###########################################################################"  >> setup.txt


}


#############
##  Main   ##
#############

Setup_RDBMS_Env   # Setup Default Values, if not present, build setup.txt file.

Get_RDBMS_Input   # Get user input on the Values - allow changes, rewrite setup.txt

if [ "$Check_Database" = "Y" ]; then
   $ECHO $m >> mods_to_run.txt
fi

if [ "$DebugMode" = "n" ]; then
   rm -f $TEMP_DIR/tmp.rdbms.$$ 2>/dev/null
fi
