Test=`env|grep RDA_Program_Version`

##  The previous line MUST be the first line in the script.  If not, the check
##  for determining if this is called or started straight from command line
##  will not work (it will throw errors back to the screen).

if [ -z "$Test" ]; then
   echo "This script cannot be run standalone"
   echo "It must be called from the main RDA rda.sh"
   echo "Exiting from rda.sh"
   exit
fi
###########################################################################
##    Name: rda.sh                                Version: 3.09
##      By: Oracle Corp.                    Last Modified: September 17, 2002
##                                                Written: 07/19/02  
##
## Purpose: This is the source script for handling the gathering of intelligent
##          agent information (configuration files, agent status, etc).
##          This is not intended to be a standalone script, it should be
##          sourced from an executable script.
##
##   Usage: Source from a script
##             . ./RDA_script_0030_RVW_IA/rda.sh
##
###########################################################################

##############################################################################
##  Modifications Section:
##############################################################################
##     Date        Author     Function       Changes
##############################################################################
##  09/17/2002     fkobylan   Review_IA      Added delete of temporary file
##    V3.09                                  from agentctl call if it hangs.
##                            Rvw_IA_Build_Links
##                                           Cleaned up list creation.
##  07/19/2002     fkobylan                  Created from NETWORK/rda.sh
##    V3.08                                  Version matches rest of RDA.
#############################################################################

#############################################################################
##   Program Explanation:
##   ===================
##   The script is not intended to be a stand alone program.  Its function
##   is to handle the Intelligent Agent information gathering and display 
##   for the RDA process.  It will execute commands determined by the SETUP_OS
##   function, formatting the output into files for display through a web
##   browser.
#############################################################################

##################################
### Start of Review_IA Function ###
##################################
Review_IA ()
{
## Procedure Name: Review_IA
################################################################
## This is a module to collect data related to the operation of
## the Oracle Intelligent Agent and its configuration.
##
##   Note: This module could be used with many scripts.
#################################################################

echo "${BOLD}Processing: Intelligent Agent Information ${OFF}"

DebugMessage=" Inside Review_IA, about to gather files"
Debug

#  This will process all the intelligent agent files that are requested.  Some
#  these files can reside in multiple well known locations so they are handled
#  separately.  The function will determine if the file should be processed.
#  The file format is:
#  Section (e.g. NETWORK, WAS, OAS, iAS, etc)
#  Type (e.g. AGENT, SQLNET, OMS, OID - basically the menu level subsection)
#  Relative_to_oh (Y/N, is the directory structure relative to $ORACLE_HOME)
#  Directory (The sub-directory under $O_H or the direct path to the file)
#  File_wanted (the file name being looked for)
#  Display_name (the name that should appear in the left frame for the link)
#  Tail_it (Y/N, should the file be tailed, if N, cat the whole thing)
#  Tail_amount (if it should be tailed, how many lines)
#  Optional (Y/N is the file optional, if not and the file is not found, still
#            create a file with a missing blurb.)
#  Partial_File_Name (Y/N is the name name provided only a partial file name
#            to cause searching for all files like this name.)

# create the variables to hold the file name/link name combinations for later
# building of the left frame
AGENT_FILE=""

while read SECTION TYPE RELATIVE_TO_OH DIRECTORY FILE_WANTED DISPLAY_NAME TAIL_IT TAIL_AMOUNT OPTIONAL PARTIAL_FILE_NAME; do
   if [ "$SECTION" = "IA" ]; then
      if [ "$TYPE" = "AGENT" ]; then
         if [ "$DIRECTORY" = "SEARCH" ]; then
            Cat_SQLNET
         else
            Cat_File
         fi
      fi
   fi
done < ./${DIR}/files.txt

DebugMessage=" Inside Review_IA, got files
  AGENT_FILE is $AGENT_FILE"
Debug

#  If AGENT_FILE is empty, we didn't find any files and none of the files were
#  required, so we need to at least say something.  For IA, this shouldn't 
#  happen, but just in case it does....
if [ -z "$AGENT_FILE" ]; then
   AGENT_FILE=`${PRD}_ia_not_found.htm#No_IA_Files_Found`
   echo "<HTML>" > $OUT_DIR/${PRD}_ia_not_found.htm
   echo "<H4>No Intelligent Agent configuration files were found" >> $OUT_DIR/${PRD}_ia_not_found.htm
   echo "and all files were optional.  This does not mean there" >> $OUT_DIR/${PRD}_ia_not_found.htm
   echo "was necessarily a problem with RDA, but it should be investigated.</H4>" >> $OUT_DIR/${PRD}_ia_not_found.htm
fi

DebugMessage=" Inside Review_IA, do status of Intelligent Agent"
Debug

#  It's possible to run into problems with lsnrctl status hanging, causing the
#  script to hang.  Rather than allowing this to happen, the status request
#  will be fired off in a background forked process.  Since the status request
#  should be very short by nature, we will sleep for 30 seconds and check the
#  job status.  If a return other than zero is encountered, we will assume it
#  is the status job still running and kill the process.

echo "  Processing Intelligent Agent status"

Agentctl_File=${PRD}_ia_status.htm
Agent_Status_File=$Agentctl_File
Lsnrctl_File=$Agentctl_File
echo "<H4>Status of the Intelligent Agent</H4>"  > $OUT_DIR/${Agent_Status_File}
echo "<PRE>" >> $OUT_DIR/${Agent_Status_File}

#  Starting in 9i, lsnrctl is no longer the interface to IA, it is now
#  agentctl.  Since it's possible there may not be a database on this box
#  we can't assume we will have the version from the database.  A better
#  bet is to check for agentctl's existence and use it if we find it,
#  otherwise try lsnrctl.

Agentctl_Test=`which agentctl 2>/dev/null`

case "$Agentctl_Test" in
#  If it's found, the result should be something like:
#  /<dir>/<subdir>/agentctl
#  Since each platform treats this differently, this was the only common way
#  to determine existence.
   */agentctl)
      Agentctl_CMD=status
      Agentctl_Found=Y
      Use_agentctl &
   ;;
   *)
      LSNR_CMD=dbsnmp_status
      GET_LOGS=N
      Agentctl_Found=N
      Use_lsnrctl &
   ;; 
esac


Max_Times_to_Try=6
Hang_Check
if [ "$Command_Hung" = "Y" ]; then
   echo "Could not get status for Intelligent Agent, command did not complete" >> $OUT_DIR/${Agent_Status_File}
   echo "Could not get status for Intelligent Agent, command did not complete"
   echo "Status Check for Intelligent Agent cancelled" >> $OUT_DIR/${Agent_Status_File}
   echo "Status Check for Intelligent Agent cancelled"
  rm $OUT_TMP/agentctl.txt$$  2>/dev/null
fi

echo "</PRE>"  >> $OUT_DIR/${Agent_Status_File}

#  Determine if the agent is running.  If it is, we want to check for the
#  existence of the COMM and WORK processes, displaying ps -ef data.

if [ "$Agentctl_Found" = "Y" ]; then
   Agent_Running=`grep "^Agent is running" $OUT_DIR/${Agent_Status_File}`
else
   Agent_Running=`grep "subagent is already running" $OUT_DIR/${Agent_Status_File}`
fi

echo "<H4>Associated Intelligent Agent process data.</H4>"  > $OUT_DIR/${PRD}_ia_processes.htm
echo "<PRE>" >> $OUT_DIR/${PRD}_ia_processes.htm
if [ -z "$Agent_Running" ]; then
   echo "   It appears the agent is not running (from lsnrctl dbsnmp_status)" >> $OUT_DIR/${PRD}_ia_processes.htm
   echo "   COMM and WORK processes should not be found.<br>" >> $OUT_DIR/${PRD}_ia_processes.htm
fi
IA_Processes=`$PS_EF |egrep '(COMM|WORK)' |grep -v grep`

$PS_EF|head -n 1 >> $OUT_DIR/${PRD}_ia_processes.htm

if [ -z "$IA_Processes" ]; then
   echo "COMM and WORK Processes not found" >> $OUT_DIR/${PRD}_ia_processes.htm 
else
   echo "$IA_Processes" >> $OUT_DIR/${PRD}_ia_processes.htm 
fi

echo "</PRE>" >> $OUT_DIR/${PRD}_ia_processes.htm
}

Rvw_IA_Build_Links ()
{
(
cat << EOF
<li>
Intelligent Agent
<table bgcolor="lightblue" width="100%">
<tr><td><ul><li>
EOF

cat << EOF
Intelligent Agent Config Files
<ul>
EOF

for a in $AGENT_FILE; do
   FILE_NAME=`echo $a|cut -f1 -d#`
   DISPLAY_NAME=`echo $a|cut -f2 -d#`
   echo "<li><a href=\"$FILE_NAME\" target=\"right_frame\">$DISPLAY_NAME</a></li>"
done
cat << EOF
</li></ul>
<li><a href="${PRD}_ia_status.htm" target="right_frame">Intelligent Agent Status</a></li>
<li><a href="${PRD}_ia_processes.htm" target="right_frame">COMM/WORK Process Status</a></li>
</ul></li></tr></td></table>
EOF
) > $OUT_TMP/rvw_ia_left_frame.$$
echo "$OUT_TMP/rvw_ia_left_frame.$$" >> $OUT_TMP/output_frames.txt.$$
}

#########################################
#  Exeucute the functions defined here  #
#########################################
Review_IA
Rvw_IA_Build_Links
