Test=`env|grep RDA_Program_Version`

##  The previous line MUST be the first line in the script.  If not, the check
##  for determining if this is called or started straight from command line
##  will not work (it will throw errors back to the screen).

if [ -z "$Test" ]; then
   echo "This script cannot be run standalone"
   echo "It must be called from the main RDA rda.sh"
   echo "Exiting from rda.sh"
   exit
fi
###########################################################################
##    Name: rda.sh                                Version: 3.08
##      By: Oracle Corp.                    Last Modified: July 19, 2002
##                                                Written: 2/19/02  
##
## Purpose: This is the source script for handling the gathering of Email
##          Server information (e.g. configuration files).  This is not
##          intended to be a standalone script, it should be sourced from
##          an executable script.
##
##   Usage: Source from a script
##             . ./RDA_script_0040_RVW_EMAIL_SRVR/rda.sh
##
###########################################################################

##############################################################################
##  Modifications Section:
##############################################################################
##     Date        Author     Function       Changes
##############################################################################
##  07/19/2002     fkobylan                  Created from NETWORK/rda.sh
##    V3.08                                  Version matches rest of RDA.
#############################################################################

#############################################################################
##   Program Explanation:
##   ===================
##   The script is not intended to be a stand alone program.  Its function
##   is to handle the Email Server information gathering and display for the
##   RDA process.  It will execute commands determined by the SETUP_OS
##   function, formatting the output into files for display through a web
##   browser.
#############################################################################

##################################
### Start of Review_EMS Function ###
##################################
Review_EMS ()
{
## Procedure Name: Review_EMS
################################################################
## This is a module to collect all the information identified
## to assist with issue resolution for Oracle Email Server
## installations.
##
##   Note: This module could be used with many scripts.
#################################################################

echo "${BOLD}Processing: Oracle E-Mail Server Information ${OFF}"

DebugMessage=" Inside Review_EMS, about to get files"
Debug

#  This will process the Email Server files that are requested.
#  The file format is:
#  Section (e.g. NETWORK, WAS, OAS, iAS, etc)
#  Type (e.g. AGENT, SQLNET, OMS, OID - basically the menu level subsection)
#  Relative_to_oh (Y/N, is the directory structure relative to $ORACLE_HOME)
#  Directory (The sub-directory under $O_H or the direct path to the file)
#  File_wanted (the file name being looked for)
#  Display_name (the name that should appear in the left frame for the link)
#  Tail_it (Y/N, should the file be tailed, if N, cat the whole thing)
#  Tail_amount (if it should be tailed, how many lines)
#  Optional (Y/N is the file optional, if not and the file is not found, still
#            create a file with a missing blurb.)
#  Partial_File_Name (Y/N is the name name provided only a partial file name
#            to cause searching for all files like this name.)
#  Some files may not be required based on questions answered when running
#  setup.sh.  These files need to be skipped if their corresponding product
#  is either not installed or not being analyzed.

# create the variables to hold the file name/link name combinations for later
# building of the left frame
EMS_FILE=""

while read SECTION TYPE RELATIVE_TO_OH DIRECTORY FILE_WANTED DISPLAY_NAME TAIL_IT TAIL_AMOUNT OPTIONAL PARTIAL_FILE_NAME; do
   if [ "$SECTION" = "EMS" ]; then
      if [ "$TYPE" = "EMS" ]; then
         Cat_File
      fi
   fi
done < ./${DIR}/files.txt

DebugMessage=" Inside Review_EMS, got files
  EMS_FILE is $EMS_FILE"
Debug

#  If EMS_FILE is empty, we didn't find any files and none of the files were
#  required, so we need to at least say something.  For EMS, this shouldn't
#  happen, but just in case it does....
if [ -z "$EMS_FILE" ]; then
   EMS_FILE=`${PRD}_ems_not_found.htm#No_EMS_Files_Found`
   echo "<HTML>" > $OUT_DIR/${PRD}_ems_not_found.htm
   echo "<H4>No EMail Server configuration files were found" >> $OUT_DIR/${PRD}_ems_not_found.htm
   echo "and all files were optional.  This does not mean there" >> $OUT_DIR/${PRD}_ems_not_found.htm
   echo "was necessarily a problem with RDA, but it should be investigated.</H4>" >> $OUT_DIR/${PRD}_ems_not_found.htm
fi

}

Rvw_EMS_Build_Links ()
{
(
cat << EOF
<li>
Oracle Email Server
<table bgcolor="lightblue" width="100%">
<tr><td>
<ul>
<li>
E-Mail Server Config Files
<ul>
EOF

for e in $EMS_FILE; do
   FILE_NAME=`echo $e|cut -f1 -d#`
   DISPLAY_NAME=`echo $e|cut -f2 -d#`
   echo "<li><a href=\"$FILE_NAME\" target=\"right_frame\">$DISPLAY_NAME</a></li>"
done
 
cat << EOF
</ul>
</td></tr>
</table>
</li>
EOF
) > $OUT_TMP/rvw_ems_left_frame.$$
echo "$OUT_TMP/rvw_ems_left_frame.$$" >> $OUT_TMP/output_frames.txt.$$
}

#########################################
#  Exeucute the functions defined here  #
#########################################
Review_EMS
Rvw_EMS_Build_Links
