Test=`env|grep RDA_Program_Version`

##  The previous line MUST be the first line in the script.  If not, the check
##  for determining if this is called or started straight from command line
##  will not work (it will throw errors back to the screen).

if [ -z "$Test" ]; then
   echo "This script cannot be run standalone"
   echo "It must be called from the main RDA rda.sh"
   echo "Exiting from rda.sh"
   exit
fi
###########################################################################
##    Name: rda.sh                                Version: 3.08
##      By: Oracle Corp.                    Last Modified: July 19, 2002
##                                                Written: 07/19/02  
##
## Purpose: This is the source script for handling the gathering of Oracle
##          Management Server information (e.g. configuration files).  This
##          is not intended to be a standalone script, it should be sourced
##          from an executable script.
##
##   Usage: Source from a script
##             . ./RDA_script_0060_RVW_MGMT_SRVR/rda.sh
##
###########################################################################

##############################################################################
##  Modifications Section:
##############################################################################
##     Date        Author     Function       Changes
##############################################################################
##  07/19/2002     fkobylan                  Created from NETWORK/rda.sh
##    V3.08                                  Version matches rest of RDA.
#############################################################################

#############################################################################
##   Program Explanation:
##   ===================
##   The script is not intended to be a stand alone program.  Its function
##   is to handle the Mgmt Srvr information gathering and display for the
##   RDA process.  It will execute commands determined by the SETUP_OS
##   function, formatting the output into files for display through a web
##   browser.
#############################################################################

##################################
### Start of Review_OMS Function ###
##################################
Review_OMS ()
{
## Procedure Name: Review_OMS
################################################################
## This is a module to collect all the data identified to assist
## in resolving issues with the Oracle Management Server.
##
##   Note: This module could be used with many scripts.
#################################################################

echo "${BOLD}Processing: Oracle Management Server Information ${OFF}"

DebugMessage=" Inside Review_OMS, about to get config files"
Debug

#  This will process all the Mgmt Srvr files requested. 
#  The file format is:
#  Section (e.g. NETWORK, WAS, OAS, iAS, etc)
#  Type (e.g. AGENT, SQLNET, OMS, OID - basically the menu level subsection)
#  Relative_to_oh (Y/N, is the directory structure relative to $ORACLE_HOME)
#  Directory (The sub-directory under $O_H or the direct path to the file)
#  File_wanted (the file name being looked for)
#  Display_name (the name that should appear in the left frame for the link)
#  Tail_it (Y/N, should the file be tailed, if N, cat the whole thing)
#  Tail_amount (if it should be tailed, how many lines)
#  Optional (Y/N is the file optional, if not and the file is not found, still
#            create a file with a missing blurb.)
#  Partial_File_Name (Y/N is the name name provided only a partial file name
#            to cause searching for all files like this name.)
#  Some files may not be required based on questions answered when running
#  setup.sh.  These files need to be skipped if their corresponding product
#  is either not installed or not being analyzed.

# create the variables to hold the file name/link name combinations for later
# building of the left frame
OMS_FILE=""

while read SECTION TYPE RELATIVE_TO_OH DIRECTORY FILE_WANTED DISPLAY_NAME TAIL_IT TAIL_AMOUNT OPTIONAL PARTIAL_FILE_NAME; do
   if [ "$SECTION" = "OMS" ]; then
      if [ "$TYPE" = "OMS" ]; then
         Cat_File
      fi
   fi
done < ./${DIR}/files.txt

DebugMessage=" Inside Review_OMS, got files
  OMS_FILE is $OMS_FILE"
Debug

#  If OMS_FILE is empty, we didn't find any files and none of the files were
#  required, so we need to at least say something.  For OMS, this shouldn't
#  happen, but just in case it does....
if [ -z "$OMS_FILE" ]; then
   OMS_FILE=`${PRD}_oms_not_found.htm#No_OMS_Files_Found`
   echo "<HTML>" > $OUT_DIR/${PRD}_oms_not_found.htm
   echo "<H4>No Management Server configuration files were found" >> $OUT_DIR/${PRD}_oms_not_found.htm
   echo "and all files were optional.  This does not mean there" >> $OUT_DIR/${PRD}_oms_not_found.htm
   echo "was necessarily a problem with RDA, but it should be investigated.</H4>" >> $OUT_DIR/${PRD}_oms_not_found.htm
fi

}

Rvw_OMS_Build_Links ()
{
(
cat << EOF
<li>
Oracle Management Server
<table bgcolor="lightblue" width="100%">
<tr><td>
<ul>
<li>
Oracle Management Server Config Files
<ul>
EOF

for o in $OMS_FILE; do
   FILE_NAME=`echo $o|cut -f1 -d#`
   DISPLAY_NAME=`echo $o|cut -f2 -d#`
   echo "<li><a href=\"$FILE_NAME\" target=\"right_frame\">$DISPLAY_NAME</a></li>"
done
 
cat << EOF
</ul>
</li>
</ul>
</td></tr>
</table>
</li>
EOF
) > $OUT_TMP/rvw_oms_left_frame.$$
echo "$OUT_TMP/rvw_oms_left_frame.$$" >> $OUT_TMP/output_frames.txt.$$
}

#########################################
#  Exeucute the functions defined here  #
#########################################
Review_OMS
Rvw_OMS_Build_Links
