Test=`env|grep RDA_Program_Version`

##  The previous line MUST be the first line in the script.  If not, the check
##  for determining if this is called or started straight from command line
##  will not work (it will throw errors back to the screen).

if [ -z "$Test" ]; then
   echo "This script cannot be run standalone"
   echo "It must be called from the main RDA rda.sh"
   echo "Exiting from rda.sh"
   exit
fi
###########################################################################
##    Name: rda.sh                                Version: 3.08
##      By: Oracle Corp.                          Last Modified: July 23, 2002
##                                                Written: 5/02/02  
##
## Purpose: This is the source script for handling the gathering of OLAP
##          information 
##          This is not intended to be a standalone script, it should be 
##          sourced from an executable script.
##
##   Usage: As a call from a script
##             . ./RDA_script_0070_RVW_OLAP/rda.sh
##
###########################################################################

##############################################################################
##  Modifications Section:
##############################################################################
##     Date        Author     Function       Changes
##############################################################################
##  07/23/2002     eferrer    Rvw_OLAP_Build_Links
##    V3.08                                  Chgd bg color for left frame.
##  05/23/2002     eferrer                   suggestion from Issue ID 144 
##    V3.04                                  implemented, which is the request
##                                           to copy the whole xsdaemon,
##                                           xsauth and OESEvent log files
##                                           instead of only the last 100 lines
##                                           suggestion from Issue ID 146
##                                           implemented. Script now takes
##                                           OES DBA user and password as
##                                           well as the SNAPI Port Number.
##                                           Also had to limit the extract of
##                                           the express logs to the last
##                                           10000 lines due to some logs 
##                                           exceeding 30MB in size 
##  05/02/2002     eferrer                   created 
##    V3.03                                  based on code from original rda.sh.
#############################################################################

#############################################################################
##   Program Explanation:
##   ===================
##   The script is not intended to be a stand alone program.  Its function
##   is to handle the OLAP information gathering and display for the RDA
##   RDA process.  It will execute Express SPL commands to get the patch level
##   of Oracle Express Server and gather files pertaining to the OES install.  
##   The output will be formatted into files for display through a web browser.
#############################################################################

######################################
### Start of Review_OES Function ###
######################################

Review_OES ()
{
## Procedure Name: Review_OES
################################################################
## Collects the Basic OES Related configurations. Also extracts
## the last 100 lines of all the OES log files
################################################################
DebugMessage=" Inside Review_OES"
Debug

echo "${BOLD}Processing: Review_OES ...${OFF}"

Create_OES_Summary

DebugMessage=" Inside Review_OES, creating a copy of oes.key"
Debug
echo "<font color=\"#3366FF\">"  >  $OUT_DIR/${PRD}_oeskey.htm
echo "<Center><H2>OLAP Services oes.key</H2></Center>" >> $OUT_DIR/${PRD}_oeskey.htm
echo "</font><PRE>" >>  $OUT_DIR/${PRD}_oeskey.htm
chmod 666 $OUT_DIR/${PRD}_oeskey.htm
if [ -r  $OES_ORACLE_HOME/olap/oes.key ]; then
  cat $OES_ORACLE_HOME/olap/oes.key >> $OUT_DIR/${PRD}_oeskey.htm 
else
  echo "$OES_ORACLE_HOME/olap/oes.key does not exist ..." >> $OUT_DIR/${PRD}_oeskey.htm
fi
echo "</PRE>" >> $OUT_DIR/${PRD}_oeskey.htm

DebugMessage=" Inside Review_OES, creating a copy of express.prm"
Debug
echo "<font color=\"#3366FF\">"  >  $OUT_DIR/${PRD}_expressprm.htm
echo "<Center><H2>OLAP Services express.prm</H2></Center>" >> $OUT_DIR/${PRD}_expressprm.htm
echo "</font><PRE>"  >>  $OUT_DIR/${PRD}_expressprm.htm
chmod 666 $OUT_DIR/${PRD}_expressprm.htm
if [ -r  $OES_ORACLE_HOME/olap/express.prm ]; then
  cat $OES_ORACLE_HOME/olap/express.prm >> $OUT_DIR/${PRD}_expressprm.htm 
else
  echo "$OES_ORACLE_HOME/olap/express.prm does not exist ..." >> $OUT_DIR/${PRD}_expressprm.htm
fi
echo "</PRE>" >> $OUT_DIR/${PRD}_expressprm.htm

DebugMessage=" Inside Review_OES, getting last 100 lines of xsdaemon.log"
Debug
echo "<font color=\"#3366FF\">"  >  $OUT_DIR/${PRD}_xsdaemon.htm
echo "<Center><H2>OES xsdaemon.log file (Last 10000 lines)</H2></Center>" >> $OUT_DIR/${PRD}_xsdaemon.htm
echo "</font><PRE>" >>  $OUT_DIR/${PRD}_xsdaemon.htm
chmod 666 $OUT_DIR/${PRD}_xsdaemon.htm
if [ -r  $OES_ORACLE_HOME/olap/log/xsdaemon.log ]; then
  tail -10000 $OES_ORACLE_HOME/olap/log/xsdaemon.log >> $OUT_DIR/${PRD}_xsdaemon.htm
else
  echo "$OES_ORACLE_HOME/olap/log/xsdaemon.log does not exist ... " >> $OUT_DIR/${PRD}_xsdaemon.htm
fi
echo "</PRE>" >> $OUT_DIR/${PRD}_xsdaemon.htm

DebugMessage=" Inside Review_OES, getting last 100 lines of xsauth.log"
Debug
echo "<font color=\"#3366FF\">"  >  $OUT_DIR/${PRD}_xsauth.htm
echo "<Center><H2>OES xsauth.log file (Last 10000 lines)</H2></Center>" >> $OUT_DIR/${PRD}_xsauth.htm
echo "</font><PRE>"  >>  $OUT_DIR/${PRD}_xsauth.htm
chmod 666 $OUT_DIR/${PRD}_xsauth.htm
if [ -r  $OES_ORACLE_HOME/olap/log/xsauth.log ]; then
  tail -10000 $OES_ORACLE_HOME/olap/log/xsauth.log >> $OUT_DIR/${PRD}_xsauth.htm
else
  echo "$OES_ORACLE_HOME/olap/log/xsauth.log does not exist ... " >> $OUT_DIR/${PRD}_xsauth.htm
fi
echo "</PRE>" >> $OUT_DIR/${PRD}_xsauth.htm

DebugMessage=" Inside Review_OES, getting last 100 of all the OESEvent.log files"
Debug
grep EventLogPath $OES_ORACLE_HOME/olap/oes.key | sed -e "s/     EventLogPath = (REG_SZ) \"//g" -e "s/\"/\/OESEvent.log/g" > $OUT_TMP/oesevents.htm
if [ -r $OUT_DIR/${PRD}_oesevents.htm ]; then
  rm $OUT_DIR/${PRD}_oesevents.htm
fi
echo "<font color=\"#3366FF\">"  >  $OUT_DIR/${PRD}_oesevents.htm
echo "<Center><H2>OESEvent log files</H2></Center>" >> $OUT_DIR/${PRD}_oesevents.htm
echo "</font><PRE>"  >>  $OUT_DIR/${PRD}_oesevents.htm
while read CurArg
 do
  DebugMessage=" Inside Review_OES, parsing $OUT_TMP/oesevents.htm
   CurArg=$CurArg"
  Debug
  echo "$RDA_html_h31" >> $OUT_DIR/${PRD}_oesevents.htm
  echo "Last 10000 lines of $CurArg" >> $OUT_DIR/${PRD}_oesevents.htm
  echo "=======================================================================" >> $OUT_DIR/${PRD}_oesevents.htm
  echo "$RDA_html_h32" >> $OUT_DIR/${PRD}_oesevents.htm
  chmod 666 $OUT_DIR/${PRD}_oesevents.htm
  if [ -r  $CurArg ]; then
    tail -10000 $CurArg >> $OUT_DIR/${PRD}_oesevents.htm
    echo " " >> $OUT_DIR/${PRD}_oesevents.htm
    echo " " >> $OUT_DIR/${PRD}_oesevents.htm
    echo " " >> $OUT_DIR/${PRD}_oesevents.htm
  else
    echo "$CurArg does not exist ... " >> $OUT_DIR/${PRD}_oesevents.htm
  fi
  echo "</PRE>" >> $OUT_DIR/${PRD}_oesevents.htm
done <  $OUT_TMP/oesevents.htm

if [ "$OFA_INSTALLED" = "Y" ]; then
  Get_OFA_Version
  Get_OFA_Config_Files
fi

if [ "$OWA_INSTALLED" = "Y" ]; then
  Get_OWA_Version
  Get_OWA_Config_Files
fi

if [ "$DPE_INSTALLED" = "Y" ]; then
  Get_DP_Info
  Create_DBC_Copy
  Create_xsoowaroas_Copy
  Create_sso_conf_Copy
fi

}

Get_DP_Info ()
{
  echo "<font color=\"#3366FF\">"  >  $OUT_DIR/${PRD}_dpeinfo.htm
  echo "<Center><H2>Demand Planning Engine Information</H2></Center>" >> $OUT_DIR/${PRD}_dpeinfo.htm
  echo "</font>"  >>  $OUT_DIR/${PRD}_dpeinfo.htm
  SQL_Login_Password=system/${DPE_DPS_Password}@$DPE_DPS_SID
  OLD_Connect_to_DB=$Connect_to_DB
  Connect_to_DB=Y
  SQL="$RDA_sqlset1
  prompt <A NAME="DPEParameters"></A>
  prompt $RDA_html_h31 Demand Plan Name : ${DPE_DP_NAME}  $RDA_html_h32
  prompt $RDA_html_tab1
  prompt $RDA_html_tdh1 Parameter Name $RDA_html_tdh2
  prompt $RDA_html_tdh1 Value $RDA_html_tdh2
  select '<TR>'||$RDA_html_td1||'EAD Name'||$RDA_html_td2||$RDA_html_td1||a.EAD_NAME||$RDA_html_td2,
         '<TR>'||$RDA_html_td1||'Express Port'||$RDA_html_td2||$RDA_html_td1||a.EXPRESS_MACHINE_PORT||$RDA_html_td2,
         '<TR>'||$RDA_html_td1||'DP Code Location'||$RDA_html_td2||$RDA_html_td1||a.CODE_LOCATION||$RDA_html_td2,
         '<TR>'||$RDA_html_td1||'Shared DB Prefix'||$RDA_html_td2||$RDA_html_td1||a.SHARED_DB_PREFIX||$RDA_html_td2,
         '<TR>'||$RDA_html_td1||'Shared DB Location'||$RDA_html_td2||$RDA_html_td1||a.SHARED_DB_LOCATION||$RDA_html_td2,
         '<TR>'||$RDA_html_td1||'OWA Virtual Path'||$RDA_html_td2||$RDA_html_td1||a.OWA_VIRTUAL_PATH_NAME||$RDA_html_td2,
         '<TR>'||$RDA_html_td1||'Express Connect String'||$RDA_html_td2||$RDA_html_td1||a.EXPRESS_CONNECT_STRING||$RDA_html_td2,
         '<TR>'||$RDA_html_td1||'Valid'||$RDA_html_td2||$RDA_html_td1||b.VALID_FLAG||$RDA_html_td2
  from msd.msd_dp_express_setup a, msd.msd_demand_plans b
  where b.DEMAND_PLAN_NAME = '$DPE_DP_NAME' and
  a.DEMAND_PLAN_ID = b.DEMAND_PLAN_ID;
  prompt </TABLE>"

  Run_SQL
  cat $OUT_DIR/$OUT_FILE.txt >> $OUT_DIR/${PRD}_dpeinfo.htm
  Connect_to_DB=$OLD_Connect_to_DB
}

Create_DBC_Copy ()
{
  echo "$RDA_html_h31" >> $OUT_DIR/${PRD}_dpeinfo.htm
  echo "DBC File : ${DPE_DBC_FILE}" >> $OUT_DIR/${PRD}_dpeinfo.htm
  echo "=======================================================================" >> $OUT_DIR/${PRD}_dpeinfo.htm
  echo "$RDA_html_h32 <PRE>" >> $OUT_DIR/${PRD}_dpeinfo.htm
  if [ -r  $DPE_DBC_FILE ]; then
    cat $DPE_DBC_FILE >> $OUT_DIR/${PRD}_dpeinfo.htm 
  else
    echo "$DPE_DBC_FILE does not exist ... " >> $OUT_DIR/${PRD}_dpeinfo.htm 
  fi
  echo " " >> $OUT_DIR/${PRD}_dpeinfo.htm 
  echo " " >> $OUT_DIR/${PRD}_dpeinfo.htm 
  echo " " >> $OUT_DIR/${PRD}_dpeinfo.htm 
}

Create_xsoowaroas_Copy ()
{
  echo "$RDA_html_h31" >> $OUT_DIR/${PRD}_dpeinfo.htm
  echo "XSOOWAROAS Configuration : ${DPE_SSO_LOCATION}/bin/xsoowaroas.cfg" >> $OUT_DIR/${PRD}_dpeinfo.htm
  echo "=======================================================================" >> $OUT_DIR/${PRD}_dpeinfo.htm
  echo "$RDA_html_h32" >> $OUT_DIR/${PRD}_dpeinfo.htm
  if [ -r  ${DPE_SSO_LOCATION}/bin/xsoowaroas.cfg ]; then
    cat ${DPE_SSO_LOCATION}/bin/xsoowaroas.cfg >> $OUT_DIR/${PRD}_dpeinfo.htm 
  else
    echo "${DPE_SSO_LOCATION}/bin/xsoowaroas.cfg does not exist ... " >> $OUT_DIR/${PRD}_dpeinfo.htm 
  fi
  echo " " >> $OUT_DIR/${PRD}_dpeinfo.htm 
  echo " " >> $OUT_DIR/${PRD}_dpeinfo.htm 
  echo " " >> $OUT_DIR/${PRD}_dpeinfo.htm 
}

Create_sso_conf_Copy ()
{
  echo "$RDA_html_h31" >> $OUT_DIR/${PRD}_dpeinfo.htm
  echo "Single Sign-On Configuration : ${DPE_SSO_LOCATION}/conf/sso.conf" >> $OUT_DIR/${PRD}_dpeinfo.htm
  echo "=======================================================================" >> $OUT_DIR/${PRD}_dpeinfo.htm
  echo "$RDA_html_h32" >> $OUT_DIR/${PRD}_dpeinfo.htm
  if [ -r ${DPE_SSO_LOCATION}/conf/sso.conf ]; then
    cat ${DPE_SSO_LOCATION}/conf/sso.conf >> $OUT_DIR/${PRD}_dpeinfo.htm 
  else
    echo "${DPE_SSO_LOCATION}/conf/sso.conf does not exist ... " >> $OUT_DIR/${PRD}_dpeinfo.htm 
  fi
  echo "</PRE>" >> $OUT_DIR/${PRD}_dpeinfo.htm 
}

Get_OWA_Version ()
{
DebugMessage=" Inside Get_OWA_Version, getting the XWDEVKIT database version"
Debug
  echo "<font color=\"#3366FF\">"  >  $OUT_DIR/${PRD}_owainfo.htm
  echo "<Center><H2>Express Web Agent Information</H2></Center>" >> $OUT_DIR/${PRD}_owainfo.htm
  echo "</font><PRE>"  >>  $OUT_DIR/${PRD}_owainfo.htm
  echo "$RDA_html_h31" >> $OUT_DIR/${PRD}_owainfo.htm
  echo "Oracle Web Agent Version (${OWA_LOCATION}/xwdevkit.db)" >> $OUT_DIR/${PRD}_owainfo.htm
  echo "=======================================================================" >> $OUT_DIR/${PRD}_owainfo.htm
  echo "$RDA_html_h32" >> $OUT_DIR/${PRD}_owainfo.htm
  if [ -r  $OWA_LOCATION/xwdevkit.db ]; then
    chmod 666 $OUT_DIR/${PRD}_owainfo.htm
    echo "dtb attach ${OWA_LOCATION}/xwdevkit.db ro" > $OUT_TMP/rdaowa.inf
    echo "otf append ${OUT_DIR}/${PRD}_owainfo.htm" >> $OUT_TMP/rdaowa.inf
    echo "shw joinchars('   _XWD_DEVKITVER = ' _xwd_devkitver)" >> $OUT_TMP/rdaowa.inf
    echo "otf eof" >> $OUT_TMP/rdaowa.inf
    echo "dtb detach ${OWA_LOCATION}/xwdevkit.db " >> $OUT_TMP/rdaowa.inf
    $OES_ORACLE_HOME/olap/bin/oescmd -b ora_ro_tcp:$MACHINE_NAME[$OES_PORT_NO] -u $OES_DBA_USER -p $OES_DBA_PWD "infile ${OUT_TMP}/rdaowa.inf" > /dev/null
  else
    echo "Can not attach the $OWA_LOCATION/xwdevkit.db database ..." >> $OUT_DIR/${PRD}_owainfo.htm
  fi
  echo " " >> $OUT_DIR/${PRD}_owainfo.htm
  echo " " >> $OUT_DIR/${PRD}_owainfo.htm
  echo " " >> $OUT_DIR/${PRD}_owainfo.htm
}

Get_OWA_Config_Files ()
{
DebugMessage=" Inside Get_OWA_Config_Files, creating copies of the OWA onfiguration files"
Debug
  echo "$RDA_html_h31" >> $OUT_DIR/${PRD}_owainfo.htm
  echo "# ${CGI_LOCATION}/${CGI_EXEC}.cfg" >> $OUT_DIR/${PRD}_owainfo.htm
  echo "=======================================================================" >> $OUT_DIR/${PRD}_owainfo.htm
  echo "$RDA_html_h32" >> $OUT_DIR/${PRD}_owainfo.htm
  if [ -r  $CGI_LOCATION/${CGI_EXEC}.cfg ]; then
    cat $CGI_LOCATION/${CGI_EXEC}.cfg >> $OUT_DIR/${PRD}_owainfo.htm 
  else
    echo "$CGI_LOCATION/${CGI_EXEC}.cfg does not exist ... " >> $OUT_DIR/${PRD}_owainfo.htm 
  fi
  echo "</PRE>" >> $OUT_DIR/${PRD}_owainfo.htm
}

Get_OFA_Version ()
{
DebugMessage=" Inside Get_OFA_Version, getting the OFA Shared version"
Debug
  echo "<font color=\"#3366FF\">"  >  $OUT_DIR/${PRD}_ofainfo.htm
  echo "<Center><H2>Oracle Financial Analyzer Information</H2></Center>" >> $OUT_DIR/${PRD}_ofainfo.htm
  echo "</font><PRE>"  >>  $OUT_DIR/${PRD}_ofainfo.htm
  echo "$RDA_html_h31" >> $OUT_DIR/${PRD}_ofainfo.htm
  echo "Oracle Financial Analyzer Versions" >> $OUT_DIR/${PRD}_ofainfo.htm
  echo "=======================================================================" >> $OUT_DIR/${PRD}_ofainfo.htm
  echo "$RDA_html_h32" >> $OUT_DIR/${PRD}_ofainfo.htm
  if [ -r  $OFA_DBA_HOME/shared/$OFAS_NAME ]; then
    echo "dtb attach ${OFA_DBA_HOME}/shared/${OFAS_NAME} ro" > $OUT_TMP/rdaofa.inf
    echo "otf append ${OUT_DIR}/${PRD}_ofainfo.htm" >> $OUT_TMP/rdaofa.inf
    echo "shw joinchars('   <B>Shared database</B> : ' fms.version)" >> $OUT_TMP/rdaofa.inf
    echo "otf eof" >> $OUT_TMP/rdaofa.inf
    echo "dtb detach ${OFA_DBA_HOME}/shared/${OFAS_NAME}" >> $OUT_TMP/rdaofa.inf
    $OES_ORACLE_HOME/olap/bin/oescmd -b ora_ro_tcp:$MACHINE_NAME[$OES_PORT_NO] -u $OES_DBA_USER -p $OES_DBA_PWD "infile ${OUT_TMP}/rdaofa.inf" > /dev/null
  else
    echo "Can not attach the $OFAS_NAME database ..." >> $OUT_DIR/${PRD}_ofainfo.htm
  fi
DebugMessage=" Inside Get_OFA_Version, getting the OFASERVE version"
Debug
  if [ -r  $OFA_DBA_HOME/code/ofaserve.db ]; then
    echo "dtb attach ${OFA_DBA_HOME}/code/ofaserve.db ro" > $OUT_TMP/rdaofa.inf
    echo "otf append ${OUT_DIR}/${PRD}_ofainfo.htm" >> $OUT_TMP/rdaofa.inf
    echo "shw joinchars('   <B>OFASERVE database</B> : ' fmsserve.version)" >> $OUT_TMP/rdaofa.inf
    echo "otf eof" >> $OUT_TMP/rdaofa.inf
    echo "dtb detach ${OFA_DBA_HOME}/code/ofaserve.db" >> $OUT_TMP/rdaofa.inf
    $OES_ORACLE_HOME/olap/bin/oescmd -b ora_ro_tcp:$MACHINE_NAME[$OES_PORT_NO] -u $OES_DBA_USER -p $OES_DBA_PWD "infile ${OUT_TMP}/rdaofa.inf"> /dev/null
  else
    echo "Can not attach the ofaserve database ..." >> $OUT_DIR/${PRD}_ofainfo.htm
  fi
DebugMessage=" Inside Get_OFA_Version, getting the OFATOOLS version"
Debug
  if [ -r  $OFA_DBA_HOME/code/ofatools.db ]; then
    echo "dtb attach ${OFA_DBA_HOME}/code/ofatools.db ro" > $OUT_TMP/rdaofa.inf
    echo "otf append ${OUT_DIR}/${PRD}_ofainfo.htm" >> $OUT_TMP/rdaofa.inf
    echo "shw joinchars('   <B>OFATOOLS database</B> : ' fmstools.version)" >> $OUT_TMP/rdaofa.inf
    echo "otf eof" >> $OUT_TMP/rdaofa.inf
    echo "dtb detach ${OFA_DBA_HOME}/code/ofatools.db" >> $OUT_TMP/rdaofa.inf
    $OES_ORACLE_HOME/olap/bin/oescmd -b ora_ro_tcp:$MACHINE_NAME[$OES_PORT_NO] -u $OES_DBA_USER -p $OES_DBA_PWD "infile ${OUT_TMP}/rdaofa.inf"> /dev/null
  else
    echo "Can not attach the ofaserve database ..." >> $OUT_DIR/${PRD}_ofainfo.htm
  fi
  echo " " >> $OUT_DIR/${PRD}_ofainfo.htm
  echo " " >> $OUT_DIR/${PRD}_ofainfo.htm
  echo " " >> $OUT_DIR/${PRD}_ofainfo.htm
}

Get_OFA_Config_Files ()
{
DebugMessage=" Inside Get_OFA_Config_Files, creating copies of the OFA onfiguration files"
Debug
  echo "$RDA_html_h31" >> $OUT_DIR/${PRD}_ofainfo.htm
  echo "OFASYSCF.CFG" >> $OUT_DIR/${PRD}_ofainfo.htm
  echo "=======================================================================" >> $OUT_DIR/${PRD}_ofainfo.htm
  echo "$RDA_html_h32" >> $OUT_DIR/${PRD}_ofainfo.htm
  if [ -r  $OFA_DBA_HOME/shared/ofasyscf.cfg ]; then
    cat $OFA_DBA_HOME/shared/ofasyscf.cfg >> $OUT_DIR/${PRD}_ofainfo.htm 
  else
    echo "$OFA_DBA_HOME/shared/ofasyscf.cfg does not exist ... " >> $OUT_DIR/${PRD}_ofainfo.htm 
  fi
  echo " " >> $OUT_DIR/${PRD}_ofainfo.htm
  echo " " >> $OUT_DIR/${PRD}_ofainfo.htm
  echo " " >> $OUT_DIR/${PRD}_ofainfo.htm
  echo "$RDA_html_h31" >> $OUT_DIR/${PRD}_ofainfo.htm
  echo "OFACDCF.CFG" >> $OUT_DIR/${PRD}_ofainfo.htm
  echo "=======================================================================" >> $OUT_DIR/${PRD}_ofainfo.htm
  echo "$RDA_html_h32" >> $OUT_DIR/${PRD}_ofainfo.htm
  if [ -r  $OFA_DBA_HOME/code/ofacdcf.cfg ]; then
    cat $OFA_DBA_HOME/code/ofacdcf.cfg >> $OUT_DIR/${PRD}_ofainfo.htm 
  else
    echo "$OFA_DBA_HOME/code/ofacdcf.cfg does not exist ... " >> $OUT_DIR/${PRD}_ofainfo.htm 
  fi
  echo "</PRE>" >> $OUT_DIR/${PRD}_ofainfo.htm 
}

Create_OES_Summary ()
{
DebugMessage=" Inside Create_OES_Summary"
Debug
Prepare_OESKEY

(
cat << EOF
<font color="#3366FF">
EOF
) >  $OUT_DIR/${PRD}_summary.htm
echo "<Center><H2>OLAP Services Summary</H2></Center>" >> $OUT_DIR/${PRD}_summary.htm
(
cat << EOF
</font>
EOF
) >>  $OUT_DIR/${PRD}_summary.htm

echo "<PRE>" >> $OUT_DIR/${PRD}_summary.htm

DebugMessage=" Inside Create_OES_Summary, parsing the oes.key file"
Debug
INFO=""
while read CurArg
 do
  if [ "$CurArg" != "" ]; then

   DebugMessage=" Getting the DisplayName of the services"
   Debug
   # Get the Name and DisplayName of the Service
   grep $CurArg#DisplayName $OUT_TMP/oeskey2.$$ | read INFO
   echo $INFO |tr "\042" "#"|cut -d# -f3|read INFO
   echo "$RDA_html_h31" >> $OUT_DIR/${PRD}_summary.htm
   echo "Service : $INFO" >> $OUT_DIR/${PRD}_summary.htm
   echo "=======================================================================" >> $OUT_DIR/${PRD}_summary.htm
   echo "$RDA_html_h32" >> $OUT_DIR/${PRD}_summary.htm
   echo "     Name : $CurArg" >> $OUT_DIR/${PRD}_summary.htm

   DebugMessage=" Getting PageBufferCount setting"
   Debug
   # Get the PageBufferCount
   grep $CurArg#PageBufferCount $OUT_TMP/oeskey2.$$ | read INFO
   if [ "$INFO" != "" ]; then
     echo $INFO |tr "\051" "###"|sed -e "s/### /#/g"|cut -d# -f3|read INFO
   else
     INFO="NA"
   fi
   echo "     PageBufferCount : $INFO" >> $OUT_DIR/${PRD}_summary.htm

   DebugMessage=" Checking if Service is running"
   Debug
   # Check if Service is running
   ps -ef |grep " $CurArg "|grep -v "grep"|read INFO
   if [ "$INFO" != "" ]; then
     INFO="Running"
     OESRUNNING="Y"
   else
     INFO="Not Running"
     OESRUNNING="N"
   fi
   echo "     State : $INFO" >> $OUT_DIR/${PRD}_summary.htm

   DebugMessage=" Getting the UUID port"
   Debug
   # Get the UUID
   grep $CurArg#ServerObjectId $OUT_TMP/oeskey2.$$ | read INFO
   echo $INFO |tr "\042" "#"|cut -d# -f3|read INFO
   echo "     ServerObjectId : $INFO" >> $OUT_DIR/${PRD}_summary.htm

   DebugMessage=" Getting the XCA port"
   Debug
   # Get the XCA port
   grep $CurArg#XCAPortNumber $OUT_TMP/oeskey2.$$ | read INFO
   if [ "$INFO" != "" ]; then
     echo $INFO |tr "\051" "###"|sed -e "s/### /#/g"|cut -d# -f3|read INFO
   else
     INFO="NA"
   fi
   echo "     XCAPortNumber : $INFO" >> $OUT_DIR/${PRD}_summary.htm

   DebugMessage=" Getting the Snapi port"
   Debug
   # Get the Snapi port
   grep $CurArg#RoListenPortNumber $OUT_TMP/oeskey2.$$ | read INFO
   if [ "$INFO" != "" ]; then
     echo $INFO |tr "\051" "###"|sed -e "s/### /#/g"|cut -d# -f3|read INFO
   else
     INFO="NA"
   fi
   echo "     RoListenPortNumber : $INFO" >> $OUT_DIR/${PRD}_summary.htm

   if [ "$OESRUNNING" = "Y" ]; then
     LD_LIBRARY_PATH=$LD_LIBRARY_PATH:$OES_ORACLE_HOME/lib
     export LD_LIBRARY_PATH
     echo "<font color=\"#3366FF\">"  >  $OUT_DIR/${PRD}_eversion.htm
     echo "<Center><H2>OES eversion</H2></Center>" >> $OUT_DIR/${PRD}_eversion.htm
     echo "</font><PRE>"  >>  $OUT_DIR/${PRD}_eversion.htm
     chmod 666 $OUT_DIR/${PRD}_eversion.htm
     EXPRESS_COMMAND="otf append ${OUT_DIR}/${PRD}_eversion.htm;shw eversion;otf eof"
     export EXPRESS_COMMAND
     $OES_ORACLE_HOME/olap/bin/oescmd -b ora_ro_tcp:$MACHINE_NAME[$OES_PORT_NO] -u $OES_DBA_USER -p $OES_DBA_PWD "$EXPRESS_COMMAND" > /dev/null
     echo "</PRE>" >> $OUT_DIR/${PRD}_eversion.htm
   fi
  fi
 done < $OUT_TMP/oeskey1.$$

echo "</PRE>" >> $OUT_DIR/${PRD}_summary.htm
DebugMessage=" Exiting Create_OES_Summary"
Debug

}

Prepare_OESKEY ()
{
DebugMessage=" Inside Prepare_OESKEY, preparing the oes.key file for parsing"
Debug
SRVC_NAME=""
SRVC_STAT=""
SERVICES=""
COMMAND=""
if [ -r $OUT_TMP/oeskey1.$$ ]; then
 rm $OUT_TMP/oeskey1.$$
fi
if [ -r $OUT_TMP/oeskey2.$$ ]; then
 rm $OUT_TMP/oeskey2.$$
fi
LCTR=1
STARTCOPY=N
TMPSTR1=""
TMPSTR2=""
TMPSTR3=""
TMPSTR4=""
cat $OES_ORACLE_HOME/olap/oes.key | tr "\134" "#" > $OUT_TMP/oeskey1.$$
cat $OUT_TMP/oeskey1.$$ | tr "\133" "#" > $OUT_TMP/oeskey2.$$
cat $OUT_TMP/oeskey2.$$ | sed -e "s/]//g" > $OUT_TMP/oeskey1.$$
# Copy the whole oes.key into a temporary file while removing blank lines
# and everything before the DatabasePagingManagement section
rm $OUT_TMP/oeskey2.$$
while read CurArg
 do
     if [ "$CurArg" != "" ]; then
       echo "$CurArg" >> $OUT_TMP/oeskey2.$$
     fi
 done <  $OUT_TMP/oeskey1.$$
rm $OUT_TMP/oeskey1.$$
#Add the OES Service name to the beginning of each line
#and also remove lines that starts with hash
while read CurArg
 do
   echo "$CurArg"|grep SYSTEM#CurrentControlSet#Services#|read TMPSTR3
   if [ "$TMPSTR3" != "" ]; then
     echo "$CurArg" | cut -d# -f5 | read SRVC_NAME
     echo "$SERVICES"|grep $SRVC_NAME|read TMPSTR4
     if [ "$TMPSTR4" = "" ]; then
       echo $SERVICES$SRVC_NAME#|read TMPSTR2
       echo $TMPSTR2|read SERVICES
     fi
   else
     echo "$CurArg"|grep Software#ORACLE#OLAP#ExpressServer|read TMPSTR2
     if [ "$TMPSTR2" != "" ]; then
       echo "$CurArg" | cut -d# -f6 | read SRVC_NAME
     else
       echo "$CurArg" | grep = | read TMPSTR1
       if [ "$TMPSTR1" != "" ]; then
         echo $SRVC_NAME#$CurArg >> $OUT_TMP/oeskey1.$$
       fi
     fi
   fi
 done <  $OUT_TMP/oeskey2.$$
sort $OUT_TMP/oeskey1.$$ > $OUT_TMP/oeskey2.$$
echo $SERVICES | tr "#" "\012" > $OUT_TMP/oeskey1.$$
}

Rvw_OLAP_Build_Links ()
{
(
cat << EOF
<li>
Express Server
<table bgcolor="lightblue" width="100%">
<tr><td>
<ul>
<li><a href="${PRD}_summary.htm" target="right_frame">Services Summary</a></li>
<li><a href="${PRD}_eversion.htm" target="right_frame">eversion</a></li>
<li><a href="${PRD}_oeskey.htm" target="right_frame">oes.key</a></li>
<li><a href="${PRD}_expressprm.htm" target="right_frame">express.prm</a></li>
</li>
<li>
       Log Excerpts
<ul>
<li><a href="${PRD}_xsdaemon.htm" target="right_frame">xsdaemon</a></li>
<li><a href="${PRD}_xsauth.htm" target="right_frame">xsauth</a></li>
<li><a href="${PRD}_oesevents.htm" target="right_frame">OESEvent</a></li>
EOF

if [ "$OWA_INSTALLED" = "Y" ]; then
  cat << EOF
  </ul>
  <li><a href="${PRD}_owainfo.htm" target="right_frame">OWA</a></li>
  <ul>
EOF
fi

if [ "$OFA_INSTALLED" = "Y" ]; then
  cat << EOF
  </ul>
  <li><a href="${PRD}_ofainfo.htm" target="right_frame">OFA</a></li>
  <ul>
EOF
fi

if [ "$DPE_INSTALLED" = "Y" ]; then
  cat << EOF
  </ul>
  <li><a href="${PRD}_dpeinfo.htm" target="right_frame">DPE</a></li>
  <ul>
EOF
fi

cat << EOF
</ul>
</td></tr>
</table>
</li>
EOF
) > $OUT_TMP/rvw_olap_left_frame.$$
echo "$OUT_TMP/rvw_olap_left_frame.$$" >> $OUT_TMP/output_frames.txt.$$
}

########################################
#  Execute the functions defined here  #
########################################
Review_OES
Rvw_OLAP_Build_Links

