Test=`env|grep Setup_Program_Version`
##  The previous line MUST be the first line in the script.  If not, the check
##  for determining if this is called or started straight from command line
##  will not work (it will throw errors back to the screen).
##############################################################################
###    Name: setup.sh                              Version: 3.09
###      By: Oracle Corp.                    Last Modified: September 05, 2002
###                                                Written: 02/20/2002
### 
### Purpose: Script used to setup the internal variables used for the OLAP
###          gathering function of the RDA process.
###
##############################################################################
##  Modifications Section:
##############################################################################
##     Date        Author     Function       Changes
##############################################################################
##  09/05/2002     fkobylan                  Added comments to denote beginning
##    3.09                                   and end of OLAP variables.
##                                           Chgd to only pull back lines from
##                                           existing setup between beginning
##                                           and end lines found above.
##  07/24/2002     fkobylan   Get_OLAP_Input Removed some unneeded echos.
##    V3.08                                  
##  07/01/2002     fkobylan   Get_OLAP_Input Chg'd default for Express_Installed
##    V3.07                                  when values not found in setup.txt.
##  05/23/2002     eferrer                   suggestion from Issue ID 146
##    V3.04                                       implemented. Script now takes
##                                           OES DBA user and password as
##                                           well as the SNAPI Port Number.
##  05/02/2002     eferrer                   Created.  Taken from original
##    V3.03                                       setup.sh from RDA.
##############################################################################
###   Program Explanation:
###   ===================
###   This program handles the response section for OLAP.  It will scan thru
###   values found in the setup.txt (if found) and allow changing from default
###   or previously entered values.  If a value is not found (due to cancelling
###   an earlier run of setup), it will prompt for new values using defaults.
### ###########################################################################
# leave this echo as is.  Since we haven't run the main setup.sh to get here
# $ECHO isn't set and there is no special formatting we have to worry about
# anyway.
if [ -z "$Test" ]; then
   echo "This script cannot be run standalone"
   echo "It must be called from the main RDA setup.sh"
   echo "Exiting from setup.sh"
   exit
fi

Setup_OLAP_Env ()
{
## Procedure: Setup_OLAP_Env ()
## Called to setup all the env variables ...
#############################################################################
## Variables Used to Process this script:
#############################################################################
## This is also used as a prefix to all the files written for the analysis.
## ie. if tnsnames.ora is collected it would be named WF_tnsnames.txt
##
ORACLE_SET=${ORACLE_HOME:=/prod/path/of/oracle_home}

Variables_Found=N
if [ "$SETUP_TXT_Found" = "Y" ]; then
   Variables_Found=Y 
##  Gather only the variables that apply to OLAP
   Start_Line=`grep -n 'Beginning of OLAP Variables' $TEMP_DIR/tmp.$$ | cut -f1 -d:`
   End_Line=`grep -n 'End of OLAP Variables' $TEMP_DIR/tmp.$$ | cut -f1 -d:`
#  Handle it when the user cancels out of a previous run of setup.  If 
#  Start_Line is null, it means they never got to this section at all.  If 
#  End_Line is null, then they cancelled in this section.
   if [ -z "$Start_Line" ]; then
      Variables_Found=N
   elif [ -z "$End_Line" ]; then
      Tail_Lines=200
   else
      Tail_Lines=`expr $End_Line - $Start_Line`
   fi
fi

if [ "$Variables_Found" = "Y" ]; then   
   tail +$Start_Line $TEMP_DIR/tmp.$$ | head -$Tail_Lines | grep -v '^##' > $TEMP_DIR/tmp.olap.$$

# This section of the else should only run when no setup.txt file is present
# Once one is there it is used to pull up the users current settings

else

$ECHO "  EXPRESS_INSTALLED=N
  OES_ORACLE_HOME=${ORACLE_SET}/ExpressServer
  OES_DBA_USER=oesdba
  OES_DBA_PWD_PROMPT=N
  OES_DBA_PWD=oesdba
  OES_PORT_NO=12287
  OWA_INSTALLED=N
  OWA_LOCATION=${OES_ORACLE_HOME}/olap/oes632/owa633
  CGI_EXEC=oowaro
  CGI_LOCATION=${OES_ORACLE_HOME}/olap/oes632/tools
  OFA_INSTALLED=N
  OFA_DBA_HOME=${OES_ORACLE_HOME}/super
  OFAS_NAME=ofas.db
  DPE_INSTALLED=N
  DPE_DP_NAME=Demand_Plan_Sample
  DPE_DPS_SQL_PASSWORD_PROMPT=N
  DPE_DPS_Password=junk
  DPE_DPS_SID=oracle9i
  DPE_DBC_FILE=/ora806/fnd_top/secure/sample.dbc
  DPE_SSO_LOCATION=/ora806/olap/sso640" > $TEMP_DIR/tmp.olap.$$
fi

}

Get_OLAP_Input ()
{
## Procedure: Get_OLAP_Input ()
## Called to setup all the env variables ...
#############################################################################
## Variables Used to Process this script:
#############################################################################
$ECHO "$BOLD Gathering parameters for the OLAP section $OFF"

NO_PROMPT=N
EXPRESS_INSTALLED_Found=N
OES_ORACLE_HOME_Found=N
OES_DBA_USER_Found=N
OES_DBA_PWD_PROMPT_Found=N
OES_DBA_PWD_Found=N
OES_PORT_NO_Found=N
OWA_INSTALLED_Found=N
OWA_LOCATION_Found=N
CGI_EXEC_Found=N
CGI_LOCATION_Found=N
OFA_INSTALLED_Found=N
OFA_DBA_HOME_Found=N
OFAS_NAME_Found=N
DPE_INSTALLED_Found=N
DPE_DP_NAME_Found=N
DPE_DPS_SQL_PASSWORD_PROMPT_Found=N
DPE_DPS_Password_Found=N
DPE_DPS_SID_Found=N
DPE_DBC_FILE_Found=N
DPE_SSO_LOCATION_Found=N

$ECHO "##############################################################################
##  Beginning of OLAP Variables
##############################################################################
##" >> setup.txt

Args=`cat $TEMP_DIR/tmp.olap.$$`
for CurArg in `$ECHO "$Args"`
do 
   Get_Arguments

   case "$NameVar" in
 
   EXPRESS_INSTALLED)
      EXPRESS_INSTALLED_Found=Y
      $ECHO
      Description="##  Is Express Installed?\n##  If not, don't prompt for OES_ORACLE_HOME and do not run the OLAP Scripts\n##"
      Prompt="Is Oracle Express Server installed on this machine (Y/N)?"
      Append_Setup
      if [ "$ValueVar" = "N" ]; then
         Check_Express=N
      else
         Check_Express=Y
      fi
   ;;
   OES_ORACLE_HOME)
      OES_ORACLE_HOME_Found=Y
      Description="##  ORACLE_HOME for Oracle Express Server\n##"
      Prompt="Enter ORACLE_HOME for Express Server"
      if [ "$Check_Express" = "Y" ]; then
         echo
      else
         NO_PROMPT=Y
      fi
      Append_Setup
   ;;
   OES_DBA_USER)
      OES_DBA_USER_Found=Y
      Description="##  OES DBA Role User ID\n##"
      Prompt="Enter the OES DBA Role User ID"
      if [ "$Check_Express" = "Y" ]; then
         echo
      else
         NO_PROMPT=Y
      fi
      Append_Setup
   ;;
   OES_DBA_PWD_PROMPT)
      OES_DBA_PWD_PROMPT_Found=Y
      if [ "$Check_Express" = "Y" ]; then
         $ECHO
         $ECHO "You have the option of specifying a password for the OES DBA Role User ID now"
         $ECHO "which means it will be stored in the setup.txt file in an un-encrypted"
         $ECHO "format, or being prompted for it during rda.sh runtime.  If you wish to be"
         $ECHO "prompted, the value for the password will not be stored anywhere, it will"
         $ECHO "just be available to the rda.sh process during its runtime."
         $ECHO
      fi
      Description="##  This parameter will allow users to be prompted for the OES DBA Role User ID \n##  password at runtime rather than storing it in a text file.\n##"
      Prompt="Do you wish to be prompted for the OES DBA Role User ID password at rda runtime (Y/N)?"
      if [ "$Check_Express" = "Y" ]; then
         true
      else
         NO_PROMPT=Y
      fi
      Append_Setup
      if [ "$ValueVar" = "N" ]; then
         OES_DBA_Prompt_Password=N
         if [ "$Check_Express" = "Y" ]; then
            $ECHO
            $ECHO "*** WARNING ***"
            $ECHO " Any passwords entered as part of setup.sh are stored as plain text in setup.txt"
            $ECHO " You may wish to either remove setup.txt or edit it to remove the passwords"
            $ECHO " after rda.sh execution."
            $ECHO
         fi
      else
         OES_DBA_Prompt_Password=Y
      fi
   ;;
   OES_DBA_PWD)
      OES_DBA_PWD_Found=Y
      Description="##  OES DBA Role User ID Password\n##"
      Prompt="Enter the password for the OES DBA Role User ID now"
      if [ "$Check_Express" = "N" -o "$OES_DBA_Prompt_Password" = "Y" ]; then
         NO_PROMPT=Y
      fi
      Append_Setup_Hidden
   ;;
   OES_PORT_NO)
      OES_PORT_NO_Found=Y
      Description="##  OES ROListenPortNumber or SNAPI Port Number\n##"
      Prompt="Enter the ROListenPortNumber or SNAPI Port Number"
      if [ "$Check_Express" = "Y" ]; then
         echo
      else
         NO_PROMPT=Y
      fi
      Append_Setup
   ;;
   OWA_INSTALLED)
      OWA_INSTALLED_Found=Y
      if [ "$Check_Express" = "Y" ]; then
        NO_PROMPT=N
      else
        NO_PROMPT=Y
      fi
      Description="##  Is Oracle Express Web Agent installed on this machine ? (Y/N)\n##  If not, don't prompt for the name and location of the CGI executable\n##"
      Prompt="Is Oracle Express Web Agent installed on this machine (Y/N)?"
      Append_Setup
      if [ "$ValueVar" = "N" ]; then
           Check_OWA=N
      else
           Check_OWA=Y
      fi
   ;;
   OWA_LOCATION)
      OWA_LOCATION_Found=Y
      Description="##  Enter the directory where OWA is installed\n##"
      Prompt="Enter the directory where OWA is installed"
      if [ "$Check_OWA" = "Y" ]; then
         echo
      else
         NO_PROMPT=Y
      fi
      Append_Setup
   ;;
   CGI_EXEC)
      CGI_EXEC_Found=Y
      Description="##  Name of the CGI Executable (oowa/oowaro/xsoowaro) \n##"
      Prompt="Enter the name of the CGI Executable (oowa/oowaro/xsoowaro)"
      if [ "$Check_OWA" = "Y" ]; then
         echo
      else
         NO_PROMPT=Y
      fi
      Append_Setup
   ;;
   CGI_LOCATION)
      CGI_LOCATION_Found=Y
      Description="##  Location of the CGI Executable\n##"
      Prompt="Enter the location of the CGI Executable"
      if [ "$Check_OWA" = "Y" ]; then
         echo
      else
         NO_PROMPT=Y
      fi
      Append_Setup
   ;;
   OFA_INSTALLED)
      OFA_INSTALLED_Found=Y
      if [ "$Check_Express" = "Y" ]; then
        NO_PROMPT=N
      else
        NO_PROMPT=Y
      fi
      Description="##  Is Oracle Financial Analyzer Server installed on this machine(Y/N)?\n##  If not, don't prompt for the Super DBA directory, the name of the shared\n##  database\n##"
      Prompt="Is Oracle Financial Analyzer Server installed on this machine (Y/N)?"
      Append_Setup
      if [ "$ValueVar" = "N" ]; then
         Check_OFA=N
      else
         Check_OFA=Y
      fi
   ;;
   OFA_DBA_HOME)
      OFA_DBA_HOME_Found=Y
      Description="##  Super DBA directory\n##"
      Prompt="Enter the directory where the Super DBA is installed"
      if [ "$Check_OFA" = "Y" ]; then
         echo
      else
         NO_PROMPT=Y
      fi
      Append_Setup
   ;;
   OFAS_NAME)
      OFAS_NAME_Found=Y
      Description="##  Name of the OFA Super shared database\n##"
      Prompt="Enter the shared database name"
      if [ "$Check_OFA" = "Y" ]; then
         echo
      else
         NO_PROMPT=Y
      fi
      Append_Setup
   ;;
   DPE_INSTALLED)
      DPE_INSTALLED_Found=Y
      if [ "$Check_Express" = "Y" ]; then
        NO_PROMPT=N
      else
        NO_PROMPT=Y
      fi
      Description="##  Is Demand Planning Engine installed on this machine(Y/N)?\n##  If not, don't prompt for the other DPE questions\n##"
      Prompt="Is Demand Planning Engine installed on this machine ? (Y/N)"
      Append_Setup
      if [ "$ValueVar" = "N" ]; then
         Check_DPE=N
      else
         Check_DPE=Y
      fi
   ;;
   DPE_DP_NAME)
      DPE_DP_NAME_Found=Y
      Description="##  Enter the Demand Plan Name\n##"
      Prompt="Enter the Demand Plan Name. Please enclose the name with ' if you have spaces in the DP Name"
      if [ "$Check_DPE" = "Y" ]; then
         echo
      else
         NO_PROMPT=Y
      fi
      Append_Setup
   ;;
   DPE_DPS_SQL_PASSWORD_PROMPT)
      DPE_DPS_SQL_PASSWORD_PROMPT_Found=Y
      if [ "$Check_DPE" = "Y" ]; then
         $ECHO
         $ECHO "You have the option of specifying a password for APPS \"system\" user now"
         $ECHO "which means it will be stored in the setup.txt file in an un-encrypted"
         $ECHO "format, or being prompted for it during rda.sh runtime.  If you wish to be"
         $ECHO "prompted, the value for the password will not be stored anywhere, it will"
         $ECHO "just be available to the rda.sh process during its runtime."
         $ECHO
      fi
      Description="##  This parameter will allow users to be prompted for the DPS database connection\n##  password at runtime rather than storing it in a text file.\n##"
      Prompt="Do you wish to be prompted for the APPS \"system\" pwd user at rda runtime (Y/N)?"
      if [ "$Check_DPE" = "Y" ]; then
         true
      else
         NO_PROMPT=Y
      fi
      Append_Setup
      if [ "$ValueVar" = "N" ]; then
         DPE_Prompt_Password=N
         if [ "$Check_DPE" = "Y" ]; then
            $ECHO
            $ECHO "*** WARNING ***"
            $ECHO " Any passwords entered as part of setup.sh are stored as plain text in setup.txt"
            $ECHO " You may wish to either remove setup.txt or edit it to remove the passwords"
            $ECHO " after rda.sh execution."
            $ECHO
         fi
      else
         DPE_Prompt_Password=Y
      fi
   ;;
   DPE_DPS_Password)
      DPE_DPS_Password_Found=Y
      Description="##  This is password for the above user.  It will default to <junk>.\n##"
      Prompt="Enter the password for the APPS \"system\" user now"
      if [ "$Check_DPE" = "N" -o "$DPE_Prompt_Password" = "Y" ]; then
         NO_PROMPT=Y
      fi
      Append_Setup_Hidden
   ;;
   DPE_DPS_SID)
      DPE_DPS_SID_Found=Y
      Description="##  Enter the connect string to the Demand Planning Server (scott/tiger@oracle9i)\n##"
      Prompt="Enter the SID for the Demand Planning Server"
      if [ "$Check_DPE" = "Y" ]; then
         echo
      else
         NO_PROMPT=Y
      fi
      Append_Setup
   ;;
   DPE_DBC_FILE)
      DPE_DBC_FILE_Found=Y
      Description="##  Enter the location and name of the DBC file in the local machine\n##"
      Prompt="Enter the location and name of the DBC file in the local machine"
      if [ "$Check_DPE" = "Y" ]; then
         echo
      else
         NO_PROMPT=Y
      fi
      Append_Setup
   ;;
   DPE_SSO_LOCATION)
      DPE_SSO_LOCATION_Found=Y
      Description="##  Enter the location of the Oracle OLAP Single Sign-On\n##"
      Prompt="Enter the location of the Oracle OLAP Single Sign-On"
      if [ "$Check_DPE" = "Y" ]; then
         echo
      else
         NO_PROMPT=Y
      fi
      Append_Setup
   ;;
   *)  junk=NoOpHere
   ;;
   esac

done

#  This next batch of code is here in case the user cancelled out of setup.sh.
#  With an incomplete setup.txt file, not all variables will be prompted for.
#  This will handle any variables that were missing from the setup.txt.
if [ "$EXPRESS_INSTALLED_Found" = "N" ]; then
   NameVar=EXPRESS_INSTALLED
   ValueVar=N
   eval  `$ECHO "$NameVar=$ValueVar"`
   $ECHO
   Description="##  Is Express Installed?\n##  If not, don't prompt for OES_ORACLE_HOME and do not run the OLAP Scripts\n##"
   Prompt="Is Oracle Express Server installed on this machine (Y/N)?"
   Append_Setup
   if [ "$ValueVar" = "N" ]; then
      Check_Express=N
   else
      Check_Express=Y
   fi
fi
if [ "$OES_ORACLE_HOME_Found" = "N" ]; then
   NameVar=OES_ORACLE_HOME
   ValueVar=${ORACLE_SET}/ExpressServer
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="##  ORACLE_HOME for Oracle Express Server\n##"
   Prompt="Enter ORACLE_HOME for Express Server"
   if [ "$Check_Express" = "Y" ]; then
      echo
   else
      NO_PROMPT=Y
   fi
   Append_Setup
fi
if [ "$OES_DBA_USER_Found" = "N" ]; then
   NameVar=OES_DBA_USER
   ValueVar=oesdba
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="##  OES DBA Role User ID\n##"
   Prompt="Enter the OES DBA Role User ID"
   if [ "$Check_Express" = "Y" ]; then
      echo
   else
      NO_PROMPT=Y
   fi
   Append_Setup
fi   
if [ "$OES_DBA_PWD_PROMPT_Found" = "N" ]; then
   NameVar="OES_DBA_PWD_PROMPT"
   ValueVar=Y
   eval `$ECHO "$NameVar=$ValueVar"`
   if [ "$Check_Express" = "Y" ]; then
      $ECHO
      $ECHO "You have the option of specifying a password for the OES DBA Role User ID now"
      $ECHO "which means it will be stored in the setup.txt file in an un-encrypted"
      $ECHO "format, or being prompted for it during rda.sh runtime.  If you wish to be"
      $ECHO "prompted, the value for the password will not be stored anywhere, it will"
      $ECHO "just be available to the rda.sh process during its runtime."
      $ECHO
   fi
   Description="##  This parameter will allow users to be prompted for the OES DBA Role User ID \n##  password at runtime rather than storing it in a text file.\n##"
   Prompt="Do you wish to be prompted for the OES DBA Role User ID password at rda runtime (Y/N)?"
   if [ "$Check_Express" = "Y" ]; then
      true
   else
      NO_PROMPT=Y
   fi
   Append_Setup
   if [ "$ValueVar" = "N" ]; then
      OES_DBA_Prompt_Password=N
   else
      OES_DBA_Prompt_Password=Y
   fi
fi
if [ "$OES_DBA_PWD_Found" = "N" ]; then
   NameVar="OES_DBA_PWD"
   ValueVar=junk
   eval `$ECHO "$NameVar=$ValueVar"`
   Description="##  OES DBA Role User ID Password\n##"
   Prompt="Enter the password for the OES DBA Role User ID now"
   if [ "$Check_Express" = "N" -o "$OES_DBA_Prompt_Password" = "Y" ]; then
      NO_PROMPT=Y
   fi
   Append_Setup_Hidden
fi
if [ "$OES_PORT_NO_Found" = "N" ]; then
   NameVar=OES_PORT_NO
   ValueVar=12287
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="##  OES ROListenPortNumber or SNAPI Port Number\n##"
   Prompt="Enter the ROListenPortNumber or SNAPI Port Number"
   if [ "$Check_Express" = "Y" ]; then
      echo
   else
      NO_PROMPT=Y
   fi
   Append_Setup
fi
if [ "$OWA_INSTALLED_Found" = "N" ]; then
   NameVar=OWA_INSTALLED
   ValueVar=N
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="##  Is Oracle Express Web Agent installed on this machine ? (Y/N)\n##  If not, don't prompt for the name and location of the CGI executable\n##"
   Prompt="Is Oracle Express Web Agent installed on this machine (Y/N)?"
   if [ "$Check_Express" = "Y" ]; then
     if [ "$ValueVar" = "N" ]; then
        Check_OWA=N
        NO_PROMPT=Y
     else
        Check_OWA=Y
     fi
   else
     Check_OWA=N
     NO_PROMPT=Y
   fi
   Append_Setup
fi
if [ "$OWA_LOCATION_Found" = "N" ]; then
   NameVar=OWA_LOCATION
   ValueVar=${OES_ORACLE_HOME}/olap/oes632/owa633
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="##  Enter the directory where OWA is installed\n##"
   Prompt="Enter the directory where OWA is installed"
   if [ "$Check_OWA" = "Y" ]; then
      echo
   else
      NO_PROMPT=Y
   fi
   Append_Setup
fi
if [ "$CGI_EXEC_Found" = "N" ]; then
   NameVar=CGI_EXEC
   ValueVar=oowaro
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="##  Name of the CGI Executable (oowa/oowaro/xsoowaro) \n##"
   Prompt="Enter the name of the CGI Executable (oowa/oowaro/xsoowaro)"
   if [ "$Check_OWA" = "Y" ]; then
      echo
   else
      NO_PROMPT=Y
   fi
   Append_Setup
fi
if [ "$CGI_LOCATION_Found" = "N" ]; then
   NameVar=CGI_LOCATION
   ValueVar=${OES_ORACLE_HOME}/olap/oes632/tools
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="##  Location of the CGI Executable\n##"
   Prompt="Enter the location of the CGI Executable"
   if [ "$Check_OWA" = "Y" ]; then
      echo
   else
      NO_PROMPT=Y
   fi
   Append_Setup
fi
if [ "$OFA_INSTALLED_Found" = "N" ]; then
   NameVar=OFA_INSTALLED
   ValueVar=N
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="##  Is Oracle Financial Analyzer Server installed on this machine(Y/N)?\n##  If not, don't prompt for the Super DBA directory, the name of the shared\n##  database\n##"
   Prompt="Is Oracle Financial Analyzer Server installed on this machine (Y/N)?"
   if [ "$Check_Express" = "Y" ]; then
      if [ "$ValueVar" = "N" ]; then
         Check_OFA=N
         NO_PROMPT=Y
      else
         Check_OFA=Y
      fi
   else
      Check_OFA=N
      NO_PROMPT=Y
   fi
   Append_Setup
fi
if [ "$OFA_DBA_HOME_Found" = "N" ]; then
   NameVar=OFA_DBA_HOME
   ValueVar=${OES_ORACLE_HOME}/super
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="##  Super DBA directory\n##"
   Prompt="Enter the directory where the Super DBA is installed"
   if [ "$Check_OFA" = "Y" ]; then
      echo
   else
      NO_PROMPT=Y
   fi
   Append_Setup
fi
if [ "$OFAS_NAME_Found" = "N" ]; then
   NameVar=OFAS_NAME
   ValueVar=ofas.db
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="##  Name of the OFA Super shared database\n##"
   Prompt="Enter the shared database name"
   if [ "$Check_OFA" = "Y" ]; then
      echo
   else
      NO_PROMPT=Y
   fi
   Append_Setup
fi
if [ "$DPE_INSTALLED_Found" = "N" ]; then
   NameVar=DPE_INSTALLED
   ValueVar=N
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="##  Is Demand Planning Engine installed on this machine(Y/N)?\n##  If not, don't prompt for the other DPE questions\n##"
   Prompt="Is Demand Planning Engine installed on this machine ? (Y/N)"
   if [ "$Check_Express" = "Y" ]; then
      if [ "$ValueVar" = "N" ]; then
         Check_DPE=N
         NO_PROMPT=Y
      else
         Check_DPE=Y
      fi
   else
      Check_DPE=N
      NO_PROMPT=Y
   fi
   Append_Setup
fi
if [ "$DPE_DP_NAME_Found" = "N" ]; then
   NameVar=DPE_DP_NAME
   ValueVar=Demand_Plan_Sample
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="##  Enter the Demand Plan Name\n##"
   Prompt="Enter the Demand Plan Name. Please enclose the name with ' if you have spaces in the DP Name"
   if [ "$Check_DPE" = "Y" ]; then
      echo
   else
      NO_PROMPT=Y
   fi
   Append_Setup
fi
if [ "$DPE_DPS_SQL_PASSWORD_PROMPT_Found" = "N" ]; then
   NameVar="DPE_DPS_SQL_PASSWORD_PROMPT"
   ValueVar=Y
   eval `$ECHO "$NameVar=$ValueVar"`
   if [ "$Check_DPE" = "Y" ]; then
      $ECHO
      $ECHO "You have the option of specifying a password for APPS \"system\" user now"
      $ECHO "which means it will be stored in the setup.txt file in an un-encrypted"
      $ECHO "format, or being prompted for it during rda.sh runtime.  If you wish to be"
      $ECHO "prompted, the value for the password will not be stored anywhere, it will"
      $ECHO "just be available to the rda.sh process during its runtime."
      $ECHO
   fi
   Description="##  This parameter will allow users to be prompted for the DPS database connection\n##  password at runtime rather than storing it in a text file.\n##"
   Prompt="Do you wish to be prompted for the pwd of your sqlplus user at rda runtime (Y/N)?"
   if [ "$Check_DPE" = "Y" ]; then
      true
   else
      NO_PROMPT=Y
   fi
   Append_Setup
   if [ "$ValueVar" = "N" ]; then
      DPE_Prompt_Password=N
   else
      DPE_Prompt_Password=Y
   fi
fi
if [ "$DPE_DPS_Password_Found" = "N" ]; then
   NameVar="DPE_DPS_Password"
   ValueVar=junk
   eval `$ECHO "$NameVar=$ValueVar"`
   Prompt="Enter the password for the APPS \"system\" user now"
   Prompt="Enter the password for the APPS \"system\" user now"
   if [ "$Check_DPE" = "N" -o "$DPE_Prompt_Password" = "Y" ]; then
      NO_PROMPT=Y
   fi
   Append_Setup_Hidden
fi
if [ "$DPE_DPS_SID_Found" = "N" ]; then
   NameVar=DPE_DPS_SID
   ValueVar=oracle9i
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="##  Enter the connect string to the Demand Planning Server (scott/tiger@oracle9i)\n##"
   Prompt="Enter the SID for the Demand Planning Server"
   if [ "$Check_DPE" = "Y" ]; then
      echo
   else
      NO_PROMPT=Y
   fi
   Append_Setup
fi
if [ "$DPE_DBC_FILE_Found" = "N" ]; then
   NameVar=DPE_DBC_FILE
   ValueVar=/ora806/fnd_top/secure/sample.dbc
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="##  Enter the location and name of the DBC file in the local machine\n##"
   Prompt="Enter the location and name of the DBC file in the local machine"
   if [ "$Check_DPE" = "Y" ]; then
      echo
   else
      NO_PROMPT=Y
   fi
   Append_Setup
fi
if [ "$DPE_SSO_LOCATION_Found" = "N" ]; then
   NameVar=DPE_SSO_LOCATION
   ValueVar=/ora806/olap/sso640
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="##  Enter the location of the Oracle OLAP Single Sign-On\n##"
   Prompt="Enter the location of the Oracle OLAP Single Sign-On"
   if [ "$Check_DPE" = "Y" ]; then
      echo
   else
      NO_PROMPT=Y
   fi
   Append_Setup
fi

$ECHO "##############################################################################
##  End of OLAP Variables
##############################################################################" >> setup.txt

}


#############
##  Main   ##
#############

Setup_OLAP_Env   # Setup Default Values, if not present, build setup.txt file.

Get_OLAP_Input   # Get user input on the Values - allow changes, rewrite setup.txt

if [ "$Check_Express" = "Y" ]; then
   $ECHO $m >> mods_to_run.txt
fi

if [ "$DebugMode" = "n" ]; then
   rm -f $TEMP_DIR/tmp.olap.$$ 2>/dev/null
fi

