Test=`env|grep RDA_Program_Version`

##  The previous line MUST be the first line in the script.  If not, the check
##  for determining if this is called or started straight from command line
##  will not work (it will throw errors back to the screen).

if [ -z "$Test" ]; then
   echo "This script cannot be run standalone"
   echo "It must be called from the main RDA rda.sh"
   echo "Exiting from rda.sh"
   exit
fi
###########################################################################
##    Name: rda.sh                                Version: 3.09
##      By: Oracle Corp.                    Last Modified: September 10, 2002
##                                                Written: 09/10/02  
##
## Purpose: This is the source script for handling the gathering of web cache
##          information (configuration files, log files, etc).
##          This is not intended to be a standalone script, it should be
##          sourced from an executable script.
##
##   Usage: Source from a script
##             . ./RDA_script_0080_RVW_WEBCACHE/rda.sh
##
###########################################################################

##############################################################################
##  Modifications Section:
##############################################################################
##     Date        Author     Function       Changes
##############################################################################
##  09/10/2002     fkobylan                  Created from IA/rda.sh
##    V3.09                                  Version matches rest of RDA.
#############################################################################

#############################################################################
##   Program Explanation:
##   ===================
##   The script is not intended to be a stand alone program.  Its function
##   is to handle the Web Cache information gathering and display 
##   for the RDA process.  It will execute commands determined by the SETUP_OS
##   function, formatting the output into files for display through a web
##   browser.
#############################################################################

##################################
### Start of Review_WebCache Function ###
##################################
Review_WebCache ()
{
## Procedure Name: Review_WebCache
################################################################
## This is a module to collect data related to the operation of
## the Oracle Web Cache and its configuration.
##
##   Note: This module could be used with many scripts.
#################################################################

echo "${BOLD}Processing: Web Cache Information ${OFF}"

WebCache_Log_Tail_Limit=5000
DebugMessage=" Inside Review_WebCache, about to gather files"
Debug

#  This will process all the web cache files that are requested.
#  The function will determine if the file should be processed.
#  The file format is:
#  Section (e.g. NETWORK, WAS, OAS, iAS, WEBCACHE etc)
#  Type (e.g. AGENT, SQLNET, OMS, OID - basically the menu level subsection)
#  Relative_to_oh (Y/N, is the directory structure relative to $ORACLE_HOME)
#  Directory (The sub-directory under $O_H or the direct path to the file)
#  File_wanted (the file name being looked for)
#  Display_name (the name that should appear in the left frame for the link)
#  Tail_it (Y/N, should the file be tailed, if N, cat the whole thing)
#  Tail_amount (if it should be tailed, how many lines)
#  Optional (Y/N is the file optional, if not and the file is not found, still
#            create a file with a missing blurb.)
#  Partial_File_Name (Y/N is the name name provided only a partial file name
#            to cause searching for all files like this name.)

# create the variables to hold the file name/link name combinations for later
# building of the left frame
WEBCACHE_LOG_FILE=""
WEBCACHE_CONFIG_FILE=""
WEBCACHE_DTD_FILE=""

echo "   Gathering Web Cache configuration and dtd files"
while read SECTION TYPE RELATIVE_TO_OH DIRECTORY FILE_WANTED DISPLAY_NAME TAIL_IT TAIL_AMOUNT OPTIONAL PARTIAL_FILE_NAME; do
   Cat_File
done < ./${DIR}/files.txt

#  Two of the log files could be relocated.  Because of this, we need to parse
#  a couple of xml files to get their actual location, then dump them.  Let's
#  use the functionality of Cat_File, so we need to build the variables for
#  the function to use.  This first set of variables will be common.  The
#  DIRECTORY, FILE_WANTED and DISPLAY_NAME will be different.

SECTION=WEBCACHE
TYPE=LOG
RELATIVE_TO_OH=N #  although this will usually be under $O_H, best bet is to
                 #  strip the directory out of the xml file.
TAIL_IT=Y
TAIL_AMOUNT=$WebCache_Log_Tail_Limit
OPTIONAL=N
PARTIAL_FILE_NAME=N

echo "   Gathering Web Cache log files"

#  Let's do the web cache access_log first.  This will be found in the 
#  $O_H/webcache/webcache.xml file.  Make sure file is readable first, if not
#  use default location for LOGDIR.

if [ -r "$ORACLE_HOME/webcache/webcache.xml" ]; then
   Access_Log_Dir=`grep 'ACCESSLOG.*LOGDIR' $ORACLE_HOME/webcache/webcache.xml | cut -f2 -d= | cut -f2 -d'"' | cut -f1 -d'"' | sed s!?!$ORACLE_HOME!`
fi

#  If the search of the xml file doesn't work, set the directory to default.
if [ -z "$Access_Log_Dir" ]; then
   DIRECTORY=$ORACLE_HOME/webcache/logs
else
   DIRECTORY=$Access_Log_Dir
fi
DISPLAY_NAME=access_log.htm
FILE_WANTED=access_log
Cat_File

#  Now let's do the web cache event_log first.  This will be found in the 
#  $O_H/webcache/internal.xml file.  This is a little different since the file
#  name is also included.

if [ -r "$ORACLE_HOME/webcache/internal.xml" ]; then
   Event_Log_Full=`grep 'MISCELLANEOUS.*ERRORLOGFILE' $ORACLE_HOME/webcache/internal.xml | cut -f2 -d= | cut -f2 -d'"' | cut -f1 -d'"' | sed s!?!$ORACLE_HOME!`
fi

#  If the search of the xml file doesn't work, set the directory to default.
if [ -z "$Event_Log_Full" ]; then
   DIRECTORY=$ORACLE_HOME/webcache/logs
   FILE_WANTED=event_log
else
   DIRECTORY=`dirname $Event_Log_Full`
   FILE_WANTED=`basename $Event_Log_Full`
fi
DISPLAY_NAME=event_log.htm
Cat_File

DebugMessage=" Inside Review_WebCache, got files
  WEBCACHE_LOG_FILE is $WEBCACHE_LOG_FILE
  WEBCACHE_CONFIG_FILE is $WEBCACHE_CONFIG_FILE
  WEBCACHE_DTD_FILE is $WEBCACHE_DTD_FILE"
Debug

}

Rvw_WebCache_Build_Links ()
{
(
cat << EOF
<li>
Web Cache
<table bgcolor="lightblue" width="100%">
<tr><td><ul><li>
Web Cache Config Files
<ul>
EOF

for a in $WEBCACHE_CONFIG_FILE; do
   FILE_NAME=`echo $a|cut -f1 -d#`
   DISPLAY_NAME=`echo $a|cut -f2 -d#`
   echo "<li><a href=\"$FILE_NAME\" target=\"right_frame\">$DISPLAY_NAME</a></li>"
done

cat << EOF
</ul><li>
Web Cache DTD Files
<ul>
EOF

for a in $WEBCACHE_DTD_FILE; do
   FILE_NAME=`echo $a|cut -f1 -d#`
   DISPLAY_NAME=`echo $a|cut -f2 -d#`
   echo "<li><a href=\"$FILE_NAME\" target=\"right_frame\">$DISPLAY_NAME</a></li>"
done

cat << EOF
</ul><li>
Web Cache Log Files
<ul>
EOF

for a in $WEBCACHE_LOG_FILE; do
   FILE_NAME=`echo $a|cut -f1 -d#`
   DISPLAY_NAME=`echo $a|cut -f2 -d#`
   echo "<li><a href=\"$FILE_NAME\" target=\"right_frame\">$DISPLAY_NAME</a></li>"
done

cat << EOF
</li></ul>
</ul></li></tr></td></table>
EOF
) > $OUT_TMP/rvw_webcache_left_frame.$$
echo "$OUT_TMP/rvw_webcache_left_frame.$$" >> $OUT_TMP/output_frames.txt.$$
}

#########################################
#  Exeucute the functions defined here  #
#########################################
Review_WebCache
Rvw_WebCache_Build_Links
