Test=`env|grep Setup_Program_Version`

##  The previous line MUST be the first line in the script.  If not, the check
##  for determining if this is called or started straight from command line
##  will not work (it will throw errors back to the screen).

##############################################################################
###    Name: setup.sh                              Version: 3.09
###      By: Oracle Corp.                    Last Modified: September 10, 2001
###                                                Written: 09/10/2002
### 
### Purpose: Script used to setup the internal variables used for gathering
###          Web Cache information as part of the rda process.  It will
###          just be sourced as part of the main setup.sh script.
###
##############################################################################
##  Modifications Section:
##############################################################################
##     Date        Author     Function       Changes
##############################################################################
##  07/19/2002     fkobylan                  Created.  Taken from original 
##                                           modularized RDA IA/setup.sh
##############################################################################
###   Program Explanation:
###   ===================
###   This program handles prompting for Web Cache parameters during
###   the run of rda.sh.  It can not be run as a standalone script, it will be
###   called (sourced) by the main setup.sh.
### ###########################################################################
# leave this echo as is.  Since we haven't run the main setup.sh to get here
# $ECHO isn't set and there is no special formatting we have to worry about
# anyway.
if [ -z "$Test" ]; then
   echo "This script cannot be run standalone"
   echo "It must be called from the main RDA setup.sh"
   echo "Exiting from setup.sh"
   exit
fi

Setup_WebCache_Env ()
{
## Procedure: Setup_WebCache_Env ()
## Called to setup all the env variables ...
#############################################################################
## Variables Used to Process this script:
#############################################################################
Variables_Found=N


if [ "$SETUP_TXT_Found" = "Y" ];then
   Variables_Found=Y
#  The setup.txt should have already been found by the main setup script
#  we just need to know whether to build from scratch or not.

##  Get only the variables that apply to IA.
   Start_Line=`grep -n 'Beginning of Web Cache Variables' $TEMP_DIR/tmp.$$ | cut -f1 -d:`
   End_Line=`grep -n 'End of Web Cache Variables' $TEMP_DIR/tmp.$$ | cut -f1 -d:`
#  Handle it when the user cancels out of a previous run of setup.  If
#  Start_Line is null, it means they never got to this section at all.  If
#  End_Line is null, then they cancelled in this section.
   if [ -z "$Start_Line" ]; then
      Variables_Found=N
   elif [ -z "$End_Line" ]; then
      Tail_Lines=200
   else
      Tail_Lines=`expr $End_Line - $Start_Line`
   fi
fi

if [ "$Variables_Found" = "Y" ]; then
   tail +$Start_Line $TEMP_DIR/tmp.$$ | head -$Tail_Lines | grep -v '^##' > $TEMP_DIR/tmp.webcache.$$

# This section of the else should only run when no setup.txt file is present
# Once one is there it is used to pull up the users current settings

else

$ECHO "WEBCACHE_IN_USE=N" > $TEMP_DIR/tmp.webcache.$$
  

fi

}

Get_WebCache_Input ()
{
## Procedure: Get_WebCache_Input ()
## Called to setup all the env variables ...
#############################################################################
## Variables Used to Process this script:
#############################################################################
$ECHO "$BOLD Gathering parameters for the Web Cache Section $OFF"

NO_PROMPT=N
WEBCACHE_IN_USE_Found=N

$ECHO "##########################################################################
##  Beginning of Web Cache Variables
##########################################################################" >> setup.txt

Args=`cat $TEMP_DIR/tmp.webcache.$$`
for CurArg in `$ECHO "$Args"`
do 
   Get_Arguments                     

   case "$NameVar" in

      WEBCACHE_IN_USE)
         WEBCACHE_IN_USE_Found=Y
         $ECHO
         Description="##  Questions to find out if Web Cache is installed or in use.\n##"
         Prompt="Is the Oracle Web Cache in use on this node (Y/N)?"
         Append_Setup
      if [ "$ValueVar" = "N" ]; then
         Check_WebCache=N
      else
         Check_WebCache=Y
      fi
      ;;
      *)  junk=NoOpHere
      ;;
   esac

done
if [ "$WEBCACHE_IN_USE_Found" = "N" ]; then
   $ECHO
   NameVar="WEBCACHE_IN_USE"
   ValueVar=N
   eval  `$ECHO "$NameVar=$ValueVar"`
   Description="##  Questions to find out if Web Cache is installed or in use.\n##"
   Prompt="Is the Oracle Web Cache in use on this node (Y/N)?"
   Append_Setup
   if [ "$ValueVar" = "N" ]; then
      Check_WebCache=N
   else
      Check_WebCache=Y
   fi
fi

$ECHO "##########################################################################
##  End of Web Cache Variables
##########################################################################" >> setup.txt

}


#############
##  Main   ##
#############

Setup_WebCache_Env  # Setup Default Values, if not present, build setup.txt file.

Get_WebCache_Input  # Get user input on the Values - allow changes, rewrite setup.txt

# Setup to run data collector for IA if requested

if [ "$Check_WebCache" = "Y" ]; then
   $ECHO $m >> mods_to_run.txt
fi

if [ "$DebugMode" = "n" ]; then
   rm -f $TEMP_DIR/tmp.webcache.$$ 2>/dev/null
fi
