#!/bin/ksh
###########################################################################
RDA_Program_Version=3.10; export RDA_Program_Version
Last_Modified="November 05, 2002"; export Last_Modified
###########################################################################

###########################################################################
##    Name: rda.sh                                Version: 3.10
##      By: Oracle Corp.                    Last Modified: November 01, 2002
##                                                Written: 7/10/00  
##
## Purpose: Script to do System Checkup for Support to Debug Problems.
##          The tool is used to capture Key Oracle setups, files and
##          known configuration issues such as related to versions.
##
##   Usage: rda.sh 
##           or   
##          rda.sh [ h | help | debug ]
##
###########################################################################

##############################################################################
##  Modifications Section:
##############################################################################
##     Date        Author     Function       Changes
##############################################################################
##  11/01/2002     fkobylan   Report_Header  Added full machine name to output.
##  V3.10                     Thanks_For_Visit
##                                           Chgd to use domain name gotten
##                                           from setup.sh.
##                            Process_Parms  New module to read parameter xml
##                                           file.  This will allow easy 
##                                           setting of certain run time
##                                           parameters.
##  10/07/2002     fkobylan   Report_Header  Chgd some of the data displays,
##  V3.09                                    adding platform and OS_Version.
##                                           This also adds O/S bits to the 
##                                           report.  Added infor for Webcache.
##                            Process_Versions
##                                           Deleted.  This is in RDBMS.
##  08/30/2002     fkobylan   Report_Header  Cleaned up some of the HTML tagging
##  V3.08                                    causing problems in some browsers.
##                                           Also added info about settings for
##                                           OLAP.
##                            Apps_Tables    Removed, this is in RVW_RDBMS/rda.sh.
##                            Package_Files  Chgd to check for existence of
##                                           compress, if not found, use gzip
##                                           instead.  (issue 164).  
##                            Thanks_For_Visit
##                                           Chgd file name to show correct
##                                           file extension.  (issue 164).  
##                            various        Added some code to handle commands
##                                           not available in PTX.
##  06/25/2002     fkobylan                  Removed some old comments.
##  V3.07                                    Also added code to ensure correct
##                                           echo command is used to handle
##                                           new line characters.
##  06/18/2002     fkobylan                  No chgs here, new version due to
##  V3.06                                    updates to Common and Setup_OS.
##  05/28/2002     fkobylan                  No chgs here, new version due to
##  V3.05                                    updates to Common and Setup_OS.
##  05/20/2002     fkobylan                  No chgs, just keeping version
##  V3.04                                    numbers in sync.
##  04/02/2002     fkobylan   Package_Files  Chgd to add process id to filename 
##  V3.02                                    of tar file to keep separate.
##                                           Added display to ftp in binary.
##                            Main           Added displays for start/end time.
##  02/18/2002     fkobylan   Throughout     Chgd to modularize.  Moved sections
##  V3.00                                    to their own scripts to allow
##                                           concurrent development to occur.
##                                           Also changed to more dynamically
##                                           pick up new modules that may be 
##                                           added.
#############################################################################

#############################################################################
##   Program Explanation:
##   ===================
##   The program was written in a fairly modular way to allow for 
##   the reuse of any of the procedures. ie. Full_Help () is an example
##   of one of the procedures. All of the control and flow of the program
##   is processed starting at the MAIN MAIN Section.....
##   Search for MAIN to find the starting point for program execution.
#############################################################################

##################################
#### Start of All Procedures  ####
##################################

Setup_Env ()
{
## Procedure: Setup_Env ()
## Called to setup all the env variables ...

#  set all the language related variables to the lowest common denominator
#  so we get the expected output from all the tools we will call later.
LANG_BEFORE_RDA=$LANG 
NLS_LANG_BEFORE_RDA=$NLS_LANG 
unset LANG
NLS_LANG=AMERICAN_AMERICA.US7ASCII
export NLS_LANG LANG_BEFORE_RDA NLS_LANG_BEFORE_RDA 
#############################################################################
## Variables Used to Process this script:
#############################################################################
BELL=`tput bel`
BOLD=`tput smso`
BLINK=`tput blink`
OFF=`tput rmso`
GO_HOME=`tput home`
REV=`tput rev`
#  Running into some problems with echo not dealing with escape characters
#  well.  Need to determine if echo -e is available and use it instead.
Echo_Test=`echo -e`
if [ "$Echo_Test" = "-e" ]; then
#  echo actually returned the -e, so -e is not a valid switch, use straight echo
   ECHO="echo"
else
   ECHO="echo -e"
fi

#  This has to be done here since clear is used w/o running SETUP_OS.
OS_NAME=`uname`
case "$OS_NAME" in
   DYNIX/ptx)
      Clear_Available=Y
   ;;
   *)
      Clear_Available=Y
   ;;
esac

# Don't change. This *must* be a tab character. 
TAB='	' 
if [ "`echo \"$TAB\" | sed -e 's/ //g'`" = "" ]; then 
       echo "Panic: RDA script has been corrupted, probably by copying & passing it as text!" 
       exit 10; 
fi 
# Don't change. This *must* be a newline character 
NL='
'
# This character is used to convert path names to (hopefully) unique plain 
# file names. Use a character that is not common in Unix filenames for this. 
PATH_REPLACE_CHAR='~' 
# Include how many log lines from the log files? 
LOGLINES=1000 
 
echo "${BOLD}RDA Starting Version $RDA_Program_Version, please wait..${OFF}"

#  Setup a couple of quick environment variables for information needed prior
#  to reading the setup.sh response file.  Just to get a couple of quick 
#  defaults.  These should be replaced by values found in setup.txt.

  PRD=RDA; export PRD
  OUT_DIR=`pwd`; export OUT_DIR
  OUT_TMP=/tmp; export OUT_TMP
#
# Unix_id - Who ran the script - is set to the current users
#
   whoami > /dev/null 2>/dev/null
   if [ $? -eq 0 ]; then
      Unix_id=`whoami`
   else
      Unix_id=`who am i | awk '{print $1}'`
   fi
  DebugMode=n

}

Get_Arguments ()
{
## Procedure: Get_Arguments ()
## Parses the command line and sets the name=value pairs as unix varialbes.
#############################################################################
## Variables Used to Process this script:
#############################################################################
 
##
##  Procedure Get_Arguments also checks for help Display Full Help if Needed...
##
if [ $ArgCount -gt 1 ]; then
   echo "${BOLD}Only 1 argument allowed to be passed to rda.sh${OFF}"
   echo "Press enter to see help or ctl-c to exit"
   read junk
   Full_Help
   exit
fi
if [ "$Args" = "help" -o "$Args" = "h" ];  then
  Full_Help
  exit
elif [ "$Args" = "debug" ]; then
   DebugMode=y
   echo "${BOLD}rda.sh will be run in Debug Mode${OFF}"
   echo "Press enter to continue or ctl-c to exit"
   read junk
else
   if [ $ArgCount = 1 ]; then
      echo "${BOLD}Argument $Args not recognized${OFF}"
      echo "Review the arguments documented in the help information"
      echo "Press enter to see help or ctl-c to exit"
      read junk
      Full_Help
      exit
   fi
fi
 
##
## Parse setup.txt file option pairs and assign
##  Name1=Value1
##  Name2=Value2
##

if [ -r setup.txt ];then

	while read CurArg
	 do 
		  NameVar=`echo "$CurArg" | awk -F"=" '{print $1}'`
		  ValueVar=`echo "$CurArg" | awk -F"=" '{print $2}'`
		  eval  `echo "export $NameVar='$ValueVar'"` >/dev/null
		  DebugMessage="GetArguments from setup.txt: $NameVar=$ValueVar"
		  Debug
	done < setup.txt
else
   echo 
   echo "setup.sh apparantly not run"
   echo "the script will not process without the output from setup.sh"
   echo "Exiting rda.sh"
   exit
fi

##
## Parse command line option pairs and assign
## Currently Not Exporting the variables..
## program db=FND_CON  allows for if $db not null do x
## 

for CurArg in `echo "$Args"`
  do
        #  echo "Current: $CurArg"
  NameVar=`echo "$CurArg" | awk -F"=" '{print $1}'`
  ValueVar=`echo "$CurArg" | awk -F"=" '{print $2}'`
  eval  `echo "$NameVar=$ValueVar"`
  DebugMessage="GetArguments Command Line: $NameVar=$ValueVar"
  Debug
done 

		  DebugMessage="DDEBUG: End of Get_Arguments"
		  Debug
}

Report_Header ()
{

##  This section will now just display pertinent run time information.  
##  Everything else can be found elsewhere in the output.

echo "<center><H2> COE Remote Diagnostic Agent(RDA): rda</H2></center>" > $OUT_DIR/$HeaderReport
echo "<H3>  Written by: Oracle Corp.                           Version: $RDA_Program_Version        </H3>" >> $OUT_DIR/$HeaderReport
echo "<PRE>" >> $OUT_DIR/$HeaderReport

echo "========= Report Created on:  `date` ==========" >> $OUT_DIR/$HeaderReport

echo  >> $OUT_DIR/$HeaderReport

echo "             Machine and Version:  `uname -a`" >> $OUT_DIR/$HeaderReport
echo "       Fully Qualified Host Name:  $MACHINE_NAME.$DOMAIN_NAME_print" >> $OUT_DIR/$HeaderReport
echo "                        Platform:  ${Bits}-bit $Platform" >> $OUT_DIR/$HeaderReport
echo "                     O/S Version:  $OS_Version" >> $OUT_DIR/$HeaderReport
echo "                    Logged in as:  $Unix_id" >> $OUT_DIR/$HeaderReport
echo "              Output File Prefix:  $PRD" >> $OUT_DIR/$HeaderReport
echo "           Output File Directory:  $OUT_DIR" >> $OUT_DIR/$HeaderReport
echo "             Temp File Directory:  $OUT_TMP" >> $OUT_DIR/$HeaderReport
echo "          Perform Network Pings?:  $NETWORK_PING_TESTS" >> $OUT_DIR/$HeaderReport
if [ "$NETWORK_PING_TESTS" = "Y" ]; then
   echo "              Local Machine Name:  $MACHINE_NAME" >> $OUT_DIR/$HeaderReport
   echo "          Wide Area Network Node:  $WAN_NODE" >> $OUT_DIR/$HeaderReport
   echo "                      RDBMS Node:  $RDBMS_NODE" >> $OUT_DIR/$HeaderReport
   echo "                 Web Server Node:  $WEB_NODE" >> $OUT_DIR/$HeaderReport
   echo "                  Client PC Node:  $CLIENT_NODE" >> $OUT_DIR/$HeaderReport
fi

echo  >> $OUT_DIR/$HeaderReport

echo "   Oracle Product: " >> $OUT_DIR/$HeaderReport
echo "                     ORACLE_HOME:  $ORACLE_HOME" >> $OUT_DIR/$HeaderReport
echo "    Gather Database Information?:  $DATABASE_INSTALLED" >> $OUT_DIR/$HeaderReport
if [ "$DATABASE_INSTALLED" = "Y" ]; then
   echo "                      ORACLE_SID:  ${TWO_TASK:=$ORACLE_SID}" >> $OUT_DIR/$HeaderReport
   echo "             Is the PFILE Local?:  $PFILE_LOCAL" >> $OUT_DIR/$HeaderReport
   if [ "$PFILE_LOCAL" = "Y" ]; then
      echo "                 PFILE LOCATION?:  $PFILE_LOCATION" >> $OUT_DIR/$HeaderReport
   fi
fi
echo "         Are Web Apps Installed?:  $WEB_APPS_INSTALLED" >> $OUT_DIR/$HeaderReport
if [ "$WEB_APPS_INSTALLED" = "Y" ]; then
   echo "                      APACHE_TOP:  $APACHE_TOP" >> $OUT_DIR/$HeaderReport
   echo "                        WEB_BASE:  $WEB_BASE" >> $OUT_DIR/$HeaderReport
   echo "                         WEB_DCD:  $WEB_DCD" >> $OUT_DIR/$HeaderReport
fi
echo "    Is Intelligent Agent in Use?:  $INTELLIGENT_AGENT_IN_USE" >> $OUT_DIR/$HeaderReport
echo "  Is Oracle EMAIL Server in Use?:  $EMAIL_SERVER_IN_USE" >> $OUT_DIR/$HeaderReport
echo "                  Is OID In Use?:  $INTERNET_DIRECTORY_IN_USE" >> $OUT_DIR/$HeaderReport
echo "      Is OEM Mgmt Server In Use?:  $MGMT_SERVER_IN_USE" >> $OUT_DIR/$HeaderReport
echo "       Is Express Server In Use?:  $EXPRESS_INSTALLED" >> $OUT_DIR/$HeaderReport
#  Only show the following if Express is installed.  If it's not, these are
#  never prompted for.
if [ "$EXPRESS_INSTALLED" = "Y" ]; then
   echo "      Express Server Oracle Home:  $OES_ORACLE_HOME" >> $OUT_DIR/$HeaderReport
   echo "         Express DBA Role UserID:  $OES_DBA_USER" >> $OUT_DIR/$HeaderReport
   echo "      Express Server Port Number:  $OES_PORT_NO" >> $OUT_DIR/$HeaderReport
   echo "    Is Express Web Agent In Use?:  $OWA_INSTALLED" >> $OUT_DIR/$HeaderReport
   if [ "$OWA_INSTALLED" = "Y" ]; then
      echo "    Web Agent Install Directory:  $OWA_LOCATION" >> $OUT_DIR/$HeaderReport
      echo "       Web Agent CGI Exectuable:  $CGI_EXEC" >> $OUT_DIR/$HeaderReport
      echo "         Web Agent CGI Location:  $CGI_LOCATION" >> $OUT_DIR/$HeaderReport
   fi
FA
   echo "   Is Financial Analyzer In Use?:  $OFA_INSTALLED" >> $OUT_DIR/$HeaderReport
   if [ "$OFA_INSTALLED" = "Y" ]; then
      echo "    Super DBA Install Directory:  $OFA_DBA_HOME" >> $OUT_DIR/$HeaderReport
      echo "           Shared Database Name:  $OFAS_NAME" >> $OUT_DIR/$HeaderReport
   fi
   echo "Is Demand Planning Engine In Use?:  $DPE_INSTALLED" >> $OUT_DIR/$HeaderReport
   if [ "$DPE_INSTALLED" = "Y" ]; then
      echo "               Demand Plan Name:  $DPE_DP_NAME" >> $OUT_DIR/$HeaderReport
      echo "     Demand Planning Server SID:  $DPE_DPS_SID" >> $OUT_DIR/$HeaderReport
      echo "  Demand Planning DBC File Name:  $DPE_DPC_FILE" >> $OUT_DIR/$HeaderReport
      echo "        Single Sign-On Location:  $DPE_SSO_LOCATION" >> $OUT_DIR/$HeaderReport
   fi
fi
echo "      Is Oracle WebCache In Use?:  $WEBCACHE_IN_USE" >> $OUT_DIR/$HeaderReport
echo  >> $OUT_DIR/$HeaderReport
echo  >> $OUT_DIR/$HeaderReport
echo "<B>This section now only contains basic runtime information." >> $OUT_DIR/$HeaderReport
echo "All data gathered can be found using the links in the left frame.</B>" >> $OUT_DIR/$HeaderReport
echo "</PRE>" >> $OUT_DIR/$HeaderReport
}

Create_JS_HTML ()
{
## Procedure Name: Create_JS_HTML ()
################################################################
## Creates all the required html files for the viewing front end
## The left_fram.html is the one with the javascripts for the
## menu system.
##
##

(
cat << EOF
<?xml version="1.0"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "DTD/xhtml1-transitional.dtd">
<html>
<head>
<title>Oracle RDA Output</title>
</head>
<body bgcolor="#ffffff">
<font face="veredana" size="+1" color="red">
<b>Oracle RDA</b>
</font>
EOF

while read FRAME_FILE
do
   cat $FRAME_FILE
done < $OUT_TMP/output_frames.txt.$$

#  if not in debug mode, get rid of the tmp files for building the left frame,
#  otherwise, copy them to $OUT_DIR for packaging with the rest of the files.
if [ "$DebugMode" = "n" ]; then
   while read FRAME_FILE
   do
      rm $FRAME_FILE
   done < $OUT_TMP/output_frames.txt.$$
   rm $OUT_TMP/output_frames.txt.$$
else
   while read FRAME_FILE
   do
      cp $FRAME_FILE $OUT_DIR 2>/dev/null
   done < $OUT_TMP/output_frames.txt.$$
   cp $OUT_TMP/output_frames.txt.$$ $OUT_DIR 2>/dev/null
fi

cat << EOF
</ul>
</body>
</html>
EOF
) > $OUT_DIR/${PRD}_left_frame.htm

echo "
<HTML>
<HEAD>
<TITLE>RDA Analysis Tool / COE</TITLE>
</HEAD>
<FRAMESET COLS=\"255,*\" border=\"0\">
<FRAME SRC=\"${PRD}_left_frame.htm\" NAME=\"left_frame\" frameborder=\"0\">
<FRAME SRC=\"${PRD}_right_frame.htm\" NAME=\"right_frame\" frameborder=\"0\">
</FRAMESET>
</HTML>
" > $OUT_DIR/${PRD}__START.htm

		  DebugMessage="DDEBUG: Create_JS_HTML"
		  Debug
}



SET_SQL ()
{
## Procedure Name: SET_SQL
################################################################
## Sets the SQL variable for Workflow SQLs based on name 
##
## Internal Procedure Usage:
##  1. Set Variable    : usesql=error, url,... 
##  2. Set 2nd Variable: name=(Depends on what usesql is set to:see below)
##  3. Call the procedure: SET_SQL 
##

if  [ "$usesql" = "run_http" ]; then
 
	SQL="select utl_http.request('$name') from dual"

elif  [ "$apps" = "invalid" ]; then

SQL="column objname format a38 heading \"OBJECT_NAME\"
column created heading \"CREATED\"
SELECT
  o.owner||'.'||o.object_name objname,
FROM sys.dba_objects o
WHERE o.owner LIKE '$owner%'
ORDER BY o.owner,o.object_name"

else
 echo "Should not be here"
fi

export SQL
 
}

Full_Help ()
{
## Procedure Name: Full_Help
################################################################
## Provides on-line help with the right options. ? help as 
## parameters passed.
## Note: Exits program after being called.
################################################################
##

if [ "$Clear_Available" = "Y" ]; then
   clear
fi
echo "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
                Check RDA Support Tool - rda.sh
#############################################################################
##    Name: rda.sh                          Version: $RDA_Program_Version 
##      By: Oracle Corp.                    Last Modified: $Last_Modified
##                                                Written: 6/22/99  
#############################################################################
##
##   Usage: rda.sh 
##
##          rda.sh [ h | help | debug ]
#############################################################################

Purpose: To Aid in analysis and support of local and remote 
         databases and file systems in relationship to 
         Oracle Products. This program was written to help
         automate the task of data collection for Support, Development
         and customers to more quickly analyze the technology stacks.
 
Example: Customer may have some problems with SQL*NET and we need
         to look at the configuration files related to that. This
         could include Database and File System information.  Content
         will continuously be added to gather information for more products.

- For more information on this program, get the latest version,
  and find examples of its use read MetaLink Document ID: 139597.1

   -or-

    email: st-automation_ww@oracle.com

Runtime options:
help or ? - Display this content

debug - Generate debugging information of the rda.sh execution for Oracle
        Support Services.  This option should be used if encountering problems
        when running rda.sh.  Debug and log files will be created in the local
        directory AND the output directory specified when running setup.sh.  
        All files should then be sent via email to st-automation_ww@oracle.com.
        Please describe the issue encountered in the body of the email.

 " | more
exit 
}
 

Debug ()
{
  if [ "$DebugMode" = "y" ]; then
     echo "------------------Debug RUN: `date`" >> $OUT_DIR/${PRD}_Debug.log
     echo ") $DebugMessage"  | tee -a $OUT_DIR/${PRD}_Debug.txt
  fi
}

Package_Files ()
{
## Procedure Name: Package_Files
################################################################
## Used to package up the files for emailing.
## Currently tars and compresses the OUT_DIR
##
################################################################

echo "${BOLD}Processing: Package_Files ...${OFF}"

cd $OUT_DIR

#  No longer need to remove the Old Tar files first since we'll have a new name
#  everytime.
#if [ -r $OUT_DIR/${PRD}.rda.tar.Z ];then
#   rm $OUT_DIR/${PRD}.rda.tar*
#fi

tar -cf $OUT_DIR/${PRD}.$$.rda.tar ${PRD}* 
#  Determine if compress is installed.  If it's not here, we're gonna use gzip
#  instead.

#  Some platforms treat a "not found" as an error, some as a valid execution
#  of "which".  Need to make sure nothing displays back to the user so send
#  stderr to bit bucket.  Because of the inconsistency, we also can't just
#  check return code since some OS's will return a 0 for a "not found", others
#  will return a 1.

if [ "$Which_Available" = "Y" ]; then
   Compress_Test=`which compress 2>/dev/null`
else
   Compress_Test="/usr/bin/compress"
fi

case "$Compress_Test" in
#  If it's found, the result should be something like:
#  /<dir>/<subdir>/compress
#  Since each platform treats this differently, this was the only common way
#  to determine existence.
   */compress)
      File_Ext=Z
      compress $OUT_DIR/${PRD}.$$.rda.tar
   ;;
   *)
      File_Ext=gz
      gzip -q $OUT_DIR/${PRD}.$$.rda.tar
   ;;
esac


}




Thanks_For_Visit ()
{
echo 
echo "${BOLD}You can view your report by:${OFF}"
echo "Copying $OUT_DIR to a web shared directory and go to:"
echo "   http://machine:port/web_shared_directory/${PRD}__START.htm"
echo ""
echo "or"
echo ""
echo "${BOLD}Try your Browser Directly:${OFF}"
MACHINE_NAME=$MACHINE_NAME.$DOMAIN_NAME_print
echo "   ftp://${Unix_id}@${MACHINE_NAME}${OUT_DIR}/${PRD}__START.htm"
echo
echo
echo
echo "${BOLD}If this file was generated to assist in resolving a TAR${OFF}"
echo "   please send ${BOLD}$OUT_DIR/${PRD}.$$.rda.tar.${File_Ext}${OFF}"
echo "   to Oracle Support by sending the file via Metalink."
echo "   If ftp'ing the file, please be sure to ftp in ${BOLD}BINARY${OFF} format."
echo
echo
echo
echo
}

#  This function will read the RDAParms.xml file, looking for KNOWN parameter
#  settings.  The format of the xml entries should be of "NAME=<known parm name>
#  VALUE=<parm value> DESC=<parm description>".  The description is more for
#  assisting users with setting a value and will not be used by the script.
#  Since shell really doesn't play too well with xml files, meaning there isn't
#  true parse functionality, the format must remain constant and the parameters
#  known so the lines can be parsed and parameter values handled/used.  If
#  the RDAParms.xml file is not found, no error should be raised, just use
#  default values for the parameters posted there.
Process_Parms ()
{
echo "${BOLD}Reading and processing RDAParms.xml file${OFF}"

#  Setup default values first
SQL_Run_Time_Limit=30

if [ -r RDAParms.xml ]; then
#  Let's get the SQL Timeout first, only if dealing with the database
   if [ "$DATABASE_INSTALLED" = "Y" ]; then
      SQL_Run_Time_Limit=`grep SQL_Run_Time_Limit RDAParms.xml | cut -f3 -d= | cut -f2 -d\"`
      if [ -z "$SQL_Run_Time_Limit" ]; then
         SQL_Run_Time_Limit=30
      else
#  Check to make sure the value is numeric"
         Junk=`expr $SQL_Run_Time_Limit + 0 2>/dev/null`
         if [ $? -eq 0 ]; then
            if [ $SQL_Run_Time_Limit -eq 0 ]; then
               echo "   $SQL_Run_Time_Limit is not valid for SQL_Run_Time_Limit"
               echo "   The default of 30 seconds will be used"
               SQL_Run_Time_Limit=30
            else
               echo "   SQL_Run_Time_Limit value will be $SQL_Run_Time_Limit seconds"
            fi
         else
            echo "   $SQL_Run_Time_Limit is not valid for SQL_Run_Time_Limit"
            echo "   The default of 30 seconds will be used"
            SQL_Run_Time_Limit=30
         fi
      fi
   fi
else
   echo "   RDAParms.xml file not found"
   echo "   The default values for parameters will be used"
fi
SQL_Hang_Times_To_Try=`expr $SQL_Run_Time_Limit / 5`
#  Check for a remainder, if one exists, bump up the number of times to check
Remainder=`expr $SQL_Run_Time_Limit % 5`
if [ $Remainder -ne 0 ]; then
   SQL_Hang_Times_To_Try=`expr $SQL_Hang_Times_To_Try + 1`
fi
}


##################################
#### BEGIN MAIN    BEGIN MAIN ####
##################################

################################################################
# Procedure Name: Main Module                                ###
# Controls which procedures get run based on the command     ###
# line options which are parsed by Process Options. If no    ###
# command line options are provided, it runs to the end and  ###
# completes with the Thanks_For_Visit Routine                ###
################################################################

#  Setup some traps to intercept bailing out of the script
echo "RDA Started `date`"
#  Handle ctl-c.  About the only issue right now is that, when prompting for
#  the password, we do an 'stty -echo' to hide the password being typed in.
#  If we don't turn echo back on, everything typed on screen after that, even
#  after the script ends, will be invisible.  Reset echo if the user presses
#  ctl-c.
trap 'stty echo;echo "Exiting from rda.sh due to ctl-c being pressed";exit' 2

##  This script needs to be sourced first so any common functions will be
##  available for ANY process, including functions found in the main script.
##  This script will just define common functions (e.g. Debug, Hang_Check,
##  Run_SQL, etc.) incorporating their code into the body of the script (like an
##  include) so that they can be called by any of the modules.
  . ./RDA_script_0000_COMMON/rda.sh  # sets up all the options like default directories 
Args="$*"
ArgCount="$#"

#  Needs to be called before Get_Arguments so command line can
#  overwrite if diff.

  Setup_Env          # sets up all the options like default directories  
  Get_Arguments      # Parse the command line ie. rda parm1=yes parm2=3
  Process_Parms      # read RDAParms.xml and parse out values

#  If mods_to_run.txt doesn't exist, don't run anything.  Throw an error message
#  and exit.  This needs to be here (after Get_Arguments) to allow running of
#  help.
if [ -r mods_to_run.txt ]; then
   true
else
   echo "${BOLD}mods_to_run.txt not found.  Rerun setup.sh to create it, then"
   echo "rerun rda.sh".
   echo "Exiting rda.sh${OFF}"
   exit
fi

#  Start processing hard coded scripts.  These will ALWAYS be executed.
  . ./RDA_script_0001_SETUP_OS/rda.sh  # sets up all the options like default directories 
  . ./RDA_script_0002_RVW_OS/rda.sh  # gather and display OS information
  . ./RDA_script_0003_RVW_PERF/rda.sh  # gather and display OS performance information
  . ./RDA_script_0004_RVW_NETWORK/rda.sh  # gather and display network performance and configuration information

#  Based on the mods_to_run.txt file, which will contain the directories
#  that need to have their modules processed, cycle thru them all.  The 
#  mods_to_run.txt should be created when running setup.sh.  If it doesn't exist
#  now, somebody deleted it, because we found it before.  Bail.

#  If the variable DIR is chgd to some other name, make sure to double check
#  in all the submodules.  There are some scripts using this value to search
#  for files and data specific to the module.
if [ -r mods_to_run.txt ]; then
   while read DIR;
   do
      if [ "$DIR" = "MODS_TO_RUN" ]; then
         true
      else
         . ./$DIR/rda.sh
      fi
   done < mods_to_run.txt
else
   echo "${BOLD}Something happened to mods_to_run.txt during the run of rda.sh"
   echo "Without the data contained in that file, rda.sh cannot continue."
   echo "Please run setup.sh again to recreate it, then rerun rda.sh."
   echo "If problems persist, contact Oracle Support Services."
   echo "Exiting rda.sh${OFF}"
   exit
fi
  Create_JS_HTML     # JavaScript Based Menu $PRD_index.htm 
                     # Moved to the end to be able to use results from others 
  Report_Header      # builds report header ie. machine, user, date etc...
                     # Moved to the end to be able to use results from others 
  Package_Files      # Package OUT_DIR files for email via tar, compress 
  Thanks_For_Visit
echo "RDA Completed `date`"
##################################
#### END MAIN        END MAIN ####
##################################
