#!/bin/sh
Setup_Program_Version=3.10; export Setup_Program_Version
Last_Modified="October 25, 2002"; export Last_Modified
### #########################################################################
###    Name: setup.sh                              Version: 3.10
###      By: Oracle Corp.                    Last Modified: September 05, 2002
###                                                Written: 7/10/00  
### 
### Purpose: Script used to setup the internal variables used in the
###          rda script. These variables could be edited manually
###          or use this script to change them.
###
###   Usage: setup.sh 
###           or   
###          setup.sh [ h | help | debug ]
### ##########################################################################
##############################################################################
##  Modifications Section:
##############################################################################
##     Date        Author     Function       Changes
##############################################################################
##  10/25/2002     fkobylan                  Added prompt for domain name. 
##    3.10                                   Also added code to determine a
##                                           default value.
##  09/05/2002     fkobylan                  Added comments to denote beginning
##    3.09                                   and end of Network variables.
##                                           Chgd to only pull back lines from
##                                           existing setup between beginning
##                                           and end lines found above.  
##  08/01/2002     fkobylan   Main           Chgd msg to determine if compress
##  V3.08                                    is installed, and if not, use gz
##                                           extension for filename instead of
##                                           .Z (issue 164).
##                            Various        Added code to deal with commands
##                                           not available on PTX.
##  06/25/2002     fkobylan                  Deleted old comments.
##  V3.07                     Append_Setup_Hidden
##                                           Dlt'd prompt for "default".
##  06/18/2002     fkobylan   Main           Chgd display at end to ask user to
##  V3.06                                    actually run rda.sh.
##  05/28/2002     fkobylan                  No chgs, just keeping version
##    3.05                                   number in sync.
##  05/20/2002     fkobylan                  No chgs, just keeping version
##    3.04                                   number in sync.
##                                           displayed in the closing message.
##  04/02/2002     fkobylan                  Chgd closing message to show that
##    3.02                                   process id will now be part of
##                                           the file name being created.
##  03/28/2002     fkobylan                  Chgd to get values for PRD and
##    3.01                                   OUT_DIR so they are correctly
##                                           Added new default for OUT_DIR.
##  02/20/2002     fkobylan                  Massive changes to deal with the
##   V3.00                                   modularization and split up of the
##                                           RDA process.  The only env variables
##                                           requested here will be for the 
##                                           creation of the output.  All other
##                                           vars will come from module setups.
##                                           Also cleaned up to deal with short
##                                           setup files if the process was 
##                                           aborted during a previous run.
##                                           Add check to see if the user wants
##                                           to use the previous settings (only
##                                           if setup.txt is found).
##############################################################################
###   Program Explanation:
###   ===================
###   This program checks for a setup.txt file and creates one if not present.
###   If it finds the setup.txt file you are then iterated thru the params
###   to change the ones you want. It can be run over and over again to vary
###   the setup.txt file.
### ###########################################################################
#  Setup some traps to intercept bailing out of the script

#  Handle ctl-c.  About the only issue right now is that, when prompting for
#  the password, we do an 'stty -echo' to hide the password being typed in.
#  If we don't turn echo back on, everything typed on screen after that, even
#  after the script ends, will be invisible.  Reset echo if the user presses
#  ctl-c.
trap 'stty echo;echo "Exiting from setup.sh due to ctl-c being pressed";exit' 2

BOLD=`tput smso`
OFF=`tput rmso`
INVIS=`tput invis`
TPUT_RESET=`tput sgr0`
TEMP_DIR=/tmp
DebugMode=n
TERM=vt220; export TERM
OS_NAME=`uname`

##  Make sure /usr/sbin, /usr/bin, /etc and /sbin are part of path.  If they aren't there, add them.
case "$PATH" in
   */usr/sbin*)
      PATH=`echo $PATH`
   ;;
   *:)
      PATH=${PATH}/usr/sbin:
   ;;
   "")
      PATH=/usr/sbin:
   ;;
   *)
      PATH=$PATH:/usr/sbin:
   ;;
esac
##  No need to check for non-existent path as, at a minimum, it has /usr/sbin from
##  the previous case statement.
case "$PATH" in
   */usr/bin*)
      PATH=`echo $PATH`
   ;;
   *:)
      PATH=${PATH}/usr/bin:
   ;;
   *)
      PATH=$PATH:/usr/bin:
   ;;
esac
 
case "$PATH" in
   */etc*)
      PATH=`echo $PATH`
   ;;
   *:)
      PATH=${PATH}/etc:
   ;;
   *)
      PATH=$PATH:/etc:
   ;;
esac
 
#  Need to do some special stuff for /sbin since /usr/sbin is also possible.  
# /sbin has to either be the first entry in the path or should be preceded by
# a colon (:)
case "$PATH" in
   /sbin*)
      PATH=`echo $PATH`
   ;;
   *:/sbin*)
      PATH=`echo $PATH`
   ;;
   *:)
      PATH=${PATH}/sbin:
   ;;
   *)
      PATH=$PATH:/sbin:
   ;;
esac

export PATH 
OS_NAME=`uname`
Machine_Name=`uname -n`

Domain_Name=`domainname 2>/dev/null`
if [ -z "$Domain_Name" ]; then
   Domain_Name=`nslookup $Machine_Name 2>/dev/null|grep Name: | cut -f2 -d: | cut -f2-10 -d.`
fi
if [ -z "$Domain_Name" ]; then
   Domain_Name=`grep "^domain " /etc/resolv.conf 2>/dev/null |sed -e "s/^domain *//g" -e "s/*$//g"` 
fi
if [ -z "$Domain_Name" ]; then
   Domain_Name=notfound.com
fi

#  Running into some problems with echo not dealing with escape characters
#  well.  Need to determine if echo -e is available and use it instead.
Echo_Test=`echo -e`
if [ "$Echo_Test" = "-e" ]; then
#  echo actually returned the -e, so -e is not a valid switch, use straight echo
   ECHO="echo"
else
   ECHO="echo -e"
fi

#  Setup some OS specific processing
case "$OS_NAME" in
   Linux)
      Which_Available=Y
      Clear_Available=Y
#  Check if running on Linux and if Korn shell is available.  If not, modify
#  rda.sh so it runs under Bourne Again shell instead.
      RDA_Shell=`head -1 rda.sh`
      if [ "$RDA_Shell" = "#!/bin/ksh" ]; then
         if [ -x /bin/ksh ]; then
            true
         else
            $ECHO "${BOLD}Korn Shell does not appear to be installed on this server"
            $ECHO "rda.sh is being modified to run under BASH instead${OFF}"
            sed s/ksh/bash/1 rda.sh > $TEMP_DIR/rda.sh.bash$$
            mv $TEMP_DIR/rda.sh.bash$$ ./rda.sh 2>/dev/null
            chmod 744 ./rda.sh 2>/dev/null
            $ECHO "rda.sh has been modified"
            $ECHO "Press enter to continue"
            read junk
         fi
      fi
   ;;
   DYNIX/ptx)
#  which and clear are not available on ptx, so need to do some special
#  processing whenever they are used.
      Which_Available=N
      Clear_Available=N
   ;;
   *)
      Which_Available=Y
      Clear_Available=Y
   ;;
esac 

Full_Help ()
{
## Procedure Name: Full_Help
################################################################
## Provides on-line help with the right options. h, help, debug as 
## parameters passed.
## Note: Exits program after being called.
################################################################
##

if [ "$Clear_Available" = "Y" ]; then
   clear
fi
$ECHO "~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
                Check RDA Support Setup Tool - setup.sh
#############################################################################
##    Name: setup.sh                          Version: $Setup_Program_Version 
##      By: Oracle Corp.                    Last Modified: $Last_Modified
##                                                Written: 6/22/99  
#############################################################################
##
##   Usage: setup.sh 
##
##          setup.sh [ h | help | debug ]
#############################################################################

Purpose: To Aid in analysis and support of local and remote 
         databases and file systems in relationship to 
         Oracle Products. This program and its companion (rda.sh)
         were created to automate the task of data collection for 
         Support, Development and customers to assist in diagnosing
         issues across technology stacks.  This program creates a 
         response file containing certain environment information
         for use by rda.sh.

Usage Notes:

         1.  There are two files created, setup.txt and mods_to_run.txt.
             setup.txt contains the responses given by the user during the
             interactive session.  mods_to_run.txt contains a list of 
             directories containing sub-modules for rda.sh to call.  Since
             the two files go hand in hand, it is probably easier to 
             re-run setup.sh and re-create the two files rather than 
             modifying them manually when problems occur or to run rda
             for another environment.

         2.  Responses can be made using environment variables (\$HOME,
             \$ORACLE_HOME, \$ORACLE_BASE, etc.).  The script will expand
             them out in setup.txt.

         3.  This script was created using the Bourne Shell (sh) which is
             available across all Unix platforms.  rda.sh, which requires
             more functionality, was coded using Korn Shell (ksh).  Linux does
             not natively provide Korn Shell, shipping with Bourne Again
             shell (bash) instead, although ksh can be installed.  Since
             there is no guarantee ksh will be available on Linux, setup.sh
             will check for the existence of ksh, and if it does not exist,
             will modify rda.sh to use bash instead.
 
- For more information on this program, get the latest version,
  and find examples of its use read MetaLink Document ID: 139597.1

   -or-

    email: st-automation_ww@oracle.com

Runtime options:
help or h - Display this content

debug - Generate debugging information of the setup.sh execution for Oracle
        Support Services.  This option should be used if encountering problems
        when running setup.sh.  A debug log file will be created in the local
        directory.  This file (along with setup.txt and mods_to_run.txt)
        should then be sent via email to st-automation_ww@oracle.com.
        Please describe the issue encountered in the body of the email.

 " | more
exit 
}
## If help is requested:
##
Args="$*"
ArgCount="$#"

if [ $ArgCount -gt 1 ]; then
   $ECHO "${BOLD}Only 1 argument allowed to be passed to setup.sh${OFF}"
   $ECHO "Press enter to see help or ctl-c to exit"
   read junk
   Full_Help
   exit
fi
if [ "$Args" = "help" -o "$Args" = "h" ];  then
  Full_Help
  exit
elif [ "$Args" = "debug" ]; then
   DebugMode=y
   $ECHO "${BOLD}setup.sh will be run in Debug Mode${OFF}"
   $ECHO "Press enter to continue or ctl-c to exit"
   read junk
else
   if [ $ArgCount = 1 ]; then
      $ECHO "${BOLD}Argument $Args not recognized${OFF}"
      $ECHO "Review the arguments documented in the help information"
      $ECHO "Press enter to see help or ctl-c to exit"
      read junk
      Full_Help
      exit
   fi
fi
 
Setup_Env ()
{
## Procedure: Setup_Env ()
## Called to setup all the env variables ...
#############################################################################
## Variables Used to Process this script:
#############################################################################

ORACLE_SET=${ORACLE_HOME:=/prod/path/of/oracle_home}
if [ -r setup.txt ];then
 
# Get the contents of the current settings in setup.txt
# This extracts all the current settings for setup.txt and puts them in 
# temp. file for processing to create the new setup.txt

   Variables_Found=Y
   $ECHO "Working with existing setup.txt file in: `pwd`"
   cp setup.txt $TEMP_DIR/tmp.$$
   chmod 600 $TEMP_DIR/tmp.$$
   SETUP_TXT_Found=Y
#  Grab only the variables for the main section.
   Start_Line=`grep -n 'Beginning of Main Variables' $TEMP_DIR/tmp.$$ | cut -f1 -d:`
   End_Line=`grep -n 'End of Main Variables' $TEMP_DIR/tmp.$$ | cut -f1 -d:`
#  Handle it when the user cancels out of a previous run of setup.  If
#  Start_Line is null, it means they never got to this section at all.  If
#  End_Line is null, then they cancelled in this section.
   if [ -z "$Start_Line" ]; then
      Variables_Found=N
   elif [ -z "$End_Line" ]; then
      Tail_Lines=200
   else
      Tail_Lines=`expr $End_Line - $Start_Line`
   fi
fi

if [ "$Variables_Found" = "Y" ]; then
   tail +$Start_Line $TEMP_DIR/tmp.$$ | head -$Tail_Lines | grep -v '^##' > $TEMP_DIR/tmp.main.$$


# This section of the else should only run when no setup.txt file is present
# Once one is there it is used to pull up the users current settings
else
   SETUP_TXT_Found=N

$ECHO "  PRD=RDA
   OUT_DIR="`pwd`/RDA_Output"
   OUT_TMP=/tmp
   ORACLE_HOME=$ORACLE_SET
   DOMAIN_NAME=$Domain_Name" > $TEMP_DIR/tmp.main.$$

fi

}

Debug ()
{
  if [ "$DebugMode" = "y" ]; then
     $ECHO "------------------Debug RUN: `date`" >> $TEMP_DIR/Debug.log.$$
     $ECHO ") $DebugMessage"  | tee -a ./Setup_Debug.txt.$$
  fi
}

Append_Setup ()
{
if [ "$NO_PROMPT" = "N" ]; then
   $ECHO "$Prompt "
   $ECHO "Hit Return to Accept Default: ${BOLD}$ValueVar${OFF}"
   $ECHO "============================> \c"
   read Input
   ValueVar=${Input:=$ValueVar}
#  It's possible the input may contain a variable.  Use the eval command to
#  expand it out.
   ValueVar=`eval $ECHO $ValueVar`
   if [ "$ValueVar" = "n" ]; then
      ValueVar=N
   elif [ "$ValueVar" = "y" ]; then
      ValueVar=Y
   fi
fi
$ECHO $Description >> setup.txt
$ECHO "$NameVar=$ValueVar" >> setup.txt
$ECHO "##" >> setup.txt
NO_PROMPT=N
}

#  This function will handle prompting for variable values to hide them from
#  prying eyes.  I don't really care for the implementation, but it's the only
#  one I could find to work.  For whatever reason, tput invis isn't making the
#  data invisible, so this will have to do until we come up with a better way.
#  It probably doesn't make sense to do a "re-enter" to confirm since the value
#  is just being stored in the setup.txt file and can be modified manually.

Append_Setup_Hidden ()
{
if [ "$NO_PROMPT" = "N" ]; then
   $ECHO "$Prompt "
   $ECHO "The value entered can be verified by viewing setup.txt after"
   $ECHO "completing execution of this script and searching for $NameVar."
   $ECHO "============================> \c"
   stty -echo
   read Input
   stty echo
   $ECHO
   ValueVar=${Input:=$ValueVar}
#  It's possible the input may contain a variable.  Use the eval command to
#  expand it out.
   ValueVar=`eval $ECHO $ValueVar`
   if [ "$ValueVar" = "n" ]; then
      ValueVar=N
   elif [ "$ValueVar" = "y" ]; then
      ValueVar=Y
   fi
fi
$ECHO $Description >> setup.txt
$ECHO "$NameVar=$ValueVar" >> setup.txt
$ECHO "##" >> setup.txt
NO_PROMPT=N
}

Get_Input ()
{
## Procedure: Setup_Env ()
## Called to setup all the env variables ...
#############################################################################
## Variables Used to Process this script:
#############################################################################
$ECHO "${BOLD}Setup for the Oracle rda.sh Version $Setup_Program_Version parameters$OFF"

if [ "$SETUP_TXT_Found" = "Y" ];then

# Make a back up in case they want to work with the last copy manually.
#
   $ECHO "Backing up setup.txt to setup.txt.orig..."
   cp setup.txt setup.txt.orig
   chmod 600 setup.txt*
fi

$ECHO "#######################################################################
## File: setup.txt      Configuration File for: rda.sh
## Oracle Corp.,  World Wide Support
## Written by: Oracle Corp.        Generated: `date`
#######################################################################
##  Beginning of Main Variables
#######################################################################" > setup.txt
NO_PROMPT=N

#  It's possible the previous run of setup.sh was cancelled by the user before
#  completing.  If any variables aren't found, they need to be created in this
#  pass to make the setup complete.  These variables will assist in keeping
#  track of which ones are found or not.
PRD_Found=N
OUT_DIR_Found=N
OUT_TMP_Found=N
ORACLE_HOME_Found=N
DOMAIN_NAME_Found=N

Args=`cat $TEMP_DIR/tmp.main.$$`
for CurArg in `$ECHO "$Args"`
do 
   Get_Arguments

   case "$NameVar" in

      PRD) 
         PRD_Found=Y
         $ECHO
         Description="##  This also makes it a bit easier to collect all the files for view/email.\n## ie. pr \$OUT_DIR/$PRD*   should be a full listing...\n##     PRD=RDA\n##"
         Prompt="Enter the Prefix for all the Files Generated"
         Append_Setup
         PRD_Echo=$ValueVar
      ;;
      OUT_DIR) 
         OUT_DIR_Found=Y
         $ECHO
         Description="##  OUT_DIR is the directory that the files will be generated to when script runs\n##            this defaults to tmp currently.\n##"
         Prompt="Enter the OUT_DIR used for all the Files Generated"
         Append_Setup
         Check_Directory
         OUT_DIR_Echo=$ValueVar
      ;;
      OUT_TMP)
         OUT_TMP_Found=Y
         $ECHO
         Description="##  OUT_TMP is used for any temp files that are required during processing.\n##"
         Prompt="Enter the OUT_TMP directory used for some temporary files"
         Append_Setup
         Check_Directory
      ;;
      ORACLE_HOME)
         ORACLE_HOME_Found=Y
         $ECHO
         Description="##  ORACLE_HOME to be Analyzed:\n##"
         Prompt="Enter the Oracle Home to be Analyzed"
         Append_Setup
      ;;
      DOMAIN_NAME)
         DOMAIN_NAME_Found=Y
         $ECHO
         Description="##  DOMAIN_NAME of this Server:\n##"
         Prompt="Enter the Domain Name of this server"
         Append_Setup
      ;;

      *)  
         junk=NoOpHere
      ;;
   esac

done

#  This is slight duplication of code, but I can't come up with a better way
#  of doing it, just yet.
if [ "$PRD_Found" = "N" ]; then
   NameVar=PRD
   ValueVar=RDA
   eval  `$ECHO "$NameVar=$ValueVar"`
   $ECHO
   Description="## This also makes it a bit easier to collect all the files for view/email.\n## ie. pr \$OUT_DIR/$PRD*   should be a full listing...\n##     PRD=RDA\n##"
   Prompt="Enter the Prefix for all the Files Generated"
   Append_Setup
   PRD_Echo=$ValueVar
fi
if [ "$OUT_DIR_Found" = "N" ]; then
   NameVar=OUT_DIR
   ValueVar="`pwd`/RDA_Output"
   eval  `$ECHO "$NameVar=$ValueVar"`
   $ECHO
   Description="## OUT_DIR is the directory that the files will be generated to when script runs\n##            this defaults to tmp currently.\n##"
   Prompt="Enter the OUT_DIR used for all the Files Generated"
   Append_Setup
   Check_Directory
   OUT_DIR_Echo=$ValueVar
fi
if [ "$OUT_TMP_Found" = "N" ]; then
   NameVar=OUT_TMP
   ValueVar=/tmp
   eval  `$ECHO "$NameVar=$ValueVar"`
   $ECHO
   Description="## OUT_TMP is used for any temp files that are required during processing.\n##"
   Prompt="Enter the OUT_TMP directory used for some temporary files"
   Append_Setup
   Check_Directory
fi
if [ "$ORACLE_HOME_Found" = "N" ]; then
   NameVar=ORACLE_HOME
   ValueVar=$ORACLE_SET
   eval  `$ECHO "$NameVar=$ValueVar"`
   $ECHO
   Description="## ORACLE_HOME to be Analyzed:\n##"
   Prompt="Enter the Oracle Home to be Analyzed"
   Append_Setup
fi
if [ "$DOMAIN_NAME_Found" = "N" ]; then
   NameVar=DOMAIN_NAME
   ValueVar=$Domain_Name
   eval  `$ECHO "$NameVar=$ValueVar"`
   $ECHO
   Description="##  DOMAIN_NAME of this Server:\n##"
   Prompt="Enter the Domain Name of this server"
   Append_Setup
fi

$ECHO "#######################################################################
##  End of Main Variables
#######################################################################" >> setup.txt
#  We've taken care of the variables for the main body of the process.  Now
#  we want to dynamically find any modules and their associated setup scripts
#  to allow them to set the variables they need.  The format for the sub-dirs
#  has to be RDA_script_nnnn_<name> and each sub-dir MUST contain a setup.sh
#  and rda.sh.  For all optional modules, the setup.sh at a minimum will need
#  to either determine on its own or prompt the user as to whether it should
#  run or not.  If it should be run, it needs to populate <some file name> so
#  that the main rda.sh script will know which modules to source.  Without the
#  setup.sh to populate <some file name>, the associated rda.sh module will not
#  be run.

## Get all the subdirectories to give us something to cycle through.  

RDA_Module_Dirs=`ls |grep RDA_script`

if [ -z "$RDA_Module_Dirs" ]; then
   $ECHO "$BOLD The RDA installation is corrupted or the files/directories"
   $ECHO "have been moved.  Please untar the installation file again and"
   $ECHO "rerun setup.sh.  If the error occurs again, please contact"
   $ECHO "Oracle Support Services.${OFF}"
else
#  For every subdirectory where there is a setup.sh, source it.  All function
#  execution should be handled in the module setup.sh
   if [ -r mods_to_run.txt ]; then
      rm -f mods_to_run.txt 2>/dev/null
   fi
   touch mods_to_run.txt
   for m in $RDA_Module_Dirs
   do
      if [ -r "./${m}/setup.sh" ]; then
         . ./${m}/setup.sh
      else
         $ECHO "readable setup.sh not found in $m"
         $ECHO "module located there will not be run"
      fi
   done
fi

#  Clean up temp file if not in debug mode
if [ "$DebugMode" = "n" ]; then
   rm -f $TEMP_DIR/tmp.$$ 2>/dev/null
   rm -f $TEMP_DIR/tmp.main.$$ 2>/dev/null
fi
}

Get_Arguments ()
{

NameVar=`$ECHO "$CurArg" | awk -F"=" '{print $1}'`       
ValueVar=`$ECHO "$CurArg" | awk -F"=" '{print $2}'`	
eval  `$ECHO "$NameVar=$ValueVar"`
DebugMessage="GetArguments: $NameVar=$ValueVar"
Debug                     

}

#  This function will allow automatic creation of a directory by setup.sh.
#  It won't cause the script to exit if the directory creation fails.  It will
#  let the user know they need to create the directory prior to running rda.sh.
Check_Directory ()
{
if [ -d "$ValueVar" ]; then
   true
else
   $ECHO
   $ECHO "Directory $ValueVar does not exist"
   $ECHO "Would you like to create it now (Y/N)?"
   read create
   if [ "$create" = "Y" -o "$create" = "y" ]; then
      mkdir $ValueVar 2>/dev/null
      if [ $? -ne 0 ]; then
         $ECHO
         $ECHO "Problem creating $ValueVar"
         $ECHO "Please resolve the issue and create the directory"
         $ECHO "prior to running rda.sh"
         $ECHO
      else
         $ECHO
         $ECHO "$ValueVar succesfully created"
         $ECHO
      fi
   else
      $ECHO
      $ECHO "You have selected to not have setup.sh create the missing directory"
      $ECHO "Please create the directory $ValueVar"
      $ECHO "prior to running rda.sh"
      $ECHO
   fi 
fi 
}

#############
##  Main   ##
#############

Setup_Env   # Setup Default Values, if not present, build setup.txt file.

Get_Input   # Get user input on the Values - allow changes, rewrite setup.txt

#  Determine if compress is installed.  If it's not here, we're gonna use gzip
#  instead.

#  Some platforms treat a "not found" as an error, some as a valid execution
#  of "which".  Need to make sure nothing displays back to the user so send
#  stderr to bit bucket.  Because of the inconsistency, we also can't just
#  check return code since some OS's will return a 0 for a "not found", others
#  will return a 1.

#  Which is not available on ptx, but compress is.  Code around it by
#  setting Compress_Test to a value that will satisfy the case stmt.
if [ "$Which_Available" = "N" ]; then
   Compress_Test="/usr/bin/compress"
else
   Compress_Test=`which compress 2>/dev/null`
fi

case "$Compress_Test" in
#  If it's found, the result should be something like:
#  /<dir>/<subdir>/compress
#  Since each platform treats this differently, this was the only common way
#  to determine existence.
   */compress)
      File_Ext=Z
   ;;
   *)
      File_Ext=gz
   ;;
esac

if [ "$Clear_Available" = "Y" ]; then
   clear
fi
$ECHO
$ECHO "At this time, you should be able to run the rda script"
$ECHO "##############################################################################"
$ECHO "1) Make sure rda.sh is executable: chmod +x rda.sh"
$ECHO "2) At this point, \$ORACLE_SID should be set and you"
$ECHO "   should be able to connect to sqlplus with the userid you entered"
$ECHO "3) Execute rda.sh using the following convention:  ./rda.sh"
$ECHO "   Using the dot ensures you execute rda.sh from the local directory"
$ECHO "4) The screen will indicate various iterations of files being collected."
$ECHO "   Once it has completed, you will be able to send the"
$ECHO "   resulting ${BOLD}$OUT_DIR_Echo/$PRD_Echo.<pid>.rda.tar.Z${OFF} file to Oracle."
$ECHO "   <pid> will be the process id from the execution of rda.sh that created"
$ECHO "   the file."
$ECHO "5) If this file was generated to assist in resolving a TAR, please send"
$ECHO "   ${BOLD}$OUT_DIR_Echo/$PRD_Echo.<pid>.rda.tar.${File_Ext}${OFF} to Oracle Support"
$ECHO "   using the 'upload to support' link in the Tar Update section of Metalink."
$ECHO "   <pid> will be the process id from the execution of rda.sh that created"
$ECHO "   the file."
$ECHO "##############################################################################"
